/* auto-target.h.  Generated from config.in by configure.  */
/* config.in.  Generated from configure.ac by autoheader.  */

/* Define to the .hidden-like directive if it exists. */
#define AS_HIDDEN_DIRECTIVE .hidden

/* Define to 1 if the assembler supports AVX. */
/* #undef HAVE_AS_AVX */

/* Define to 1 if the assembler supports .cfi_sections .debug_frame directive.
   */
#define HAVE_AS_CFI_SECTIONS 1

/* Define to 1 if the assembler supports LSE. */
#define HAVE_AS_LSE 1

/* Define to 1 if the target assembler supports thread-local storage. */
/* #undef HAVE_CC_TLS */

/* Define to 1 if you have the <ftw.h> header file. */
#define HAVE_FTW_H 1

/* Define if _Unwind_GetIPInfo is available. */
#define HAVE_GETIPINFO 1

/* Define if the compiler supports init priority. */
#define HAVE_INIT_PRIORITY 1

/* Define to 1 if you have the <inttypes.h> header file. */
#define HAVE_INTTYPES_H 1

/* Define to 1 if you have the <memory.h> header file. */
#define HAVE_MEMORY_H 1

/* Define if the system-provided CRTs are present on Solaris. */
/* #undef HAVE_SOLARIS_CRTS */

/* Define to 1 if you have the <stdint.h> header file. */
#define HAVE_STDINT_H 1

/* Define to 1 if you have the <stdlib.h> header file. */
#define HAVE_STDLIB_H 1

/* Define to 1 if you have the <strings.h> header file. */
#define HAVE_STRINGS_H 1

/* Define to 1 if you have the <string.h> header file. */
#define HAVE_STRING_H 1

/* Define to 1 if you have the <sys/auxv.h> header file. */
#define HAVE_SYS_AUXV_H 1

/* Define to 1 if you have the <sys/mman.h> header file. */
#define HAVE_SYS_MMAN_H 1

/* Define to 1 if you have the <sys/stat.h> header file. */
#define HAVE_SYS_STAT_H 1

/* Define to 1 if you have the <sys/types.h> header file. */
#define HAVE_SYS_TYPES_H 1

/* Define to 1 if you have the <unistd.h> header file. */
#define HAVE_UNISTD_H 1

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT ""

/* Define to the full name of this package. */
#define PACKAGE_NAME "GNU C Runtime Library"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "GNU C Runtime Library 1.0"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "libgcc"

/* Define to the home page for this package. */
#define PACKAGE_URL "http://www.gnu.org/software/libgcc/"

/* Define to the version of this package. */
#define PACKAGE_VERSION "1.0"

/* The size of `double', as computed by sizeof. */
#define SIZEOF_DOUBLE 8

/* The size of `long double', as computed by sizeof. */
#define SIZEOF_LONG_DOUBLE 16

/* Define to 1 if you have the ANSI C header files. */
/* #undef STDC_HEADERS */

/* Define to 1 if the target use emutls for thread-local storage. */
/* #undef USE_EMUTLS */

/* Enable large inode numbers on Mac OS X 10.5.  */
#ifndef _DARWIN_USE_64_BIT_INODE
# define _DARWIN_USE_64_BIT_INODE 1
#endif

/* Number of bits in a file offset, on hosts where this is settable. */
/* #undef _FILE_OFFSET_BITS */

/* Define for large files, on AIX-style hosts. */
/* #undef _LARGE_FILES */
