/* Type information for emit-rtl.cc.
   Copyright (C) 2004-2022 Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */

/* This file is machine generated.  Do not edit.  */

void
gt_ggc_mx_hash_table_const_int_hasher_ (void *x_p)
{
  hash_table<const_int_hasher> * const x = (hash_table<const_int_hasher> *)x_p;
  if (ggc_test_and_set_mark (x))
    {
      gt_ggc_mx (x);
    }
}

void
gt_ggc_mx (struct const_int_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_int_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_ggc_mx_hash_table_const_wide_int_hasher_ (void *x_p)
{
  hash_table<const_wide_int_hasher> * const x = (hash_table<const_wide_int_hasher> *)x_p;
  if (ggc_test_and_set_mark (x))
    {
      gt_ggc_mx (x);
    }
}

void
gt_ggc_mx (struct const_wide_int_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_wide_int_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_ggc_mx_hash_table_const_poly_int_hasher_ (void *x_p)
{
  hash_table<const_poly_int_hasher> * const x = (hash_table<const_poly_int_hasher> *)x_p;
  if (ggc_test_and_set_mark (x))
    {
      gt_ggc_mx (x);
    }
}

void
gt_ggc_mx (struct const_poly_int_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_poly_int_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_ggc_mx_hash_table_reg_attr_hasher_ (void *x_p)
{
  hash_table<reg_attr_hasher> * const x = (hash_table<reg_attr_hasher> *)x_p;
  if (ggc_test_and_set_mark (x))
    {
      gt_ggc_mx (x);
    }
}

void
gt_ggc_mx (struct reg_attr_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct reg_attr_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_ggc_mx_hash_table_const_double_hasher_ (void *x_p)
{
  hash_table<const_double_hasher> * const x = (hash_table<const_double_hasher> *)x_p;
  if (ggc_test_and_set_mark (x))
    {
      gt_ggc_mx (x);
    }
}

void
gt_ggc_mx (struct const_double_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_double_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_ggc_mx_hash_table_const_fixed_hasher_ (void *x_p)
{
  hash_table<const_fixed_hasher> * const x = (hash_table<const_fixed_hasher> *)x_p;
  if (ggc_test_and_set_mark (x))
    {
      gt_ggc_mx (x);
    }
}

void
gt_ggc_mx (struct const_fixed_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_fixed_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_pch_nx_hash_table_const_int_hasher_ (void *x_p)
{
  hash_table<const_int_hasher> * const x = (hash_table<const_int_hasher> *)x_p;
  if (gt_pch_note_object (x, x, gt_pch_p_28hash_table_const_int_hasher_))
    {
      gt_pch_nx (x);
    }
}

void
gt_pch_nx (struct const_int_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_int_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_pch_nx_hash_table_const_wide_int_hasher_ (void *x_p)
{
  hash_table<const_wide_int_hasher> * const x = (hash_table<const_wide_int_hasher> *)x_p;
  if (gt_pch_note_object (x, x, gt_pch_p_33hash_table_const_wide_int_hasher_))
    {
      gt_pch_nx (x);
    }
}

void
gt_pch_nx (struct const_wide_int_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_wide_int_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_pch_nx_hash_table_const_poly_int_hasher_ (void *x_p)
{
  hash_table<const_poly_int_hasher> * const x = (hash_table<const_poly_int_hasher> *)x_p;
  if (gt_pch_note_object (x, x, gt_pch_p_33hash_table_const_poly_int_hasher_))
    {
      gt_pch_nx (x);
    }
}

void
gt_pch_nx (struct const_poly_int_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_poly_int_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_pch_nx_hash_table_reg_attr_hasher_ (void *x_p)
{
  hash_table<reg_attr_hasher> * const x = (hash_table<reg_attr_hasher> *)x_p;
  if (gt_pch_note_object (x, x, gt_pch_p_27hash_table_reg_attr_hasher_))
    {
      gt_pch_nx (x);
    }
}

void
gt_pch_nx (struct reg_attr_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct reg_attr_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_pch_nx_hash_table_const_double_hasher_ (void *x_p)
{
  hash_table<const_double_hasher> * const x = (hash_table<const_double_hasher> *)x_p;
  if (gt_pch_note_object (x, x, gt_pch_p_31hash_table_const_double_hasher_))
    {
      gt_pch_nx (x);
    }
}

void
gt_pch_nx (struct const_double_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_double_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_pch_nx_hash_table_const_fixed_hasher_ (void *x_p)
{
  hash_table<const_fixed_hasher> * const x = (hash_table<const_fixed_hasher> *)x_p;
  if (gt_pch_note_object (x, x, gt_pch_p_30hash_table_const_fixed_hasher_))
    {
      gt_pch_nx (x);
    }
}

void
gt_pch_nx (struct const_fixed_hasher& x_r ATTRIBUTE_UNUSED)
{
  struct const_fixed_hasher * ATTRIBUTE_UNUSED x = &x_r;
}

void
gt_pch_p_28hash_table_const_int_hasher_ (ATTRIBUTE_UNUSED void *this_obj,
	void *x_p,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
  struct hash_table<const_int_hasher> * x ATTRIBUTE_UNUSED = (struct hash_table<const_int_hasher> *)x_p;
  if ((void *)(x) == this_obj)
    gt_pch_nx (&((*x)), op, cookie);
}

void
gt_pch_nx (struct const_int_hasher* x ATTRIBUTE_UNUSED,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
}

void
gt_pch_p_33hash_table_const_wide_int_hasher_ (ATTRIBUTE_UNUSED void *this_obj,
	void *x_p,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
  struct hash_table<const_wide_int_hasher> * x ATTRIBUTE_UNUSED = (struct hash_table<const_wide_int_hasher> *)x_p;
  if ((void *)(x) == this_obj)
    gt_pch_nx (&((*x)), op, cookie);
}

void
gt_pch_nx (struct const_wide_int_hasher* x ATTRIBUTE_UNUSED,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
}

void
gt_pch_p_33hash_table_const_poly_int_hasher_ (ATTRIBUTE_UNUSED void *this_obj,
	void *x_p,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
  struct hash_table<const_poly_int_hasher> * x ATTRIBUTE_UNUSED = (struct hash_table<const_poly_int_hasher> *)x_p;
  if ((void *)(x) == this_obj)
    gt_pch_nx (&((*x)), op, cookie);
}

void
gt_pch_nx (struct const_poly_int_hasher* x ATTRIBUTE_UNUSED,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
}

void
gt_pch_p_27hash_table_reg_attr_hasher_ (ATTRIBUTE_UNUSED void *this_obj,
	void *x_p,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
  struct hash_table<reg_attr_hasher> * x ATTRIBUTE_UNUSED = (struct hash_table<reg_attr_hasher> *)x_p;
  if ((void *)(x) == this_obj)
    gt_pch_nx (&((*x)), op, cookie);
}

void
gt_pch_nx (struct reg_attr_hasher* x ATTRIBUTE_UNUSED,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
}

void
gt_pch_p_31hash_table_const_double_hasher_ (ATTRIBUTE_UNUSED void *this_obj,
	void *x_p,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
  struct hash_table<const_double_hasher> * x ATTRIBUTE_UNUSED = (struct hash_table<const_double_hasher> *)x_p;
  if ((void *)(x) == this_obj)
    gt_pch_nx (&((*x)), op, cookie);
}

void
gt_pch_nx (struct const_double_hasher* x ATTRIBUTE_UNUSED,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
}

void
gt_pch_p_30hash_table_const_fixed_hasher_ (ATTRIBUTE_UNUSED void *this_obj,
	void *x_p,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
  struct hash_table<const_fixed_hasher> * x ATTRIBUTE_UNUSED = (struct hash_table<const_fixed_hasher> *)x_p;
  if ((void *)(x) == this_obj)
    gt_pch_nx (&((*x)), op, cookie);
}

void
gt_pch_nx (struct const_fixed_hasher* x ATTRIBUTE_UNUSED,
	ATTRIBUTE_UNUSED gt_pointer_operator op,
	ATTRIBUTE_UNUSED void *cookie)
{
}

/* GC roots.  */

EXPORTED_CONST struct ggc_root_tab gt_ggc_r_gt_emit_rtl_h[] = {
  {
    &spill_slot_decl,
    1,
    sizeof (spill_slot_decl),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &const_fixed_htab,
    1,
    sizeof (const_fixed_htab),
    &gt_ggc_mx_hash_table_const_fixed_hasher_,
    &gt_pch_nx_hash_table_const_fixed_hasher_
  },
  {
    &const_double_htab,
    1,
    sizeof (const_double_htab),
    &gt_ggc_mx_hash_table_const_double_hasher_,
    &gt_pch_nx_hash_table_const_double_hasher_
  },
  {
    &reg_attrs_htab,
    1,
    sizeof (reg_attrs_htab),
    &gt_ggc_mx_hash_table_reg_attr_hasher_,
    &gt_pch_nx_hash_table_reg_attr_hasher_
  },
  {
    &const_poly_int_htab,
    1,
    sizeof (const_poly_int_htab),
    &gt_ggc_mx_hash_table_const_poly_int_hasher_,
    &gt_pch_nx_hash_table_const_poly_int_hasher_
  },
  {
    &const_wide_int_htab,
    1,
    sizeof (const_wide_int_htab),
    &gt_ggc_mx_hash_table_const_wide_int_hasher_,
    &gt_pch_nx_hash_table_const_wide_int_hasher_
  },
  {
    &const_int_htab,
    1,
    sizeof (const_int_htab),
    &gt_ggc_mx_hash_table_const_int_hasher_,
    &gt_pch_nx_hash_table_const_int_hasher_
  },
  LAST_GGC_ROOT_TAB
};

EXPORTED_CONST struct ggc_root_tab gt_ggc_rd_gt_emit_rtl_h[] = {
  { &hard_reg_clobbers, 1, sizeof (hard_reg_clobbers), NULL, NULL },
  { &free_sequence_stack, 1, sizeof (free_sequence_stack), NULL, NULL },
  LAST_GGC_ROOT_TAB
};

void
gt_clear_caches_gt_emit_rtl_h ()
{
  gt_cleare_cache (const_fixed_htab);
  gt_cleare_cache (const_double_htab);
  gt_cleare_cache (reg_attrs_htab);
  gt_cleare_cache (const_poly_int_htab);
  gt_cleare_cache (const_wide_int_htab);
  gt_cleare_cache (const_int_htab);
}

EXPORTED_CONST struct ggc_root_tab gt_pch_rs_gt_emit_rtl_h[] = {
  { &label_num, 1, sizeof (label_num), NULL, NULL },
  LAST_GGC_ROOT_TAB
};

