#ifndef TARGET_D_CPU_VERSIONS
#define TARGET_D_CPU_VERSIONS hook_void_void
#endif
#ifndef TARGET_D_OS_VERSIONS
#define TARGET_D_OS_VERSIONS hook_void_void
#endif
#ifndef TARGET_D_REGISTER_CPU_TARGET_INFO
#define TARGET_D_REGISTER_CPU_TARGET_INFO hook_void_void
#endif
#ifndef TARGET_D_REGISTER_OS_TARGET_INFO
#define TARGET_D_REGISTER_OS_TARGET_INFO hook_void_void
#endif
#ifndef TARGET_D_MINFO_SECTION
#define TARGET_D_MINFO_SECTION NULL
#endif
#ifndef TARGET_D_MINFO_START_NAME
#define TARGET_D_MINFO_START_NAME NULL
#endif
#ifndef TARGET_D_MINFO_END_NAME
#define TARGET_D_MINFO_END_NAME NULL
#endif
#ifndef TARGET_D_HAS_STDCALL_CONVENTION
#define TARGET_D_HAS_STDCALL_CONVENTION hook_bool_uintp_uintp_false
#endif
#ifndef TARGET_D_TEMPLATES_ALWAYS_COMDAT
#define TARGET_D_TEMPLATES_ALWAYS_COMDAT false
#endif

#define TARGETDM_INITIALIZER \
  { \
    TARGET_D_CPU_VERSIONS, \
    TARGET_D_OS_VERSIONS, \
    TARGET_D_REGISTER_CPU_TARGET_INFO, \
    TARGET_D_REGISTER_OS_TARGET_INFO, \
    TARGET_D_MINFO_SECTION, \
    TARGET_D_MINFO_START_NAME, \
    TARGET_D_MINFO_END_NAME, \
    TARGET_D_HAS_STDCALL_CONVENTION, \
    TARGET_D_TEMPLATES_ALWAYS_COMDAT, \
  }
