/* Type information for tree-profile.cc.
   Copyright (C) 2004-2022 Free Software Foundation, Inc.

This file is part of GCC.

GCC is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3, or (at your option) any later
version.

GCC is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3.  If not see
<http://www.gnu.org/licenses/>.  */

/* This file is machine generated.  Do not edit.  */

/* GC roots.  */

EXPORTED_CONST struct ggc_root_tab gt_ggc_r_gt_tree_profile_h[] = {
  {
    &ic_tuple_callee_field,
    1,
    sizeof (ic_tuple_callee_field),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &ic_tuple_counters_field,
    1,
    sizeof (ic_tuple_counters_field),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &ic_tuple_var,
    1,
    sizeof (ic_tuple_var),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &tree_time_profiler_counter,
    1,
    sizeof (tree_time_profiler_counter),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &tree_ior_profiler_fn,
    1,
    sizeof (tree_ior_profiler_fn),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &tree_average_profiler_fn,
    1,
    sizeof (tree_average_profiler_fn),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &tree_indirect_call_profiler_fn,
    1,
    sizeof (tree_indirect_call_profiler_fn),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &tree_topn_values_profiler_fn,
    1,
    sizeof (tree_topn_values_profiler_fn),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &tree_pow2_profiler_fn,
    1,
    sizeof (tree_pow2_profiler_fn),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &tree_interval_profiler_fn,
    1,
    sizeof (tree_interval_profiler_fn),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  {
    &gcov_type_node,
    1,
    sizeof (gcov_type_node),
    &gt_ggc_mx_tree_node,
    &gt_pch_nx_tree_node
  },
  LAST_GGC_ROOT_TAB
};

