/* config.h.  Generated from config.h.in by configure.  */
/* config.h.in.  Generated from configure.ac by autoheader.  */

/* Define to 1 if you want more run-time sanity checks. */
#define NMS_CHECKING 0

/* Define to the address where bug reports for this package should be sent. */
#define PACKAGE_BUGREPORT "github.com/urnathan/libcody"

/* Define to the full name of this package. */
#define PACKAGE_NAME "codylib"

/* Define to the full name and version of this package. */
#define PACKAGE_STRING "codylib 0.0"

/* Define to the one symbol short name of this package. */
#define PACKAGE_TARNAME "codylib"

/* Define to the home page for this package. */
#define PACKAGE_URL ""

/* Define to the version of this package. */
#define PACKAGE_VERSION "0.0"

/* #undef _FORTIFY_SOURCE */

#define _GNU_SOURCE 1
