#ifndef GCC_TM_D_H
#define GCC_TM_D_H
#ifdef IN_GCC
# include "options.h"
# include "insn-constants.h"
# include "config/aarch64/aarch64.h"
# include "config/aarch64/aarch64-protos.h"
#endif
# include "./defaults.h"
#endif /* GCC_TM_D_H */
