/* Generated automatically by the program `genenums'
   from the machine description file.  */

#include "config.h"

#include "system.h"

#include "insn-constants.h"


const char *const arches_strings[] = {
  "ARCHES_ANY",
  "ARCHES_RCPC8_4",
  "ARCHES_FP",
  "ARCHES_SIMD",
  "ARCHES_SVE",
  "ARCHES_FP16"
};

const char *const unspec_strings[] = {
  "UNSPEC_AUTIA1716",
  "UNSPEC_AUTIB1716",
  "UNSPEC_AUTIASP",
  "UNSPEC_AUTIBSP",
  "UNSPEC_CALLEE_ABI",
  "UNSPEC_CASESI",
  "UNSPEC_CPYMEM",
  "UNSPEC_CRC32B",
  "UNSPEC_CRC32CB",
  "UNSPEC_CRC32CH",
  "UNSPEC_CRC32CW",
  "UNSPEC_CRC32CX",
  "UNSPEC_CRC32H",
  "UNSPEC_CRC32W",
  "UNSPEC_CRC32X",
  "UNSPEC_FCVTZS",
  "UNSPEC_FCVTZU",
  "UNSPEC_FJCVTZS",
  "UNSPEC_FRINT32Z",
  "UNSPEC_FRINT32X",
  "UNSPEC_FRINT64Z",
  "UNSPEC_FRINT64X",
  "UNSPEC_URECPE",
  "UNSPEC_FRECPE",
  "UNSPEC_FRECPS",
  "UNSPEC_FRECPX",
  "UNSPEC_FRINTA",
  "UNSPEC_FRINTI",
  "UNSPEC_FRINTM",
  "UNSPEC_FRINTN",
  "UNSPEC_FRINTP",
  "UNSPEC_FRINTX",
  "UNSPEC_FRINTZ",
  "UNSPEC_GOTSMALLPIC",
  "UNSPEC_GOTSMALLPIC28K",
  "UNSPEC_GOTSMALLTLS",
  "UNSPEC_GOTTINYPIC",
  "UNSPEC_GOTTINYTLS",
  "UNSPEC_LD1",
  "UNSPEC_LD2",
  "UNSPEC_LD2_DREG",
  "UNSPEC_LD2_DUP",
  "UNSPEC_LD3",
  "UNSPEC_LD3_DREG",
  "UNSPEC_LD3_DUP",
  "UNSPEC_LD4",
  "UNSPEC_LD4_DREG",
  "UNSPEC_LD4_DUP",
  "UNSPEC_LD2_LANE",
  "UNSPEC_LD3_LANE",
  "UNSPEC_LD4_LANE",
  "UNSPEC_LD64B",
  "UNSPEC_ST64B",
  "UNSPEC_ST64BV",
  "UNSPEC_ST64BV_RET",
  "UNSPEC_ST64BV0",
  "UNSPEC_ST64BV0_RET",
  "UNSPEC_MB",
  "UNSPEC_MOVMEM",
  "UNSPEC_NOP",
  "UNSPEC_PACIA1716",
  "UNSPEC_PACIB1716",
  "UNSPEC_PACIASP",
  "UNSPEC_PACIBSP",
  "UNSPEC_PRLG_STK",
  "UNSPEC_REV",
  "UNSPEC_RBIT",
  "UNSPEC_SABAL",
  "UNSPEC_SABAL2",
  "UNSPEC_SABDL",
  "UNSPEC_SABDL2",
  "UNSPEC_SADALP",
  "UNSPEC_SCVTF",
  "UNSPEC_SETMEM",
  "UNSPEC_SISD_NEG",
  "UNSPEC_SISD_SSHL",
  "UNSPEC_SISD_USHL",
  "UNSPEC_SSHL_2S",
  "UNSPEC_ST1",
  "UNSPEC_ST2",
  "UNSPEC_ST3",
  "UNSPEC_ST4",
  "UNSPEC_ST2_LANE",
  "UNSPEC_ST3_LANE",
  "UNSPEC_ST4_LANE",
  "UNSPEC_TLS",
  "UNSPEC_TLSDESC",
  "UNSPEC_TLSLE12",
  "UNSPEC_TLSLE24",
  "UNSPEC_TLSLE32",
  "UNSPEC_TLSLE48",
  "UNSPEC_UABAL",
  "UNSPEC_UABAL2",
  "UNSPEC_UABDL",
  "UNSPEC_UABDL2",
  "UNSPEC_UADALP",
  "UNSPEC_UCVTF",
  "UNSPEC_USHL_2S",
  "UNSPEC_VSTRUCTDUMMY",
  "UNSPEC_SSP_SYSREG",
  "UNSPEC_SP_SET",
  "UNSPEC_SP_TEST",
  "UNSPEC_RSHRN",
  "UNSPEC_RSQRT",
  "UNSPEC_RSQRTE",
  "UNSPEC_RSQRTS",
  "UNSPEC_NZCV",
  "UNSPEC_XPACLRI",
  "UNSPEC_LD1_SVE",
  "UNSPEC_ST1_SVE",
  "UNSPEC_LDNT1_SVE",
  "UNSPEC_STNT1_SVE",
  "UNSPEC_LD1RQ",
  "UNSPEC_LD1_GATHER",
  "UNSPEC_LDFF1_GATHER",
  "UNSPEC_LDNT1_GATHER",
  "UNSPEC_ST1_SCATTER",
  "UNSPEC_STNT1_SCATTER",
  "UNSPEC_PRED_X",
  "UNSPEC_PRED_Z",
  "UNSPEC_PTEST",
  "UNSPEC_PTRUE",
  "UNSPEC_UNPACKSHI",
  "UNSPEC_UNPACKUHI",
  "UNSPEC_UNPACKSLO",
  "UNSPEC_UNPACKULO",
  "UNSPEC_PACK",
  "UNSPEC_WHILEGE",
  "UNSPEC_WHILEGT",
  "UNSPEC_WHILEHI",
  "UNSPEC_WHILEHS",
  "UNSPEC_WHILELE",
  "UNSPEC_WHILELO",
  "UNSPEC_WHILELS",
  "UNSPEC_WHILELT",
  "UNSPEC_WHILERW",
  "UNSPEC_WHILEWR",
  "UNSPEC_LDN",
  "UNSPEC_STN",
  "UNSPEC_INSR",
  "UNSPEC_CLASTA",
  "UNSPEC_CLASTB",
  "UNSPEC_FADDA",
  "UNSPEC_REV_SUBREG",
  "UNSPEC_REINTERPRET",
  "UNSPEC_SPECULATION_TRACKER",
  "UNSPEC_SPECULATION_TRACKER_REV",
  "UNSPEC_COPYSIGN",
  "UNSPEC_TTEST",
  "UNSPEC_UPDATE_FFR",
  "UNSPEC_UPDATE_FFRT",
  "UNSPEC_RDFFR",
  "UNSPEC_WRFFR",
  "UNSPEC_SVE_LANE_SELECT",
  "UNSPEC_SVE_CNT_PAT",
  "UNSPEC_SVE_PREFETCH",
  "UNSPEC_SVE_PREFETCH_GATHER",
  "UNSPEC_SVE_COMPACT",
  "UNSPEC_SVE_SPLICE",
  "UNSPEC_GEN_TAG",
  "UNSPEC_GEN_TAG_RND",
  "UNSPEC_TAG_SPACE",
  "UNSPEC_LD1RO",
  "UNSPEC_SALT_ADDR",
  "UNSPEC_ASHIFT_SIGNED",
  "UNSPEC_ASHIFT_UNSIGNED",
  "UNSPEC_ABS",
  "UNSPEC_FMAX",
  "UNSPEC_FMAXNMV",
  "UNSPEC_FMAXV",
  "UNSPEC_FMIN",
  "UNSPEC_FMINNMV",
  "UNSPEC_FMINV",
  "UNSPEC_FADDV",
  "UNSPEC_ADDV",
  "UNSPEC_SADDLV",
  "UNSPEC_UADDLV",
  "UNSPEC_SMAXV",
  "UNSPEC_SMINV",
  "UNSPEC_UMAXV",
  "UNSPEC_UMINV",
  "UNSPEC_SHADD",
  "UNSPEC_UHADD",
  "UNSPEC_SRHADD",
  "UNSPEC_URHADD",
  "UNSPEC_SHSUB",
  "UNSPEC_UHSUB",
  "UNSPEC_ADDHN",
  "UNSPEC_RADDHN",
  "UNSPEC_SUBHN",
  "UNSPEC_RSUBHN",
  "UNSPEC_SQDMULH",
  "UNSPEC_SQRDMULH",
  "UNSPEC_PMUL",
  "UNSPEC_FMULX",
  "UNSPEC_USQADD",
  "UNSPEC_SUQADD",
  "UNSPEC_SQXTUN",
  "UNSPEC_SSRA",
  "UNSPEC_USRA",
  "UNSPEC_SRSRA",
  "UNSPEC_URSRA",
  "UNSPEC_SRSHR",
  "UNSPEC_URSHR",
  "UNSPEC_SQSHLU",
  "UNSPEC_SQSHL",
  "UNSPEC_UQSHL",
  "UNSPEC_SQSHRUN",
  "UNSPEC_SQRSHRUN",
  "UNSPEC_SQSHRN",
  "UNSPEC_UQSHRN",
  "UNSPEC_SQRSHRN",
  "UNSPEC_UQRSHRN",
  "UNSPEC_SSHL",
  "UNSPEC_USHL",
  "UNSPEC_SRSHL",
  "UNSPEC_URSHL",
  "UNSPEC_SQRSHL",
  "UNSPEC_UQRSHL",
  "UNSPEC_SSLI",
  "UNSPEC_USLI",
  "UNSPEC_SSRI",
  "UNSPEC_USRI",
  "UNSPEC_SSHLL",
  "UNSPEC_USHLL",
  "UNSPEC_ADDP",
  "UNSPEC_SADDLP",
  "UNSPEC_UADDLP",
  "UNSPEC_TBL",
  "UNSPEC_TBX",
  "UNSPEC_CONCAT",
  "UNSPEC_ZIP1",
  "UNSPEC_ZIP2",
  "UNSPEC_UZP1",
  "UNSPEC_UZP2",
  "UNSPEC_TRN1",
  "UNSPEC_TRN2",
  "UNSPEC_EXT",
  "UNSPEC_REV64",
  "UNSPEC_REV32",
  "UNSPEC_REV16",
  "UNSPEC_AESE",
  "UNSPEC_AESD",
  "UNSPEC_AESMC",
  "UNSPEC_AESIMC",
  "UNSPEC_SHA1C",
  "UNSPEC_SHA1M",
  "UNSPEC_SHA1P",
  "UNSPEC_SHA1H",
  "UNSPEC_SHA1SU0",
  "UNSPEC_SHA1SU1",
  "UNSPEC_SHA256H",
  "UNSPEC_SHA256H2",
  "UNSPEC_SHA256SU0",
  "UNSPEC_SHA256SU1",
  "UNSPEC_PMULL",
  "UNSPEC_PMULL2",
  "UNSPEC_REV_REGLIST",
  "UNSPEC_VEC_SHR",
  "UNSPEC_SQRDMLAH",
  "UNSPEC_SQRDMLSH",
  "UNSPEC_FMAXNM",
  "UNSPEC_FMINNM",
  "UNSPEC_SDOT",
  "UNSPEC_UDOT",
  "UNSPEC_SM3SS1",
  "UNSPEC_SM3TT1A",
  "UNSPEC_SM3TT1B",
  "UNSPEC_SM3TT2A",
  "UNSPEC_SM3TT2B",
  "UNSPEC_SM3PARTW1",
  "UNSPEC_SM3PARTW2",
  "UNSPEC_SM4E",
  "UNSPEC_SM4EKEY",
  "UNSPEC_SHA512H",
  "UNSPEC_SHA512H2",
  "UNSPEC_SHA512SU0",
  "UNSPEC_SHA512SU1",
  "UNSPEC_FMLAL",
  "UNSPEC_FMLSL",
  "UNSPEC_FMLAL2",
  "UNSPEC_FMLSL2",
  "UNSPEC_ADR",
  "UNSPEC_SEL",
  "UNSPEC_BRKA",
  "UNSPEC_BRKB",
  "UNSPEC_BRKN",
  "UNSPEC_BRKPA",
  "UNSPEC_BRKPB",
  "UNSPEC_PFIRST",
  "UNSPEC_PNEXT",
  "UNSPEC_CNTP",
  "UNSPEC_SADDV",
  "UNSPEC_UADDV",
  "UNSPEC_ANDV",
  "UNSPEC_IORV",
  "UNSPEC_XORV",
  "UNSPEC_ANDF",
  "UNSPEC_IORF",
  "UNSPEC_XORF",
  "UNSPEC_REVB",
  "UNSPEC_REVH",
  "UNSPEC_REVW",
  "UNSPEC_REVBHW",
  "UNSPEC_SMUL_HIGHPART",
  "UNSPEC_UMUL_HIGHPART",
  "UNSPEC_FMLA",
  "UNSPEC_FMLS",
  "UNSPEC_FEXPA",
  "UNSPEC_FMMLA",
  "UNSPEC_FTMAD",
  "UNSPEC_FTSMUL",
  "UNSPEC_FTSSEL",
  "UNSPEC_SMATMUL",
  "UNSPEC_UMATMUL",
  "UNSPEC_USMATMUL",
  "UNSPEC_TRN1Q",
  "UNSPEC_TRN2Q",
  "UNSPEC_UZP1Q",
  "UNSPEC_UZP2Q",
  "UNSPEC_ZIP1Q",
  "UNSPEC_ZIP2Q",
  "UNSPEC_TRN1_CONV",
  "UNSPEC_COND_CMPEQ_WIDE",
  "UNSPEC_COND_CMPGE_WIDE",
  "UNSPEC_COND_CMPGT_WIDE",
  "UNSPEC_COND_CMPHI_WIDE",
  "UNSPEC_COND_CMPHS_WIDE",
  "UNSPEC_COND_CMPLE_WIDE",
  "UNSPEC_COND_CMPLO_WIDE",
  "UNSPEC_COND_CMPLS_WIDE",
  "UNSPEC_COND_CMPLT_WIDE",
  "UNSPEC_COND_CMPNE_WIDE",
  "UNSPEC_COND_FABS",
  "UNSPEC_COND_FADD",
  "UNSPEC_COND_FCADD90",
  "UNSPEC_COND_FCADD270",
  "UNSPEC_COND_FCMEQ",
  "UNSPEC_COND_FCMGE",
  "UNSPEC_COND_FCMGT",
  "UNSPEC_COND_FCMLA",
  "UNSPEC_COND_FCMLA90",
  "UNSPEC_COND_FCMLA180",
  "UNSPEC_COND_FCMLA270",
  "UNSPEC_COND_FCMLE",
  "UNSPEC_COND_FCMLT",
  "UNSPEC_COND_FCMNE",
  "UNSPEC_COND_FCMUO",
  "UNSPEC_COND_FCVT",
  "UNSPEC_COND_FCVTZS",
  "UNSPEC_COND_FCVTZU",
  "UNSPEC_COND_FDIV",
  "UNSPEC_COND_FMAX",
  "UNSPEC_COND_FMAXNM",
  "UNSPEC_COND_FMIN",
  "UNSPEC_COND_FMINNM",
  "UNSPEC_COND_FMLA",
  "UNSPEC_COND_FMLS",
  "UNSPEC_COND_FMUL",
  "UNSPEC_COND_FMULX",
  "UNSPEC_COND_FNEG",
  "UNSPEC_COND_FNMLA",
  "UNSPEC_COND_FNMLS",
  "UNSPEC_COND_FRECPX",
  "UNSPEC_COND_FRINTA",
  "UNSPEC_COND_FRINTI",
  "UNSPEC_COND_FRINTM",
  "UNSPEC_COND_FRINTN",
  "UNSPEC_COND_FRINTP",
  "UNSPEC_COND_FRINTX",
  "UNSPEC_COND_FRINTZ",
  "UNSPEC_COND_FSCALE",
  "UNSPEC_COND_FSQRT",
  "UNSPEC_COND_FSUB",
  "UNSPEC_COND_SCVTF",
  "UNSPEC_COND_UCVTF",
  "UNSPEC_LASTA",
  "UNSPEC_LASTB",
  "UNSPEC_ASHIFT_WIDE",
  "UNSPEC_ASHIFTRT_WIDE",
  "UNSPEC_LSHIFTRT_WIDE",
  "UNSPEC_LDFF1",
  "UNSPEC_LDNF1",
  "UNSPEC_FCADD90",
  "UNSPEC_FCADD270",
  "UNSPEC_FCMLA",
  "UNSPEC_FCMLA90",
  "UNSPEC_FCMLA180",
  "UNSPEC_FCMLA270",
  "UNSPEC_FCMUL",
  "UNSPEC_FCMUL_CONJ",
  "UNSPEC_FCMLA_CONJ",
  "UNSPEC_FCMLA180_CONJ",
  "UNSPEC_ASRD",
  "UNSPEC_ADCLB",
  "UNSPEC_ADCLT",
  "UNSPEC_ADDHNB",
  "UNSPEC_ADDHNT",
  "UNSPEC_BDEP",
  "UNSPEC_BEXT",
  "UNSPEC_BGRP",
  "UNSPEC_CADD270",
  "UNSPEC_CADD90",
  "UNSPEC_CDOT",
  "UNSPEC_CDOT180",
  "UNSPEC_CDOT270",
  "UNSPEC_CDOT90",
  "UNSPEC_CMLA",
  "UNSPEC_CMLA180",
  "UNSPEC_CMLA270",
  "UNSPEC_CMLA90",
  "UNSPEC_CMLA_CONJ",
  "UNSPEC_CMLA180_CONJ",
  "UNSPEC_CMUL",
  "UNSPEC_CMUL_CONJ",
  "UNSPEC_COND_FCVTLT",
  "UNSPEC_COND_FCVTNT",
  "UNSPEC_COND_FCVTX",
  "UNSPEC_COND_FCVTXNT",
  "UNSPEC_COND_FLOGB",
  "UNSPEC_EORBT",
  "UNSPEC_EORTB",
  "UNSPEC_FADDP",
  "UNSPEC_FMAXNMP",
  "UNSPEC_FMAXP",
  "UNSPEC_FMINNMP",
  "UNSPEC_FMINP",
  "UNSPEC_FMLALB",
  "UNSPEC_FMLALT",
  "UNSPEC_FMLSLB",
  "UNSPEC_FMLSLT",
  "UNSPEC_HISTCNT",
  "UNSPEC_HISTSEG",
  "UNSPEC_MATCH",
  "UNSPEC_NMATCH",
  "UNSPEC_PMULLB",
  "UNSPEC_PMULLB_PAIR",
  "UNSPEC_PMULLT",
  "UNSPEC_PMULLT_PAIR",
  "UNSPEC_RADDHNB",
  "UNSPEC_RADDHNT",
  "UNSPEC_RSHRNB",
  "UNSPEC_RSHRNT",
  "UNSPEC_RSUBHNB",
  "UNSPEC_RSUBHNT",
  "UNSPEC_SABDLB",
  "UNSPEC_SABDLT",
  "UNSPEC_SADDLB",
  "UNSPEC_SADDLBT",
  "UNSPEC_SADDLT",
  "UNSPEC_SADDWB",
  "UNSPEC_SADDWT",
  "UNSPEC_SBCLB",
  "UNSPEC_SBCLT",
  "UNSPEC_SHRNB",
  "UNSPEC_SHRNT",
  "UNSPEC_SLI",
  "UNSPEC_SMAXP",
  "UNSPEC_SMINP",
  "UNSPEC_SMULHRS",
  "UNSPEC_SMULHS",
  "UNSPEC_SMULLB",
  "UNSPEC_SMULLT",
  "UNSPEC_SQCADD270",
  "UNSPEC_SQCADD90",
  "UNSPEC_SQDMULLB",
  "UNSPEC_SQDMULLBT",
  "UNSPEC_SQDMULLT",
  "UNSPEC_SQRDCMLAH",
  "UNSPEC_SQRDCMLAH180",
  "UNSPEC_SQRDCMLAH270",
  "UNSPEC_SQRDCMLAH90",
  "UNSPEC_SQRSHRNB",
  "UNSPEC_SQRSHRNT",
  "UNSPEC_SQRSHRUNB",
  "UNSPEC_SQRSHRUNT",
  "UNSPEC_SQSHRNB",
  "UNSPEC_SQSHRNT",
  "UNSPEC_SQSHRUNB",
  "UNSPEC_SQSHRUNT",
  "UNSPEC_SQXTNB",
  "UNSPEC_SQXTNT",
  "UNSPEC_SQXTUNB",
  "UNSPEC_SQXTUNT",
  "UNSPEC_SRI",
  "UNSPEC_SSHLLB",
  "UNSPEC_SSHLLT",
  "UNSPEC_SSUBLB",
  "UNSPEC_SSUBLBT",
  "UNSPEC_SSUBLT",
  "UNSPEC_SSUBLTB",
  "UNSPEC_SSUBWB",
  "UNSPEC_SSUBWT",
  "UNSPEC_SUBHNB",
  "UNSPEC_SUBHNT",
  "UNSPEC_TBL2",
  "UNSPEC_UABDLB",
  "UNSPEC_UABDLT",
  "UNSPEC_UADDLB",
  "UNSPEC_UADDLT",
  "UNSPEC_UADDWB",
  "UNSPEC_UADDWT",
  "UNSPEC_UMAXP",
  "UNSPEC_UMINP",
  "UNSPEC_UMULHRS",
  "UNSPEC_UMULHS",
  "UNSPEC_UMULLB",
  "UNSPEC_UMULLT",
  "UNSPEC_UQRSHRNB",
  "UNSPEC_UQRSHRNT",
  "UNSPEC_UQSHRNB",
  "UNSPEC_UQSHRNT",
  "UNSPEC_UQXTNB",
  "UNSPEC_UQXTNT",
  "UNSPEC_USHLLB",
  "UNSPEC_USHLLT",
  "UNSPEC_USUBLB",
  "UNSPEC_USUBLT",
  "UNSPEC_USUBWB",
  "UNSPEC_USUBWT",
  "UNSPEC_USDOT",
  "UNSPEC_SUDOT",
  "UNSPEC_BFDOT",
  "UNSPEC_BFMLALB",
  "UNSPEC_BFMLALT",
  "UNSPEC_BFMMLA",
  "UNSPEC_BFCVTN",
  "UNSPEC_BFCVTN2",
  "UNSPEC_BFCVT",
  "UNSPEC_FCVTXN"
};

const char *const unspecv_strings[] = {
  "UNSPECV_EH_RETURN",
  "UNSPECV_GET_FPCR",
  "UNSPECV_SET_FPCR",
  "UNSPECV_GET_FPSR",
  "UNSPECV_SET_FPSR",
  "UNSPECV_BLOCKAGE",
  "UNSPECV_PROBE_STACK_RANGE",
  "UNSPECV_SPECULATION_BARRIER",
  "UNSPECV_BTI_NOARG",
  "UNSPECV_BTI_C",
  "UNSPECV_BTI_J",
  "UNSPECV_BTI_JC",
  "UNSPECV_TSTART",
  "UNSPECV_TCOMMIT",
  "UNSPECV_TCANCEL",
  "UNSPEC_RNDR",
  "UNSPEC_RNDRRS",
  "UNSPECV_LX",
  "UNSPECV_SX",
  "UNSPECV_LDA",
  "UNSPECV_STL",
  "UNSPECV_ATOMIC_CMPSW",
  "UNSPECV_ATOMIC_EXCHG",
  "UNSPECV_ATOMIC_CAS",
  "UNSPECV_ATOMIC_SWP",
  "UNSPECV_ATOMIC_OP",
  "UNSPECV_ATOMIC_LDOP_OR",
  "UNSPECV_ATOMIC_LDOP_BIC",
  "UNSPECV_ATOMIC_LDOP_XOR",
  "UNSPECV_ATOMIC_LDOP_PLUS"
};
