/* Generated automatically by the program `genoutput'
   from the machine description file `md'.  */

#define IN_TARGET_CODE 1
#include "config.h"
#include "system.h"
#include "coretypes.h"
#include "backend.h"
#include "predict.h"
#include "tree.h"
#include "rtl.h"
#include "flags.h"
#include "alias.h"
#include "varasm.h"
#include "stor-layout.h"
#include "calls.h"
#include "insn-config.h"
#include "expmed.h"
#include "dojump.h"
#include "explow.h"
#include "memmodel.h"
#include "emit-rtl.h"
#include "stmt.h"
#include "expr.h"
#include "insn-codes.h"
#include "tm_p.h"
#include "regs.h"
#include "conditions.h"
#include "insn-attr.h"

#include "recog.h"

#include "diagnostic-core.h"
#include "output.h"
#include "target.h"
#include "tm-constrs.h"

static const char *
output_1 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 487 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    output_asm_insn ("br\t%0", operands);
    return aarch64_sls_barrier (aarch64_harden_sls_retbr_p ());
  }
}

static const char * const output_3[] = {
  "ccmp\t%w2, %w3, %k5, %m4",
  "ccmp\t%w2, %3, %k5, %m4",
  "ccmn\t%w2, #%n3, %k5, %m4",
};

static const char * const output_4[] = {
  "ccmp\t%x2, %x3, %k5, %m4",
  "ccmp\t%x2, %3, %k5, %m4",
  "ccmn\t%x2, #%n3, %k5, %m4",
};

static const char * const output_9[] = {
  "ccmp\t%w2, %w3, %k5, %M4",
  "ccmp\t%w2, %3, %k5, %M4",
  "ccmn\t%w2, #%n3, %k5, %M4",
};

static const char * const output_10[] = {
  "ccmp\t%x2, %x3, %k5, %M4",
  "ccmp\t%x2, %3, %k5, %M4",
  "ccmn\t%x2, #%n3, %k5, %M4",
};

static const char *
output_15 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 676 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    /* GCC's traditional style has been to use "beq" instead of "b.eq", etc.,
       but the "." is required for SVE conditions.  */
    bool use_dot_p = GET_MODE (operands[1]) == CC_NZCmode;
    if (get_attr_length (insn) == 8)
      return aarch64_gen_far_branch (operands, 2, "Lbcond",
				     use_dot_p ? "b.%M0\t" : "b%M0\t");
    else
      return use_dot_p ? "b.%m0\t%l2" : "b%m0\t%l2";
  }
}

static const char *
output_24 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 807 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"

  return aarch64_output_casesi (operands);
  
}

static const char *
output_26 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 826 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    const char * pftype[2][4] =
    {
      {"prfm\tPLDL1STRM, %0",
       "prfm\tPLDL3KEEP, %0",
       "prfm\tPLDL2KEEP, %0",
       "prfm\tPLDL1KEEP, %0"},
      {"prfm\tPSTL1STRM, %0",
       "prfm\tPSTL3KEEP, %0",
       "prfm\tPSTL2KEEP, %0",
       "prfm\tPSTL1KEEP, %0"},
    };

    int locality = INTVAL (operands[2]);

    gcc_assert (IN_RANGE (locality, 0, 3));

    /* PRFM accepts the same addresses as a 64-bit LDR so wrap
       the address into a DImode MEM so that aarch64_print_operand knows
       how to print it.  */
    operands[0] = gen_rtx_MEM (DImode, operands[0]);
    return pftype[INTVAL(operands[1])][locality];
  }
}

static const char *
output_28 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    const char *ret = NULL;
    if (aarch64_return_address_signing_enabled ()
	&& (TARGET_PAUTH))
      {
	if (aarch64_ra_sign_key == AARCH64_KEY_B)
	  ret = "retab";
	else
	  ret = "retaa";
      }
    else
      ret = "ret";
    output_asm_insn (ret, operands);
    return aarch64_sls_barrier (aarch64_harden_sls_retbr_p ());
  }
}

static const char *
output_29 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 916 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    output_asm_insn ("ret", operands);
    return aarch64_sls_barrier (aarch64_harden_sls_retbr_p ());
  }
}

static const char *
output_30 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 930 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      return aarch64_gen_far_branch (operands, 1, "Lcb", "cbnz\t%w0, ");
    else
      return "cbz\t%w0, %l1";
  }
}

static const char *
output_31 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 930 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      return aarch64_gen_far_branch (operands, 1, "Lcb", "cbz\t%w0, ");
    else
      return "cbnz\t%w0, %l1";
  }
}

static const char *
output_32 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 930 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      return aarch64_gen_far_branch (operands, 1, "Lcb", "cbnz\t%x0, ");
    else
      return "cbz\t%x0, %l1";
  }
}

static const char *
output_33 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 930 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      return aarch64_gen_far_branch (operands, 1, "Lcb", "cbz\t%x0, ");
    else
      return "cbnz\t%x0, %l1";
  }
}

static const char *
output_34 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 960 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 2, "Ltb",
					 "tbnz\t%w0, %1, ");
	else
	  {
	    operands[1] = GEN_INT (HOST_WIDE_INT_1U << UINTVAL (operands[1]));
	    return "tst\t%w0, %1\n\tbeq\t%l2";
	  }
      }
    else
      return "tbz\t%w0, %1, %l2";
  }
}

static const char *
output_35 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 960 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 2, "Ltb",
					 "tbz\t%w0, %1, ");
	else
	  {
	    operands[1] = GEN_INT (HOST_WIDE_INT_1U << UINTVAL (operands[1]));
	    return "tst\t%w0, %1\n\tbne\t%l2";
	  }
      }
    else
      return "tbnz\t%w0, %1, %l2";
  }
}

static const char *
output_36 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 960 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 2, "Ltb",
					 "tbnz\t%x0, %1, ");
	else
	  {
	    operands[1] = GEN_INT (HOST_WIDE_INT_1U << UINTVAL (operands[1]));
	    return "tst\t%x0, %1\n\tbeq\t%l2";
	  }
      }
    else
      return "tbz\t%x0, %1, %l2";
  }
}

static const char *
output_37 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 960 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 2, "Ltb",
					 "tbz\t%x0, %1, ");
	else
	  {
	    operands[1] = GEN_INT (HOST_WIDE_INT_1U << UINTVAL (operands[1]));
	    return "tst\t%x0, %1\n\tbne\t%l2";
	  }
      }
    else
      return "tbnz\t%x0, %1, %l2";
  }
}

static const char *
output_38 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbz\t%w0, #7, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (QImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%w0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "bne\t%l1";
	  }
      }
    else
      return "tbnz\t%w0, #7, %l1";
  }
}

static const char *
output_39 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbnz\t%w0, #7, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (QImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%w0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "beq\t%l1";
	  }
      }
    else
      return "tbz\t%w0, #7, %l1";
  }
}

static const char *
output_40 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbz\t%w0, #15, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (HImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%w0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "bne\t%l1";
	  }
      }
    else
      return "tbnz\t%w0, #15, %l1";
  }
}

static const char *
output_41 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbnz\t%w0, #15, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (HImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%w0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "beq\t%l1";
	  }
      }
    else
      return "tbz\t%w0, #15, %l1";
  }
}

static const char *
output_42 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbz\t%w0, #31, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (SImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%w0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "bne\t%l1";
	  }
      }
    else
      return "tbnz\t%w0, #31, %l1";
  }
}

static const char *
output_43 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbnz\t%w0, #31, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (SImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%w0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "beq\t%l1";
	  }
      }
    else
      return "tbz\t%w0, #31, %l1";
  }
}

static const char *
output_44 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbz\t%x0, #63, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (DImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%x0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "bne\t%l1";
	  }
      }
    else
      return "tbnz\t%x0, #63, %l1";
  }
}

static const char *
output_45 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 996 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (get_attr_length (insn) == 8)
      {
	if (get_attr_far_branch (insn) == 1)
	  return aarch64_gen_far_branch (operands, 1, "Ltb",
					 "tbnz\t%x0, #63, ");
	else
	  {
	    char buf[64];
	    uint64_t val = ((uint64_t) 1)
		<< (GET_MODE_SIZE (DImode) * BITS_PER_UNIT - 1);
	    sprintf (buf, "tst\t%%x0, %" PRId64, val);
	    output_asm_insn (buf, operands);
	    return "beq\t%l1";
	  }
      }
    else
      return "tbz\t%x0, #63, %l1";
  }
}

static const char *
output_46 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0:
       return aarch64_indirect_call_asm (operands[0]);
    case 1: return "bl\t%c0";
      default: gcc_unreachable ();
    }
}

static const char *
output_47 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0:
       return aarch64_indirect_call_asm (operands[1]);
    case 1: return "bl\t%c1";
      default: gcc_unreachable ();
    }
}

static const char *
output_48 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1118 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (which_alternative == 0)
      {
	output_asm_insn ("br\t%0", operands);
	return aarch64_sls_barrier (aarch64_harden_sls_retbr_p ());
      }
    return "b\t%c0";
  }
}

static const char *
output_49 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1138 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (which_alternative == 0)
      {
	output_asm_insn ("br\t%1", operands);
	return aarch64_sls_barrier (aarch64_harden_sls_retbr_p ());
      }
    return "b\t%c1";
  }
}

static const char *
output_50 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1204 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
   switch (which_alternative)
     {
     case 0:
       return "mov\t%w0, %w1";
     case 1:
       return "mov\t%w0, %1";
     case 2:
       return aarch64_output_scalar_simd_mov_immediate (operands[1],
							QImode);
     case 3:
       return aarch64_output_sve_cnt_immediate ("cnt", "%x0", operands[1]);
     case 4:
       return "ldrb\t%w0, %1";
     case 5:
       return "ldr\t%b0, %1";
     case 6:
       return "strb\t%w1, %0";
     case 7:
       return "str\t%b1, %0";
     case 8:
       return "umov\t%w0, %1.b[0]";
     case 9:
       return "dup\t%0.8b, %w1";
     case 10:
       return "dup\t%b0, %1.b[0]";
     default:
       gcc_unreachable ();
     }
}
}

static const char *
output_51 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1204 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
   switch (which_alternative)
     {
     case 0:
       return "mov\t%w0, %w1";
     case 1:
       return "mov\t%w0, %1";
     case 2:
       return aarch64_output_scalar_simd_mov_immediate (operands[1],
							HImode);
     case 3:
       return aarch64_output_sve_cnt_immediate ("cnt", "%x0", operands[1]);
     case 4:
       return "ldrh\t%w0, %1";
     case 5:
       return "ldr\t%h0, %1";
     case 6:
       return "strh\t%w1, %0";
     case 7:
       return "str\t%h1, %0";
     case 8:
       return "umov\t%w0, %1.h[0]";
     case 9:
       return "dup\t%0.4h, %w1";
     case 10:
       return "dup\t%h0, %1.h[0]";
     default:
       gcc_unreachable ();
     }
}
}

static const char *
output_52 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%w0, %w1";
    case 1: return "mov\t%w0, %w1";
    case 2: return "mov\t%w0, %w1";
    case 3: return "mov\t%w0, %1";
    case 4: return "#";
    case 5:
       return aarch64_output_sve_cnt_immediate ("cnt", "%x0", operands[1]);
    case 6: return "ldr\t%w0, %1";
    case 7: return "ldr\t%s0, %1";
    case 8: return "str\t%w1, %0";
    case 9: return "str\t%s1, %0";
    case 10: return "adrp\t%x0, %A1\n\tldr\t%w0, [%x0, %L1]";
    case 11: return "adr\t%x0, %c1";
    case 12: return "adrp\t%x0, %A1";
    case 13: return "fmov\t%s0, %w1";
    case 14: return "fmov\t%w0, %s1";
    case 15: return "fmov\t%s0, %s1";
    case 16:
       return aarch64_output_scalar_simd_mov_immediate (operands[1], SImode);
      default: gcc_unreachable ();
    }
}

static const char *
output_53 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%x0, %x1";
    case 1: return "mov\t%0, %x1";
    case 2: return "mov\t%x0, %1";
    case 3: return "mov\t%x0, %1";
    case 4: return "mov\t%w0, %1";
    case 5: return "#";
    case 6:
       return aarch64_output_sve_cnt_immediate ("cnt", "%x0", operands[1]);
    case 7: return "ldr\t%x0, %1";
    case 8: return "ldr\t%d0, %1";
    case 9: return "str\t%x1, %0";
    case 10: return "str\t%d1, %0";
    case 11:
       return TARGET_ILP32 ? "adrp\t%0, %A1\n\tldr\t%w0, [%0, %L1]" : "adrp\t%0, %A1\n\tldr\t%0, [%0, %L1]";
    case 12: return "adr\t%x0, %c1";
    case 13: return "adrp\t%x0, %A1";
    case 14: return "fmov\t%d0, %x1";
    case 15: return "fmov\t%x0, %d1";
    case 16: return "fmov\t%d0, %d1";
    case 17:
       return aarch64_output_scalar_simd_mov_immediate (operands[1], DImode);
      default: gcc_unreachable ();
    }
}

static const char *
output_56 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int shift = aarch64_movk_shift (rtx_mode_t (operands[2], SImode),
				    rtx_mode_t (operands[3], SImode));
    operands[2] = gen_int_mode (UINTVAL (operands[3]) >> shift, SImode);
    operands[3] = gen_int_mode (shift, SImode);
    return "movk\t%w0, #%X2, lsl %3";
  }
}

static const char *
output_57 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int shift = aarch64_movk_shift (rtx_mode_t (operands[2], DImode),
				    rtx_mode_t (operands[3], DImode));
    operands[2] = gen_int_mode (UINTVAL (operands[3]) >> shift, SImode);
    operands[3] = gen_int_mode (shift, SImode);
    return "movk\t%x0, #%X2, lsl %3";
  }
}

static const char * const output_58[] = {
  "#",
  "movi\t%0.2d, #0",
  "#",
  "#",
  "mov\t%0.16b, %1.16b",
  "ldp\t%0, %H0, %1",
  "stp\t%1, %H1, %0",
  "stp\txzr, xzr, %0",
  "ldr\t%q0, %1",
  "str\t%q1, %0",
};

static const char *
output_59 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "movi\t%0.4h, #0";
    case 1: return "fmov\t%h0, %w1";
    case 2: return "dup\t%w0.4h, %w1";
    case 3: return "umov\t%w0, %1.h[0]";
    case 4: return "mov\t%0.h[0], %1.h[0]";
    case 5: return "fmov\t%h0, %1";
    case 6:
       return aarch64_output_scalar_simd_mov_immediate (operands[1], HImode);
    case 7: return "ldr\t%h0, %1";
    case 8: return "str\t%h1, %0";
    case 9: return "ldrh\t%w0, %1";
    case 10: return "strh\t%w1, %0";
    case 11: return "mov\t%w0, %w1";
      default: gcc_unreachable ();
    }
}

static const char *
output_60 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "movi\t%0.4h, #0";
    case 1: return "fmov\t%h0, %w1";
    case 2: return "dup\t%w0.4h, %w1";
    case 3: return "umov\t%w0, %1.h[0]";
    case 4: return "mov\t%0.h[0], %1.h[0]";
    case 5: return "fmov\t%h0, %1";
    case 6:
       return aarch64_output_scalar_simd_mov_immediate (operands[1], HImode);
    case 7: return "ldr\t%h0, %1";
    case 8: return "str\t%h1, %0";
    case 9: return "ldrh\t%w0, %1";
    case 10: return "strh\t%w1, %0";
    case 11: return "mov\t%w0, %w1";
      default: gcc_unreachable ();
    }
}

static const char *
output_61 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "movi\t%0.2s, #0";
    case 1: return "fmov\t%s0, %w1";
    case 2: return "fmov\t%w0, %s1";
    case 3: return "fmov\t%s0, %s1";
    case 4: return "fmov\t%s0, %1";
    case 5:
       return aarch64_output_scalar_simd_mov_immediate (operands[1], SImode);
    case 6: return "ldr\t%s0, %1";
    case 7: return "str\t%s1, %0";
    case 8: return "ldr\t%w0, %1";
    case 9: return "str\t%w1, %0";
    case 10: return "mov\t%w0, %w1";
    case 11: return "mov\t%w0, %1";
      default: gcc_unreachable ();
    }
}

static const char *
output_62 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "movi\t%d0, #0";
    case 1: return "fmov\t%d0, %x1";
    case 2: return "fmov\t%x0, %d1";
    case 3: return "fmov\t%d0, %d1";
    case 4: return "fmov\t%d0, %1";
    case 5:
       return aarch64_output_scalar_simd_mov_immediate (operands[1], DImode);
    case 6: return "ldr\t%d0, %1";
    case 7: return "str\t%d1, %0";
    case 8: return "ldr\t%x0, %1";
    case 9: return "str\t%x1, %0";
    case 10: return "mov\t%x0, %x1";
    case 11: return "mov\t%x0, %1";
      default: gcc_unreachable ();
    }
}

static const char * const output_63[] = {
  "mov\t%0.16b, %1.16b",
  "#",
  "#",
  "#",
  "movi\t%0.2d, #0",
  "fmov\t%s0, wzr",
  "ldr\t%q0, %1",
  "str\t%q1, %0",
  "ldp\t%0, %H0, %1",
  "stp\t%1, %H1, %0",
  "stp\txzr, xzr, %0",
};

static const char * const output_67[] = {
  "ldp\t%w0, %w2, %z1",
  "ldp\t%s0, %s2, %z1",
};

static const char * const output_68[] = {
  "ldp\t%w0, %w2, %z1",
  "ldp\t%s0, %s2, %z1",
};

static const char * const output_69[] = {
  "ldp\t%w0, %w2, %z1",
  "ldp\t%s0, %s2, %z1",
};

static const char * const output_70[] = {
  "ldp\t%w0, %w2, %z1",
  "ldp\t%s0, %s2, %z1",
};

static const char * const output_71[] = {
  "ldp\t%x0, %x2, %z1",
  "ldp\t%d0, %d2, %z1",
};

static const char * const output_72[] = {
  "ldp\t%x0, %x2, %z1",
  "ldp\t%d0, %d2, %z1",
};

static const char * const output_73[] = {
  "ldp\t%x0, %x2, %z1",
  "ldp\t%d0, %d2, %z1",
};

static const char * const output_74[] = {
  "ldp\t%x0, %x2, %z1",
  "ldp\t%d0, %d2, %z1",
};

static const char * const output_76[] = {
  "stp\t%w1, %w3, %z0",
  "stp\t%s1, %s3, %z0",
};

static const char * const output_77[] = {
  "stp\t%w1, %w3, %z0",
  "stp\t%s1, %s3, %z0",
};

static const char * const output_78[] = {
  "stp\t%w1, %w3, %z0",
  "stp\t%s1, %s3, %z0",
};

static const char * const output_79[] = {
  "stp\t%w1, %w3, %z0",
  "stp\t%s1, %s3, %z0",
};

static const char * const output_80[] = {
  "stp\t%x1, %x3, %z0",
  "stp\t%d1, %d3, %z0",
};

static const char * const output_81[] = {
  "stp\t%x1, %x3, %z0",
  "stp\t%d1, %d3, %z0",
};

static const char * const output_82[] = {
  "stp\t%x1, %x3, %z0",
  "stp\t%d1, %d3, %z0",
};

static const char * const output_83[] = {
  "stp\t%x1, %x3, %z0",
  "stp\t%d1, %d3, %z0",
};

static const char * const output_109[] = {
  "sxtw\t%0, %w1",
  "ldrsw\t%0, %1",
};

static const char * const output_111[] = {
  "uxtw\t%0, %w1",
  "ldr\t%w0, %1",
  "fmov\t%s0, %w1",
  "ldr\t%s0, %1",
  "fmov\t%w0, %s1",
  "fmov\t%s0, %s1",
};

static const char * const output_112[] = {
  "ldp\t%w0, %w2, %z1",
  "ldp\t%s0, %s2, %z1",
};

static const char * const output_113[] = {
  "sxtb\t%w0, %w1",
  "ldrsb\t%w0, %1",
  "smov\t%w0, %1.b[0]",
};

static const char * const output_114[] = {
  "sxth\t%w0, %w1",
  "ldrsh\t%w0, %1",
  "smov\t%w0, %1.h[0]",
};

static const char * const output_115[] = {
  "sxtb\t%x0, %w1",
  "ldrsb\t%x0, %1",
  "smov\t%x0, %1.b[0]",
};

static const char * const output_116[] = {
  "sxth\t%x0, %w1",
  "ldrsh\t%x0, %1",
  "smov\t%x0, %1.h[0]",
};

static const char * const output_117[] = {
  "and\t%w0, %w1, 255",
  "ldrb\t%w0, %1",
  "ldr\t%b0, %1",
  "umov\t%w0, %1.b[0]",
};

static const char * const output_118[] = {
  "and\t%w0, %w1, 65535",
  "ldrh\t%w0, %1",
  "ldr\t%h0, %1",
  "umov\t%w0, %1.h[0]",
};

static const char * const output_119[] = {
  "and\t%x0, %x1, 255",
  "ldrb\t%w0, %1",
  "ldr\t%b0, %1",
  "umov\t%w0, %1.b[0]",
};

static const char * const output_120[] = {
  "and\t%x0, %x1, 65535",
  "ldrh\t%w0, %1",
  "ldr\t%h0, %1",
  "umov\t%w0, %1.h[0]",
};

static const char * const output_121[] = {
  "sxtb\t%w0, %w1",
  "ldrsb\t%w0, %1",
};

static const char * const output_122[] = {
  "and\t%w0, %w1, 255",
  "ldrb\t%w0, %1",
};

static const char *
output_123 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%w0, %w1, %2";
    case 1: return "add\t%w0, %w1, %w2";
    case 2: return "add\t%0.2s, %1.2s, %2.2s";
    case 3: return "sub\t%w0, %w1, #%n2";
    case 4: return "#";
    case 5:
       return aarch64_output_sve_scalar_inc_dec (operands[2]);
    case 6:
       return aarch64_output_sve_addvl_addpl (operands[2]);
      default: gcc_unreachable ();
    }
}

static const char *
output_124 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%x0, %x1, %2";
    case 1: return "add\t%x0, %x1, %x2";
    case 2: return "add\t%d0, %d1, %d2";
    case 3: return "sub\t%x0, %x1, #%n2";
    case 4: return "#";
    case 5:
       return aarch64_output_sve_scalar_inc_dec (operands[2]);
    case 6:
       return aarch64_output_sve_addvl_addpl (operands[2]);
      default: gcc_unreachable ();
    }
}

static const char * const output_125[] = {
  "add\t%w0, %w1, %2",
  "add\t%w0, %w1, %w2",
  "sub\t%w0, %w1, #%n2",
  "#",
};

static const char *
output_126 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%w0, %w1, %2";
    case 1: return "add\t%w0, %w1, %w2";
    case 2: return "sub\t%w0, %w1, #%n2";
    case 3: return "#";
    case 4:
       return aarch64_output_sve_scalar_inc_dec (operands[2]);
    case 5:
       return aarch64_output_sve_addvl_addpl (operands[2]);
    case 6: return "#";
      default: gcc_unreachable ();
    }
}

static const char *
output_127 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%x0, %x1, %2";
    case 1: return "add\t%x0, %x1, %x2";
    case 2: return "sub\t%x0, %x1, #%n2";
    case 3: return "#";
    case 4:
       return aarch64_output_sve_scalar_inc_dec (operands[2]);
    case 5:
       return aarch64_output_sve_addvl_addpl (operands[2]);
    case 6: return "#";
      default: gcc_unreachable ();
    }
}

static const char * const output_128[] = {
  "adds\t%w0, %w1, %w2",
  "adds\t%w0, %w1, %2",
  "subs\t%w0, %w1, #%n2",
};

static const char * const output_129[] = {
  "adds\t%x0, %x1, %x2",
  "adds\t%x0, %x1, %2",
  "subs\t%x0, %x1, #%n2",
};

static const char * const output_130[] = {
  "adds\t%w0, %w1, %w2",
  "adds\t%w0, %w1, %2",
  "subs\t%w0, %w1, #%n2",
};

static const char * const output_131[] = {
  "cmn\t%w0, %w1",
  "cmn\t%w0, %1",
  "cmp\t%w0, #%n1",
};

static const char * const output_132[] = {
  "cmn\t%x0, %x1",
  "cmn\t%x0, %1",
  "cmp\t%x0, #%n1",
};

static const char * const output_133[] = {
  "adds\t%w0, %w1, %w2",
  "adds\t%w0, %w1, %2",
  "subs\t%w0, %w1, #%n2",
};

static const char * const output_134[] = {
  "adds\t%x0, %x1, %x2",
  "adds\t%x0, %x1, %2",
  "subs\t%x0, %x1, #%n2",
};

static const char * const output_135[] = {
  "cmn\t%w0, %w1",
  "cmp\t%w0, #%n1",
};

static const char * const output_136[] = {
  "cmn\t%x0, %x1",
  "cmp\t%x0, #%n1",
};

static const char * const output_139[] = {
  "adds\t%w0, %w1, %w2",
  "subs\t%w0, %w1, #%n2",
};

static const char * const output_140[] = {
  "adds\t%x0, %x1, %x2",
  "subs\t%x0, %x1, #%n2",
};

static const char * const output_203[] = {
  "cmn\t%w0, %w1",
  "cmn\t%w0, %1",
  "cmp\t%w0, #%n1",
};

static const char * const output_204[] = {
  "cmn\t%x0, %x1",
  "cmn\t%x0, %1",
  "cmp\t%x0, #%n1",
};

static const char *
output_265 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2846 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"

  operands[3] = GEN_INT (aarch64_uxt_size (INTVAL(operands[2]),
					   INTVAL (operands[3])));
  return "add\t%w0, %w4, %w1, uxt%e3 %2";
}

static const char *
output_266 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2846 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"

  operands[3] = GEN_INT (aarch64_uxt_size (INTVAL(operands[2]),
					   INTVAL (operands[3])));
  return "add\t%x0, %x4, %w1, uxt%e3 %2";
}

static const char *
output_267 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2863 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"

  operands[3] = GEN_INT (aarch64_uxt_size (INTVAL (operands[2]),
					   INTVAL (operands[3])));
  return "add\t%w0, %w4, %w1, uxt%e3 %2";
}

static const char * const output_270[] = {
  "sub\t%x0, %x1, %x2",
  "sub\t%d0, %d1, %d2",
};

static const char * const output_273[] = {
  "subs\t%w0, %w1, %2",
  "adds\t%w0, %w1, #%n2",
};

static const char * const output_274[] = {
  "subs\t%x0, %x1, %2",
  "adds\t%x0, %x1, #%n2",
};

static const char * const output_279[] = {
  "cmp\t%w0, %w1",
  "cmp\t%w0, %1",
  "cmp\t%w0, #%n1",
};

static const char * const output_280[] = {
  "cmp\t%x0, %x1",
  "cmp\t%x0, %1",
  "cmp\t%x0, #%n1",
};

static const char * const output_286[] = {
  "subs\t%w0, %w1, %2",
  "adds\t%w0, %w1, #%n2",
};

static const char * const output_287[] = {
  "subs\t%x0, %x1, %2",
  "adds\t%x0, %x1, #%n2",
};

static const char *
output_350 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3550 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"

  operands[3] = GEN_INT (aarch64_uxt_size (INTVAL (operands[2]),
					   INTVAL (operands[3])));
  return "sub\t%w0, %w4, %w1, uxt%e3 %2";
}

static const char *
output_351 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3550 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"

  operands[3] = GEN_INT (aarch64_uxt_size (INTVAL (operands[2]),
					   INTVAL (operands[3])));
  return "sub\t%x0, %x4, %w1, uxt%e3 %2";
}

static const char *
output_352 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3567 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"

  operands[3] = GEN_INT (aarch64_uxt_size (INTVAL (operands[2]),
					   INTVAL (operands[3])));
  return "sub\t%w0, %w4, %w1, uxt%e3 %2";
}

static const char * const output_353[] = {
  "neg\t%w0, %w1",
  "neg\t%0.2s, %1.2s",
};

static const char * const output_354[] = {
  "neg\t%x0, %x1",
  "neg\t%d0, %d1",
};

static const char * const output_406[] = {
  "cmp\t%w0, %w1",
  "cmp\t%w0, %1",
  "cmn\t%w0, #%n1",
};

static const char * const output_407[] = {
  "cmp\t%x0, %x1",
  "cmp\t%x0, %1",
  "cmn\t%x0, #%n1",
};

static const char * const output_408[] = {
  "fcmp\t%s0, #0.0",
  "fcmp\t%s0, %s1",
};

static const char * const output_409[] = {
  "fcmp\t%d0, #0.0",
  "fcmp\t%d0, %d1",
};

static const char * const output_410[] = {
  "fcmpe\t%s0, #0.0",
  "fcmpe\t%s0, %s1",
};

static const char * const output_411[] = {
  "fcmpe\t%d0, #0.0",
  "fcmpe\t%d0, %d1",
};

static const char * const output_456[] = {
  "csel\t%w0, %w3, %w4, %m1",
  "csinv\t%w0, %w3, wzr, %m1",
  "csinv\t%w0, %w4, wzr, %M1",
  "csinc\t%w0, %w3, wzr, %m1",
  "csinc\t%w0, %w4, wzr, %M1",
  "mov\t%w0, -1",
  "mov\t%w0, 1",
};

static const char * const output_457[] = {
  "csel\t%w0, %w3, %w4, %m1",
  "csinv\t%w0, %w3, wzr, %m1",
  "csinv\t%w0, %w4, wzr, %M1",
  "csinc\t%w0, %w3, wzr, %m1",
  "csinc\t%w0, %w4, wzr, %M1",
  "mov\t%w0, -1",
  "mov\t%w0, 1",
};

static const char * const output_458[] = {
  "csel\t%w0, %w3, %w4, %m1",
  "csinv\t%w0, %w3, wzr, %m1",
  "csinv\t%w0, %w4, wzr, %M1",
  "csinc\t%w0, %w3, wzr, %m1",
  "csinc\t%w0, %w4, wzr, %M1",
  "mov\t%w0, -1",
  "mov\t%w0, 1",
};

static const char * const output_459[] = {
  "csel\t%x0, %x3, %x4, %m1",
  "csinv\t%x0, %x3, xzr, %m1",
  "csinv\t%x0, %x4, xzr, %M1",
  "csinc\t%x0, %x3, xzr, %m1",
  "csinc\t%x0, %x4, xzr, %M1",
  "mov\t%x0, -1",
  "mov\t%x0, 1",
};

static const char * const output_460[] = {
  "csel\t%w0, %w3, %w4, %m1",
  "csinv\t%w0, %w3, wzr, %m1",
  "csinv\t%w0, %w4, wzr, %M1",
  "csinc\t%w0, %w3, wzr, %m1",
  "csinc\t%w0, %w4, wzr, %M1",
  "mov\t%w0, -1",
  "mov\t%w0, 1",
};

static const char *
output_464 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (QImode) >= 64)
      return "crc32b\t%w0, %w1, %x2";
    else
      return "crc32b\t%w0, %w1, %w2";
  }
}

static const char *
output_465 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (HImode) >= 64)
      return "crc32h\t%w0, %w1, %x2";
    else
      return "crc32h\t%w0, %w1, %w2";
  }
}

static const char *
output_466 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (SImode) >= 64)
      return "crc32w\t%w0, %w1, %x2";
    else
      return "crc32w\t%w0, %w1, %w2";
  }
}

static const char *
output_467 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (DImode) >= 64)
      return "crc32x\t%w0, %w1, %x2";
    else
      return "crc32x\t%w0, %w1, %w2";
  }
}

static const char *
output_468 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (QImode) >= 64)
      return "crc32cb\t%w0, %w1, %x2";
    else
      return "crc32cb\t%w0, %w1, %w2";
  }
}

static const char *
output_469 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (HImode) >= 64)
      return "crc32ch\t%w0, %w1, %x2";
    else
      return "crc32ch\t%w0, %w1, %w2";
  }
}

static const char *
output_470 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (SImode) >= 64)
      return "crc32cw\t%w0, %w1, %x2";
    else
      return "crc32cw\t%w0, %w1, %w2";
  }
}

static const char *
output_471 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4274 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    if (GET_MODE_BITSIZE (DImode) >= 64)
      return "crc32cx\t%w0, %w1, %x2";
    else
      return "crc32cx\t%w0, %w1, %w2";
  }
}

static const char *
output_488 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4428 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    return aarch64_output_sve_cnt_immediate ("uqdec", "%w0", operands[2]);
  }
}

static const char *
output_489 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4428 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    return aarch64_output_sve_cnt_immediate ("uqdec", "%x0", operands[2]);
  }
}

static const char * const output_500[] = {
  "and\t%w0, %w1, %w2",
  "and\t%w0, %w1, %2",
  "and\t%0.8b, %1.8b, %2.8b",
};

static const char * const output_501[] = {
  "orr\t%w0, %w1, %w2",
  "orr\t%w0, %w1, %2",
  "orr\t%0.8b, %1.8b, %2.8b",
};

static const char * const output_502[] = {
  "eor\t%w0, %w1, %w2",
  "eor\t%w0, %w1, %2",
  "eor\t%0.8b, %1.8b, %2.8b",
};

static const char * const output_503[] = {
  "and\t%x0, %x1, %x2",
  "and\t%x0, %x1, %2",
  "and\t%0.8b, %1.8b, %2.8b",
};

static const char * const output_504[] = {
  "orr\t%x0, %x1, %x2",
  "orr\t%x0, %x1, %2",
  "orr\t%0.8b, %1.8b, %2.8b",
};

static const char * const output_505[] = {
  "eor\t%x0, %x1, %x2",
  "eor\t%x0, %x1, %2",
  "eor\t%0.8b, %1.8b, %2.8b",
};

static const char * const output_506[] = {
  "and\t%w0, %w1, %w2",
  "and\t%w0, %w1, %2",
};

static const char * const output_507[] = {
  "orr\t%w0, %w1, %w2",
  "orr\t%w0, %w1, %2",
};

static const char * const output_508[] = {
  "eor\t%w0, %w1, %w2",
  "eor\t%w0, %w1, %2",
};

static const char * const output_509[] = {
  "ands\t%w0, %w1, %w2",
  "ands\t%w0, %w1, %2",
};

static const char * const output_510[] = {
  "ands\t%x0, %x1, %x2",
  "ands\t%x0, %x1, %2",
};

static const char * const output_511[] = {
  "ands\t%w0, %w1, %w2",
  "ands\t%w0, %w1, %2",
};

static const char * const output_569[] = {
  "mvn\t%w0, %w1",
  "mvn\t%0.8b, %1.8b",
};

static const char * const output_570[] = {
  "mvn\t%x0, %x1",
  "mvn\t%0.8b, %1.8b",
};

static const char * const output_580[] = {
  "bic\t%w0, %w2, %w1",
  "bic\t%0.8b, %2.8b, %1.8b",
};

static const char * const output_581[] = {
  "orn\t%w0, %w2, %w1",
  "orn\t%0.8b, %2.8b, %1.8b",
};

static const char * const output_582[] = {
  "bic\t%x0, %x2, %x1",
  "bic\t%0.8b, %2.8b, %1.8b",
};

static const char * const output_583[] = {
  "orn\t%x0, %x2, %x1",
  "orn\t%0.8b, %2.8b, %1.8b",
};

static const char * const output_587[] = {
  "eon\t%w0, %w1, %w2",
  "#",
};

static const char * const output_588[] = {
  "eon\t%x0, %x1, %x2",
  "#",
};

static const char * const output_664[] = {
  "tst\t%w0, %w1",
  "tst\t%w0, %1",
};

static const char * const output_665[] = {
  "tst\t%x0, %x1",
  "tst\t%x0, %1",
};

static const char *
output_666 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5052 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[1]
      = aarch64_mask_from_zextract_ops (operands[1], operands[2]);
    return "tst\t%w0, %1";
  }
}

static const char *
output_667 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5052 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[1]
      = aarch64_mask_from_zextract_ops (operands[1], operands[2]);
    return "tst\t%x0, %1";
  }
}

static const char *
output_694 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  rtx xop[3];
  xop[0] = operands[0];
  xop[1] = operands[1];
  xop[2] = gen_lowpart (GET_MODE (operands[4]), operands[2]);
  output_asm_insn ("lsl\t%x0, %x1, %x2", xop);
  return "";
}
}

static const char *
output_695 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  rtx xop[3];
  xop[0] = operands[0];
  xop[1] = operands[1];
  xop[2] = gen_lowpart (GET_MODE (operands[4]), operands[2]);
  output_asm_insn ("asr\t%x0, %x1, %x2", xop);
  return "";
}
}

static const char *
output_696 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  rtx xop[3];
  xop[0] = operands[0];
  xop[1] = operands[1];
  xop[2] = gen_lowpart (GET_MODE (operands[4]), operands[2]);
  output_asm_insn ("lsr\t%x0, %x1, %x2", xop);
  return "";
}
}

static const char *
output_697 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  rtx xop[3];
  xop[0] = operands[0];
  xop[1] = operands[1];
  xop[2] = gen_lowpart (GET_MODE (operands[4]), operands[2]);
  output_asm_insn ("ror\t%x0, %x1, %x2", xop);
  return "";
}
}

static const char * const output_704[] = {
  "lsl\t%w0, %w1, %2",
  "lsl\t%w0, %w1, %w2",
  "shl\t%0.2s, %1.2s, %2",
  "ushl\t%0.2s, %1.2s, %2.2s",
};

static const char * const output_705[] = {
  "lsl\t%x0, %x1, %2",
  "lsl\t%x0, %x1, %x2",
  "shl\t%d0, %d1, %2",
  "ushl\t%d0, %d1, %d2",
};

static const char * const output_706[] = {
  "lsr\t%w0, %w1, %2",
  "lsr\t%w0, %w1, %w2",
  "ushr\t%0.2s, %1.2s, %2",
  "#",
  "#",
};

static const char * const output_707[] = {
  "lsr\t%x0, %x1, %2",
  "lsr\t%x0, %x1, %x2",
  "ushr\t%d0, %d1, %2",
  "#",
  "#",
};

static const char * const output_708[] = {
  "asr\t%w0, %w1, %2",
  "asr\t%w0, %w1, %w2",
  "sshr\t%0.2s, %1.2s, %2",
  "#",
  "#",
};

static const char * const output_709[] = {
  "asr\t%x0, %x1, %2",
  "asr\t%x0, %x1, %x2",
  "sshr\t%d0, %d1, %2",
  "#",
  "#",
};

static const char * const output_715[] = {
  "ror\t%w0, %w1, %2",
  "ror\t%w0, %w1, %w2",
};

static const char * const output_716[] = {
  "ror\t%x0, %x1, %2",
  "ror\t%x0, %x1, %x2",
};

static const char * const output_717[] = {
  "lsl\t%w0, %w1, %2",
  "lsl\t%w0, %w1, %w2",
};

static const char * const output_718[] = {
  "asr\t%w0, %w1, %2",
  "asr\t%w0, %w1, %w2",
};

static const char * const output_719[] = {
  "lsr\t%w0, %w1, %2",
  "lsr\t%w0, %w1, %w2",
};

static const char * const output_720[] = {
  "ror\t%w0, %w1, %2",
  "ror\t%w0, %w1, %w2",
};

static const char *
output_721 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5488 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "ubfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_722 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5488 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "sbfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_723 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5488 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "ubfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_724 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5488 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "ubfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_725 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5488 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "sbfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_726 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5488 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "ubfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_734 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5570 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (32 - UINTVAL (operands[2]));
  return "ror\t%w0, %w1, %3";
}
}

static const char *
output_735 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5570 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (64 - UINTVAL (operands[2]));
  return "ror\t%x0, %x1, %3";
}
}

static const char *
output_736 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5584 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (32 - UINTVAL (operands[2]));
  return "ror\t%w0, %w1, %3";
}
}

static const char *
output_737 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "sbfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_738 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "ubfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_739 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "sbfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_740 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "ubfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_741 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "sbfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_742 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "ubfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_743 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "sbfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_744 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5597 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "ubfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_745 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5610 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "ubfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_746 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5610 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "ubfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_747 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5610 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "ubfx\t%x0, %x1, %2, %3";
}
}

static const char *
output_748 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5610 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "ubfx\t%x0, %x1, %2, %3";
}
}

static const char *
output_749 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5623 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "sbfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_750 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5623 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "sbfx\t%w0, %w1, %2, %3";
}
}

static const char *
output_751 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5623 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (8 - UINTVAL (operands[2]));
  return "sbfx\t%x0, %x1, %2, %3";
}
}

static const char *
output_752 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5623 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = GEN_INT (16 - UINTVAL (operands[2]));
  return "sbfx\t%x0, %x1, %2, %3";
}
}

static const char *
output_769 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5784 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[5] = GEN_INT (GET_MODE_BITSIZE (SImode) - UINTVAL (operands[4]));
  return "bfi\t%w0, %w3, %4, %5";
}
}

static const char *
output_770 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5784 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[5] = GEN_INT (GET_MODE_BITSIZE (DImode) - UINTVAL (operands[4]));
  return "bfi\t%x0, %x3, %4, %5";
}
}

static const char *
output_771 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5801 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[5] = GEN_INT (GET_MODE_BITSIZE (SImode) - UINTVAL (operands[2]));
  return "bfi\t%w0, %w1, %2, %5";
}
}

static const char *
output_772 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5801 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[5] = GEN_INT (GET_MODE_BITSIZE (DImode) - UINTVAL (operands[2]));
  return "bfi\t%x0, %x1, %2, %5";
}
}

static const char *
output_782 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (8 <= (32 - UINTVAL (operands[2])))
	      ? GEN_INT (8)
	      : GEN_INT (32 - UINTVAL (operands[2]));
  return "sbfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_783 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (8 <= (32 - UINTVAL (operands[2])))
	      ? GEN_INT (8)
	      : GEN_INT (32 - UINTVAL (operands[2]));
  return "ubfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_784 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (8 <= (64 - UINTVAL (operands[2])))
	      ? GEN_INT (8)
	      : GEN_INT (64 - UINTVAL (operands[2]));
  return "sbfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_785 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (8 <= (64 - UINTVAL (operands[2])))
	      ? GEN_INT (8)
	      : GEN_INT (64 - UINTVAL (operands[2]));
  return "ubfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_786 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (16 <= (32 - UINTVAL (operands[2])))
	      ? GEN_INT (16)
	      : GEN_INT (32 - UINTVAL (operands[2]));
  return "sbfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_787 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (16 <= (32 - UINTVAL (operands[2])))
	      ? GEN_INT (16)
	      : GEN_INT (32 - UINTVAL (operands[2]));
  return "ubfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_788 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (16 <= (64 - UINTVAL (operands[2])))
	      ? GEN_INT (16)
	      : GEN_INT (64 - UINTVAL (operands[2]));
  return "sbfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_789 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (16 <= (64 - UINTVAL (operands[2])))
	      ? GEN_INT (16)
	      : GEN_INT (64 - UINTVAL (operands[2]));
  return "ubfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_790 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (32 <= (32 - UINTVAL (operands[2])))
	      ? GEN_INT (32)
	      : GEN_INT (32 - UINTVAL (operands[2]));
  return "sbfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_791 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (32 <= (32 - UINTVAL (operands[2])))
	      ? GEN_INT (32)
	      : GEN_INT (32 - UINTVAL (operands[2]));
  return "ubfiz\t%w0, %w1, %2, %3";
}
}

static const char *
output_792 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (32 <= (64 - UINTVAL (operands[2])))
	      ? GEN_INT (32)
	      : GEN_INT (64 - UINTVAL (operands[2]));
  return "sbfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_793 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5888 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  operands[3] = (32 <= (64 - UINTVAL (operands[2])))
	      ? GEN_INT (32)
	      : GEN_INT (64 - UINTVAL (operands[2]));
  return "ubfiz\t%x0, %x1, %2, %3";
}
}

static const char *
output_804 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5988 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    switch (which_alternative)
    {
      case 0:
	operands[3] = GEN_INT (ctz_hwi (~INTVAL (operands[3])));
	return "bfxil\t%w0, %w1, 0, %3";
      case 1:
	operands[3] = GEN_INT (ctz_hwi (~INTVAL (operands[4])));
	return "bfxil\t%w0, %w2, 0, %3";
      default:
	gcc_unreachable ();
    }
  }
}

static const char *
output_805 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5988 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    switch (which_alternative)
    {
      case 0:
	operands[3] = GEN_INT (ctz_hwi (~INTVAL (operands[3])));
	return "bfxil\t%x0, %x1, 0, %3";
      case 1:
	operands[3] = GEN_INT (ctz_hwi (~INTVAL (operands[4])));
	return "bfxil\t%x0, %x2, 0, %3";
      default:
	gcc_unreachable ();
    }
  }
}

static const char *
output_806 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6015 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    switch (which_alternative)
    {
      case 0:
	operands[3] = GEN_INT (ctz_hwi (~INTVAL (operands[3])));
	return "bfxil\t%w0, %w1, 0, %3";
      case 1:
	operands[3] = GEN_INT (ctz_hwi (~INTVAL (operands[4])));
	return "bfxil\t%w0, %w2, 0, %3";
      default:
	gcc_unreachable ();
    }
  }
}

static const char *
output_893 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzs\t%%w0, %%s1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_894 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzu\t%%w0, %%s1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_895 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzs\t%%w0, %%d1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_896 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzu\t%%w0, %%d1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_897 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzs\t%%x0, %%s1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_898 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzu\t%%x0, %%s1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_899 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzs\t%%x0, %%d1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_900 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6109 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    int fbits = aarch64_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzu\t%%x0, %%d1, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char * const output_919[] = {
  "fcvtzs\t%s0, %s1",
  "fcvtzs\t%w0, %s1",
};

static const char * const output_920[] = {
  "fcvtzu\t%s0, %s1",
  "fcvtzu\t%w0, %s1",
};

static const char * const output_921[] = {
  "fcvtzs\t%d0, %d1",
  "fcvtzs\t%x0, %d1",
};

static const char * const output_922[] = {
  "fcvtzu\t%d0, %d1",
  "fcvtzu\t%x0, %d1",
};

static const char *
output_933 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6314 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    switch (which_alternative)
    {
      case 0:
	return "scvtf\t%s0, %s1, #%2";
      case 1:
	return "scvtf\t%s0, %w1, #%2";
      default:
	gcc_unreachable ();
    }
  }
}

static const char *
output_934 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6314 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    switch (which_alternative)
    {
      case 0:
	return "ucvtf\t%s0, %s1, #%2";
      case 1:
	return "ucvtf\t%s0, %w1, #%2";
      default:
	gcc_unreachable ();
    }
  }
}

static const char *
output_935 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6314 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    switch (which_alternative)
    {
      case 0:
	return "scvtf\t%d0, %d1, #%2";
      case 1:
	return "scvtf\t%d0, %x1, #%2";
      default:
	gcc_unreachable ();
    }
  }
}

static const char *
output_936 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6314 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    switch (which_alternative)
    {
      case 0:
	return "ucvtf\t%d0, %d1, #%2";
      case 1:
	return "ucvtf\t%d0, %x1, #%2";
      default:
	gcc_unreachable ();
    }
  }
}

static const char *
output_937 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6337 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    return "scvtf\t%s0, %x1, #%2";
  }
}

static const char *
output_938 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6337 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    return "ucvtf\t%s0, %x1, #%2";
  }
}

static const char *
output_939 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6337 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    return "scvtf\t%d0, %w1, #%2";
  }
}

static const char *
output_940 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6337 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[2] = GEN_INT (aarch64_fpconst_pow2_recip (operands[2]));
    return "ucvtf\t%d0, %w1, #%2";
  }
}

static const char * const output_941[] = {
  "scvtf\t%s0, %s1",
  "scvtf\t%s0, %w1",
};

static const char * const output_942[] = {
  "ucvtf\t%s0, %s1",
  "ucvtf\t%s0, %w1",
};

static const char * const output_943[] = {
  "scvtf\t%d0, %d1",
  "scvtf\t%d0, %x1",
};

static const char * const output_944[] = {
  "ucvtf\t%d0, %d1",
  "ucvtf\t%d0, %x1",
};

static const char * const output_953[] = {
  "fcvtzs\t%w0, %s1, #%2",
  "fcvtzs\t%s0, %s1, #%2",
};

static const char * const output_954[] = {
  "fcvtzu\t%w0, %s1, #%2",
  "fcvtzu\t%s0, %s1, #%2",
};

static const char * const output_955[] = {
  "fcvtzs\t%x0, %d1, #%2",
  "fcvtzs\t%d0, %d1, #%2",
};

static const char * const output_956[] = {
  "fcvtzu\t%x0, %d1, #%2",
  "fcvtzu\t%d0, %d1, #%2",
};

static const char * const output_957[] = {
  "scvtf\t%s0, %w1, #%2",
  "scvtf\t%s0, %s1, #%2",
};

static const char * const output_958[] = {
  "ucvtf\t%s0, %w1, #%2",
  "ucvtf\t%s0, %s1, #%2",
};

static const char * const output_959[] = {
  "scvtf\t%d0, %x1, #%2",
  "scvtf\t%d0, %d1, #%2",
};

static const char * const output_960[] = {
  "ucvtf\t%d0, %x1, #%2",
  "ucvtf\t%d0, %d1, #%2",
};

static const char * const output_1014[] = {
  "bsl\t%0.8b, %2.8b, %1.8b",
  "bit\t%0.8b, %2.8b, %3.8b",
  "bif\t%0.8b, %1.8b, %3.8b",
  "bfxil\t%w0, %w1, #0, #31",
};

static const char * const output_1015[] = {
  "bsl\t%0.8b, %2.8b, %1.8b",
  "bit\t%0.8b, %2.8b, %3.8b",
  "bif\t%0.8b, %1.8b, %3.8b",
  "bfxil\t%x0, %x1, #0, #63",
};

static const char *
output_1066 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7155 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  return aarch64_output_probe_stack_range (operands[0], operands[2]);
}
}

static const char *
output_1067 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7173 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  return aarch64_output_probe_sve_stack_clash (operands[0], operands[2],
					       operands[3], operands[4]);
}
}

static const char *
output_1068 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7173 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
  return aarch64_output_probe_sve_stack_clash (operands[0], operands[2],
					       operands[3], operands[4]);
}
}

static const char *
output_1069 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7223 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
   char buf[150];
   snprintf (buf, 150, "mrs\t%%w0, %s",
	    aarch64_stack_protector_guard_reg_str);
   output_asm_insn (buf, operands);
   return "";
 }
}

static const char *
output_1070 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7223 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
   char buf[150];
   snprintf (buf, 150, "mrs\t%%x0, %s",
	    aarch64_stack_protector_guard_reg_str);
   output_asm_insn (buf, operands);
   return "";
 }
}

static const char *
output_1083 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7350 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[1] = gen_rtx_REG (DImode, SPECULATION_TRACKER_REGNUM);
    output_asm_insn ("csel\t%1, %1, xzr, %m0", operands);
    return "";
  }
}

static const char *
output_1084 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7364 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[1] = gen_rtx_REG (DImode, SPECULATION_TRACKER_REGNUM);
    output_asm_insn ("csel\t%1, %1, xzr, %M0", operands);
    return "";
  }
}

static const char *
output_1090 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7450 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[3] = gen_rtx_REG (DImode, SPECULATION_TRACKER_REGNUM);
    output_asm_insn ("cmp\t%3, #0\n\tcsel\t%w0, %w1, %w2, ne\n\thint\t0x14 // csdb",
		     operands);
    return "";
  }
}

static const char *
output_1091 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7450 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[3] = gen_rtx_REG (DImode, SPECULATION_TRACKER_REGNUM);
    output_asm_insn ("cmp\t%3, #0\n\tcsel\t%w0, %w1, %w2, ne\n\thint\t0x14 // csdb",
		     operands);
    return "";
  }
}

static const char *
output_1092 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7450 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[3] = gen_rtx_REG (DImode, SPECULATION_TRACKER_REGNUM);
    output_asm_insn ("cmp\t%3, #0\n\tcsel\t%w0, %w1, %w2, ne\n\thint\t0x14 // csdb",
		     operands);
    return "";
  }
}

static const char *
output_1093 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7450 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[3] = gen_rtx_REG (DImode, SPECULATION_TRACKER_REGNUM);
    output_asm_insn ("cmp\t%3, #0\n\tcsel\t%x0, %x1, %x2, ne\n\thint\t0x14 // csdb",
		     operands);
    return "";
  }
}

static const char *
output_1094 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7470 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md"
{
    operands[3] = gen_rtx_REG (DImode, SPECULATION_TRACKER_REGNUM);
    output_asm_insn
      ("cmp\t%3, #0\n\tcsel\t%0, %1, %2, ne\n\tcsel\t%H0, %H1, %H2, ne\n\thint\t0x14 // csdb",
       operands);
    return "";
  }
}

static const char * const output_1136[] = {
  "dup\t%0.8b, %1.b[0]",
  "dup\t%0.8b, %w1",
};

static const char * const output_1137[] = {
  "dup\t%0.16b, %1.b[0]",
  "dup\t%0.16b, %w1",
};

static const char * const output_1138[] = {
  "dup\t%0.4h, %1.h[0]",
  "dup\t%0.4h, %w1",
};

static const char * const output_1139[] = {
  "dup\t%0.8h, %1.h[0]",
  "dup\t%0.8h, %w1",
};

static const char * const output_1140[] = {
  "dup\t%0.2s, %1.s[0]",
  "dup\t%0.2s, %w1",
};

static const char * const output_1141[] = {
  "dup\t%0.4s, %1.s[0]",
  "dup\t%0.4s, %w1",
};

static const char * const output_1142[] = {
  "dup\t%0.2d, %1.d[0]",
  "dup\t%0.2d, %x1",
};

static const char * const output_1143[] = {
  "dup\t%0.4h, %1.h[0]",
  "dup\t%0.4h, %w1",
};

static const char * const output_1144[] = {
  "dup\t%0.8h, %1.h[0]",
  "dup\t%0.8h, %w1",
};

static const char * const output_1145[] = {
  "dup\t%0.2s, %1.s[0]",
  "dup\t%0.2s, %w1",
};

static const char * const output_1146[] = {
  "dup\t%0.4s, %1.s[0]",
  "dup\t%0.4s, %w1",
};

static const char * const output_1147[] = {
  "dup\t%0.2d, %1.d[0]",
  "dup\t%0.2d, %x1",
};

static const char * const output_1148[] = {
  "dup\t%0.4h, %1.h[0]",
  "dup\t%0.4h, %w1",
};

static const char * const output_1149[] = {
  "dup\t%0.8h, %1.h[0]",
  "dup\t%0.8h, %w1",
};

static const char *
output_1150 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[2]));
    return "dup\t%0.8b, %1.b[%2]";
  }
}

static const char *
output_1151 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[2]));
    return "dup\t%0.16b, %1.b[%2]";
  }
}

static const char *
output_1152 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[2]));
    return "dup\t%0.4h, %1.h[%2]";
  }
}

static const char *
output_1153 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[2]));
    return "dup\t%0.8h, %1.h[%2]";
  }
}

static const char *
output_1154 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[2]));
    return "dup\t%0.2s, %1.s[%2]";
  }
}

static const char *
output_1155 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[2]));
    return "dup\t%0.4s, %1.s[%2]";
  }
}

static const char *
output_1156 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DImode, INTVAL (operands[2]));
    return "dup\t%0.2d, %1.d[%2]";
  }
}

static const char *
output_1157 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[2]));
    return "dup\t%0.4h, %1.h[%2]";
  }
}

static const char *
output_1158 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HFmode, INTVAL (operands[2]));
    return "dup\t%0.8h, %1.h[%2]";
  }
}

static const char *
output_1159 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4BFmode, INTVAL (operands[2]));
    return "dup\t%0.4h, %1.h[%2]";
  }
}

static const char *
output_1160 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8BFmode, INTVAL (operands[2]));
    return "dup\t%0.8h, %1.h[%2]";
  }
}

static const char *
output_1161 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[2]));
    return "dup\t%0.2s, %1.s[%2]";
  }
}

static const char *
output_1162 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[2]));
    return "dup\t%0.4s, %1.s[%2]";
  }
}

static const char *
output_1163 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 95 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[2]));
    return "dup\t%0.2d, %1.d[%2]";
  }
}

static const char *
output_1164 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[2]));
    return "dup\t%0.8b, %1.b[%2]";
  }
}

static const char *
output_1165 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[2]));
    return "dup\t%0.16b, %1.b[%2]";
  }
}

static const char *
output_1166 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[2]));
    return "dup\t%0.4h, %1.h[%2]";
  }
}

static const char *
output_1167 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[2]));
    return "dup\t%0.8h, %1.h[%2]";
  }
}

static const char *
output_1168 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[2]));
    return "dup\t%0.2s, %1.s[%2]";
  }
}

static const char *
output_1169 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[2]));
    return "dup\t%0.4s, %1.s[%2]";
  }
}

static const char *
output_1170 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HFmode, INTVAL (operands[2]));
    return "dup\t%0.4h, %1.h[%2]";
  }
}

static const char *
output_1171 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[2]));
    return "dup\t%0.8h, %1.h[%2]";
  }
}

static const char *
output_1172 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[2]));
    return "dup\t%0.2s, %1.s[%2]";
  }
}

static const char *
output_1173 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 110 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[2]));
    return "dup\t%0.4s, %1.s[%2]";
  }
}

static const char *
output_1174 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 125 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   switch (which_alternative)
     {
     case 0: return "ldr\t%d0, %1";
     case 1: return "str\txzr, %0";
     case 2: return "str\t%d1, %0";
     case 3: return "mov\t%0.8b, %1.8b";
     case 4: return "umov\t%0, %1.d[0]";
     case 5: return "fmov\t%d0, %1";
     case 6: return "mov\t%0, %1";
     case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 64);
     default: gcc_unreachable ();
     }
}
}

static const char *
output_1175 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 125 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   switch (which_alternative)
     {
     case 0: return "ldr\t%d0, %1";
     case 1: return "str\txzr, %0";
     case 2: return "str\t%d1, %0";
     case 3: return "mov\t%0.8b, %1.8b";
     case 4: return "umov\t%0, %1.d[0]";
     case 5: return "fmov\t%d0, %1";
     case 6: return "mov\t%0, %1";
     case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 64);
     default: gcc_unreachable ();
     }
}
}

static const char *
output_1176 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 125 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   switch (which_alternative)
     {
     case 0: return "ldr\t%d0, %1";
     case 1: return "str\txzr, %0";
     case 2: return "str\t%d1, %0";
     case 3: return "mov\t%0.8b, %1.8b";
     case 4: return "umov\t%0, %1.d[0]";
     case 5: return "fmov\t%d0, %1";
     case 6: return "mov\t%0, %1";
     case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 64);
     default: gcc_unreachable ();
     }
}
}

static const char *
output_1177 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 125 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   switch (which_alternative)
     {
     case 0: return "ldr\t%d0, %1";
     case 1: return "str\txzr, %0";
     case 2: return "str\t%d1, %0";
     case 3: return "mov\t%0.8b, %1.8b";
     case 4: return "umov\t%0, %1.d[0]";
     case 5: return "fmov\t%d0, %1";
     case 6: return "mov\t%0, %1";
     case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 64);
     default: gcc_unreachable ();
     }
}
}

static const char *
output_1178 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 125 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   switch (which_alternative)
     {
     case 0: return "ldr\t%d0, %1";
     case 1: return "str\txzr, %0";
     case 2: return "str\t%d1, %0";
     case 3: return "mov\t%0.8b, %1.8b";
     case 4: return "umov\t%0, %1.d[0]";
     case 5: return "fmov\t%d0, %1";
     case 6: return "mov\t%0, %1";
     case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 64);
     default: gcc_unreachable ();
     }
}
}

static const char *
output_1179 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 125 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   switch (which_alternative)
     {
     case 0: return "ldr\t%d0, %1";
     case 1: return "str\txzr, %0";
     case 2: return "str\t%d1, %0";
     case 3: return "mov\t%0.8b, %1.8b";
     case 4: return "umov\t%0, %1.d[0]";
     case 5: return "fmov\t%d0, %1";
     case 6: return "mov\t%0, %1";
     case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 64);
     default: gcc_unreachable ();
     }
}
}

static const char *
output_1180 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char *
output_1181 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char *
output_1182 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char *
output_1183 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char *
output_1184 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char *
output_1185 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char *
output_1186 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char *
output_1187 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 153 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  switch (which_alternative)
    {
    case 0:
	return "ldr\t%q0, %1";
    case 1:
	return "stp\txzr, xzr, %0";
    case 2:
	return "str\t%q1, %0";
    case 3:
	return "mov\t%0.16b, %1.16b";
    case 4:
    case 5:
    case 6:
	return "#";
    case 7:
	return aarch64_output_simd_mov_immediate (operands[1], 128);
    default:
	gcc_unreachable ();
    }
}
}

static const char * const output_1402[] = {
  "#",
  "umov\t%0, %1.d[0]",
};

static const char * const output_1403[] = {
  "#",
  "umov\t%0, %1.d[0]",
};

static const char * const output_1404[] = {
  "#",
  "umov\t%0, %1.d[0]",
};

static const char * const output_1405[] = {
  "#",
  "umov\t%0, %1.d[0]",
};

static const char * const output_1406[] = {
  "#",
  "umov\t%0, %1.d[0]",
};

static const char * const output_1407[] = {
  "#",
  "umov\t%0, %1.d[0]",
};

static const char * const output_1408[] = {
  "dup\t%d0, %1.d[1]",
  "umov\t%0, %1.d[1]",
};

static const char * const output_1409[] = {
  "dup\t%d0, %1.d[1]",
  "umov\t%0, %1.d[1]",
};

static const char * const output_1410[] = {
  "dup\t%d0, %1.d[1]",
  "umov\t%0, %1.d[1]",
};

static const char * const output_1411[] = {
  "dup\t%d0, %1.d[1]",
  "umov\t%0, %1.d[1]",
};

static const char * const output_1412[] = {
  "dup\t%d0, %1.d[1]",
  "umov\t%0, %1.d[1]",
};

static const char * const output_1413[] = {
  "dup\t%d0, %1.d[1]",
  "umov\t%0, %1.d[1]",
};

static const char *
output_1485 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #0";
}
}

static const char *
output_1486 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #90";
}
}

static const char *
output_1487 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #180";
}
}

static const char *
output_1488 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #270";
}
}

static const char *
output_1489 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #0";
}
}

static const char *
output_1490 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #90";
}
}

static const char *
output_1491 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #180";
}
}

static const char *
output_1492 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #270";
}
}

static const char *
output_1493 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2s, %2.2s, %3.2s, #0";
}
}

static const char *
output_1494 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2s, %2.2s, %3.2s, #90";
}
}

static const char *
output_1495 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2s, %2.2s, %3.2s, #180";
}
}

static const char *
output_1496 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2s, %2.2s, %3.2s, #270";
}
}

static const char *
output_1497 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #0";
}
}

static const char *
output_1498 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #90";
}
}

static const char *
output_1499 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #180";
}
}

static const char *
output_1500 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #270";
}
}

static const char *
output_1501 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (DFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2d, %2.2d, %3.<FCMLA_maybe_lane>, #0";
}
}

static const char *
output_1502 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (DFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2d, %2.2d, %3.<FCMLA_maybe_lane>, #90";
}
}

static const char *
output_1503 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (DFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2d, %2.2d, %3.<FCMLA_maybe_lane>, #180";
}
}

static const char *
output_1504 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 514 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (DFmode, INTVAL (operands[4]));
  return "fcmla\t%0.2d, %2.2d, %3.<FCMLA_maybe_lane>, #270";
}
}

static const char *
output_1505 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #0";
}
}

static const char *
output_1506 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #90";
}
}

static const char *
output_1507 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #180";
}
}

static const char *
output_1508 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));
  return "fcmla\t%0.4h, %2.4h, %3.h[%4], #270";
}
}

static const char *
output_1509 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V4HFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #0";
}
}

static const char *
output_1510 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V4HFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #90";
}
}

static const char *
output_1511 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V4HFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #180";
}
}

static const char *
output_1512 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V4HFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.8h, %2.8h, %3.h[%4], #270";
}
}

static const char *
output_1513 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V2SFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #0";
}
}

static const char *
output_1514 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V2SFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #90";
}
}

static const char *
output_1515 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V2SFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #180";
}
}

static const char *
output_1516 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 544 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V2SFmode).to_constant ();
  operands[4]
    = gen_int_mode (ENDIAN_LANE_N (nunits / 2, INTVAL (operands[4])), SImode);
  return "fcmla\t%0.4s, %2.4s, %3.s[%4], #270";
}
}

static const char *
output_1523 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 649 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[4]));
    return "sdot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1524 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 649 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[4]));
    return "udot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1525 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 649 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[4]));
    return "sdot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1526 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 649 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[4]));
    return "udot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1527 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 665 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[4]));
    return "sdot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1528 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 665 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[4]));
    return "udot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1529 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 665 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[4]));
    return "sdot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1530 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 665 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[4]));
    return "udot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1531 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V8QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "usdot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1532 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V8QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "sudot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1533 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V8QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "usdot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1534 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V8QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "sudot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1535 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V16QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "usdot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1536 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V16QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "sudot\t%0.2s, %2.8b, %3.4b[%4]";
  }
}

static const char *
output_1537 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V16QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "usdot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1538 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 683 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int nunits = GET_MODE_NUNITS (V16QImode).to_constant ();
    int lane = INTVAL (operands[4]);
    operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 4, lane), SImode);
    return "sudot\t%0.4s, %2.16b, %3.4b[%4]";
  }
}

static const char *
output_1539 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
    return "mul\t%0.4h, %1.4h, %2.h[%3]";
  }
}

static const char *
output_1540 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
    return "mul\t%0.8h, %1.8h, %2.h[%3]";
  }
}

static const char *
output_1541 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
    return "mul\t%0.2s, %1.2s, %2.s[%3]";
  }
}

static const char *
output_1542 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
    return "mul\t%0.4s, %1.4s, %2.s[%3]";
  }
}

static const char *
output_1543 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[3]));
    return "fmul\t%0.4h, %1.4h, %2.h[%3]";
  }
}

static const char *
output_1544 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[3]));
    return "fmul\t%0.8h, %1.8h, %2.h[%3]";
  }
}

static const char *
output_1545 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[3]));
    return "fmul\t%0.2s, %1.2s, %2.s[%3]";
  }
}

static const char *
output_1546 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 719 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[3]));
    return "fmul\t%0.4s, %1.4s, %2.s[%3]";
  }
}

static const char *
output_1547 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
    return "mul\t%0.4h, %1.4h, %2.h[%3]";
  }
}

static const char *
output_1548 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
    return "mul\t%0.8h, %1.8h, %2.h[%3]";
  }
}

static const char *
output_1549 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
    return "mul\t%0.2s, %1.2s, %2.s[%3]";
  }
}

static const char *
output_1550 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
    return "mul\t%0.4s, %1.4s, %2.s[%3]";
  }
}

static const char *
output_1551 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HFmode, INTVAL (operands[3]));
    return "fmul\t%0.4h, %1.4h, %2.h[%3]";
  }
}

static const char *
output_1552 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HFmode, INTVAL (operands[3]));
    return "fmul\t%0.8h, %1.8h, %2.h[%3]";
  }
}

static const char *
output_1553 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[3]));
    return "fmul\t%0.2s, %1.2s, %2.s[%3]";
  }
}

static const char *
output_1554 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[3]));
    return "fmul\t%0.4s, %1.4s, %2.s[%3]";
  }
}

static const char *
output_1555 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[3]));
    return "fmul\t%0.2d, %1.2d, %2.d[%3]";
  }
}

static const char *
output_1583 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[2]));
    return "fmul\t%0.2d, %3.2d, %1.d[%2]";
  }
}

static const char *
output_1674 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 984 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "and\t%0.8b, %1.8b, %2.8b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 64,
						  AARCH64_CHECK_BIC);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1675 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 984 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "and\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_BIC);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1676 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 984 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "and\t%0.8b, %1.8b, %2.8b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 64,
						  AARCH64_CHECK_BIC);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1677 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 984 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "and\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_BIC);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1678 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 984 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "and\t%0.8b, %1.8b, %2.8b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 64,
						  AARCH64_CHECK_BIC);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1679 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 984 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "and\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_BIC);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1680 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 984 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "and\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_BIC);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1681 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1005 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "orr\t%0.8b, %1.8b, %2.8b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 64,
						  AARCH64_CHECK_ORR);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1682 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1005 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "orr\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_ORR);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1683 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1005 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "orr\t%0.8b, %1.8b, %2.8b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 64,
						  AARCH64_CHECK_ORR);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1684 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1005 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "orr\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_ORR);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1685 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1005 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "orr\t%0.8b, %1.8b, %2.8b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 64,
						  AARCH64_CHECK_ORR);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1686 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1005 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "orr\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_ORR);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1687 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1005 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    switch (which_alternative)
      {
      case 0:
	return "orr\t%0.16b, %1.16b, %2.16b";
      case 1:
	return aarch64_output_simd_mov_immediate (operands[2], 128,
						  AARCH64_CHECK_ORR);
      default:
	gcc_unreachable ();
      }
  }
}

static const char *
output_1702 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.b[%p2], %1.b[0]";
     case 1:
	return "ins\t%0.b[%p2], %w1";
     case 2:
        return "ld1\t{%0.b}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1703 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (16, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.b[%p2], %1.b[0]";
     case 1:
	return "ins\t%0.b[%p2], %w1";
     case 2:
        return "ld1\t{%0.b}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1704 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.h[%p2], %1.h[0]";
     case 1:
	return "ins\t%0.h[%p2], %w1";
     case 2:
        return "ld1\t{%0.h}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1705 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.h[%p2], %1.h[0]";
     case 1:
	return "ins\t%0.h[%p2], %w1";
     case 2:
        return "ld1\t{%0.h}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1706 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.s[%p2], %1.s[0]";
     case 1:
	return "ins\t%0.s[%p2], %w1";
     case 2:
        return "ld1\t{%0.s}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1707 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.s[%p2], %1.s[0]";
     case 1:
	return "ins\t%0.s[%p2], %w1";
     case 2:
        return "ld1\t{%0.s}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1708 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.d[%p2], %1.d[0]";
     case 1:
	return "ins\t%0.d[%p2], %x1";
     case 2:
        return "ld1\t{%0.d}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1709 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.h[%p2], %1.h[0]";
     case 1:
	return "ins\t%0.h[%p2], %w1";
     case 2:
        return "ld1\t{%0.h}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1710 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.h[%p2], %1.h[0]";
     case 1:
	return "ins\t%0.h[%p2], %w1";
     case 2:
        return "ld1\t{%0.h}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1711 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.h[%p2], %1.h[0]";
     case 1:
	return "ins\t%0.h[%p2], %w1";
     case 2:
        return "ld1\t{%0.h}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1712 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.h[%p2], %1.h[0]";
     case 1:
	return "ins\t%0.h[%p2], %w1";
     case 2:
        return "ld1\t{%0.h}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1713 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.s[%p2], %1.s[0]";
     case 1:
	return "ins\t%0.s[%p2], %w1";
     case 2:
        return "ld1\t{%0.s}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1714 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.s[%p2], %1.s[0]";
     case 1:
	return "ins\t%0.s[%p2], %w1";
     case 2:
        return "ld1\t{%0.s}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1715 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1045 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
   int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
   operands[2] = GEN_INT ((HOST_WIDE_INT) 1 << elt);
   switch (which_alternative)
     {
     case 0:
	return "ins\t%0.d[%p2], %1.d[0]";
     case 1:
	return "ins\t%0.d[%p2], %x1";
     case 2:
        return "ld1\t{%0.d}[%p2], %1";
     default:
	gcc_unreachable ();
     }
  }
}

static const char *
output_1716 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[4]));

    return "ins\t%0.b[%p2], %3.b[%4]";
  }
}

static const char *
output_1717 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (16, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[4]));

    return "ins\t%0.b[%p2], %3.b[%4]";
  }
}

static const char *
output_1718 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1719 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1720 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char *
output_1721 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char *
output_1722 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V2DImode, INTVAL (operands[4]));

    return "ins\t%0.d[%p2], %3.d[%4]";
  }
}

static const char *
output_1723 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1724 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V8HFmode, INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1725 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4BFmode, INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1726 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V8BFmode, INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1727 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char *
output_1728 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char *
output_1729 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1074 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[4]));

    return "ins\t%0.d[%p2], %3.d[%4]";
  }
}

static const char *
output_1730 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[4]));

    return "ins\t%0.b[%p2], %3.b[%4]";
  }
}

static const char *
output_1731 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (16, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[4]));

    return "ins\t%0.b[%p2], %3.b[%4]";
  }
}

static const char *
output_1732 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1733 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1734 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4SImode,
					   INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char *
output_1735 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V2SImode,
					   INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char *
output_1736 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V8HFmode,
					   INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1737 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (8, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4HFmode,
					   INTVAL (operands[4]));

    return "ins\t%0.h[%p2], %3.h[%4]";
  }
}

static const char *
output_1738 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (2, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V4SFmode,
					   INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char *
output_1739 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1095 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int elt = ENDIAN_LANE_N (4, exact_log2 (INTVAL (operands[2])));
    operands[2] = GEN_INT (HOST_WIDE_INT_1 << elt);
    operands[4] = aarch64_endian_lane_rtx (V2SFmode,
					   INTVAL (operands[4]));

    return "ins\t%0.s[%p2], %3.s[%4]";
  }
}

static const char * const output_1747[] = {
  "cmlt\t%0.8b, %1.8b, #0",
  "sshr\t%0.8b, %1.8b, %2",
};

static const char * const output_1748[] = {
  "cmlt\t%0.16b, %1.16b, #0",
  "sshr\t%0.16b, %1.16b, %2",
};

static const char * const output_1749[] = {
  "cmlt\t%0.4h, %1.4h, #0",
  "sshr\t%0.4h, %1.4h, %2",
};

static const char * const output_1750[] = {
  "cmlt\t%0.8h, %1.8h, #0",
  "sshr\t%0.8h, %1.8h, %2",
};

static const char * const output_1751[] = {
  "cmlt\t%0.2s, %1.2s, #0",
  "sshr\t%0.2s, %1.2s, %2",
};

static const char * const output_1752[] = {
  "cmlt\t%0.4s, %1.4s, #0",
  "sshr\t%0.4s, %1.4s, %2",
};

static const char * const output_1753[] = {
  "cmlt\t%0.2d, %1.2d, #0",
  "sshr\t%0.2d, %1.2d, %2",
};

static const char *
output_1796 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (BYTES_BIG_ENDIAN)
      return "shl %d0, %d1, %2";
    else
      return "ushr %d0, %d1, %2";
  }
}

static const char *
output_1797 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (BYTES_BIG_ENDIAN)
      return "shl %d0, %d1, %2";
    else
      return "ushr %d0, %d1, %2";
  }
}

static const char *
output_1798 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (BYTES_BIG_ENDIAN)
      return "shl %d0, %d1, %2";
    else
      return "ushr %d0, %d1, %2";
  }
}

static const char *
output_1799 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (BYTES_BIG_ENDIAN)
      return "shl %d0, %d1, %2";
    else
      return "ushr %d0, %d1, %2";
  }
}

static const char *
output_1800 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (BYTES_BIG_ENDIAN)
      return "shl %d0, %d1, %2";
    else
      return "ushr %d0, %d1, %2";
  }
}

static const char *
output_1801 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1369 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (BYTES_BIG_ENDIAN)
      return "shl %d0, %d1, %2";
    else
      return "ushr %d0, %d1, %2";
  }
}

static const char *
output_1808 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1414 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[2]));
    return "mla\t%0.4h, %3.4h, %1.h[%2]";
  }
}

static const char *
output_1809 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1414 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[2]));
    return "mla\t%0.8h, %3.8h, %1.h[%2]";
  }
}

static const char *
output_1810 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1414 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[2]));
    return "mla\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_1811 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1414 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[2]));
    return "mla\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_1812 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1432 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[2]));
    return "mla\t%0.4h, %3.4h, %1.h[%2]";
  }
}

static const char *
output_1813 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1432 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[2]));
    return "mla\t%0.8h, %3.8h, %1.h[%2]";
  }
}

static const char *
output_1814 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1432 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[2]));
    return "mla\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_1815 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1432 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[2]));
    return "mla\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_1826 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1473 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[2]));
    return "mls\t%0.4h, %3.4h, %1.h[%2]";
  }
}

static const char *
output_1827 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1473 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[2]));
    return "mls\t%0.8h, %3.8h, %1.h[%2]";
  }
}

static const char *
output_1828 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1473 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[2]));
    return "mls\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_1829 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1473 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[2]));
    return "mls\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_1830 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1491 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[2]));
    return "mls\t%0.4h, %3.4h, %1.h[%2]";
  }
}

static const char *
output_1831 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1491 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[2]));
    return "mls\t%0.8h, %3.8h, %1.h[%2]";
  }
}

static const char *
output_1832 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1491 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[2]));
    return "mls\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_1833 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1491 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[2]));
    return "mls\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_1918 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1669 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  if (!BYTES_BIG_ENDIAN)
    return "uzp1\t%0.16b, %1.16b, %2.16b";
  else
    return "uzp1\t%0.16b, %2.16b, %1.16b";
}
}

static const char *
output_1919 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1669 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  if (!BYTES_BIG_ENDIAN)
    return "uzp1\t%0.8h, %1.8h, %2.8h";
  else
    return "uzp1\t%0.8h, %2.8h, %1.8h";
}
}

static const char *
output_1920 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1669 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  if (!BYTES_BIG_ENDIAN)
    return "uzp1\t%0.4s, %1.4s, %2.4s";
  else
    return "uzp1\t%0.4s, %2.4s, %1.4s";
}
}

static const char *
output_2057 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
    return "smull\t%0.4s, %1.4h, %2.h[%3]";
  }
}

static const char *
output_2058 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
    return "umull\t%0.4s, %1.4h, %2.h[%3]";
  }
}

static const char *
output_2059 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
    return "smull\t%0.4s, %1.4h, %2.h[%3]";
  }
}

static const char *
output_2060 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
    return "umull\t%0.4s, %1.4h, %2.h[%3]";
  }
}

static const char *
output_2061 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
    return "smull\t%0.2d, %1.2s, %2.s[%3]";
  }
}

static const char *
output_2062 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
    return "umull\t%0.2d, %1.2s, %2.s[%3]";
  }
}

static const char *
output_2063 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
    return "smull\t%0.2d, %1.2s, %2.s[%3]";
  }
}

static const char *
output_2064 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2328 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
    return "umull\t%0.2d, %1.2s, %2.s[%3]";
  }
}

static const char *
output_2065 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2348 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return "smull2\t%0.4s, %1.8h, %3.h[%4]";
  }
}

static const char *
output_2066 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2348 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return "umull2\t%0.4s, %1.8h, %3.h[%4]";
  }
}

static const char *
output_2067 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2348 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return "smull2\t%0.2d, %1.4s, %3.s[%4]";
  }
}

static const char *
output_2068 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2348 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return "umull2\t%0.2d, %1.4s, %3.s[%4]";
  }
}

static const char *
output_2069 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2382 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return "smull2\t%0.4s, %1.8h, %3.h[%4]";
  }
}

static const char *
output_2070 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2382 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return "umull2\t%0.4s, %1.8h, %3.h[%4]";
  }
}

static const char *
output_2071 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2382 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return "smull2\t%0.2d, %1.4s, %3.s[%4]";
  }
}

static const char *
output_2072 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2382 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return "umull2\t%0.2d, %1.4s, %3.s[%4]";
  }
}

static const char *
output_2081 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return "smlal\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2082 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return "umlal\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2083 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return "smlal\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2084 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return "umlal\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2085 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return "smlal\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2086 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return "umlal\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2087 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return "smlal\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2088 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2458 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return "umlal\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2089 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2480 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[5]));
    return "smlal2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2090 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2480 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[5]));
    return "umlal2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2091 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2480 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[5]));
    return "smlal2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2092 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2480 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[5]));
    return "umlal2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2093 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2517 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[5]));
    return "smlal2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2094 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2517 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[5]));
    return "umlal2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2095 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2517 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[5]));
    return "smlal2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2096 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2517 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[5]));
    return "umlal2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2097 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return "smlsl\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2098 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return "umlsl\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2099 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return "smlsl\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2100 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return "umlsl\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2101 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return "smlsl\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2102 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return "umlsl\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2103 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return "smlsl\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2104 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2552 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return "umlsl\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2105 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2575 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[5]));
    return "smlsl2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2106 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2575 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[5]));
    return "umlsl2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2107 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2575 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[5]));
    return "smlsl2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2108 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2575 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[5]));
    return "umlsl2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2109 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2613 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[5]));
    return "smlsl2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2110 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2613 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[5]));
    return "umlsl2\t%0.4s, %2.8h, %4.h[%5]";
  }
}

static const char *
output_2111 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2613 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[5]));
    return "smlsl2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2112 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2613 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[5] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[5]));
    return "umlsl2\t%0.2d, %2.4s, %4.s[%5]";
  }
}

static const char *
output_2148 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2890 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[2]));
    return "fmla\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_2149 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2890 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[2]));
    return "fmla\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_2150 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2890 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[2]));
    return "fmla\t%0.2d, %3.2d, %1.d[%2]";
  }
}

static const char *
output_2151 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2907 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[2]));
    return "fmla\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_2152 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2907 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[2]));
    return "fmla\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_2162 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2935 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[2]));
    return "fmla\t%0.2d, %3.2d, %1.d[%2]";
  }
}

static const char *
output_2168 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[2]));
    return "fmls\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_2169 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[2]));
    return "fmls\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_2170 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[2]));
    return "fmls\t%0.2d, %3.2d, %1.d[%2]";
  }
}

static const char *
output_2171 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2982 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[2]));
    return "fmls\t%0.2s, %3.2s, %1.s[%2]";
  }
}

static const char *
output_2172 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2982 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[2]));
    return "fmls\t%0.4s, %3.4s, %1.s[%2]";
  }
}

static const char *
output_2182 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3012 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[2]));
    return "fmls\t%0.2d, %3.2d, %1.d[%2]";
  }
}

static const char *
output_2282 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3078 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int fbits = aarch64_vec_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzs\t%%0.2s, %%1.2s, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_2283 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3078 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int fbits = aarch64_vec_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzu\t%%0.2s, %%1.2s, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_2284 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3078 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int fbits = aarch64_vec_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzs\t%%0.4s, %%1.4s, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_2285 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3078 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int fbits = aarch64_vec_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzu\t%%0.4s, %%1.4s, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_2286 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3078 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int fbits = aarch64_vec_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzs\t%%0.2d, %%1.2d, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char *
output_2287 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 3078 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    int fbits = aarch64_vec_fpconst_pow_of_2 (operands[2]);
    char buf[64];
    snprintf (buf, 64, "fcvtzu\t%%0.2d, %%1.2d, #%d", fbits);
    output_asm_insn (buf, operands);
    return "";
  }
}

static const char * const output_2468[] = {
  "bsl\t%0.8b, %2.8b, %3.8b",
  "bit\t%0.8b, %2.8b, %1.8b",
  "bif\t%0.8b, %3.8b, %1.8b",
};

static const char * const output_2469[] = {
  "bsl\t%0.16b, %2.16b, %3.16b",
  "bit\t%0.16b, %2.16b, %1.16b",
  "bif\t%0.16b, %3.16b, %1.16b",
};

static const char * const output_2470[] = {
  "bsl\t%0.8b, %2.8b, %3.8b",
  "bit\t%0.8b, %2.8b, %1.8b",
  "bif\t%0.8b, %3.8b, %1.8b",
};

static const char * const output_2471[] = {
  "bsl\t%0.16b, %2.16b, %3.16b",
  "bit\t%0.16b, %2.16b, %1.16b",
  "bif\t%0.16b, %3.16b, %1.16b",
};

static const char * const output_2472[] = {
  "bsl\t%0.8b, %2.8b, %3.8b",
  "bit\t%0.8b, %2.8b, %1.8b",
  "bif\t%0.8b, %3.8b, %1.8b",
};

static const char * const output_2473[] = {
  "bsl\t%0.16b, %2.16b, %3.16b",
  "bit\t%0.16b, %2.16b, %1.16b",
  "bif\t%0.16b, %3.16b, %1.16b",
};

static const char * const output_2474[] = {
  "bsl\t%0.16b, %2.16b, %3.16b",
  "bit\t%0.16b, %2.16b, %1.16b",
  "bif\t%0.16b, %3.16b, %1.16b",
};

static const char * const output_2475[] = {
  "bsl\t%0.8b, %3.8b, %2.8b",
  "bit\t%0.8b, %3.8b, %1.8b",
  "bif\t%0.8b, %2.8b, %1.8b",
};

static const char * const output_2476[] = {
  "bsl\t%0.16b, %3.16b, %2.16b",
  "bit\t%0.16b, %3.16b, %1.16b",
  "bif\t%0.16b, %2.16b, %1.16b",
};

static const char * const output_2477[] = {
  "bsl\t%0.8b, %3.8b, %2.8b",
  "bit\t%0.8b, %3.8b, %1.8b",
  "bif\t%0.8b, %2.8b, %1.8b",
};

static const char * const output_2478[] = {
  "bsl\t%0.16b, %3.16b, %2.16b",
  "bit\t%0.16b, %3.16b, %1.16b",
  "bif\t%0.16b, %2.16b, %1.16b",
};

static const char * const output_2479[] = {
  "bsl\t%0.8b, %3.8b, %2.8b",
  "bit\t%0.8b, %3.8b, %1.8b",
  "bif\t%0.8b, %2.8b, %1.8b",
};

static const char * const output_2480[] = {
  "bsl\t%0.16b, %3.16b, %2.16b",
  "bit\t%0.16b, %3.16b, %1.16b",
  "bif\t%0.16b, %2.16b, %1.16b",
};

static const char * const output_2481[] = {
  "bsl\t%0.16b, %3.16b, %2.16b",
  "bit\t%0.16b, %3.16b, %1.16b",
  "bif\t%0.16b, %2.16b, %1.16b",
};

static const char * const output_2482[] = {
  "bsl\t%0.8b, %2.8b, %3.8b",
  "bit\t%0.8b, %2.8b, %1.8b",
  "bif\t%0.8b, %3.8b, %1.8b",
  "#",
};

static const char * const output_2483[] = {
  "bsl\t%0.8b, %3.8b, %2.8b",
  "bit\t%0.8b, %3.8b, %1.8b",
  "bif\t%0.8b, %2.8b, %1.8b",
  "#",
};

static const char *
output_2484 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[2]));
    return "smov\t%w0, %1.b[%2]";
  }
}

static const char *
output_2485 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[2]));
    return "smov\t%x0, %1.b[%2]";
  }
}

static const char *
output_2486 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[2]));
    return "smov\t%w0, %1.b[%2]";
  }
}

static const char *
output_2487 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[2]));
    return "smov\t%x0, %1.b[%2]";
  }
}

static const char *
output_2488 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[2]));
    return "smov\t%w0, %1.h[%2]";
  }
}

static const char *
output_2489 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[2]));
    return "smov\t%x0, %1.h[%2]";
  }
}

static const char *
output_2490 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[2]));
    return "smov\t%w0, %1.h[%2]";
  }
}

static const char *
output_2491 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4172 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[2]));
    return "smov\t%x0, %1.h[%2]";
  }
}

static const char *
output_2492 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.b[%2]";
  }
}

static const char *
output_2493 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.b[%2]";
  }
}

static const char *
output_2494 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.b[%2]";
  }
}

static const char *
output_2495 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.b[%2]";
  }
}

static const char *
output_2496 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.h[%2]";
  }
}

static const char *
output_2497 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.h[%2]";
  }
}

static const char *
output_2498 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.h[%2]";
  }
}

static const char *
output_2499 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4187 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[2]));
    return "umov\t%w0, %1.h[%2]";
  }
}

static const char *
output_2500 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.b[%2]";
	case 1:
	  return "dup\t%b0, %1.b[%2]";
	case 2:
	  return "st1\t{%1.b}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2501 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.b[%2]";
	case 1:
	  return "dup\t%b0, %1.b[%2]";
	case 2:
	  return "st1\t{%1.b}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2502 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2503 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2504 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[%2]";
	case 1:
	  return "dup\t%s0, %1.s[%2]";
	case 2:
	  return "st1\t{%1.s}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2505 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[%2]";
	case 1:
	  return "dup\t%s0, %1.s[%2]";
	case 2:
	  return "st1\t{%1.s}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2506 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DImode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%x0, %1.d[%2]";
	case 1:
	  return "dup\t%d0, %1.d[%2]";
	case 2:
	  return "st1\t{%1.d}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2507 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HFmode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2508 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HFmode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2509 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4BFmode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2510 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8BFmode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2511 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[%2]";
	case 1:
	  return "dup\t%s0, %1.s[%2]";
	case 2:
	  return "st1\t{%1.s}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2512 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[%2]";
	case 1:
	  return "dup\t%s0, %1.s[%2]";
	case 2:
	  return "st1\t{%1.s}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_2513 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4206 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[2]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%x0, %1.d[%2]";
	case 1:
	  return "dup\t%d0, %1.d[%2]";
	case 2:
	  return "st1\t{%1.d}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char * const output_2524[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2525[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2526[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2527[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2528[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2529[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2530[] = {
  "stp\t%s1, %s2, %y0",
  "stp\t%w1, %w2, %y0",
};

static const char * const output_2531[] = {
  "stp\t%s1, %s2, %y0",
  "stp\t%w1, %w2, %y0",
};

static const char * const output_2532[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2533[] = {
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2534[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2535[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2536[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2537[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2538[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2539[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2540[] = {
  "ins\t%0.s[1], %2.s[0]",
  "ins\t%0.s[1], %w2",
  "ld1\t{%0.s}[1], %2",
  "stp\t%s1, %s2, %y0",
  "stp\t%w1, %w2, %y0",
};

static const char * const output_2541[] = {
  "ins\t%0.s[1], %2.s[0]",
  "ins\t%0.s[1], %w2",
  "ld1\t{%0.s}[1], %2",
  "stp\t%s1, %s2, %y0",
  "stp\t%w1, %w2, %y0",
};

static const char * const output_2542[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2543[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d1, %d2, %y0",
  "stp\t%x1, %x2, %y0",
};

static const char * const output_2544[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2545[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2546[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2547[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2548[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2549[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2550[] = {
  "ins\t%0.s[1], %2.s[0]",
  "ins\t%0.s[1], %w2",
  "ld1\t{%0.s}[1], %2",
  "stp\t%s2, %s1, %y0",
  "stp\t%w2, %w1, %y0",
};

static const char * const output_2551[] = {
  "ins\t%0.s[1], %2.s[0]",
  "ins\t%0.s[1], %w2",
  "ld1\t{%0.s}[1], %2",
  "stp\t%s2, %s1, %y0",
  "stp\t%w2, %w1, %y0",
};

static const char * const output_2552[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2553[] = {
  "ins\t%0.d[1], %2.d[0]",
  "ins\t%0.d[1], %x2",
  "ld1\t{%0.d}[1], %2",
  "stp\t%d2, %d1, %y0",
  "stp\t%x2, %x1, %y0",
};

static const char * const output_2554[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2555[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2556[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2557[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2558[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2559[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2560[] = {
  "fmov\t%s0, %s1",
  "fmov\t%s0, %w1",
  "ldr\t%s0, %1",
};

static const char * const output_2561[] = {
  "fmov\t%s0, %s1",
  "fmov\t%s0, %w1",
  "ldr\t%s0, %1",
};

static const char * const output_2562[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2563[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2564[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2565[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2566[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2567[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2568[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2569[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2570[] = {
  "fmov\t%s0, %s1",
  "fmov\t%s0, %w1",
  "ldr\t%s0, %1",
};

static const char * const output_2571[] = {
  "fmov\t%s0, %s1",
  "fmov\t%s0, %w1",
  "ldr\t%s0, %1",
};

static const char * const output_2572[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char * const output_2573[] = {
  "fmov\t%d0, %d1",
  "fmov\t%d0, %x1",
  "ldr\t%d0, %1",
};

static const char *
output_2742 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4909 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[3]));
    return "fmulx\t%0.2s, %1.2s, %2.s[%3]";
  }
}

static const char *
output_2743 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4909 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[3]));
    return "fmulx\t%0.4s, %1.4s, %2.s[%3]";
  }
}

static const char *
output_2744 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4928 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[3]));
    return "fmulx\t%0.2s, %1.2s, %2.s[%3]";
  }
}

static const char *
output_2745 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4928 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[3]));
    return "fmulx\t%0.4s, %1.4s, %2.s[%3]";
  }
}

static const char *
output_2746 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4928 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[3]));
    return "fmulx\t%0.2d, %1.2d, %2.d[%3]";
  }
}

static const char *
output_2752 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4962 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode, INTVAL (operands[3]));
    return "fmulx\t%s0, %s1, %2.s[%3]";
  }
}

static const char *
output_2753 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4962 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode, INTVAL (operands[3]));
    return "fmulx\t%s0, %s1, %2.s[%3]";
  }
}

static const char *
output_2754 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 4962 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DFmode, INTVAL (operands[3]));
    return "fmulx\t%d0, %d1, %2.d[%3]";
  }
}

static const char *
output_2908 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.4h, %1.4h, %2.h[%3]";
}

static const char *
output_2909 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.4h, %1.4h, %2.h[%3]";
}

static const char *
output_2910 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.8h, %1.8h, %2.h[%3]";
}

static const char *
output_2911 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.8h, %1.8h, %2.h[%3]";
}

static const char *
output_2912 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.2s, %1.2s, %2.s[%3]";
}

static const char *
output_2913 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.2s, %1.2s, %2.s[%3]";
}

static const char *
output_2914 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.4s, %1.4s, %2.s[%3]";
}

static const char *
output_2915 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5226 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.4s, %1.4s, %2.s[%3]";
}

static const char *
output_2916 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.4h, %1.4h, %2.h[%3]";
}

static const char *
output_2917 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.4h, %1.4h, %2.h[%3]";
}

static const char *
output_2918 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.8h, %1.8h, %2.h[%3]";
}

static const char *
output_2919 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.8h, %1.8h, %2.h[%3]";
}

static const char *
output_2920 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.2s, %1.2s, %2.s[%3]";
}

static const char *
output_2921 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.2s, %1.2s, %2.s[%3]";
}

static const char *
output_2922 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
   return "sqdmulh\t%0.4s, %1.4s, %2.s[%3]";
}

static const char *
output_2923 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5241 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
   return "sqrdmulh\t%0.4s, %1.4s, %2.s[%3]";
}

static const char *
output_2924 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
   return "sqdmulh\t%h0, %h1, %2.h[%3]";
}

static const char *
output_2925 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
   return "sqrdmulh\t%h0, %h1, %2.h[%3]";
}

static const char *
output_2926 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
   return "sqdmulh\t%s0, %s1, %2.s[%3]";
}

static const char *
output_2927 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5256 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
   return "sqrdmulh\t%s0, %s1, %2.s[%3]";
}

static const char *
output_2928 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5271 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
   return "sqdmulh\t%h0, %h1, %2.h[%3]";
}

static const char *
output_2929 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5271 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
   return "sqrdmulh\t%h0, %h1, %2.h[%3]";
}

static const char *
output_2930 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5271 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
   return "sqdmulh\t%s0, %s1, %2.s[%3]";
}

static const char *
output_2931 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5271 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"

   operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
   return "sqrdmulh\t%s0, %s1, %2.s[%3]";
}

static const char *
output_2944 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.4h, %2.4h, %3.h[%4]";
   }
}

static const char *
output_2945 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.4h, %2.4h, %3.h[%4]";
   }
}

static const char *
output_2946 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.8h, %2.8h, %3.h[%4]";
   }
}

static const char *
output_2947 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.8h, %2.8h, %3.h[%4]";
   }
}

static const char *
output_2948 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.2s, %2.2s, %3.s[%4]";
   }
}

static const char *
output_2949 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.2s, %2.2s, %3.s[%4]";
   }
}

static const char *
output_2950 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.4s, %2.4s, %3.s[%4]";
   }
}

static const char *
output_2951 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5303 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.4s, %2.4s, %3.s[%4]";
   }
}

static const char *
output_2952 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5321 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%h0, %h2, %3.h[%4]";
   }
}

static const char *
output_2953 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5321 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%h0, %h2, %3.h[%4]";
   }
}

static const char *
output_2954 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5321 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%s0, %s2, %3.s[%4]";
   }
}

static const char *
output_2955 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5321 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%s0, %s2, %3.s[%4]";
   }
}

static const char *
output_2956 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.4h, %2.4h, %3.h[%4]";
   }
}

static const char *
output_2957 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.4h, %2.4h, %3.h[%4]";
   }
}

static const char *
output_2958 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.8h, %2.8h, %3.h[%4]";
   }
}

static const char *
output_2959 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.8h, %2.8h, %3.h[%4]";
   }
}

static const char *
output_2960 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.2s, %2.2s, %3.s[%4]";
   }
}

static const char *
output_2961 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.2s, %2.2s, %3.s[%4]";
   }
}

static const char *
output_2962 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%0.4s, %2.4s, %3.s[%4]";
   }
}

static const char *
output_2963 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5341 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%0.4s, %2.4s, %3.s[%4]";
   }
}

static const char *
output_2964 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5359 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%h0, %h2, %3.h[%4]";
   }
}

static const char *
output_2965 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5359 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%h0, %h2, %3.h[%4]";
   }
}

static const char *
output_2966 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5359 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
     return
      "sqrdmlah\t%s0, %s2, %3.s[%4]";
   }
}

static const char *
output_2967 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5359 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
     operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
     return
      "sqrdmlsh\t%s0, %s2, %3.s[%4]";
   }
}

static const char *
output_2976 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5419 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2977 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5419 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2978 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5443 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2979 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5443 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2980 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5468 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2981 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5468 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2982 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5492 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%0.4s, %2.4h, %3.h[%4]";
  }
}

static const char *
output_2983 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5492 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%0.2d, %2.2s, %3.s[%4]";
  }
}

static const char *
output_2984 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5516 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%s0, %h2, %3.h[%4]";
  }
}

static const char *
output_2985 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5516 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%d0, %s2, %3.s[%4]";
  }
}

static const char *
output_2986 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%s0, %h2, %3.h[%4]";
  }
}

static const char *
output_2987 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5539 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%d0, %s2, %3.s[%4]";
  }
}

static const char *
output_2988 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5563 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%s0, %h2, %3.h[%4]";
  }
}

static const char *
output_2989 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5563 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return
      "sqdmlal\t%d0, %s2, %3.s[%4]";
  }
}

static const char *
output_2990 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5586 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%s0, %h2, %3.h[%4]";
  }
}

static const char *
output_2991 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5586 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return
      "sqdmlsl\t%d0, %s2, %3.s[%4]";
  }
}

static const char *
output_3000 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5709 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return
     "sqdmlsl2\t%0.4s, %2.8h, %3.h[%4]";
  }
}

static const char *
output_3001 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5709 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return
     "sqdmlsl2\t%0.2d, %2.4s, %3.s[%4]";
  }
}

static const char *
output_3002 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[4]));
    return
     "sqdmlal2\t%0.4s, %2.8h, %3.h[%4]";
  }
}

static const char *
output_3003 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5735 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[4]));
    return
     "sqdmlal2\t%0.2d, %2.4s, %3.s[%4]";
  }
}

static const char *
output_3004 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5761 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return
     "sqdmlsl2\t%0.4s, %2.8h, %3.h[%4]";
  }
}

static const char *
output_3005 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5761 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return
     "sqdmlsl2\t%0.2d, %2.4s, %3.s[%4]";
  }
}

static const char *
output_3006 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5787 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[4]));
    return
     "sqdmlal2\t%0.4s, %2.8h, %3.h[%4]";
  }
}

static const char *
output_3007 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5787 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[4] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[4]));
    return
     "sqdmlal2\t%0.2d, %2.4s, %3.s[%4]";
  }
}

static const char *
output_3016 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5915 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
    return "sqdmull\t%0.4s, %1.4h, %2.h[%3]";
  }
}

static const char *
output_3017 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5915 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
    return "sqdmull\t%0.2d, %1.2s, %2.s[%3]";
  }
}

static const char *
output_3018 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5936 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
    return "sqdmull\t%0.4s, %1.4h, %2.h[%3]";
  }
}

static const char *
output_3019 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5936 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
    return "sqdmull\t%0.2d, %1.2s, %2.s[%3]";
  }
}

static const char *
output_3020 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5956 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
    return "sqdmull\t%s0, %h1, %2.h[%3]";
  }
}

static const char *
output_3021 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5956 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
    return "sqdmull\t%d0, %s1, %2.s[%3]";
  }
}

static const char *
output_3022 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5976 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
    return "sqdmull\t%s0, %h1, %2.h[%3]";
  }
}

static const char *
output_3023 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 5976 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
    return "sqdmull\t%d0, %s1, %2.s[%3]";
  }
}

static const char *
output_3028 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6052 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode, INTVAL (operands[3]));
    return "sqdmull2\t%0.4s, %1.8h, %2.h[%3]";
  }
}

static const char *
output_3029 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6052 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode, INTVAL (operands[3]));
    return "sqdmull2\t%0.2d, %1.4s, %2.s[%3]";
  }
}

static const char *
output_3030 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6075 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode, INTVAL (operands[3]));
    return "sqdmull2\t%0.4s, %1.8h, %2.h[%3]";
  }
}

static const char *
output_3031 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6075 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode, INTVAL (operands[3]));
    return "sqdmull2\t%0.2d, %1.4s, %2.s[%3]";
  }
}

static const char *
output_3110 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6210 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V16QImode))
      return "shll\t%0.8h, %1.8b, %3";
    else
      return "sshll\t%0.8h, %1.8b, %3";
  }
}

static const char *
output_3111 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6210 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V16QImode))
      return "shll\t%0.8h, %1.8b, %3";
    else
      return "ushll\t%0.8h, %1.8b, %3";
  }
}

static const char *
output_3112 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6210 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V8HImode))
      return "shll\t%0.4s, %1.4h, %3";
    else
      return "sshll\t%0.4s, %1.4h, %3";
  }
}

static const char *
output_3113 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6210 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V8HImode))
      return "shll\t%0.4s, %1.4h, %3";
    else
      return "ushll\t%0.4s, %1.4h, %3";
  }
}

static const char *
output_3114 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6210 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V4SImode))
      return "shll\t%0.2d, %1.2s, %3";
    else
      return "sshll\t%0.2d, %1.2s, %3";
  }
}

static const char *
output_3115 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6210 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V4SImode))
      return "shll\t%0.2d, %1.2s, %3";
    else
      return "ushll\t%0.2d, %1.2s, %3";
  }
}

static const char *
output_3116 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6228 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V16QImode))
      return "shll2\t%0.8h, %1.16b, %3";
    else
      return "sshll2\t%0.8h, %1.16b, %3";
  }
}

static const char *
output_3117 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6228 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V16QImode))
      return "shll2\t%0.8h, %1.16b, %3";
    else
      return "ushll2\t%0.8h, %1.16b, %3";
  }
}

static const char *
output_3118 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6228 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V8HImode))
      return "shll2\t%0.4s, %1.8h, %3";
    else
      return "sshll2\t%0.4s, %1.8h, %3";
  }
}

static const char *
output_3119 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6228 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V8HImode))
      return "shll2\t%0.4s, %1.8h, %3";
    else
      return "ushll2\t%0.4s, %1.8h, %3";
  }
}

static const char *
output_3120 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6228 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V4SImode))
      return "shll2\t%0.2d, %1.4s, %3";
    else
      return "sshll2\t%0.2d, %1.4s, %3";
  }
}

static const char *
output_3121 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6228 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[3]) == GET_MODE_UNIT_BITSIZE (V4SImode))
      return "shll2\t%0.2d, %1.4s, %3";
    else
      return "ushll2\t%0.2d, %1.4s, %3";
  }
}

static const char *
output_3122 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6244 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V8QImode))
      return "shll\t%0.8h, %1.8b, %2";
    else
      return "sshll\t%0.8h, %1.8b, %2";
  }
}

static const char *
output_3123 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6244 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V8QImode))
      return "shll\t%0.8h, %1.8b, %2";
    else
      return "ushll\t%0.8h, %1.8b, %2";
  }
}

static const char *
output_3124 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6244 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V4HImode))
      return "shll\t%0.4s, %1.4h, %2";
    else
      return "sshll\t%0.4s, %1.4h, %2";
  }
}

static const char *
output_3125 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6244 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V4HImode))
      return "shll\t%0.4s, %1.4h, %2";
    else
      return "ushll\t%0.4s, %1.4h, %2";
  }
}

static const char *
output_3126 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6244 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V2SImode))
      return "shll\t%0.2d, %1.2s, %2";
    else
      return "sshll\t%0.2d, %1.2s, %2";
  }
}

static const char *
output_3127 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6244 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V2SImode))
      return "shll\t%0.2d, %1.2s, %2";
    else
      return "ushll\t%0.2d, %1.2s, %2";
  }
}

static const char *
output_3128 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6261 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V16QImode))
      return "shll2\t%0.8h, %1.16b, %2";
    else
      return "sshll2\t%0.8h, %1.16b, %2";
  }
}

static const char *
output_3129 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6261 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V16QImode))
      return "shll2\t%0.8h, %1.16b, %2";
    else
      return "ushll2\t%0.8h, %1.16b, %2";
  }
}

static const char *
output_3130 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6261 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V8HImode))
      return "shll2\t%0.4s, %1.8h, %2";
    else
      return "sshll2\t%0.4s, %1.8h, %2";
  }
}

static const char *
output_3131 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6261 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V8HImode))
      return "shll2\t%0.4s, %1.8h, %2";
    else
      return "ushll2\t%0.4s, %1.8h, %2";
  }
}

static const char *
output_3132 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6261 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V4SImode))
      return "shll2\t%0.2d, %1.4s, %2";
    else
      return "sshll2\t%0.2d, %1.4s, %2";
  }
}

static const char *
output_3133 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6261 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    if (INTVAL (operands[2]) == GET_MODE_UNIT_BITSIZE (V4SImode))
      return "shll2\t%0.2d, %1.4s, %2";
    else
      return "ushll2\t%0.2d, %1.4s, %2";
  }
}

static const char * const output_3337[] = {
  "cmgt\t%0.8b, %2.8b, %1.8b",
  "cmlt\t%0.8b, %1.8b, #0",
};

static const char * const output_3338[] = {
  "cmge\t%0.8b, %2.8b, %1.8b",
  "cmle\t%0.8b, %1.8b, #0",
};

static const char * const output_3339[] = {
  "cmeq\t%0.8b, %1.8b, %2.8b",
  "cmeq\t%0.8b, %1.8b, #0",
};

static const char * const output_3340[] = {
  "cmge\t%0.8b, %1.8b, %2.8b",
  "cmge\t%0.8b, %1.8b, #0",
};

static const char * const output_3341[] = {
  "cmgt\t%0.8b, %1.8b, %2.8b",
  "cmgt\t%0.8b, %1.8b, #0",
};

static const char * const output_3342[] = {
  "cmgt\t%0.16b, %2.16b, %1.16b",
  "cmlt\t%0.16b, %1.16b, #0",
};

static const char * const output_3343[] = {
  "cmge\t%0.16b, %2.16b, %1.16b",
  "cmle\t%0.16b, %1.16b, #0",
};

static const char * const output_3344[] = {
  "cmeq\t%0.16b, %1.16b, %2.16b",
  "cmeq\t%0.16b, %1.16b, #0",
};

static const char * const output_3345[] = {
  "cmge\t%0.16b, %1.16b, %2.16b",
  "cmge\t%0.16b, %1.16b, #0",
};

static const char * const output_3346[] = {
  "cmgt\t%0.16b, %1.16b, %2.16b",
  "cmgt\t%0.16b, %1.16b, #0",
};

static const char * const output_3347[] = {
  "cmgt\t%0.4h, %2.4h, %1.4h",
  "cmlt\t%0.4h, %1.4h, #0",
};

static const char * const output_3348[] = {
  "cmge\t%0.4h, %2.4h, %1.4h",
  "cmle\t%0.4h, %1.4h, #0",
};

static const char * const output_3349[] = {
  "cmeq\t%0.4h, %1.4h, %2.4h",
  "cmeq\t%0.4h, %1.4h, #0",
};

static const char * const output_3350[] = {
  "cmge\t%0.4h, %1.4h, %2.4h",
  "cmge\t%0.4h, %1.4h, #0",
};

static const char * const output_3351[] = {
  "cmgt\t%0.4h, %1.4h, %2.4h",
  "cmgt\t%0.4h, %1.4h, #0",
};

static const char * const output_3352[] = {
  "cmgt\t%0.8h, %2.8h, %1.8h",
  "cmlt\t%0.8h, %1.8h, #0",
};

static const char * const output_3353[] = {
  "cmge\t%0.8h, %2.8h, %1.8h",
  "cmle\t%0.8h, %1.8h, #0",
};

static const char * const output_3354[] = {
  "cmeq\t%0.8h, %1.8h, %2.8h",
  "cmeq\t%0.8h, %1.8h, #0",
};

static const char * const output_3355[] = {
  "cmge\t%0.8h, %1.8h, %2.8h",
  "cmge\t%0.8h, %1.8h, #0",
};

static const char * const output_3356[] = {
  "cmgt\t%0.8h, %1.8h, %2.8h",
  "cmgt\t%0.8h, %1.8h, #0",
};

static const char * const output_3357[] = {
  "cmgt\t%0.2s, %2.2s, %1.2s",
  "cmlt\t%0.2s, %1.2s, #0",
};

static const char * const output_3358[] = {
  "cmge\t%0.2s, %2.2s, %1.2s",
  "cmle\t%0.2s, %1.2s, #0",
};

static const char * const output_3359[] = {
  "cmeq\t%0.2s, %1.2s, %2.2s",
  "cmeq\t%0.2s, %1.2s, #0",
};

static const char * const output_3360[] = {
  "cmge\t%0.2s, %1.2s, %2.2s",
  "cmge\t%0.2s, %1.2s, #0",
};

static const char * const output_3361[] = {
  "cmgt\t%0.2s, %1.2s, %2.2s",
  "cmgt\t%0.2s, %1.2s, #0",
};

static const char * const output_3362[] = {
  "cmgt\t%0.4s, %2.4s, %1.4s",
  "cmlt\t%0.4s, %1.4s, #0",
};

static const char * const output_3363[] = {
  "cmge\t%0.4s, %2.4s, %1.4s",
  "cmle\t%0.4s, %1.4s, #0",
};

static const char * const output_3364[] = {
  "cmeq\t%0.4s, %1.4s, %2.4s",
  "cmeq\t%0.4s, %1.4s, #0",
};

static const char * const output_3365[] = {
  "cmge\t%0.4s, %1.4s, %2.4s",
  "cmge\t%0.4s, %1.4s, #0",
};

static const char * const output_3366[] = {
  "cmgt\t%0.4s, %1.4s, %2.4s",
  "cmgt\t%0.4s, %1.4s, #0",
};

static const char * const output_3367[] = {
  "cmgt\t%0.2d, %2.2d, %1.2d",
  "cmlt\t%0.2d, %1.2d, #0",
};

static const char * const output_3368[] = {
  "cmge\t%0.2d, %2.2d, %1.2d",
  "cmle\t%0.2d, %1.2d, #0",
};

static const char * const output_3369[] = {
  "cmeq\t%0.2d, %1.2d, %2.2d",
  "cmeq\t%0.2d, %1.2d, #0",
};

static const char * const output_3370[] = {
  "cmge\t%0.2d, %1.2d, %2.2d",
  "cmge\t%0.2d, %1.2d, #0",
};

static const char * const output_3371[] = {
  "cmgt\t%0.2d, %1.2d, %2.2d",
  "cmgt\t%0.2d, %1.2d, #0",
};

static const char * const output_3377[] = {
  "cmgt\t%d0, %d2, %d1",
  "cmlt\t%d0, %d1, #0",
};

static const char * const output_3378[] = {
  "cmge\t%d0, %d2, %d1",
  "cmle\t%d0, %d1, #0",
};

static const char * const output_3379[] = {
  "cmeq\t%d0, %d1, %d2",
  "cmeq\t%d0, %d1, #0",
};

static const char * const output_3380[] = {
  "cmge\t%d0, %d1, %d2",
  "cmge\t%d0, %d1, #0",
};

static const char * const output_3381[] = {
  "cmgt\t%d0, %d1, %d2",
  "cmgt\t%d0, %d1, #0",
};

static const char * const output_3434[] = {
  "fcmgt\t%0.4h, %2.4h, %1.4h",
  "fcmlt\t%0.4h, %1.4h, 0",
};

static const char * const output_3435[] = {
  "fcmge\t%0.4h, %2.4h, %1.4h",
  "fcmle\t%0.4h, %1.4h, 0",
};

static const char * const output_3436[] = {
  "fcmeq\t%0.4h, %1.4h, %2.4h",
  "fcmeq\t%0.4h, %1.4h, 0",
};

static const char * const output_3437[] = {
  "fcmge\t%0.4h, %1.4h, %2.4h",
  "fcmge\t%0.4h, %1.4h, 0",
};

static const char * const output_3438[] = {
  "fcmgt\t%0.4h, %1.4h, %2.4h",
  "fcmgt\t%0.4h, %1.4h, 0",
};

static const char * const output_3439[] = {
  "fcmgt\t%0.8h, %2.8h, %1.8h",
  "fcmlt\t%0.8h, %1.8h, 0",
};

static const char * const output_3440[] = {
  "fcmge\t%0.8h, %2.8h, %1.8h",
  "fcmle\t%0.8h, %1.8h, 0",
};

static const char * const output_3441[] = {
  "fcmeq\t%0.8h, %1.8h, %2.8h",
  "fcmeq\t%0.8h, %1.8h, 0",
};

static const char * const output_3442[] = {
  "fcmge\t%0.8h, %1.8h, %2.8h",
  "fcmge\t%0.8h, %1.8h, 0",
};

static const char * const output_3443[] = {
  "fcmgt\t%0.8h, %1.8h, %2.8h",
  "fcmgt\t%0.8h, %1.8h, 0",
};

static const char * const output_3444[] = {
  "fcmgt\t%0.2s, %2.2s, %1.2s",
  "fcmlt\t%0.2s, %1.2s, 0",
};

static const char * const output_3445[] = {
  "fcmge\t%0.2s, %2.2s, %1.2s",
  "fcmle\t%0.2s, %1.2s, 0",
};

static const char * const output_3446[] = {
  "fcmeq\t%0.2s, %1.2s, %2.2s",
  "fcmeq\t%0.2s, %1.2s, 0",
};

static const char * const output_3447[] = {
  "fcmge\t%0.2s, %1.2s, %2.2s",
  "fcmge\t%0.2s, %1.2s, 0",
};

static const char * const output_3448[] = {
  "fcmgt\t%0.2s, %1.2s, %2.2s",
  "fcmgt\t%0.2s, %1.2s, 0",
};

static const char * const output_3449[] = {
  "fcmgt\t%0.4s, %2.4s, %1.4s",
  "fcmlt\t%0.4s, %1.4s, 0",
};

static const char * const output_3450[] = {
  "fcmge\t%0.4s, %2.4s, %1.4s",
  "fcmle\t%0.4s, %1.4s, 0",
};

static const char * const output_3451[] = {
  "fcmeq\t%0.4s, %1.4s, %2.4s",
  "fcmeq\t%0.4s, %1.4s, 0",
};

static const char * const output_3452[] = {
  "fcmge\t%0.4s, %1.4s, %2.4s",
  "fcmge\t%0.4s, %1.4s, 0",
};

static const char * const output_3453[] = {
  "fcmgt\t%0.4s, %1.4s, %2.4s",
  "fcmgt\t%0.4s, %1.4s, 0",
};

static const char * const output_3454[] = {
  "fcmgt\t%0.2d, %2.2d, %1.2d",
  "fcmlt\t%0.2d, %1.2d, 0",
};

static const char * const output_3455[] = {
  "fcmge\t%0.2d, %2.2d, %1.2d",
  "fcmle\t%0.2d, %1.2d, 0",
};

static const char * const output_3456[] = {
  "fcmeq\t%0.2d, %1.2d, %2.2d",
  "fcmeq\t%0.2d, %1.2d, 0",
};

static const char * const output_3457[] = {
  "fcmge\t%0.2d, %1.2d, %2.2d",
  "fcmge\t%0.2d, %1.2d, 0",
};

static const char * const output_3458[] = {
  "fcmgt\t%0.2d, %1.2d, %2.2d",
  "fcmgt\t%0.2d, %1.2d, 0",
};

static const char * const output_3459[] = {
  "fcmgt\t%h0, %h2, %h1",
  "fcmlt\t%h0, %h1, 0",
};

static const char * const output_3460[] = {
  "fcmge\t%h0, %h2, %h1",
  "fcmle\t%h0, %h1, 0",
};

static const char * const output_3461[] = {
  "fcmeq\t%h0, %h1, %h2",
  "fcmeq\t%h0, %h1, 0",
};

static const char * const output_3462[] = {
  "fcmge\t%h0, %h1, %h2",
  "fcmge\t%h0, %h1, 0",
};

static const char * const output_3463[] = {
  "fcmgt\t%h0, %h1, %h2",
  "fcmgt\t%h0, %h1, 0",
};

static const char * const output_3464[] = {
  "fcmgt\t%s0, %s2, %s1",
  "fcmlt\t%s0, %s1, 0",
};

static const char * const output_3465[] = {
  "fcmge\t%s0, %s2, %s1",
  "fcmle\t%s0, %s1, 0",
};

static const char * const output_3466[] = {
  "fcmeq\t%s0, %s1, %s2",
  "fcmeq\t%s0, %s1, 0",
};

static const char * const output_3467[] = {
  "fcmge\t%s0, %s1, %s2",
  "fcmge\t%s0, %s1, 0",
};

static const char * const output_3468[] = {
  "fcmgt\t%s0, %s1, %s2",
  "fcmgt\t%s0, %s1, 0",
};

static const char * const output_3469[] = {
  "fcmgt\t%d0, %d2, %d1",
  "fcmlt\t%d0, %d1, 0",
};

static const char * const output_3470[] = {
  "fcmge\t%d0, %d2, %d1",
  "fcmle\t%d0, %d1, 0",
};

static const char * const output_3471[] = {
  "fcmeq\t%d0, %d1, %d2",
  "fcmeq\t%d0, %d1, 0",
};

static const char * const output_3472[] = {
  "fcmge\t%d0, %d1, %d2",
  "fcmge\t%d0, %d1, 0",
};

static const char * const output_3473[] = {
  "fcmgt\t%d0, %d1, %d2",
  "fcmgt\t%d0, %d1, 0",
};

static const char *
output_3543 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.b - %T0.b}[%3], %1";
  }
}

static const char *
output_3544 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.h - %T0.h}[%3], %1";
  }
}

static const char *
output_3545 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.s - %T0.s}[%3], %1";
  }
}

static const char *
output_3546 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (DImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.d - %T0.d}[%3], %1";
  }
}

static const char *
output_3547 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.h - %T0.h}[%3], %1";
  }
}

static const char *
output_3548 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.s - %T0.s}[%3], %1";
  }
}

static const char *
output_3549 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (DFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.d - %T0.d}[%3], %1";
  }
}

static const char *
output_3550 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4BFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.h - %T0.h}[%3], %1";
  }
}

static const char *
output_3551 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.b - %T0.b}[%3], %1";
  }
}

static const char *
output_3552 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.h - %T0.h}[%3], %1";
  }
}

static const char *
output_3553 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.s - %T0.s}[%3], %1";
  }
}

static const char *
output_3554 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DImode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.d - %T0.d}[%3], %1";
  }
}

static const char *
output_3555 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.h - %T0.h}[%3], %1";
  }
}

static const char *
output_3556 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.s - %T0.s}[%3], %1";
  }
}

static const char *
output_3557 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.d - %T0.d}[%3], %1";
  }
}

static const char *
output_3558 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8BFmode,
					   INTVAL (operands[3]));
    return "ld2\t{%S0.h - %T0.h}[%3], %1";
  }
}

static const char *
output_3567 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.b - %T1.b}[%2], %0";
  }
}

static const char *
output_3568 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.h - %T1.h}[%2], %0";
  }
}

static const char *
output_3569 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.s - %T1.s}[%2], %0";
  }
}

static const char *
output_3570 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (DImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.d - %T1.d}[%2], %0";
  }
}

static const char *
output_3571 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.h - %T1.h}[%2], %0";
  }
}

static const char *
output_3572 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.s - %T1.s}[%2], %0";
  }
}

static const char *
output_3573 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (DFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.d - %T1.d}[%2], %0";
  }
}

static const char *
output_3574 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4BFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.h - %T1.h}[%2], %0";
  }
}

static const char *
output_3575 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.b - %T1.b}[%2], %0";
  }
}

static const char *
output_3576 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.h - %T1.h}[%2], %0";
  }
}

static const char *
output_3577 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.s - %T1.s}[%2], %0";
  }
}

static const char *
output_3578 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DImode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.d - %T1.d}[%2], %0";
  }
}

static const char *
output_3579 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.h - %T1.h}[%2], %0";
  }
}

static const char *
output_3580 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.s - %T1.s}[%2], %0";
  }
}

static const char *
output_3581 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.d - %T1.d}[%2], %0";
  }
}

static const char *
output_3582 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6809 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8BFmode,
					   INTVAL (operands[2]));
    return "st2\t{%S1.h - %T1.h}[%2], %0";
  }
}

static const char *
output_3607 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.b - %U0.b}[%3], %1";
}
}

static const char *
output_3608 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.h - %U0.h}[%3], %1";
}
}

static const char *
output_3609 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.s - %U0.s}[%3], %1";
}
}

static const char *
output_3610 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (DImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.d - %U0.d}[%3], %1";
}
}

static const char *
output_3611 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.h - %U0.h}[%3], %1";
}
}

static const char *
output_3612 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.s - %U0.s}[%3], %1";
}
}

static const char *
output_3613 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (DFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.d - %U0.d}[%3], %1";
}
}

static const char *
output_3614 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4BFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.h - %U0.h}[%3], %1";
}
}

static const char *
output_3615 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.b - %U0.b}[%3], %1";
}
}

static const char *
output_3616 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.h - %U0.h}[%3], %1";
}
}

static const char *
output_3617 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.s - %U0.s}[%3], %1";
}
}

static const char *
output_3618 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DImode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.d - %U0.d}[%3], %1";
}
}

static const char *
output_3619 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.h - %U0.h}[%3], %1";
}
}

static const char *
output_3620 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.s - %U0.s}[%3], %1";
}
}

static const char *
output_3621 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.d - %U0.d}[%3], %1";
}
}

static const char *
output_3622 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6864 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8BFmode,
					   INTVAL (operands[3]));
    return "ld3\t{%S0.h - %U0.h}[%3], %1";
}
}

static const char *
output_3631 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.b - %U1.b}[%2], %0";
  }
}

static const char *
output_3632 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.h - %U1.h}[%2], %0";
  }
}

static const char *
output_3633 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.s - %U1.s}[%2], %0";
  }
}

static const char *
output_3634 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (DImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.d - %U1.d}[%2], %0";
  }
}

static const char *
output_3635 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.h - %U1.h}[%2], %0";
  }
}

static const char *
output_3636 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.s - %U1.s}[%2], %0";
  }
}

static const char *
output_3637 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (DFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.d - %U1.d}[%2], %0";
  }
}

static const char *
output_3638 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4BFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.h - %U1.h}[%2], %0";
  }
}

static const char *
output_3639 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.b - %U1.b}[%2], %0";
  }
}

static const char *
output_3640 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.h - %U1.h}[%2], %0";
  }
}

static const char *
output_3641 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.s - %U1.s}[%2], %0";
  }
}

static const char *
output_3642 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DImode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.d - %U1.d}[%2], %0";
  }
}

static const char *
output_3643 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.h - %U1.h}[%2], %0";
  }
}

static const char *
output_3644 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.s - %U1.s}[%2], %0";
  }
}

static const char *
output_3645 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.d - %U1.d}[%2], %0";
  }
}

static const char *
output_3646 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6908 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8BFmode,
					   INTVAL (operands[2]));
    return "st3\t{%S1.h - %U1.h}[%2], %0";
  }
}

static const char *
output_3671 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.b - %V0.b}[%3], %1";
}
}

static const char *
output_3672 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.h - %V0.h}[%3], %1";
}
}

static const char *
output_3673 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.s - %V0.s}[%3], %1";
}
}

static const char *
output_3674 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (DImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.d - %V0.d}[%3], %1";
}
}

static const char *
output_3675 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4HFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.h - %V0.h}[%3], %1";
}
}

static const char *
output_3676 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2SFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.s - %V0.s}[%3], %1";
}
}

static const char *
output_3677 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (DFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.d - %V0.d}[%3], %1";
}
}

static const char *
output_3678 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4BFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.h - %V0.h}[%3], %1";
}
}

static const char *
output_3679 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.b - %V0.b}[%3], %1";
}
}

static const char *
output_3680 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.h - %V0.h}[%3], %1";
}
}

static const char *
output_3681 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.s - %V0.s}[%3], %1";
}
}

static const char *
output_3682 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DImode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.d - %V0.d}[%3], %1";
}
}

static const char *
output_3683 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8HFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.h - %V0.h}[%3], %1";
}
}

static const char *
output_3684 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V4SFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.s - %V0.s}[%3], %1";
}
}

static const char *
output_3685 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V2DFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.d - %V0.d}[%3], %1";
}
}

static const char *
output_3686 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 6964 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[3] = aarch64_endian_lane_rtx (V8BFmode,
					   INTVAL (operands[3]));
    return "ld4\t{%S0.h - %V0.h}[%3], %1";
}
}

static const char *
output_3695 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8QImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.b - %V1.b}[%2], %0";
  }
}

static const char *
output_3696 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.h - %V1.h}[%2], %0";
  }
}

static const char *
output_3697 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.s - %V1.s}[%2], %0";
  }
}

static const char *
output_3698 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (DImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.d - %V1.d}[%2], %0";
  }
}

static const char *
output_3699 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4HFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.h - %V1.h}[%2], %0";
  }
}

static const char *
output_3700 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2SFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.s - %V1.s}[%2], %0";
  }
}

static const char *
output_3701 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (DFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.d - %V1.d}[%2], %0";
  }
}

static const char *
output_3702 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4BFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.h - %V1.h}[%2], %0";
  }
}

static const char *
output_3703 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V16QImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.b - %V1.b}[%2], %0";
  }
}

static const char *
output_3704 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.h - %V1.h}[%2], %0";
  }
}

static const char *
output_3705 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.s - %V1.s}[%2], %0";
  }
}

static const char *
output_3706 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DImode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.d - %V1.d}[%2], %0";
  }
}

static const char *
output_3707 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8HFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.h - %V1.h}[%2], %0";
  }
}

static const char *
output_3708 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V4SFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.s - %V1.s}[%2], %0";
  }
}

static const char *
output_3709 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V2DFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.d - %V1.d}[%2], %0";
  }
}

static const char *
output_3710 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7009 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
    operands[2] = aarch64_endian_lane_rtx (V8BFmode,
					   INTVAL (operands[2]));
    return "st4\t{%S1.h - %V1.h}[%2], %0";
  }
}

static const char * const output_3839[] = {
  "#",
  "st1\t{%S1.8b - %T1.8b}, %0",
  "ld1\t{%S0.8b - %T0.8b}, %1",
};

static const char * const output_3840[] = {
  "#",
  "st1\t{%S1.4h - %T1.4h}, %0",
  "ld1\t{%S0.4h - %T0.4h}, %1",
};

static const char * const output_3841[] = {
  "#",
  "st1\t{%S1.2s - %T1.2s}, %0",
  "ld1\t{%S0.2s - %T0.2s}, %1",
};

static const char * const output_3842[] = {
  "#",
  "st1\t{%S1.1d - %T1.1d}, %0",
  "ld1\t{%S0.1d - %T0.1d}, %1",
};

static const char * const output_3843[] = {
  "#",
  "st1\t{%S1.4h - %T1.4h}, %0",
  "ld1\t{%S0.4h - %T0.4h}, %1",
};

static const char * const output_3844[] = {
  "#",
  "st1\t{%S1.2s - %T1.2s}, %0",
  "ld1\t{%S0.2s - %T0.2s}, %1",
};

static const char * const output_3845[] = {
  "#",
  "st1\t{%S1.1d - %T1.1d}, %0",
  "ld1\t{%S0.1d - %T0.1d}, %1",
};

static const char * const output_3846[] = {
  "#",
  "st1\t{%S1.4h - %T1.4h}, %0",
  "ld1\t{%S0.4h - %T0.4h}, %1",
};

static const char * const output_3847[] = {
  "#",
  "st1\t{%S1.8b - %U1.8b}, %0",
  "ld1\t{%S0.8b - %U0.8b}, %1",
};

static const char * const output_3848[] = {
  "#",
  "st1\t{%S1.4h - %U1.4h}, %0",
  "ld1\t{%S0.4h - %U0.4h}, %1",
};

static const char * const output_3849[] = {
  "#",
  "st1\t{%S1.2s - %U1.2s}, %0",
  "ld1\t{%S0.2s - %U0.2s}, %1",
};

static const char * const output_3850[] = {
  "#",
  "st1\t{%S1.1d - %U1.1d}, %0",
  "ld1\t{%S0.1d - %U0.1d}, %1",
};

static const char * const output_3851[] = {
  "#",
  "st1\t{%S1.4h - %U1.4h}, %0",
  "ld1\t{%S0.4h - %U0.4h}, %1",
};

static const char * const output_3852[] = {
  "#",
  "st1\t{%S1.2s - %U1.2s}, %0",
  "ld1\t{%S0.2s - %U0.2s}, %1",
};

static const char * const output_3853[] = {
  "#",
  "st1\t{%S1.1d - %U1.1d}, %0",
  "ld1\t{%S0.1d - %U0.1d}, %1",
};

static const char * const output_3854[] = {
  "#",
  "st1\t{%S1.4h - %U1.4h}, %0",
  "ld1\t{%S0.4h - %U0.4h}, %1",
};

static const char * const output_3855[] = {
  "#",
  "st1\t{%S1.8b - %V1.8b}, %0",
  "ld1\t{%S0.8b - %V0.8b}, %1",
};

static const char * const output_3856[] = {
  "#",
  "st1\t{%S1.4h - %V1.4h}, %0",
  "ld1\t{%S0.4h - %V0.4h}, %1",
};

static const char * const output_3857[] = {
  "#",
  "st1\t{%S1.2s - %V1.2s}, %0",
  "ld1\t{%S0.2s - %V0.2s}, %1",
};

static const char * const output_3858[] = {
  "#",
  "st1\t{%S1.1d - %V1.1d}, %0",
  "ld1\t{%S0.1d - %V0.1d}, %1",
};

static const char * const output_3859[] = {
  "#",
  "st1\t{%S1.4h - %V1.4h}, %0",
  "ld1\t{%S0.4h - %V0.4h}, %1",
};

static const char * const output_3860[] = {
  "#",
  "st1\t{%S1.2s - %V1.2s}, %0",
  "ld1\t{%S0.2s - %V0.2s}, %1",
};

static const char * const output_3861[] = {
  "#",
  "st1\t{%S1.1d - %V1.1d}, %0",
  "ld1\t{%S0.1d - %V0.1d}, %1",
};

static const char * const output_3862[] = {
  "#",
  "st1\t{%S1.4h - %V1.4h}, %0",
  "ld1\t{%S0.4h - %V0.4h}, %1",
};

static const char * const output_3863[] = {
  "#",
  "st1\t{%S1.16b - %T1.16b}, %0",
  "ld1\t{%S0.16b - %T0.16b}, %1",
};

static const char * const output_3864[] = {
  "#",
  "st1\t{%S1.8h - %T1.8h}, %0",
  "ld1\t{%S0.8h - %T0.8h}, %1",
};

static const char * const output_3865[] = {
  "#",
  "st1\t{%S1.4s - %T1.4s}, %0",
  "ld1\t{%S0.4s - %T0.4s}, %1",
};

static const char * const output_3866[] = {
  "#",
  "st1\t{%S1.2d - %T1.2d}, %0",
  "ld1\t{%S0.2d - %T0.2d}, %1",
};

static const char * const output_3867[] = {
  "#",
  "st1\t{%S1.8h - %T1.8h}, %0",
  "ld1\t{%S0.8h - %T0.8h}, %1",
};

static const char * const output_3868[] = {
  "#",
  "st1\t{%S1.4s - %T1.4s}, %0",
  "ld1\t{%S0.4s - %T0.4s}, %1",
};

static const char * const output_3869[] = {
  "#",
  "st1\t{%S1.2d - %T1.2d}, %0",
  "ld1\t{%S0.2d - %T0.2d}, %1",
};

static const char * const output_3870[] = {
  "#",
  "st1\t{%S1.8h - %T1.8h}, %0",
  "ld1\t{%S0.8h - %T0.8h}, %1",
};

static const char * const output_3871[] = {
  "#",
  "st1\t{%S1.16b - %U1.16b}, %0",
  "ld1\t{%S0.16b - %U0.16b}, %1",
};

static const char * const output_3872[] = {
  "#",
  "st1\t{%S1.8h - %U1.8h}, %0",
  "ld1\t{%S0.8h - %U0.8h}, %1",
};

static const char * const output_3873[] = {
  "#",
  "st1\t{%S1.4s - %U1.4s}, %0",
  "ld1\t{%S0.4s - %U0.4s}, %1",
};

static const char * const output_3874[] = {
  "#",
  "st1\t{%S1.2d - %U1.2d}, %0",
  "ld1\t{%S0.2d - %U0.2d}, %1",
};

static const char * const output_3875[] = {
  "#",
  "st1\t{%S1.8h - %U1.8h}, %0",
  "ld1\t{%S0.8h - %U0.8h}, %1",
};

static const char * const output_3876[] = {
  "#",
  "st1\t{%S1.4s - %U1.4s}, %0",
  "ld1\t{%S0.4s - %U0.4s}, %1",
};

static const char * const output_3877[] = {
  "#",
  "st1\t{%S1.2d - %U1.2d}, %0",
  "ld1\t{%S0.2d - %U0.2d}, %1",
};

static const char * const output_3878[] = {
  "#",
  "st1\t{%S1.8h - %U1.8h}, %0",
  "ld1\t{%S0.8h - %U0.8h}, %1",
};

static const char * const output_3879[] = {
  "#",
  "st1\t{%S1.16b - %V1.16b}, %0",
  "ld1\t{%S0.16b - %V0.16b}, %1",
};

static const char * const output_3880[] = {
  "#",
  "st1\t{%S1.8h - %V1.8h}, %0",
  "ld1\t{%S0.8h - %V0.8h}, %1",
};

static const char * const output_3881[] = {
  "#",
  "st1\t{%S1.4s - %V1.4s}, %0",
  "ld1\t{%S0.4s - %V0.4s}, %1",
};

static const char * const output_3882[] = {
  "#",
  "st1\t{%S1.2d - %V1.2d}, %0",
  "ld1\t{%S0.2d - %V0.2d}, %1",
};

static const char * const output_3883[] = {
  "#",
  "st1\t{%S1.8h - %V1.8h}, %0",
  "ld1\t{%S0.8h - %V0.8h}, %1",
};

static const char * const output_3884[] = {
  "#",
  "st1\t{%S1.4s - %V1.4s}, %0",
  "ld1\t{%S0.4s - %V0.4s}, %1",
};

static const char * const output_3885[] = {
  "#",
  "st1\t{%S1.2d - %V1.2d}, %0",
  "ld1\t{%S0.2d - %V0.2d}, %1",
};

static const char * const output_3886[] = {
  "#",
  "st1\t{%S1.8h - %V1.8h}, %0",
  "ld1\t{%S0.8h - %V0.8h}, %1",
};

static const char * const output_3887[] = {
  "#",
  "st1\t{%S1.16b - %T1.16b}, %0",
  "ld1\t{%S0.16b - %T0.16b}, %1",
};

static const char * const output_3888[] = {
  "#",
  "st1\t{%S1.16b - %U1.16b}, %0",
  "ld1\t{%S0.16b - %U0.16b}, %1",
};

static const char * const output_3889[] = {
  "#",
  "st1\t{%S1.16b - %V1.16b}, %0",
  "ld1\t{%S0.16b - %V0.16b}, %1",
};

static const char * const output_3921[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3922[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3923[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3924[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3925[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3926[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3927[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3928[] = {
  "#",
  "stp\t%d1, %R1, %0",
  "ldp\t%d0, %R0, %1",
};

static const char * const output_3929[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3930[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3931[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3932[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3933[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3934[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3935[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3936[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char * const output_3937[] = {
  "#",
  "stp\t%q1, %R1, %0",
  "ldp\t%q0, %R0, %1",
};

static const char *
output_4097 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V8QImode));
  return "ext\t%0.8b, %1.8b, %2.8b, #%3";
}
}

static const char *
output_4098 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V16QImode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4099 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V4HImode));
  return "ext\t%0.8b, %1.8b, %2.8b, #%3";
}
}

static const char *
output_4100 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V8HImode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4101 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V2SImode));
  return "ext\t%0.8b, %1.8b, %2.8b, #%3";
}
}

static const char *
output_4102 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V4SImode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4103 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V2DImode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4104 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V4HFmode));
  return "ext\t%0.8b, %1.8b, %2.8b, #%3";
}
}

static const char *
output_4105 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V8HFmode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4106 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V4BFmode));
  return "ext\t%0.8b, %1.8b, %2.8b, #%3";
}
}

static const char *
output_4107 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V8BFmode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4108 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V2SFmode));
  return "ext\t%0.8b, %1.8b, %2.8b, #%3";
}
}

static const char *
output_4109 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V4SFmode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4110 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 7791 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[3] = GEN_INT (INTVAL (operands[3])
      * GET_MODE_UNIT_SIZE (V2DFmode));
  return "ext\t%0.16b, %1.16b, %2.16b, #%3";
}
}

static const char *
output_4306 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8992 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V4BFmode).to_constant ();
  int lane = INTVAL (operands[4]);
  operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 2, lane), SImode);
  return "bfdot\t%0.2s, %2.4h, %3.2h[%4]";
}
}

static const char *
output_4307 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8992 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V8BFmode).to_constant ();
  int lane = INTVAL (operands[4]);
  operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 2, lane), SImode);
  return "bfdot\t%0.2s, %2.4h, %3.2h[%4]";
}
}

static const char *
output_4308 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8992 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V4BFmode).to_constant ();
  int lane = INTVAL (operands[4]);
  operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 2, lane), SImode);
  return "bfdot\t%0.4s, %2.8h, %3.2h[%4]";
}
}

static const char *
output_4309 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8992 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  int nunits = GET_MODE_NUNITS (V8BFmode).to_constant ();
  int lane = INTVAL (operands[4]);
  operands[4] = gen_int_mode (ENDIAN_LANE_N (nunits / 2, lane), SImode);
  return "bfdot\t%0.4s, %2.8h, %3.2h[%4]";
}
}

static const char *
output_4313 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9054 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4BFmode, INTVAL (operands[4]));
  return "bfmlalb\t%0.4s, %2.8h, %3.h[%4]";
}
}

static const char *
output_4314 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9054 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V4BFmode, INTVAL (operands[4]));
  return "bfmlalt\t%0.4s, %2.8h, %3.h[%4]";
}
}

static const char *
output_4315 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9054 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V8BFmode, INTVAL (operands[4]));
  return "bfmlalb\t%0.4s, %2.8h, %3.h[%4]";
}
}

static const char *
output_4316 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9054 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md"
{
  operands[4] = aarch64_endian_lane_rtx (V8BFmode, INTVAL (operands[4]));
  return "bfmlalt\t%0.4s, %2.8h, %3.h[%4]";
}
}

static const char *
output_4333 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 129 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
  enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
  if (is_mm_relaxed (model))
    return "casb\t%w0, %w2, %1";
  else if (is_mm_acquire (model) || is_mm_consume (model))
    return "casab\t%w0, %w2, %1";
  else if (is_mm_release (model))
    return "caslb\t%w0, %w2, %1";
  else
    return "casalb\t%w0, %w2, %1";
}
}

static const char *
output_4334 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 129 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
  enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
  if (is_mm_relaxed (model))
    return "cash\t%w0, %w2, %1";
  else if (is_mm_acquire (model) || is_mm_consume (model))
    return "casah\t%w0, %w2, %1";
  else if (is_mm_release (model))
    return "caslh\t%w0, %w2, %1";
  else
    return "casalh\t%w0, %w2, %1";
}
}

static const char *
output_4335 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 151 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
  enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
  if (is_mm_relaxed (model))
    return "cas\t%w0, %w2, %1";
  else if (is_mm_acquire (model) || is_mm_consume (model))
    return "casa\t%w0, %w2, %1";
  else if (is_mm_release (model))
    return "casl\t%w0, %w2, %1";
  else
    return "casal\t%w0, %w2, %1";
}
}

static const char *
output_4336 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 151 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
  enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
  if (is_mm_relaxed (model))
    return "cas\t%x0, %x2, %1";
  else if (is_mm_acquire (model) || is_mm_consume (model))
    return "casa\t%x0, %x2, %1";
  else if (is_mm_release (model))
    return "casl\t%x0, %x2, %1";
  else
    return "casal\t%x0, %x2, %1";
}
}

static const char *
output_4337 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 173 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
  enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
  if (is_mm_relaxed (model))
    return "casp\t%0, %R0, %2, %R2, %1";
  else if (is_mm_acquire (model) || is_mm_consume (model))
    return "caspa\t%0, %R0, %2, %R2, %1";
  else if (is_mm_release (model))
    return "caspl\t%0, %R0, %2, %R2, %1";
  else
    return "caspal\t%0, %R0, %2, %R2, %1";
}
}

static const char *
output_4342 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 247 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model))
      return "swpb\t%w2, %w0, %1";
    else if (is_mm_acquire (model) || is_mm_consume (model))
      return "swpab\t%w2, %w0, %1";
    else if (is_mm_release (model))
      return "swplb\t%w2, %w0, %1";
    else
      return "swpalb\t%w2, %w0, %1";
  }
}

static const char *
output_4343 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 247 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model))
      return "swph\t%w2, %w0, %1";
    else if (is_mm_acquire (model) || is_mm_consume (model))
      return "swpah\t%w2, %w0, %1";
    else if (is_mm_release (model))
      return "swplh\t%w2, %w0, %1";
    else
      return "swpalh\t%w2, %w0, %1";
  }
}

static const char *
output_4344 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 247 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model))
      return "swp\t%w2, %w0, %1";
    else if (is_mm_acquire (model) || is_mm_consume (model))
      return "swpa\t%w2, %w0, %1";
    else if (is_mm_release (model))
      return "swpl\t%w2, %w0, %1";
    else
      return "swpal\t%w2, %w0, %1";
  }
}

static const char *
output_4345 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 247 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model))
      return "swp\t%x2, %x0, %1";
    else if (is_mm_acquire (model) || is_mm_consume (model))
      return "swpa\t%x2, %x0, %1";
    else if (is_mm_release (model))
      return "swpl\t%x2, %x0, %1";
    else
      return "swpal\t%x2, %x0, %1";
  }
}

static const char *
output_4366 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldsetb\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldsetlb\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldsetab\t%w1, %w3, %0";
   else
     return "ldsetalb\t%w1, %w3, %0";
  }
}

static const char *
output_4367 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldclrb\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldclrlb\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclrab\t%w1, %w3, %0";
   else
     return "ldclralb\t%w1, %w3, %0";
  }
}

static const char *
output_4368 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldeorb\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldeorlb\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeorab\t%w1, %w3, %0";
   else
     return "ldeoralb\t%w1, %w3, %0";
  }
}

static const char *
output_4369 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldaddb\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldaddlb\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldaddab\t%w1, %w3, %0";
   else
     return "ldaddalb\t%w1, %w3, %0";
  }
}

static const char *
output_4370 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldseth\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldsetlh\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldsetah\t%w1, %w3, %0";
   else
     return "ldsetalh\t%w1, %w3, %0";
  }
}

static const char *
output_4371 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldclrh\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldclrlh\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclrah\t%w1, %w3, %0";
   else
     return "ldclralh\t%w1, %w3, %0";
  }
}

static const char *
output_4372 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldeorh\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldeorlh\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeorah\t%w1, %w3, %0";
   else
     return "ldeoralh\t%w1, %w3, %0";
  }
}

static const char *
output_4373 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldaddh\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldaddlh\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldaddah\t%w1, %w3, %0";
   else
     return "ldaddalh\t%w1, %w3, %0";
  }
}

static const char *
output_4374 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldset\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldsetl\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldseta\t%w1, %w3, %0";
   else
     return "ldsetal\t%w1, %w3, %0";
  }
}

static const char *
output_4375 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldclr\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldclrl\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclra\t%w1, %w3, %0";
   else
     return "ldclral\t%w1, %w3, %0";
  }
}

static const char *
output_4376 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldeor\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldeorl\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeora\t%w1, %w3, %0";
   else
     return "ldeoral\t%w1, %w3, %0";
  }
}

static const char *
output_4377 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldadd\t%w1, %w3, %0";
   else if (is_mm_release (model))
     return "ldaddl\t%w1, %w3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldadda\t%w1, %w3, %0";
   else
     return "ldaddal\t%w1, %w3, %0";
  }
}

static const char *
output_4378 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldset\t%x1, %x3, %0";
   else if (is_mm_release (model))
     return "ldsetl\t%x1, %x3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldseta\t%x1, %x3, %0";
   else
     return "ldsetal\t%x1, %x3, %0";
  }
}

static const char *
output_4379 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldclr\t%x1, %x3, %0";
   else if (is_mm_release (model))
     return "ldclrl\t%x1, %x3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclra\t%x1, %x3, %0";
   else
     return "ldclral\t%x1, %x3, %0";
  }
}

static const char *
output_4380 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldeor\t%x1, %x3, %0";
   else if (is_mm_release (model))
     return "ldeorl\t%x1, %x3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeora\t%x1, %x3, %0";
   else
     return "ldeoral\t%x1, %x3, %0";
  }
}

static const char *
output_4381 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 380 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
   if (is_mm_relaxed (model))
     return "ldadd\t%x1, %x3, %0";
   else if (is_mm_release (model))
     return "ldaddl\t%x1, %x3, %0";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldadda\t%x1, %x3, %0";
   else
     return "ldaddal\t%x1, %x3, %0";
  }
}

static const char *
output_4406 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldsetb\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldsetab\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldsetlb\t%w2, %w0, %1";
   else
     return "ldsetalb\t%w2, %w0, %1";
  }
}

static const char *
output_4407 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldclrb\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclrab\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldclrlb\t%w2, %w0, %1";
   else
     return "ldclralb\t%w2, %w0, %1";
  }
}

static const char *
output_4408 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldeorb\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeorab\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldeorlb\t%w2, %w0, %1";
   else
     return "ldeoralb\t%w2, %w0, %1";
  }
}

static const char *
output_4409 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldaddb\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldaddab\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldaddlb\t%w2, %w0, %1";
   else
     return "ldaddalb\t%w2, %w0, %1";
  }
}

static const char *
output_4410 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldseth\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldsetah\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldsetlh\t%w2, %w0, %1";
   else
     return "ldsetalh\t%w2, %w0, %1";
  }
}

static const char *
output_4411 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldclrh\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclrah\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldclrlh\t%w2, %w0, %1";
   else
     return "ldclralh\t%w2, %w0, %1";
  }
}

static const char *
output_4412 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldeorh\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeorah\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldeorlh\t%w2, %w0, %1";
   else
     return "ldeoralh\t%w2, %w0, %1";
  }
}

static const char *
output_4413 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldaddh\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldaddah\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldaddlh\t%w2, %w0, %1";
   else
     return "ldaddalh\t%w2, %w0, %1";
  }
}

static const char *
output_4414 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldset\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldseta\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldsetl\t%w2, %w0, %1";
   else
     return "ldsetal\t%w2, %w0, %1";
  }
}

static const char *
output_4415 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldclr\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclra\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldclrl\t%w2, %w0, %1";
   else
     return "ldclral\t%w2, %w0, %1";
  }
}

static const char *
output_4416 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldeor\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeora\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldeorl\t%w2, %w0, %1";
   else
     return "ldeoral\t%w2, %w0, %1";
  }
}

static const char *
output_4417 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldadd\t%w2, %w0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldadda\t%w2, %w0, %1";
   else if (is_mm_release (model))
     return "ldaddl\t%w2, %w0, %1";
   else
     return "ldaddal\t%w2, %w0, %1";
  }
}

static const char *
output_4418 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldset\t%x2, %x0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldseta\t%x2, %x0, %1";
   else if (is_mm_release (model))
     return "ldsetl\t%x2, %x0, %1";
   else
     return "ldsetal\t%x2, %x0, %1";
  }
}

static const char *
output_4419 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldclr\t%x2, %x0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldclra\t%x2, %x0, %1";
   else if (is_mm_release (model))
     return "ldclrl\t%x2, %x0, %1";
   else
     return "ldclral\t%x2, %x0, %1";
  }
}

static const char *
output_4420 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldeor\t%x2, %x0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldeora\t%x2, %x0, %1";
   else if (is_mm_release (model))
     return "ldeorl\t%x2, %x0, %1";
   else
     return "ldeoral\t%x2, %x0, %1";
  }
}

static const char *
output_4421 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 529 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
   enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
   if (is_mm_relaxed (model))
     return "ldadd\t%x2, %x0, %1";
   else if (is_mm_acquire (model) || is_mm_consume (model))
     return "ldadda\t%x2, %x0, %1";
   else if (is_mm_release (model))
     return "ldaddl\t%x2, %x0, %1";
   else
     return "ldaddal\t%x2, %x0, %1";
  }
}

static const char *
output_4450 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 650 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldrb\t%w0, %1";
    else
      return "ldarb\t%w0, %1";
  }
}

static const char *
output_4451 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 650 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldrh\t%w0, %1";
    else
      return "ldarh\t%w0, %1";
  }
}

static const char *
output_4452 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 650 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldr\t%w0, %1";
    else
      return "ldar\t%w0, %1";
  }
}

static const char *
output_4453 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 650 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldr\t%x0, %1";
    else
      return "ldar\t%x0, %1";
  }
}

static const char *
output_4454 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 666 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "strb\t%w1, %0";
    else if (which_alternative == 0)
      return "stlrb\t%w1, %0";
    else
      return "stlurb\t%w1, %0";
  }
}

static const char *
output_4455 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 666 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "strh\t%w1, %0";
    else if (which_alternative == 0)
      return "stlrh\t%w1, %0";
    else
      return "stlurh\t%w1, %0";
  }
}

static const char *
output_4456 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 666 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "str\t%w1, %0";
    else if (which_alternative == 0)
      return "stlr\t%w1, %0";
    else
      return "stlur\t%w1, %0";
  }
}

static const char *
output_4457 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 666 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "str\t%x1, %0";
    else if (which_alternative == 0)
      return "stlr\t%x1, %0";
    else
      return "stlur\t%x1, %0";
  }
}

static const char *
output_4458 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 686 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldxrb\t%w0, %1";
    else
      return "ldaxrb\t%w0, %1";
  }
}

static const char *
output_4459 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 686 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldxrh\t%w0, %1";
    else
      return "ldaxrh\t%w0, %1";
  }
}

static const char *
output_4460 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 702 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldxr\t%w0, %1";
    else
      return "ldaxr\t%w0, %1";
  }
}

static const char *
output_4461 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 702 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[2]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldxr\t%x0, %1";
    else
      return "ldaxr\t%x0, %1";
  }
}

static const char *
output_4462 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 720 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_release (model))
      return "ldxp\t%0, %1, %2";
    else
      return "ldaxp\t%0, %1, %2";
  }
}

static const char *
output_4463 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 738 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "stxrb\t%w0, %w2, %1";
    else
      return "stlxrb\t%w0, %w2, %1";
  }
}

static const char *
output_4464 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 738 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "stxrh\t%w0, %w2, %1";
    else
      return "stlxrh\t%w0, %w2, %1";
  }
}

static const char *
output_4465 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 738 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "stxr\t%w0, %w2, %1";
    else
      return "stlxr\t%w0, %w2, %1";
  }
}

static const char *
output_4466 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 738 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[3]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "stxr\t%w0, %x2, %1";
    else
      return "stlxr\t%w0, %x2, %1";
  }
}

static const char *
output_4467 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 757 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[4]));
    if (is_mm_relaxed (model) || is_mm_consume (model) || is_mm_acquire (model))
      return "stxp\t%w0, %x2, %x3, %1";
    else
      return "stlxp\t%w0, %x2, %x3, %1";
  }
}

static const char *
output_4468 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 793 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md"
{
    enum memmodel model = memmodel_from_int (INTVAL (operands[1]));
    if (is_mm_acquire (model))
      return "dmb\tishld";
    else
      return "dmb\tish";
  }
}

static const char *
output_4469 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4470 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4471 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4472 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4473 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4474 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4475 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4476 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "ldr\t%0, %1";
    case 1: return "str\t%1, %0";
    case 2: return "mov\t%0.d, %1.d";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4477 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4478 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4479 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4480 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4481 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4482 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4483 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4484 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4485 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4486 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4487 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4488 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4489 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4490 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4491 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4492 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4493 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4494 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.d, %1.d";
    case 1:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char * const output_4495[] = {
  "#",
  "ld1b\t%0.b, %1/z, %2",
  "st1b\t%2.b, %1, %0",
};

static const char * const output_4496[] = {
  "#",
  "ld1b\t%0.h, %1/z, %2",
  "st1b\t%2.h, %1, %0",
};

static const char * const output_4497[] = {
  "#",
  "ld1b\t%0.s, %1/z, %2",
  "st1b\t%2.s, %1, %0",
};

static const char * const output_4498[] = {
  "#",
  "ld1b\t%0.d, %1/z, %2",
  "st1b\t%2.d, %1, %0",
};

static const char * const output_4499[] = {
  "#",
  "ld1h\t%0.h, %1/z, %2",
  "st1h\t%2.h, %1, %0",
};

static const char * const output_4500[] = {
  "#",
  "ld1h\t%0.s, %1/z, %2",
  "st1h\t%2.s, %1, %0",
};

static const char * const output_4501[] = {
  "#",
  "ld1h\t%0.d, %1/z, %2",
  "st1h\t%2.d, %1, %0",
};

static const char * const output_4502[] = {
  "#",
  "ld1h\t%0.h, %1/z, %2",
  "st1h\t%2.h, %1, %0",
};

static const char * const output_4503[] = {
  "#",
  "ld1h\t%0.s, %1/z, %2",
  "st1h\t%2.s, %1, %0",
};

static const char * const output_4504[] = {
  "#",
  "ld1h\t%0.d, %1/z, %2",
  "st1h\t%2.d, %1, %0",
};

static const char * const output_4505[] = {
  "#",
  "ld1h\t%0.h, %1/z, %2",
  "st1h\t%2.h, %1, %0",
};

static const char * const output_4506[] = {
  "#",
  "ld1h\t%0.s, %1/z, %2",
  "st1h\t%2.s, %1, %0",
};

static const char * const output_4507[] = {
  "#",
  "ld1h\t%0.d, %1/z, %2",
  "st1h\t%2.d, %1, %0",
};

static const char * const output_4508[] = {
  "#",
  "ld1w\t%0.s, %1/z, %2",
  "st1w\t%2.s, %1, %0",
};

static const char * const output_4509[] = {
  "#",
  "ld1w\t%0.d, %1/z, %2",
  "st1w\t%2.d, %1, %0",
};

static const char * const output_4510[] = {
  "#",
  "ld1w\t%0.s, %1/z, %2",
  "st1w\t%2.s, %1, %0",
};

static const char * const output_4511[] = {
  "#",
  "ld1w\t%0.d, %1/z, %2",
  "st1w\t%2.d, %1, %0",
};

static const char * const output_4512[] = {
  "#",
  "ld1d\t%0.d, %1/z, %2",
  "st1d\t%2.d, %1, %0",
};

static const char * const output_4513[] = {
  "#",
  "ld1d\t%0.d, %1/z, %2",
  "st1d\t%2.d, %1, %0",
};

static const char *
output_4624 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.b, %1.b";
    case 1: return "str\t%1, %0";
    case 2: return "ldr\t%0, %1";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4625 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.b, %1.b";
    case 1: return "str\t%1, %0";
    case 2: return "ldr\t%0, %1";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4626 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.b, %1.b";
    case 1: return "str\t%1, %0";
    case 2: return "ldr\t%0, %1";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4627 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "mov\t%0.b, %1.b";
    case 1: return "str\t%1, %0";
    case 2: return "ldr\t%0, %1";
    case 3:
       return aarch64_output_sve_mov_immediate (operands[1]);
      default: gcc_unreachable ();
    }
}

static const char *
output_4628 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 980 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char *
output_4629 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1006 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char *
output_4630 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1006 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char *
output_4631 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1006 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char *
output_4632 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1032 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char *
output_4633 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1058 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char *
output_4634 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1058 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char *
output_4635 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1058 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_ptrues (operands[1]);
  }
}

static const char * const output_4636[] = {
  "setffr",
  "wrffr\t%0.b",
};

static const char * const output_4793[] = {
  "ld1b\t%0.s, %5/z, [%2.s]",
  "ld1b\t%0.s, %5/z, [%2.s, #%1]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4794[] = {
  "ld1h\t%0.s, %5/z, [%2.s]",
  "ld1h\t%0.s, %5/z, [%2.s, #%1]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4795[] = {
  "ld1h\t%0.s, %5/z, [%2.s]",
  "ld1h\t%0.s, %5/z, [%2.s, #%1]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4796[] = {
  "ld1h\t%0.s, %5/z, [%2.s]",
  "ld1h\t%0.s, %5/z, [%2.s, #%1]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4797[] = {
  "ld1w\t%0.s, %5/z, [%2.s]",
  "ld1w\t%0.s, %5/z, [%2.s, #%1]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4798[] = {
  "ld1w\t%0.s, %5/z, [%2.s]",
  "ld1w\t%0.s, %5/z, [%2.s, #%1]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1w\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4799[] = {
  "ld1b\t%0.d, %5/z, [%2.d]",
  "ld1b\t%0.d, %5/z, [%2.d, #%1]",
  "ld1b\t%0.d, %5/z, [%1, %2.d]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4800[] = {
  "ld1h\t%0.d, %5/z, [%2.d]",
  "ld1h\t%0.d, %5/z, [%2.d, #%1]",
  "ld1h\t%0.d, %5/z, [%1, %2.d]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4801[] = {
  "ld1h\t%0.d, %5/z, [%2.d]",
  "ld1h\t%0.d, %5/z, [%2.d, #%1]",
  "ld1h\t%0.d, %5/z, [%1, %2.d]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4802[] = {
  "ld1h\t%0.d, %5/z, [%2.d]",
  "ld1h\t%0.d, %5/z, [%2.d, #%1]",
  "ld1h\t%0.d, %5/z, [%1, %2.d]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4803[] = {
  "ld1w\t%0.d, %5/z, [%2.d]",
  "ld1w\t%0.d, %5/z, [%2.d, #%1]",
  "ld1w\t%0.d, %5/z, [%1, %2.d]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4804[] = {
  "ld1w\t%0.d, %5/z, [%2.d]",
  "ld1w\t%0.d, %5/z, [%2.d, #%1]",
  "ld1w\t%0.d, %5/z, [%1, %2.d]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4805[] = {
  "ld1d\t%0.d, %5/z, [%2.d]",
  "ld1d\t%0.d, %5/z, [%2.d, #%1]",
  "ld1d\t%0.d, %5/z, [%1, %2.d]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4806[] = {
  "ld1d\t%0.d, %5/z, [%2.d]",
  "ld1d\t%0.d, %5/z, [%2.d, #%1]",
  "ld1d\t%0.d, %5/z, [%1, %2.d]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4807[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4808[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4809[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4810[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4811[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4812[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4813[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4814[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4815[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4816[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4817[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4818[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4819[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4820[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4821[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4822[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4823[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4824[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4825[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4826[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4827[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4828[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4829[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4830[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4831[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4832[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4833[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4834[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4835[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4836[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4837[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4838[] = {
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1d\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4839[] = {
  "ld1sb\t%0.s, %5/z, [%2.s]",
  "ld1sb\t%0.s, %5/z, [%2.s, #%1]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4840[] = {
  "ld1b\t%0.s, %5/z, [%2.s]",
  "ld1b\t%0.s, %5/z, [%2.s, #%1]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4841[] = {
  "ld1sb\t%0.s, %5/z, [%2.s]",
  "ld1sb\t%0.s, %5/z, [%2.s, #%1]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1sb\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4842[] = {
  "ld1b\t%0.s, %5/z, [%2.s]",
  "ld1b\t%0.s, %5/z, [%2.s, #%1]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1b\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4843[] = {
  "ld1sh\t%0.s, %5/z, [%2.s]",
  "ld1sh\t%0.s, %5/z, [%2.s, #%1]",
  "ld1sh\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1sh\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1sh\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1sh\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4844[] = {
  "ld1h\t%0.s, %5/z, [%2.s]",
  "ld1h\t%0.s, %5/z, [%2.s, #%1]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ld1h\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4845[] = {
  "ld1sb\t%0.d, %5/z, [%2.d]",
  "ld1sb\t%0.d, %5/z, [%2.d, #%1]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4846[] = {
  "ld1b\t%0.d, %5/z, [%2.d]",
  "ld1b\t%0.d, %5/z, [%2.d, #%1]",
  "ld1b\t%0.d, %5/z, [%1, %2.d]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4847[] = {
  "ld1sb\t%0.d, %5/z, [%2.d]",
  "ld1sb\t%0.d, %5/z, [%2.d, #%1]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4848[] = {
  "ld1b\t%0.d, %5/z, [%2.d]",
  "ld1b\t%0.d, %5/z, [%2.d, #%1]",
  "ld1b\t%0.d, %5/z, [%1, %2.d]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4849[] = {
  "ld1sh\t%0.d, %5/z, [%2.d]",
  "ld1sh\t%0.d, %5/z, [%2.d, #%1]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4850[] = {
  "ld1h\t%0.d, %5/z, [%2.d]",
  "ld1h\t%0.d, %5/z, [%2.d, #%1]",
  "ld1h\t%0.d, %5/z, [%1, %2.d]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4851[] = {
  "ld1sb\t%0.d, %5/z, [%2.d]",
  "ld1sb\t%0.d, %5/z, [%2.d, #%1]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4852[] = {
  "ld1b\t%0.d, %5/z, [%2.d]",
  "ld1b\t%0.d, %5/z, [%2.d, #%1]",
  "ld1b\t%0.d, %5/z, [%1, %2.d]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4853[] = {
  "ld1sh\t%0.d, %5/z, [%2.d]",
  "ld1sh\t%0.d, %5/z, [%2.d, #%1]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4854[] = {
  "ld1h\t%0.d, %5/z, [%2.d]",
  "ld1h\t%0.d, %5/z, [%2.d, #%1]",
  "ld1h\t%0.d, %5/z, [%1, %2.d]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4855[] = {
  "ld1sw\t%0.d, %5/z, [%2.d]",
  "ld1sw\t%0.d, %5/z, [%2.d, #%1]",
  "ld1sw\t%0.d, %5/z, [%1, %2.d]",
  "ld1sw\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4856[] = {
  "ld1w\t%0.d, %5/z, [%2.d]",
  "ld1w\t%0.d, %5/z, [%2.d, #%1]",
  "ld1w\t%0.d, %5/z, [%1, %2.d]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4857[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4858[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4859[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4860[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4861[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4862[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4863[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4864[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4865[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4866[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4867[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4868[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4869[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4870[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4871[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4872[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4873[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4874[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4875[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4876[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4877[] = {
  "ld1sw\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sw\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4878[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4879[] = {
  "ld1sw\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sw\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4880[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4881[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4882[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4883[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4884[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4885[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4886[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4887[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4888[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4889[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4890[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4891[] = {
  "ld1sw\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1sw\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4892[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4893[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4894[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4895[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4896[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4897[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4898[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4899[] = {
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sb\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4900[] = {
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4901[] = {
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sh\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4902[] = {
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4903[] = {
  "ld1sw\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1sw\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4904[] = {
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ld1w\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4905[] = {
  "ldff1w\t%0.s, %5/z, [%2.s]",
  "ldff1w\t%0.s, %5/z, [%2.s, #%1]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4906[] = {
  "ldff1w\t%0.s, %5/z, [%2.s]",
  "ldff1w\t%0.s, %5/z, [%2.s, #%1]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ldff1w\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4907[] = {
  "ldff1d\t%0.d, %5/z, [%2.d]",
  "ldff1d\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4908[] = {
  "ldff1d\t%0.d, %5/z, [%2.d]",
  "ldff1d\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4909[] = {
  "ldff1d\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4910[] = {
  "ldff1d\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4911[] = {
  "ldff1d\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4912[] = {
  "ldff1d\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1d\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4913[] = {
  "ldff1sb\t%0.s, %5/z, [%2.s]",
  "ldff1sb\t%0.s, %5/z, [%2.s, #%1]",
  "ldff1sb\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ldff1sb\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ldff1sb\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ldff1sb\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4914[] = {
  "ldff1b\t%0.s, %5/z, [%2.s]",
  "ldff1b\t%0.s, %5/z, [%2.s, #%1]",
  "ldff1b\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ldff1b\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ldff1b\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ldff1b\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4915[] = {
  "ldff1sh\t%0.s, %5/z, [%2.s]",
  "ldff1sh\t%0.s, %5/z, [%2.s, #%1]",
  "ldff1sh\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ldff1sh\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ldff1sh\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ldff1sh\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4916[] = {
  "ldff1h\t%0.s, %5/z, [%2.s]",
  "ldff1h\t%0.s, %5/z, [%2.s, #%1]",
  "ldff1h\t%0.s, %5/z, [%1, %2.s, sxtw]",
  "ldff1h\t%0.s, %5/z, [%1, %2.s, uxtw]",
  "ldff1h\t%0.s, %5/z, [%1, %2.s, sxtw %p4]",
  "ldff1h\t%0.s, %5/z, [%1, %2.s, uxtw %p4]",
};

static const char * const output_4917[] = {
  "ldff1sb\t%0.d, %5/z, [%2.d]",
  "ldff1sb\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1sb\t%0.d, %5/z, [%1, %2.d]",
  "ldff1sb\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4918[] = {
  "ldff1b\t%0.d, %5/z, [%2.d]",
  "ldff1b\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1b\t%0.d, %5/z, [%1, %2.d]",
  "ldff1b\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4919[] = {
  "ldff1sh\t%0.d, %5/z, [%2.d]",
  "ldff1sh\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1sh\t%0.d, %5/z, [%1, %2.d]",
  "ldff1sh\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4920[] = {
  "ldff1h\t%0.d, %5/z, [%2.d]",
  "ldff1h\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1h\t%0.d, %5/z, [%1, %2.d]",
  "ldff1h\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4921[] = {
  "ldff1sw\t%0.d, %5/z, [%2.d]",
  "ldff1sw\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1sw\t%0.d, %5/z, [%1, %2.d]",
  "ldff1sw\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4922[] = {
  "ldff1w\t%0.d, %5/z, [%2.d]",
  "ldff1w\t%0.d, %5/z, [%2.d, #%1]",
  "ldff1w\t%0.d, %5/z, [%1, %2.d]",
  "ldff1w\t%0.d, %5/z, [%1, %2.d, lsl %p4]",
};

static const char * const output_4923[] = {
  "ldff1sb\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1sb\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4924[] = {
  "ldff1b\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1b\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4925[] = {
  "ldff1sh\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1sh\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4926[] = {
  "ldff1h\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1h\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4927[] = {
  "ldff1sw\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1sw\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4928[] = {
  "ldff1w\t%0.d, %5/z, [%1, %2.d, sxtw]",
  "ldff1w\t%0.d, %5/z, [%1, %2.d, sxtw %p4]",
};

static const char * const output_4929[] = {
  "ldff1sb\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1sb\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4930[] = {
  "ldff1b\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1b\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4931[] = {
  "ldff1sh\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1sh\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4932[] = {
  "ldff1h\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1h\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4933[] = {
  "ldff1sw\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1sw\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char * const output_4934[] = {
  "ldff1w\t%0.d, %5/z, [%1, %2.d, uxtw]",
  "ldff1w\t%0.d, %5/z, [%1, %2.d, uxtw %p4]",
};

static const char *
output_4935 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1949 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (VNx16QImode, operands[1]);
    return aarch64_output_sve_prefetch ("prfb", operands[2], "%0, %1");
  }
}

static const char *
output_4936 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1949 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (VNx8HImode, operands[1]);
    return aarch64_output_sve_prefetch ("prfh", operands[2], "%0, %1");
  }
}

static const char *
output_4937 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1949 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (VNx4SImode, operands[1]);
    return aarch64_output_sve_prefetch ("prfw", operands[2], "%0, %1");
  }
}

static const char *
output_4938 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1949 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (VNx2DImode, operands[1]);
    return aarch64_output_sve_prefetch ("prfd", operands[2], "%0, %1");
  }
}

static const char *
output_4939 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1989 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%2.s]",
      "prfb", "%0, [%2.s, #%1]",
      "prfb", "%0, [%1, %2.s, sxtw]",
      "prfb", "%0, [%1, %2.s, uxtw]",
      "prfb", "%0, [%1, %2.s, sxtw %p4]",
      "prfb", "%0, [%1, %2.s, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4940 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1989 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfh", "%0, [%2.s]",
      "prfh", "%0, [%2.s, #%1]",
      "prfb", "%0, [%1, %2.s, sxtw]",
      "prfb", "%0, [%1, %2.s, uxtw]",
      "prfh", "%0, [%1, %2.s, sxtw %p4]",
      "prfh", "%0, [%1, %2.s, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4941 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1989 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfw", "%0, [%2.s]",
      "prfw", "%0, [%2.s, #%1]",
      "prfb", "%0, [%1, %2.s, sxtw]",
      "prfb", "%0, [%1, %2.s, uxtw]",
      "prfw", "%0, [%1, %2.s, sxtw %p4]",
      "prfw", "%0, [%1, %2.s, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4942 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 1989 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfd", "%0, [%2.s]",
      "prfd", "%0, [%2.s, #%1]",
      "prfb", "%0, [%1, %2.s, sxtw]",
      "prfb", "%0, [%1, %2.s, uxtw]",
      "prfd", "%0, [%1, %2.s, sxtw %p4]",
      "prfd", "%0, [%1, %2.s, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4943 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2018 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%2.d]",
      "prfb", "%0, [%2.d, #%1]",
      "prfb", "%0, [%1, %2.d]",
      "prfb", "%0, [%1, %2.d, lsl %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4944 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2018 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfh", "%0, [%2.d]",
      "prfh", "%0, [%2.d, #%1]",
      "prfb", "%0, [%1, %2.d]",
      "prfh", "%0, [%1, %2.d, lsl %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4945 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2018 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfw", "%0, [%2.d]",
      "prfw", "%0, [%2.d, #%1]",
      "prfb", "%0, [%1, %2.d]",
      "prfw", "%0, [%1, %2.d, lsl %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4946 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2018 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfd", "%0, [%2.d]",
      "prfd", "%0, [%2.d, #%1]",
      "prfb", "%0, [%1, %2.d]",
      "prfd", "%0, [%1, %2.d, lsl %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4947 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2049 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, sxtw]",
      "prfb", "%0, [%1, %2.d, sxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4948 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2049 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, sxtw]",
      "prfh", "%0, [%1, %2.d, sxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4949 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2049 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, sxtw]",
      "prfw", "%0, [%1, %2.d, sxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4950 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2049 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, sxtw]",
      "prfd", "%0, [%1, %2.d, sxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4951 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2079 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, uxtw]",
      "prfb", "%0, [%1, %2.d, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4952 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2079 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, uxtw]",
      "prfh", "%0, [%1, %2.d, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4953 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2079 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, uxtw]",
      "prfw", "%0, [%1, %2.d, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char *
output_4954 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2079 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    static const char *const insns[][2] = {
      "prfb", "%0, [%1, %2.d, uxtw]",
      "prfd", "%0, [%1, %2.d, uxtw %p4]"
    };
    const char *const *parts = insns[which_alternative];
    return aarch64_output_sve_prefetch (parts[0], operands[6], parts[1]);
  }
}

static const char * const output_5012[] = {
  "st1b\t%4.s, %5, [%1.s]",
  "st1b\t%4.s, %5, [%1.s, #%0]",
  "st1b\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1b\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1b\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1b\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5013[] = {
  "st1h\t%4.s, %5, [%1.s]",
  "st1h\t%4.s, %5, [%1.s, #%0]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5014[] = {
  "st1h\t%4.s, %5, [%1.s]",
  "st1h\t%4.s, %5, [%1.s, #%0]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5015[] = {
  "st1h\t%4.s, %5, [%1.s]",
  "st1h\t%4.s, %5, [%1.s, #%0]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5016[] = {
  "st1w\t%4.s, %5, [%1.s]",
  "st1w\t%4.s, %5, [%1.s, #%0]",
  "st1w\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1w\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1w\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1w\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5017[] = {
  "st1w\t%4.s, %5, [%1.s]",
  "st1w\t%4.s, %5, [%1.s, #%0]",
  "st1w\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1w\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1w\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1w\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5018[] = {
  "st1b\t%4.d, %5, [%1.d]",
  "st1b\t%4.d, %5, [%1.d, #%0]",
  "st1b\t%4.d, %5, [%0, %1.d]",
  "st1b\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5019[] = {
  "st1h\t%4.d, %5, [%1.d]",
  "st1h\t%4.d, %5, [%1.d, #%0]",
  "st1h\t%4.d, %5, [%0, %1.d]",
  "st1h\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5020[] = {
  "st1h\t%4.d, %5, [%1.d]",
  "st1h\t%4.d, %5, [%1.d, #%0]",
  "st1h\t%4.d, %5, [%0, %1.d]",
  "st1h\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5021[] = {
  "st1h\t%4.d, %5, [%1.d]",
  "st1h\t%4.d, %5, [%1.d, #%0]",
  "st1h\t%4.d, %5, [%0, %1.d]",
  "st1h\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5022[] = {
  "st1w\t%4.d, %5, [%1.d]",
  "st1w\t%4.d, %5, [%1.d, #%0]",
  "st1w\t%4.d, %5, [%0, %1.d]",
  "st1w\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5023[] = {
  "st1w\t%4.d, %5, [%1.d]",
  "st1w\t%4.d, %5, [%1.d, #%0]",
  "st1w\t%4.d, %5, [%0, %1.d]",
  "st1w\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5024[] = {
  "st1d\t%4.d, %5, [%1.d]",
  "st1d\t%4.d, %5, [%1.d, #%0]",
  "st1d\t%4.d, %5, [%0, %1.d]",
  "st1d\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5025[] = {
  "st1d\t%4.d, %5, [%1.d]",
  "st1d\t%4.d, %5, [%1.d, #%0]",
  "st1d\t%4.d, %5, [%0, %1.d]",
  "st1d\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5026[] = {
  "st1b\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1b\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5027[] = {
  "st1b\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1b\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5028[] = {
  "st1h\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5029[] = {
  "st1h\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5030[] = {
  "st1h\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5031[] = {
  "st1h\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5032[] = {
  "st1h\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5033[] = {
  "st1h\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5034[] = {
  "st1w\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5035[] = {
  "st1w\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5036[] = {
  "st1w\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5037[] = {
  "st1w\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5038[] = {
  "st1d\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5039[] = {
  "st1d\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5040[] = {
  "st1d\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5041[] = {
  "st1d\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5042[] = {
  "st1b\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1b\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5043[] = {
  "st1h\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5044[] = {
  "st1h\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5045[] = {
  "st1h\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5046[] = {
  "st1w\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5047[] = {
  "st1w\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5048[] = {
  "st1d\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5049[] = {
  "st1d\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5050[] = {
  "st1b\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1b\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5051[] = {
  "st1h\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5052[] = {
  "st1h\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5053[] = {
  "st1h\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5054[] = {
  "st1w\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5055[] = {
  "st1w\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5056[] = {
  "st1d\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5057[] = {
  "st1d\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1d\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5058[] = {
  "st1b\t%4.s, %5, [%1.s]",
  "st1b\t%4.s, %5, [%1.s, #%0]",
  "st1b\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1b\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1b\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1b\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5059[] = {
  "st1h\t%4.s, %5, [%1.s]",
  "st1h\t%4.s, %5, [%1.s, #%0]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw]",
  "st1h\t%4.s, %5, [%0, %1.s, sxtw %p3]",
  "st1h\t%4.s, %5, [%0, %1.s, uxtw %p3]",
};

static const char * const output_5060[] = {
  "st1b\t%4.d, %5, [%1.d]",
  "st1b\t%4.d, %5, [%1.d, #%0]",
  "st1b\t%4.d, %5, [%0, %1.d]",
  "st1b\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5061[] = {
  "st1h\t%4.d, %5, [%1.d]",
  "st1h\t%4.d, %5, [%1.d, #%0]",
  "st1h\t%4.d, %5, [%0, %1.d]",
  "st1h\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5062[] = {
  "st1w\t%4.d, %5, [%1.d]",
  "st1w\t%4.d, %5, [%1.d, #%0]",
  "st1w\t%4.d, %5, [%0, %1.d]",
  "st1w\t%4.d, %5, [%0, %1.d, lsl %p3]",
};

static const char * const output_5063[] = {
  "st1b\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1b\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5064[] = {
  "st1h\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5065[] = {
  "st1w\t%4.d, %5, [%0, %1.d, sxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, sxtw %p3]",
};

static const char * const output_5066[] = {
  "st1b\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1b\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5067[] = {
  "st1h\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1h\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5068[] = {
  "st1w\t%4.d, %5, [%0, %1.d, uxtw]",
  "st1w\t%4.d, %5, [%0, %1.d, uxtw %p3]",
};

static const char * const output_5069[] = {
  "mov\t%0.b, %w1",
  "mov\t%0.b, %b1",
  "#",
};

static const char * const output_5070[] = {
  "mov\t%0.b, %w1",
  "mov\t%0.b, %b1",
  "#",
};

static const char * const output_5071[] = {
  "mov\t%0.b, %w1",
  "mov\t%0.b, %b1",
  "#",
};

static const char * const output_5072[] = {
  "mov\t%0.b, %w1",
  "mov\t%0.b, %b1",
  "#",
};

static const char * const output_5073[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5074[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5075[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5076[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5077[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5078[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5079[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5080[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5081[] = {
  "mov\t%0.h, %w1",
  "mov\t%0.h, %h1",
  "#",
};

static const char * const output_5082[] = {
  "mov\t%0.s, %w1",
  "mov\t%0.s, %s1",
  "#",
};

static const char * const output_5083[] = {
  "mov\t%0.s, %w1",
  "mov\t%0.s, %s1",
  "#",
};

static const char * const output_5084[] = {
  "mov\t%0.s, %w1",
  "mov\t%0.s, %s1",
  "#",
};

static const char * const output_5085[] = {
  "mov\t%0.s, %w1",
  "mov\t%0.s, %s1",
  "#",
};

static const char * const output_5086[] = {
  "mov\t%0.d, %x1",
  "mov\t%0.d, %d1",
  "#",
};

static const char * const output_5087[] = {
  "mov\t%0.d, %x1",
  "mov\t%0.d, %d1",
  "#",
};

static const char *
output_5088 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx16QImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5089 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx8HImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5090 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx4SImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5091 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx2DImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5092 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx8BFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5093 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx8HFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5094 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx4SFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5095 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2541 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx2DFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5096 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx16QImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5097 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx8HImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5098 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx4SImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5099 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx2DImode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5100 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx8BFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5101 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx8HFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5102 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx4SFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5103 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2562 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (VNx2DFmode, REGNO (operands[1]));
    return "dup\t%0.q, %1.q[0]";
  }
}

static const char *
output_5123 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (QImode, XEXP (operands[1], 0));
    return "ld1rqb\t%0.b, %2/z, %1";
  }
}

static const char *
output_5124 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (HImode, XEXP (operands[1], 0));
    return "ld1rqh\t%0.h, %2/z, %1";
  }
}

static const char *
output_5125 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (SImode, XEXP (operands[1], 0));
    return "ld1rqw\t%0.s, %2/z, %1";
  }
}

static const char *
output_5126 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (DImode, XEXP (operands[1], 0));
    return "ld1rqd\t%0.d, %2/z, %1";
  }
}

static const char *
output_5127 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (BFmode, XEXP (operands[1], 0));
    return "ld1rqh\t%0.h, %2/z, %1";
  }
}

static const char *
output_5128 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (HFmode, XEXP (operands[1], 0));
    return "ld1rqh\t%0.h, %2/z, %1";
  }
}

static const char *
output_5129 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (SFmode, XEXP (operands[1], 0));
    return "ld1rqw\t%0.s, %2/z, %1";
  }
}

static const char *
output_5130 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2592 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (DFmode, XEXP (operands[1], 0));
    return "ld1rqd\t%0.d, %2/z, %1";
  }
}

static const char *
output_5131 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (QImode, XEXP (operands[1], 0));
    return "ld1rob\t%0.b, %2/z, %1";
  }
}

static const char *
output_5132 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (HImode, XEXP (operands[1], 0));
    return "ld1roh\t%0.h, %2/z, %1";
  }
}

static const char *
output_5133 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (SImode, XEXP (operands[1], 0));
    return "ld1row\t%0.s, %2/z, %1";
  }
}

static const char *
output_5134 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (DImode, XEXP (operands[1], 0));
    return "ld1rod\t%0.d, %2/z, %1";
  }
}

static const char *
output_5135 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (BFmode, XEXP (operands[1], 0));
    return "ld1roh\t%0.h, %2/z, %1";
  }
}

static const char *
output_5136 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (HFmode, XEXP (operands[1], 0));
    return "ld1roh\t%0.h, %2/z, %1";
  }
}

static const char *
output_5137 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (SFmode, XEXP (operands[1], 0));
    return "ld1row\t%0.s, %2/z, %1";
  }
}

static const char *
output_5138 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2606 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_MEM (DFmode, XEXP (operands[1], 0));
    return "ld1rod\t%0.d, %2/z, %1";
  }
}

static const char * const output_5139[] = {
  "insr\t%0.b, %w2",
  "insr\t%0.b, %b2",
  "movprfx\t%0, %1\n\tinsr\t%0.b, %w2",
  "movprfx\t%0, %1\n\tinsr\t%0.b, %b2",
};

static const char * const output_5140[] = {
  "insr\t%0.h, %w2",
  "insr\t%0.h, %h2",
  "movprfx\t%0, %1\n\tinsr\t%0.h, %w2",
  "movprfx\t%0, %1\n\tinsr\t%0.h, %h2",
};

static const char * const output_5141[] = {
  "insr\t%0.s, %w2",
  "insr\t%0.s, %s2",
  "movprfx\t%0, %1\n\tinsr\t%0.s, %w2",
  "movprfx\t%0, %1\n\tinsr\t%0.s, %s2",
};

static const char * const output_5142[] = {
  "insr\t%0.d, %x2",
  "insr\t%0.d, %d2",
  "movprfx\t%0, %1\n\tinsr\t%0.d, %x2",
  "movprfx\t%0, %1\n\tinsr\t%0.d, %d2",
};

static const char * const output_5143[] = {
  "insr\t%0.h, %w2",
  "insr\t%0.h, %h2",
  "movprfx\t%0, %1\n\tinsr\t%0.h, %w2",
  "movprfx\t%0, %1\n\tinsr\t%0.h, %h2",
};

static const char * const output_5144[] = {
  "insr\t%0.h, %w2",
  "insr\t%0.h, %h2",
  "movprfx\t%0, %1\n\tinsr\t%0.h, %w2",
  "movprfx\t%0, %1\n\tinsr\t%0.h, %h2",
};

static const char * const output_5145[] = {
  "insr\t%0.s, %w2",
  "insr\t%0.s, %s2",
  "movprfx\t%0, %1\n\tinsr\t%0.s, %w2",
  "movprfx\t%0, %1\n\tinsr\t%0.s, %s2",
};

static const char * const output_5146[] = {
  "insr\t%0.d, %x2",
  "insr\t%0.d, %d2",
  "movprfx\t%0, %1\n\tinsr\t%0.d, %x2",
  "movprfx\t%0, %1\n\tinsr\t%0.d, %d2",
};

static const char * const output_5147[] = {
  "index\t%0.b, #%1, %w2",
  "index\t%0.b, %w1, #%2",
  "index\t%0.b, %w1, %w2",
};

static const char * const output_5148[] = {
  "index\t%0.h, #%1, %w2",
  "index\t%0.h, %w1, #%2",
  "index\t%0.h, %w1, %w2",
};

static const char * const output_5149[] = {
  "index\t%0.s, #%1, %w2",
  "index\t%0.s, %w1, #%2",
  "index\t%0.s, %w1, %w2",
};

static const char * const output_5150[] = {
  "index\t%0.d, #%1, %x2",
  "index\t%0.d, %x1, #%2",
  "index\t%0.d, %x1, %x2",
};

static const char * const output_5151[] = {
  "index\t%0.h, #%1, %w2",
  "index\t%0.h, %w1, #%2",
  "index\t%0.h, %w1, %w2",
};

static const char * const output_5152[] = {
  "index\t%0.s, #%1, %w2",
  "index\t%0.s, %w1, #%2",
  "index\t%0.s, %w1, %w2",
};

static const char * const output_5153[] = {
  "index\t%0.d, #%1, %x2",
  "index\t%0.d, %x1, #%2",
  "index\t%0.d, %x1, %x2",
};

static const char * const output_5154[] = {
  "index\t%0.s, #%1, %w2",
  "index\t%0.s, %w1, #%2",
  "index\t%0.s, %w1, %w2",
};

static const char * const output_5155[] = {
  "index\t%0.d, #%1, %x2",
  "index\t%0.d, %x1, #%2",
  "index\t%0.d, %x1, %x2",
};

static const char * const output_5156[] = {
  "index\t%0.d, #%1, %x2",
  "index\t%0.d, %x1, #%2",
  "index\t%0.d, %x1, %x2",
};

static const char *
output_5157 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.b, %w1, #%2";
  }
}

static const char *
output_5158 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.h, %w1, #%2";
  }
}

static const char *
output_5159 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.s, %w1, #%2";
  }
}

static const char *
output_5160 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.d, %x1, #%2";
  }
}

static const char *
output_5161 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.h, %w1, #%2";
  }
}

static const char *
output_5162 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.s, %w1, #%2";
  }
}

static const char *
output_5163 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.d, %x1, #%2";
  }
}

static const char *
output_5164 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.s, %w1, #%2";
  }
}

static const char *
output_5165 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.d, %x1, #%2";
  }
}

static const char *
output_5166 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2673 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[2] = aarch64_check_zero_based_sve_index_immediate (operands[2]);
    return "index\t%0.d, %x1, #%2";
  }
}

static const char *
output_5167 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V16QImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.b[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.b}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5168 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V8HImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.h}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5169 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V4SImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.s}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5170 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V2DImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%x0, %1.d[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.d}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5171 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V8BFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.h}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5172 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V8HFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.h}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5173 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V4SFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.s}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5174 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2764 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V2DFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%x0, %1.d[0]";
	case 1:
	  return "#";
	case 2:
	  return "st1\t{%1.d}[0], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5175 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V16QImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.b[%2]";
	case 1:
	  return "dup\t%b0, %1.b[%2]";
	case 2:
	  return "st1\t{%1.b}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5176 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V8HImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5177 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V4SImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[%2]";
	case 1:
	  return "dup\t%s0, %1.s[%2]";
	case 2:
	  return "st1\t{%1.s}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5178 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V2DImode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%x0, %1.d[%2]";
	case 1:
	  return "dup\t%d0, %1.d[%2]";
	case 2:
	  return "st1\t{%1.d}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5179 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V8BFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5180 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V8HFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.h[%2]";
	case 1:
	  return "dup\t%h0, %1.h[%2]";
	case 2:
	  return "st1\t{%1.h}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5181 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V4SFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%w0, %1.s[%2]";
	case 1:
	  return "dup\t%s0, %1.s[%2]";
	case 2:
	  return "st1\t{%1.s}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5182 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2799 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[1] = gen_rtx_REG (V2DFmode, REGNO (operands[1]));
    switch (which_alternative)
      {
	case 0:
	  return "umov\t%x0, %1.d[%2]";
	case 1:
	  return "dup\t%d0, %1.d[%2]";
	case 2:
	  return "st1\t{%1.d}[%2], %0";
	default:
	  gcc_unreachable ();
      }
  }
}

static const char *
output_5183 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx16QImode, REGNO (operands[0]));
    return "dup\t%0.b, %1.b[%2]";
  }
}

static const char *
output_5184 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx8HImode, REGNO (operands[0]));
    return "dup\t%0.h, %1.h[%2]";
  }
}

static const char *
output_5185 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx4SImode, REGNO (operands[0]));
    return "dup\t%0.s, %1.s[%2]";
  }
}

static const char *
output_5186 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx2DImode, REGNO (operands[0]));
    return "dup\t%0.d, %1.d[%2]";
  }
}

static const char *
output_5187 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx8BFmode, REGNO (operands[0]));
    return "dup\t%0.h, %1.h[%2]";
  }
}

static const char *
output_5188 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx8HFmode, REGNO (operands[0]));
    return "dup\t%0.h, %1.h[%2]";
  }
}

static const char *
output_5189 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx4SFmode, REGNO (operands[0]));
    return "dup\t%0.s, %1.s[%2]";
  }
}

static const char *
output_5190 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2825 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx2DFmode, REGNO (operands[0]));
    return "dup\t%0.d, %1.d[%2]";
  }
}

static const char *
output_5191 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx16QImode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (QImode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char *
output_5192 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx8HImode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (HImode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char *
output_5193 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx4SImode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (SImode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char *
output_5194 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx2DImode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (DImode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char *
output_5195 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx8BFmode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (BFmode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char *
output_5196 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx8HFmode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (HFmode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char *
output_5197 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx4SFmode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (SFmode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char *
output_5198 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 2839 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[0] = gen_rtx_REG (VNx2DFmode, REGNO (operands[0]));
    operands[2] = GEN_INT (INTVAL (operands[2]) * GET_MODE_SIZE (DFmode));
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %0.b, #%2"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %1.b, #%2");
  }
}

static const char * const output_5199[] = {
  "lasta\t%w0, %1, %2.b",
  "lasta\t%b0, %1, %2.b",
};

static const char * const output_5200[] = {
  "lastb\t%w0, %1, %2.b",
  "lastb\t%b0, %1, %2.b",
};

static const char * const output_5201[] = {
  "lasta\t%w0, %1, %2.h",
  "lasta\t%h0, %1, %2.h",
};

static const char * const output_5202[] = {
  "lastb\t%w0, %1, %2.h",
  "lastb\t%h0, %1, %2.h",
};

static const char * const output_5203[] = {
  "lasta\t%w0, %1, %2.s",
  "lasta\t%s0, %1, %2.s",
};

static const char * const output_5204[] = {
  "lastb\t%w0, %1, %2.s",
  "lastb\t%s0, %1, %2.s",
};

static const char * const output_5205[] = {
  "lasta\t%x0, %1, %2.d",
  "lasta\t%d0, %1, %2.d",
};

static const char * const output_5206[] = {
  "lastb\t%x0, %1, %2.d",
  "lastb\t%d0, %1, %2.d",
};

static const char * const output_5207[] = {
  "lasta\t%w0, %1, %2.h",
  "lasta\t%h0, %1, %2.h",
};

static const char * const output_5208[] = {
  "lastb\t%w0, %1, %2.h",
  "lastb\t%h0, %1, %2.h",
};

static const char * const output_5209[] = {
  "lasta\t%w0, %1, %2.h",
  "lasta\t%h0, %1, %2.h",
};

static const char * const output_5210[] = {
  "lastb\t%w0, %1, %2.h",
  "lastb\t%h0, %1, %2.h",
};

static const char * const output_5211[] = {
  "lasta\t%w0, %1, %2.s",
  "lasta\t%s0, %1, %2.s",
};

static const char * const output_5212[] = {
  "lastb\t%w0, %1, %2.s",
  "lastb\t%s0, %1, %2.s",
};

static const char * const output_5213[] = {
  "lasta\t%x0, %1, %2.d",
  "lasta\t%d0, %1, %2.d",
};

static const char * const output_5214[] = {
  "lastb\t%x0, %1, %2.d",
  "lastb\t%d0, %1, %2.d",
};

static const char * const output_5215[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5216[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5217[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5218[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5219[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5220[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5221[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5222[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5223[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5224[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5225[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5226[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5227[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5228[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5229[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5230[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5231[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5232[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5233[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5234[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5235[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5236[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5237[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5238[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5239[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5240[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5241[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5242[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5243[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5244[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5245[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5246[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5247[] = {
  "abs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5248[] = {
  "neg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5249[] = {
  "not\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5250[] = {
  "cls\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5251[] = {
  "clz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5252[] = {
  "cnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5253[] = {
  "sqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5254[] = {
  "sqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5255[] = {
  "abs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5256[] = {
  "neg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5257[] = {
  "not\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5258[] = {
  "cls\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5259[] = {
  "clz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5260[] = {
  "cnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5261[] = {
  "sqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5262[] = {
  "sqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5263[] = {
  "abs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5264[] = {
  "neg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5265[] = {
  "not\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5266[] = {
  "cls\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5267[] = {
  "clz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5268[] = {
  "cnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5269[] = {
  "sqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5270[] = {
  "sqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5271[] = {
  "abs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5272[] = {
  "neg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5273[] = {
  "not\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5274[] = {
  "cls\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tcls\t%0.s, %1/m, %2.s",
};

static const char * const output_5275[] = {
  "clz\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tclz\t%0.s, %1/m, %2.s",
};

static const char * const output_5276[] = {
  "cnt\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tcnt\t%0.s, %1/m, %2.s",
};

static const char * const output_5277[] = {
  "sqabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsqabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5278[] = {
  "sqneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsqneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5279[] = {
  "abs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5280[] = {
  "neg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5281[] = {
  "not\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5282[] = {
  "cls\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tcls\t%0.s, %1/m, %2.s",
};

static const char * const output_5283[] = {
  "clz\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tclz\t%0.s, %1/m, %2.s",
};

static const char * const output_5284[] = {
  "cnt\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tcnt\t%0.s, %1/m, %2.s",
};

static const char * const output_5285[] = {
  "sqabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsqabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5286[] = {
  "sqneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsqneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5287[] = {
  "abs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5288[] = {
  "neg\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5289[] = {
  "not\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tnot\t%0.d, %1/m, %2.d",
};

static const char * const output_5290[] = {
  "cls\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tcls\t%0.d, %1/m, %2.d",
};

static const char * const output_5291[] = {
  "clz\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tclz\t%0.d, %1/m, %2.d",
};

static const char * const output_5292[] = {
  "cnt\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tcnt\t%0.d, %1/m, %2.d",
};

static const char * const output_5293[] = {
  "sqabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsqabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5294[] = {
  "sqneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsqneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5295[] = {
  "abs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5296[] = {
  "neg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5297[] = {
  "not\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5298[] = {
  "cls\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5299[] = {
  "clz\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5300[] = {
  "cnt\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5301[] = {
  "sqabs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5302[] = {
  "sqneg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5303[] = {
  "abs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5304[] = {
  "neg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5305[] = {
  "not\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5306[] = {
  "cls\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5307[] = {
  "clz\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5308[] = {
  "cnt\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5309[] = {
  "sqabs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5310[] = {
  "sqneg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5311[] = {
  "abs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5312[] = {
  "neg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5313[] = {
  "not\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5314[] = {
  "cls\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5315[] = {
  "clz\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5316[] = {
  "cnt\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5317[] = {
  "sqabs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5318[] = {
  "sqneg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5319[] = {
  "abs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5320[] = {
  "neg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5321[] = {
  "not\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5322[] = {
  "cls\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5323[] = {
  "clz\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5324[] = {
  "cnt\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5325[] = {
  "sqabs\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5326[] = {
  "sqneg\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5327[] = {
  "abs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5328[] = {
  "neg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5329[] = {
  "not\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5330[] = {
  "cls\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5331[] = {
  "clz\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5332[] = {
  "cnt\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5333[] = {
  "sqabs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5334[] = {
  "sqneg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5335[] = {
  "abs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5336[] = {
  "neg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5337[] = {
  "not\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5338[] = {
  "cls\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5339[] = {
  "clz\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5340[] = {
  "cnt\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5341[] = {
  "sqabs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5342[] = {
  "sqneg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5343[] = {
  "abs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5344[] = {
  "neg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5345[] = {
  "not\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5346[] = {
  "cls\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5347[] = {
  "clz\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5348[] = {
  "cnt\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5349[] = {
  "sqabs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5350[] = {
  "sqneg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5351[] = {
  "abs\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5352[] = {
  "neg\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5353[] = {
  "not\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5354[] = {
  "cls\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tcls\t%0.s, %1/m, %2.s",
};

static const char * const output_5355[] = {
  "clz\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tclz\t%0.s, %1/m, %2.s",
};

static const char * const output_5356[] = {
  "cnt\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tcnt\t%0.s, %1/m, %2.s",
};

static const char * const output_5357[] = {
  "sqabs\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tsqabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5358[] = {
  "sqneg\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tsqneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5359[] = {
  "abs\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5360[] = {
  "neg\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5361[] = {
  "not\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5362[] = {
  "cls\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tcls\t%0.s, %1/m, %2.s",
};

static const char * const output_5363[] = {
  "clz\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tclz\t%0.s, %1/m, %2.s",
};

static const char * const output_5364[] = {
  "cnt\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tcnt\t%0.s, %1/m, %2.s",
};

static const char * const output_5365[] = {
  "sqabs\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tsqabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5366[] = {
  "sqneg\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tsqneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5367[] = {
  "abs\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5368[] = {
  "neg\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5369[] = {
  "not\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tnot\t%0.d, %1/m, %2.d",
};

static const char * const output_5370[] = {
  "cls\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tcls\t%0.d, %1/m, %2.d",
};

static const char * const output_5371[] = {
  "clz\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tclz\t%0.d, %1/m, %2.d",
};

static const char * const output_5372[] = {
  "cnt\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tcnt\t%0.d, %1/m, %2.d",
};

static const char * const output_5373[] = {
  "sqabs\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tsqabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5374[] = {
  "sqneg\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tsqneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5375[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5376[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5377[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5378[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5379[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tclz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5380[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5381[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5382[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5383[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5384[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5385[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5386[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5387[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tclz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5388[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5389[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5390[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5391[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5392[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5393[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5394[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5395[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tclz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5396[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5397[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5398[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5399[] = {
  "abs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5400[] = {
  "neg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5401[] = {
  "not\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5402[] = {
  "cls\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcls\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcls\t%0.b, %1/m, %2.b",
};

static const char * const output_5403[] = {
  "clz\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tclz\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tclz\t%0.b, %1/m, %2.b",
};

static const char * const output_5404[] = {
  "cnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnt\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tcnt\t%0.b, %1/m, %2.b",
};

static const char * const output_5405[] = {
  "sqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqabs\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqabs\t%0.b, %1/m, %2.b",
};

static const char * const output_5406[] = {
  "sqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqneg\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\tsqneg\t%0.b, %1/m, %2.b",
};

static const char * const output_5407[] = {
  "abs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5408[] = {
  "neg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5409[] = {
  "not\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5410[] = {
  "cls\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcls\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5411[] = {
  "clz\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tclz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5412[] = {
  "cnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5413[] = {
  "sqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5414[] = {
  "sqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5415[] = {
  "abs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5416[] = {
  "neg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5417[] = {
  "not\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5418[] = {
  "cls\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcls\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5419[] = {
  "clz\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tclz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5420[] = {
  "cnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5421[] = {
  "sqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5422[] = {
  "sqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5423[] = {
  "abs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5424[] = {
  "neg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5425[] = {
  "not\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5426[] = {
  "cls\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcls\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tcls\t%0.h, %1/m, %2.h",
};

static const char * const output_5427[] = {
  "clz\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tclz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tclz\t%0.h, %1/m, %2.h",
};

static const char * const output_5428[] = {
  "cnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcnt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tcnt\t%0.h, %1/m, %2.h",
};

static const char * const output_5429[] = {
  "sqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tsqabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5430[] = {
  "sqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tsqneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5431[] = {
  "abs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5432[] = {
  "neg\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5433[] = {
  "not\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5434[] = {
  "cls\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tcls\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tcls\t%0.s, %1/m, %2.s",
};

static const char * const output_5435[] = {
  "clz\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tclz\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tclz\t%0.s, %1/m, %2.s",
};

static const char * const output_5436[] = {
  "cnt\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tcnt\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tcnt\t%0.s, %1/m, %2.s",
};

static const char * const output_5437[] = {
  "sqabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tsqabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5438[] = {
  "sqneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tsqneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5439[] = {
  "abs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5440[] = {
  "neg\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5441[] = {
  "not\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5442[] = {
  "cls\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tcls\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tcls\t%0.s, %1/m, %2.s",
};

static const char * const output_5443[] = {
  "clz\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tclz\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tclz\t%0.s, %1/m, %2.s",
};

static const char * const output_5444[] = {
  "cnt\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tcnt\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tcnt\t%0.s, %1/m, %2.s",
};

static const char * const output_5445[] = {
  "sqabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tsqabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5446[] = {
  "sqneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tsqneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5447[] = {
  "abs\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5448[] = {
  "neg\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5449[] = {
  "not\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tnot\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tnot\t%0.d, %1/m, %2.d",
};

static const char * const output_5450[] = {
  "cls\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tcls\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tcls\t%0.d, %1/m, %2.d",
};

static const char * const output_5451[] = {
  "clz\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tclz\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tclz\t%0.d, %1/m, %2.d",
};

static const char * const output_5452[] = {
  "cnt\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tcnt\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tcnt\t%0.d, %1/m, %2.d",
};

static const char * const output_5453[] = {
  "sqabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsqabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tsqabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5454[] = {
  "sqneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsqneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tsqneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5455[] = {
  "rbit\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\trbit\t%0.b, %1/m, %2.b",
};

static const char * const output_5456[] = {
  "rbit\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\trbit\t%0.h, %1/m, %2.h",
};

static const char * const output_5457[] = {
  "revb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\trevb\t%0.h, %1/m, %2.h",
};

static const char * const output_5458[] = {
  "rbit\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trbit\t%0.s, %1/m, %2.s",
};

static const char * const output_5459[] = {
  "revb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trevb\t%0.s, %1/m, %2.s",
};

static const char * const output_5460[] = {
  "revh\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trevh\t%0.s, %1/m, %2.s",
};

static const char * const output_5461[] = {
  "rbit\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trbit\t%0.d, %1/m, %2.d",
};

static const char * const output_5462[] = {
  "revb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevb\t%0.d, %1/m, %2.d",
};

static const char * const output_5463[] = {
  "revh\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevh\t%0.d, %1/m, %2.d",
};

static const char * const output_5464[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5465[] = {
  "revb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\trevb\t%0.h, %1/m, %2.h",
};

static const char * const output_5466[] = {
  "revb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trevb\t%0.s, %1/m, %2.s",
};

static const char * const output_5467[] = {
  "revh\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trevh\t%0.s, %1/m, %2.s",
};

static const char * const output_5468[] = {
  "revh\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trevh\t%0.s, %1/m, %2.s",
};

static const char * const output_5469[] = {
  "revh\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trevh\t%0.s, %1/m, %2.s",
};

static const char * const output_5470[] = {
  "revh\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\trevh\t%0.s, %1/m, %2.s",
};

static const char * const output_5471[] = {
  "revb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevb\t%0.d, %1/m, %2.d",
};

static const char * const output_5472[] = {
  "revh\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevh\t%0.d, %1/m, %2.d",
};

static const char * const output_5473[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5474[] = {
  "revh\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevh\t%0.d, %1/m, %2.d",
};

static const char * const output_5475[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5476[] = {
  "revh\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevh\t%0.d, %1/m, %2.d",
};

static const char * const output_5477[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5478[] = {
  "revh\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevh\t%0.d, %1/m, %2.d",
};

static const char * const output_5479[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5480[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5481[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5482[] = {
  "rbit\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\trbit\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %3\n\trbit\t%0.b, %1/m, %2.b",
};

static const char * const output_5483[] = {
  "rbit\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\trbit\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\trbit\t%0.h, %1/m, %2.h",
};

static const char * const output_5484[] = {
  "revb\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\trevb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\trevb\t%0.h, %1/m, %2.h",
};

static const char * const output_5485[] = {
  "rbit\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\trbit\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\trbit\t%0.s, %1/m, %2.s",
};

static const char * const output_5486[] = {
  "revb\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\trevb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\trevb\t%0.s, %1/m, %2.s",
};

static const char * const output_5487[] = {
  "revh\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\trevh\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\trevh\t%0.s, %1/m, %2.s",
};

static const char * const output_5488[] = {
  "rbit\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\trbit\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\trbit\t%0.d, %1/m, %2.d",
};

static const char * const output_5489[] = {
  "revb\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\trevb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\trevb\t%0.d, %1/m, %2.d",
};

static const char * const output_5490[] = {
  "revh\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\trevh\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\trevh\t%0.d, %1/m, %2.d",
};

static const char * const output_5491[] = {
  "revw\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\trevw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\trevw\t%0.d, %1/m, %2.d",
};

static const char * const output_5492[] = {
  "sxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5493[] = {
  "uxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tuxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5494[] = {
  "sxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5495[] = {
  "uxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tuxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5496[] = {
  "sxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5497[] = {
  "uxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tuxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5498[] = {
  "sxtb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsxtb\t%0.s, %1/m, %2.s",
};

static const char * const output_5499[] = {
  "uxtb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tuxtb\t%0.s, %1/m, %2.s",
};

static const char * const output_5500[] = {
  "sxth\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsxth\t%0.s, %1/m, %2.s",
};

static const char * const output_5501[] = {
  "uxth\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tuxth\t%0.s, %1/m, %2.s",
};

static const char * const output_5502[] = {
  "sxtb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsxtb\t%0.s, %1/m, %2.s",
};

static const char * const output_5503[] = {
  "uxtb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tuxtb\t%0.s, %1/m, %2.s",
};

static const char * const output_5504[] = {
  "sxth\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsxth\t%0.s, %1/m, %2.s",
};

static const char * const output_5505[] = {
  "uxth\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tuxth\t%0.s, %1/m, %2.s",
};

static const char * const output_5506[] = {
  "sxtb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsxtb\t%0.d, %1/m, %2.d",
};

static const char * const output_5507[] = {
  "uxtb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tuxtb\t%0.d, %1/m, %2.d",
};

static const char * const output_5508[] = {
  "sxth\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsxth\t%0.d, %1/m, %2.d",
};

static const char * const output_5509[] = {
  "uxth\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tuxth\t%0.d, %1/m, %2.d",
};

static const char * const output_5510[] = {
  "sxtw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsxtw\t%0.d, %1/m, %2.d",
};

static const char * const output_5511[] = {
  "uxtw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tuxtw\t%0.d, %1/m, %2.d",
};

static const char * const output_5512[] = {
  "sxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tsxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5513[] = {
  "sxtb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsxtb\t%0.s, %1/m, %2.s",
};

static const char * const output_5514[] = {
  "sxth\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tsxth\t%0.s, %1/m, %2.s",
};

static const char * const output_5515[] = {
  "sxtb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsxtb\t%0.d, %1/m, %2.d",
};

static const char * const output_5516[] = {
  "sxth\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsxth\t%0.d, %1/m, %2.d",
};

static const char * const output_5517[] = {
  "sxtw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tsxtw\t%0.d, %1/m, %2.d",
};

static const char * const output_5518[] = {
  "sxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsxtb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tsxtb\t%0.h, %1/m, %2.h",
};

static const char * const output_5519[] = {
  "sxtb\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsxtb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tsxtb\t%0.s, %1/m, %2.s",
};

static const char * const output_5520[] = {
  "sxth\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsxth\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tsxth\t%0.s, %1/m, %2.s",
};

static const char * const output_5521[] = {
  "sxtb\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsxtb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tsxtb\t%0.d, %1/m, %2.d",
};

static const char * const output_5522[] = {
  "sxth\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsxth\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tsxth\t%0.d, %1/m, %2.d",
};

static const char * const output_5523[] = {
  "sxtw\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsxtw\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tsxtw\t%0.d, %1/m, %2.d",
};

static const char * const output_5524[] = {
  "uxt%e3\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5525[] = {
  "uxt%e3\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5526[] = {
  "uxt%e3\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5527[] = {
  "uxt%e3\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5528[] = {
  "uxt%e3\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.h, %1/m, %2.h",
};

static const char * const output_5529[] = {
  "uxt%e3\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.h, %1/m, %2.h",
};

static const char * const output_5530[] = {
  "uxt%e3\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.h, %1/m, %2.h",
};

static const char * const output_5531[] = {
  "uxt%e3\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.s, %1/m, %2.s",
};

static const char * const output_5532[] = {
  "uxt%e3\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.s, %1/m, %2.s",
};

static const char * const output_5533[] = {
  "uxt%e3\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tuxt%e3\t%0.d, %1/m, %2.d",
};

static const char * const output_5534[] = {
  "uxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5535[] = {
  "uxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5536[] = {
  "uxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5537[] = {
  "uxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuxt%e3\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.b, %1/m, %2.b",
};

static const char * const output_5538[] = {
  "uxt%e3\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuxt%e3\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.h, %1/m, %2.h",
};

static const char * const output_5539[] = {
  "uxt%e3\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuxt%e3\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.h, %1/m, %2.h",
};

static const char * const output_5540[] = {
  "uxt%e3\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuxt%e3\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.h, %1/m, %2.h",
};

static const char * const output_5541[] = {
  "uxt%e3\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuxt%e3\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.s, %1/m, %2.s",
};

static const char * const output_5542[] = {
  "uxt%e3\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuxt%e3\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.s, %1/m, %2.s",
};

static const char * const output_5543[] = {
  "uxt%e3\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuxt%e3\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %4\n\tuxt%e3\t%0.d, %1/m, %2.d",
};

static const char * const output_5554[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5555[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5556[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5557[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5558[] = {
  "cnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5559[] = {
  "cnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5560[] = {
  "cnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5561[] = {
  "cnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tcnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5562[] = {
  "cnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tcnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5563[] = {
  "cnot\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tcnot\t%0.d, %1/m, %2.d",
};

static const char * const output_5564[] = {
  "cnot\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5565[] = {
  "cnot\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5566[] = {
  "cnot\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5567[] = {
  "cnot\t%0.b, %1/m, %0.b",
  "movprfx\t%0, %2\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5568[] = {
  "cnot\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5569[] = {
  "cnot\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5570[] = {
  "cnot\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5571[] = {
  "cnot\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tcnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5572[] = {
  "cnot\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tcnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5573[] = {
  "cnot\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tcnot\t%0.d, %1/m, %2.d",
};

static const char * const output_5574[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %6\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5575[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %6\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5576[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %6\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5577[] = {
  "cnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tcnot\t%0.b, %1/m, %2.b",
  "movprfx\t%0, %6\n\tcnot\t%0.b, %1/m, %2.b",
};

static const char * const output_5578[] = {
  "cnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %6\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5579[] = {
  "cnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %6\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5580[] = {
  "cnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tcnot\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %6\n\tcnot\t%0.h, %1/m, %2.h",
};

static const char * const output_5581[] = {
  "cnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tcnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %6\n\tcnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5582[] = {
  "cnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tcnot\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %6\n\tcnot\t%0.s, %1/m, %2.s",
};

static const char * const output_5583[] = {
  "cnot\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tcnot\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %6\n\tcnot\t%0.d, %1/m, %2.d",
};

static const char * const output_5593[] = {
  "fabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5594[] = {
  "fneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5595[] = {
  "frecpx\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrecpx\t%0.h, %1/m, %2.h",
};

static const char * const output_5596[] = {
  "frinta\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrinta\t%0.h, %1/m, %2.h",
};

static const char * const output_5597[] = {
  "frinti\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrinti\t%0.h, %1/m, %2.h",
};

static const char * const output_5598[] = {
  "frintm\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrintm\t%0.h, %1/m, %2.h",
};

static const char * const output_5599[] = {
  "frintn\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrintn\t%0.h, %1/m, %2.h",
};

static const char * const output_5600[] = {
  "frintp\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrintp\t%0.h, %1/m, %2.h",
};

static const char * const output_5601[] = {
  "frintx\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrintx\t%0.h, %1/m, %2.h",
};

static const char * const output_5602[] = {
  "frintz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfrintz\t%0.h, %1/m, %2.h",
};

static const char * const output_5603[] = {
  "fsqrt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfsqrt\t%0.h, %1/m, %2.h",
};

static const char * const output_5604[] = {
  "fabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5605[] = {
  "fneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5606[] = {
  "frecpx\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrecpx\t%0.s, %1/m, %2.s",
};

static const char * const output_5607[] = {
  "frinta\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrinta\t%0.s, %1/m, %2.s",
};

static const char * const output_5608[] = {
  "frinti\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrinti\t%0.s, %1/m, %2.s",
};

static const char * const output_5609[] = {
  "frintm\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrintm\t%0.s, %1/m, %2.s",
};

static const char * const output_5610[] = {
  "frintn\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrintn\t%0.s, %1/m, %2.s",
};

static const char * const output_5611[] = {
  "frintp\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrintp\t%0.s, %1/m, %2.s",
};

static const char * const output_5612[] = {
  "frintx\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrintx\t%0.s, %1/m, %2.s",
};

static const char * const output_5613[] = {
  "frintz\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfrintz\t%0.s, %1/m, %2.s",
};

static const char * const output_5614[] = {
  "fsqrt\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfsqrt\t%0.s, %1/m, %2.s",
};

static const char * const output_5615[] = {
  "fabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5616[] = {
  "fneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5617[] = {
  "frecpx\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrecpx\t%0.d, %1/m, %2.d",
};

static const char * const output_5618[] = {
  "frinta\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrinta\t%0.d, %1/m, %2.d",
};

static const char * const output_5619[] = {
  "frinti\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrinti\t%0.d, %1/m, %2.d",
};

static const char * const output_5620[] = {
  "frintm\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrintm\t%0.d, %1/m, %2.d",
};

static const char * const output_5621[] = {
  "frintn\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrintn\t%0.d, %1/m, %2.d",
};

static const char * const output_5622[] = {
  "frintp\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrintp\t%0.d, %1/m, %2.d",
};

static const char * const output_5623[] = {
  "frintx\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrintx\t%0.d, %1/m, %2.d",
};

static const char * const output_5624[] = {
  "frintz\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfrintz\t%0.d, %1/m, %2.d",
};

static const char * const output_5625[] = {
  "fsqrt\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfsqrt\t%0.d, %1/m, %2.d",
};

static const char * const output_5626[] = {
  "fabs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5627[] = {
  "fneg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5628[] = {
  "frecpx\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrecpx\t%0.h, %1/m, %2.h",
};

static const char * const output_5629[] = {
  "frinta\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrinta\t%0.h, %1/m, %2.h",
};

static const char * const output_5630[] = {
  "frinti\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrinti\t%0.h, %1/m, %2.h",
};

static const char * const output_5631[] = {
  "frintm\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintm\t%0.h, %1/m, %2.h",
};

static const char * const output_5632[] = {
  "frintn\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintn\t%0.h, %1/m, %2.h",
};

static const char * const output_5633[] = {
  "frintp\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintp\t%0.h, %1/m, %2.h",
};

static const char * const output_5634[] = {
  "frintx\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintx\t%0.h, %1/m, %2.h",
};

static const char * const output_5635[] = {
  "frintz\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintz\t%0.h, %1/m, %2.h",
};

static const char * const output_5636[] = {
  "fsqrt\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfsqrt\t%0.h, %1/m, %2.h",
};

static const char * const output_5637[] = {
  "fabs\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5638[] = {
  "fneg\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5639[] = {
  "frecpx\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrecpx\t%0.s, %1/m, %2.s",
};

static const char * const output_5640[] = {
  "frinta\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrinta\t%0.s, %1/m, %2.s",
};

static const char * const output_5641[] = {
  "frinti\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrinti\t%0.s, %1/m, %2.s",
};

static const char * const output_5642[] = {
  "frintm\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintm\t%0.s, %1/m, %2.s",
};

static const char * const output_5643[] = {
  "frintn\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintn\t%0.s, %1/m, %2.s",
};

static const char * const output_5644[] = {
  "frintp\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintp\t%0.s, %1/m, %2.s",
};

static const char * const output_5645[] = {
  "frintx\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintx\t%0.s, %1/m, %2.s",
};

static const char * const output_5646[] = {
  "frintz\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintz\t%0.s, %1/m, %2.s",
};

static const char * const output_5647[] = {
  "fsqrt\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfsqrt\t%0.s, %1/m, %2.s",
};

static const char * const output_5648[] = {
  "fabs\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5649[] = {
  "fneg\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5650[] = {
  "frecpx\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrecpx\t%0.d, %1/m, %2.d",
};

static const char * const output_5651[] = {
  "frinta\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrinta\t%0.d, %1/m, %2.d",
};

static const char * const output_5652[] = {
  "frinti\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrinti\t%0.d, %1/m, %2.d",
};

static const char * const output_5653[] = {
  "frintm\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintm\t%0.d, %1/m, %2.d",
};

static const char * const output_5654[] = {
  "frintn\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintn\t%0.d, %1/m, %2.d",
};

static const char * const output_5655[] = {
  "frintp\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintp\t%0.d, %1/m, %2.d",
};

static const char * const output_5656[] = {
  "frintx\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintx\t%0.d, %1/m, %2.d",
};

static const char * const output_5657[] = {
  "frintz\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintz\t%0.d, %1/m, %2.d",
};

static const char * const output_5658[] = {
  "fsqrt\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfsqrt\t%0.d, %1/m, %2.d",
};

static const char * const output_5659[] = {
  "fabs\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5660[] = {
  "fneg\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5661[] = {
  "frecpx\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrecpx\t%0.h, %1/m, %2.h",
};

static const char * const output_5662[] = {
  "frinta\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrinta\t%0.h, %1/m, %2.h",
};

static const char * const output_5663[] = {
  "frinti\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrinti\t%0.h, %1/m, %2.h",
};

static const char * const output_5664[] = {
  "frintm\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintm\t%0.h, %1/m, %2.h",
};

static const char * const output_5665[] = {
  "frintn\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintn\t%0.h, %1/m, %2.h",
};

static const char * const output_5666[] = {
  "frintp\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintp\t%0.h, %1/m, %2.h",
};

static const char * const output_5667[] = {
  "frintx\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintx\t%0.h, %1/m, %2.h",
};

static const char * const output_5668[] = {
  "frintz\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfrintz\t%0.h, %1/m, %2.h",
};

static const char * const output_5669[] = {
  "fsqrt\t%0.h, %1/m, %0.h",
  "movprfx\t%0, %2\n\tfsqrt\t%0.h, %1/m, %2.h",
};

static const char * const output_5670[] = {
  "fabs\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5671[] = {
  "fneg\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5672[] = {
  "frecpx\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrecpx\t%0.s, %1/m, %2.s",
};

static const char * const output_5673[] = {
  "frinta\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrinta\t%0.s, %1/m, %2.s",
};

static const char * const output_5674[] = {
  "frinti\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrinti\t%0.s, %1/m, %2.s",
};

static const char * const output_5675[] = {
  "frintm\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintm\t%0.s, %1/m, %2.s",
};

static const char * const output_5676[] = {
  "frintn\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintn\t%0.s, %1/m, %2.s",
};

static const char * const output_5677[] = {
  "frintp\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintp\t%0.s, %1/m, %2.s",
};

static const char * const output_5678[] = {
  "frintx\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintx\t%0.s, %1/m, %2.s",
};

static const char * const output_5679[] = {
  "frintz\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfrintz\t%0.s, %1/m, %2.s",
};

static const char * const output_5680[] = {
  "fsqrt\t%0.s, %1/m, %0.s",
  "movprfx\t%0, %2\n\tfsqrt\t%0.s, %1/m, %2.s",
};

static const char * const output_5681[] = {
  "fabs\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5682[] = {
  "fneg\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5683[] = {
  "frecpx\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrecpx\t%0.d, %1/m, %2.d",
};

static const char * const output_5684[] = {
  "frinta\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrinta\t%0.d, %1/m, %2.d",
};

static const char * const output_5685[] = {
  "frinti\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrinti\t%0.d, %1/m, %2.d",
};

static const char * const output_5686[] = {
  "frintm\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintm\t%0.d, %1/m, %2.d",
};

static const char * const output_5687[] = {
  "frintn\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintn\t%0.d, %1/m, %2.d",
};

static const char * const output_5688[] = {
  "frintp\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintp\t%0.d, %1/m, %2.d",
};

static const char * const output_5689[] = {
  "frintx\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintx\t%0.d, %1/m, %2.d",
};

static const char * const output_5690[] = {
  "frintz\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfrintz\t%0.d, %1/m, %2.d",
};

static const char * const output_5691[] = {
  "fsqrt\t%0.d, %1/m, %0.d",
  "movprfx\t%0, %2\n\tfsqrt\t%0.d, %1/m, %2.d",
};

static const char * const output_5692[] = {
  "fabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5693[] = {
  "fneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5694[] = {
  "frecpx\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrecpx\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrecpx\t%0.h, %1/m, %2.h",
};

static const char * const output_5695[] = {
  "frinta\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrinta\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrinta\t%0.h, %1/m, %2.h",
};

static const char * const output_5696[] = {
  "frinti\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrinti\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrinti\t%0.h, %1/m, %2.h",
};

static const char * const output_5697[] = {
  "frintm\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintm\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintm\t%0.h, %1/m, %2.h",
};

static const char * const output_5698[] = {
  "frintn\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintn\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintn\t%0.h, %1/m, %2.h",
};

static const char * const output_5699[] = {
  "frintp\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintp\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintp\t%0.h, %1/m, %2.h",
};

static const char * const output_5700[] = {
  "frintx\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintx\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintx\t%0.h, %1/m, %2.h",
};

static const char * const output_5701[] = {
  "frintz\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintz\t%0.h, %1/m, %2.h",
};

static const char * const output_5702[] = {
  "fsqrt\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfsqrt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfsqrt\t%0.h, %1/m, %2.h",
};

static const char * const output_5703[] = {
  "fabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5704[] = {
  "fneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5705[] = {
  "frecpx\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrecpx\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrecpx\t%0.s, %1/m, %2.s",
};

static const char * const output_5706[] = {
  "frinta\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrinta\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrinta\t%0.s, %1/m, %2.s",
};

static const char * const output_5707[] = {
  "frinti\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrinti\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrinti\t%0.s, %1/m, %2.s",
};

static const char * const output_5708[] = {
  "frintm\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintm\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintm\t%0.s, %1/m, %2.s",
};

static const char * const output_5709[] = {
  "frintn\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintn\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintn\t%0.s, %1/m, %2.s",
};

static const char * const output_5710[] = {
  "frintp\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintp\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintp\t%0.s, %1/m, %2.s",
};

static const char * const output_5711[] = {
  "frintx\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintx\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintx\t%0.s, %1/m, %2.s",
};

static const char * const output_5712[] = {
  "frintz\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintz\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintz\t%0.s, %1/m, %2.s",
};

static const char * const output_5713[] = {
  "fsqrt\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfsqrt\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfsqrt\t%0.s, %1/m, %2.s",
};

static const char * const output_5714[] = {
  "fabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5715[] = {
  "fneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5716[] = {
  "frecpx\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrecpx\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrecpx\t%0.d, %1/m, %2.d",
};

static const char * const output_5717[] = {
  "frinta\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrinta\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrinta\t%0.d, %1/m, %2.d",
};

static const char * const output_5718[] = {
  "frinti\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrinti\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrinti\t%0.d, %1/m, %2.d",
};

static const char * const output_5719[] = {
  "frintm\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintm\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintm\t%0.d, %1/m, %2.d",
};

static const char * const output_5720[] = {
  "frintn\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintn\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintn\t%0.d, %1/m, %2.d",
};

static const char * const output_5721[] = {
  "frintp\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintp\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintp\t%0.d, %1/m, %2.d",
};

static const char * const output_5722[] = {
  "frintx\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintx\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintx\t%0.d, %1/m, %2.d",
};

static const char * const output_5723[] = {
  "frintz\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintz\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintz\t%0.d, %1/m, %2.d",
};

static const char * const output_5724[] = {
  "fsqrt\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfsqrt\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfsqrt\t%0.d, %1/m, %2.d",
};

static const char * const output_5725[] = {
  "fabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfabs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfabs\t%0.h, %1/m, %2.h",
};

static const char * const output_5726[] = {
  "fneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfneg\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfneg\t%0.h, %1/m, %2.h",
};

static const char * const output_5727[] = {
  "frecpx\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrecpx\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrecpx\t%0.h, %1/m, %2.h",
};

static const char * const output_5728[] = {
  "frinta\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrinta\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrinta\t%0.h, %1/m, %2.h",
};

static const char * const output_5729[] = {
  "frinti\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrinti\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrinti\t%0.h, %1/m, %2.h",
};

static const char * const output_5730[] = {
  "frintm\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintm\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintm\t%0.h, %1/m, %2.h",
};

static const char * const output_5731[] = {
  "frintn\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintn\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintn\t%0.h, %1/m, %2.h",
};

static const char * const output_5732[] = {
  "frintp\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintp\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintp\t%0.h, %1/m, %2.h",
};

static const char * const output_5733[] = {
  "frintx\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintx\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintx\t%0.h, %1/m, %2.h",
};

static const char * const output_5734[] = {
  "frintz\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfrintz\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfrintz\t%0.h, %1/m, %2.h",
};

static const char * const output_5735[] = {
  "fsqrt\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfsqrt\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfsqrt\t%0.h, %1/m, %2.h",
};

static const char * const output_5736[] = {
  "fabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfabs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfabs\t%0.s, %1/m, %2.s",
};

static const char * const output_5737[] = {
  "fneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfneg\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfneg\t%0.s, %1/m, %2.s",
};

static const char * const output_5738[] = {
  "frecpx\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrecpx\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrecpx\t%0.s, %1/m, %2.s",
};

static const char * const output_5739[] = {
  "frinta\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrinta\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrinta\t%0.s, %1/m, %2.s",
};

static const char * const output_5740[] = {
  "frinti\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrinti\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrinti\t%0.s, %1/m, %2.s",
};

static const char * const output_5741[] = {
  "frintm\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintm\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintm\t%0.s, %1/m, %2.s",
};

static const char * const output_5742[] = {
  "frintn\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintn\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintn\t%0.s, %1/m, %2.s",
};

static const char * const output_5743[] = {
  "frintp\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintp\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintp\t%0.s, %1/m, %2.s",
};

static const char * const output_5744[] = {
  "frintx\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintx\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintx\t%0.s, %1/m, %2.s",
};

static const char * const output_5745[] = {
  "frintz\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfrintz\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfrintz\t%0.s, %1/m, %2.s",
};

static const char * const output_5746[] = {
  "fsqrt\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfsqrt\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfsqrt\t%0.s, %1/m, %2.s",
};

static const char * const output_5747[] = {
  "fabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfabs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfabs\t%0.d, %1/m, %2.d",
};

static const char * const output_5748[] = {
  "fneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfneg\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfneg\t%0.d, %1/m, %2.d",
};

static const char * const output_5749[] = {
  "frecpx\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrecpx\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrecpx\t%0.d, %1/m, %2.d",
};

static const char * const output_5750[] = {
  "frinta\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrinta\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrinta\t%0.d, %1/m, %2.d",
};

static const char * const output_5751[] = {
  "frinti\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrinti\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrinti\t%0.d, %1/m, %2.d",
};

static const char * const output_5752[] = {
  "frintm\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintm\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintm\t%0.d, %1/m, %2.d",
};

static const char * const output_5753[] = {
  "frintn\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintn\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintn\t%0.d, %1/m, %2.d",
};

static const char * const output_5754[] = {
  "frintp\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintp\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintp\t%0.d, %1/m, %2.d",
};

static const char * const output_5755[] = {
  "frintx\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintx\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintx\t%0.d, %1/m, %2.d",
};

static const char * const output_5756[] = {
  "frintz\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfrintz\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfrintz\t%0.d, %1/m, %2.d",
};

static const char * const output_5757[] = {
  "fsqrt\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfsqrt\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfsqrt\t%0.d, %1/m, %2.d",
};

static const char * const output_5762[] = {
  "#",
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5763[] = {
  "#",
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5764[] = {
  "#",
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5765[] = {
  "#",
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5766[] = {
  "#",
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5767[] = {
  "#",
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5768[] = {
  "#",
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5769[] = {
  "#",
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5770[] = {
  "#",
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5771[] = {
  "#",
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5772[] = {
  "#",
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5773[] = {
  "#",
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5774[] = {
  "#",
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5775[] = {
  "#",
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5776[] = {
  "#",
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5777[] = {
  "#",
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5778[] = {
  "#",
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5779[] = {
  "#",
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5780[] = {
  "#",
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5781[] = {
  "#",
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5782[] = {
  "#",
  "mul\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5783[] = {
  "#",
  "smax\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5784[] = {
  "#",
  "smin\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5785[] = {
  "#",
  "umax\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5786[] = {
  "#",
  "umin\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5787[] = {
  "#",
  "mul\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5788[] = {
  "#",
  "smax\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5789[] = {
  "#",
  "smin\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5790[] = {
  "#",
  "umax\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5791[] = {
  "#",
  "umin\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5792[] = {
  "#",
  "mul\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5793[] = {
  "#",
  "smax\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5794[] = {
  "#",
  "smin\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5795[] = {
  "#",
  "umax\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5796[] = {
  "#",
  "umin\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5797[] = {
  "#",
  "mul\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5798[] = {
  "#",
  "smax\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5799[] = {
  "#",
  "smin\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5800[] = {
  "#",
  "umax\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5801[] = {
  "#",
  "umin\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5802[] = {
  "#",
  "mul\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5803[] = {
  "#",
  "smax\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5804[] = {
  "#",
  "smin\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5805[] = {
  "#",
  "umax\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5806[] = {
  "#",
  "umin\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5807[] = {
  "#",
  "mul\t%0.d, %1/m, %0.d, %3.d",
  "#",
  "movprfx\t%0, %2\n\tmul\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_5808[] = {
  "#",
  "smax\t%0.d, %1/m, %0.d, %3.d",
  "#",
  "movprfx\t%0, %2\n\tsmax\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_5809[] = {
  "#",
  "smin\t%0.d, %1/m, %0.d, %3.d",
  "#",
  "movprfx\t%0, %2\n\tsmin\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_5810[] = {
  "#",
  "umax\t%0.d, %1/m, %0.d, %3.d",
  "#",
  "movprfx\t%0, %2\n\tumax\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_5811[] = {
  "#",
  "umin\t%0.d, %1/m, %0.d, %3.d",
  "#",
  "movprfx\t%0, %2\n\tumin\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_5812[] = {
  "mul\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.b, %0.b, #%2",
};

static const char * const output_5813[] = {
  "smax\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.b, %0.b, #%2",
};

static const char * const output_5814[] = {
  "smin\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.b, %0.b, #%2",
};

static const char * const output_5815[] = {
  "umax\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.b, %0.b, #%D2",
};

static const char * const output_5816[] = {
  "umin\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.b, %0.b, #%D2",
};

static const char * const output_5817[] = {
  "mul\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.b, %0.b, #%2",
};

static const char * const output_5818[] = {
  "smax\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.b, %0.b, #%2",
};

static const char * const output_5819[] = {
  "smin\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.b, %0.b, #%2",
};

static const char * const output_5820[] = {
  "umax\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.b, %0.b, #%D2",
};

static const char * const output_5821[] = {
  "umin\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.b, %0.b, #%D2",
};

static const char * const output_5822[] = {
  "mul\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.b, %0.b, #%2",
};

static const char * const output_5823[] = {
  "smax\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.b, %0.b, #%2",
};

static const char * const output_5824[] = {
  "smin\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.b, %0.b, #%2",
};

static const char * const output_5825[] = {
  "umax\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.b, %0.b, #%D2",
};

static const char * const output_5826[] = {
  "umin\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.b, %0.b, #%D2",
};

static const char * const output_5827[] = {
  "mul\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.b, %0.b, #%2",
};

static const char * const output_5828[] = {
  "smax\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.b, %0.b, #%2",
};

static const char * const output_5829[] = {
  "smin\t%0.b, %0.b, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.b, %0.b, #%2",
};

static const char * const output_5830[] = {
  "umax\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.b, %0.b, #%D2",
};

static const char * const output_5831[] = {
  "umin\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.b, %0.b, #%D2",
};

static const char * const output_5832[] = {
  "mul\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.h, %0.h, #%2",
};

static const char * const output_5833[] = {
  "smax\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.h, %0.h, #%2",
};

static const char * const output_5834[] = {
  "smin\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.h, %0.h, #%2",
};

static const char * const output_5835[] = {
  "umax\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.h, %0.h, #%D2",
};

static const char * const output_5836[] = {
  "umin\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.h, %0.h, #%D2",
};

static const char * const output_5837[] = {
  "mul\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.h, %0.h, #%2",
};

static const char * const output_5838[] = {
  "smax\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.h, %0.h, #%2",
};

static const char * const output_5839[] = {
  "smin\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.h, %0.h, #%2",
};

static const char * const output_5840[] = {
  "umax\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.h, %0.h, #%D2",
};

static const char * const output_5841[] = {
  "umin\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.h, %0.h, #%D2",
};

static const char * const output_5842[] = {
  "mul\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.h, %0.h, #%2",
};

static const char * const output_5843[] = {
  "smax\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.h, %0.h, #%2",
};

static const char * const output_5844[] = {
  "smin\t%0.h, %0.h, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.h, %0.h, #%2",
};

static const char * const output_5845[] = {
  "umax\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.h, %0.h, #%D2",
};

static const char * const output_5846[] = {
  "umin\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.h, %0.h, #%D2",
};

static const char * const output_5847[] = {
  "mul\t%0.s, %0.s, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.s, %0.s, #%2",
};

static const char * const output_5848[] = {
  "smax\t%0.s, %0.s, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.s, %0.s, #%2",
};

static const char * const output_5849[] = {
  "smin\t%0.s, %0.s, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.s, %0.s, #%2",
};

static const char * const output_5850[] = {
  "umax\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.s, %0.s, #%D2",
};

static const char * const output_5851[] = {
  "umin\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.s, %0.s, #%D2",
};

static const char * const output_5852[] = {
  "mul\t%0.s, %0.s, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.s, %0.s, #%2",
};

static const char * const output_5853[] = {
  "smax\t%0.s, %0.s, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.s, %0.s, #%2",
};

static const char * const output_5854[] = {
  "smin\t%0.s, %0.s, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.s, %0.s, #%2",
};

static const char * const output_5855[] = {
  "umax\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.s, %0.s, #%D2",
};

static const char * const output_5856[] = {
  "umin\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.s, %0.s, #%D2",
};

static const char * const output_5857[] = {
  "mul\t%0.d, %0.d, #%2",
  "movprfx\t%0, %1\n\tmul\t%0.d, %0.d, #%2",
};

static const char * const output_5858[] = {
  "smax\t%0.d, %0.d, #%2",
  "movprfx\t%0, %1\n\tsmax\t%0.d, %0.d, #%2",
};

static const char * const output_5859[] = {
  "smin\t%0.d, %0.d, #%2",
  "movprfx\t%0, %1\n\tsmin\t%0.d, %0.d, #%2",
};

static const char * const output_5860[] = {
  "umax\t%0.d, %0.d, #%D2",
  "movprfx\t%0, %1\n\tumax\t%0.d, %0.d, #%D2",
};

static const char * const output_5861[] = {
  "umin\t%0.d, %0.d, #%D2",
  "movprfx\t%0, %1\n\tumin\t%0.d, %0.d, #%D2",
};

static const char * const output_5862[] = {
  "add\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5863[] = {
  "sub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5864[] = {
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5865[] = {
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5866[] = {
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5867[] = {
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5868[] = {
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5869[] = {
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5870[] = {
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5871[] = {
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5872[] = {
  "and\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tand\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5873[] = {
  "orr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\torr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5874[] = {
  "eor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\teor\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5875[] = {
  "sqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5876[] = {
  "uqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5877[] = {
  "sqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5878[] = {
  "uqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5879[] = {
  "add\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5880[] = {
  "sub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5881[] = {
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5882[] = {
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5883[] = {
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5884[] = {
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5885[] = {
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5886[] = {
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5887[] = {
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5888[] = {
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5889[] = {
  "and\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tand\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5890[] = {
  "orr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\torr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5891[] = {
  "eor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\teor\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5892[] = {
  "sqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5893[] = {
  "uqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5894[] = {
  "sqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5895[] = {
  "uqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5896[] = {
  "add\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5897[] = {
  "sub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5898[] = {
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5899[] = {
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5900[] = {
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5901[] = {
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5902[] = {
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5903[] = {
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5904[] = {
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5905[] = {
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5906[] = {
  "and\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tand\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5907[] = {
  "orr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\torr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5908[] = {
  "eor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\teor\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5909[] = {
  "sqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5910[] = {
  "uqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5911[] = {
  "sqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5912[] = {
  "uqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5913[] = {
  "add\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5914[] = {
  "sub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5915[] = {
  "mul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tmul\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5916[] = {
  "smax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5917[] = {
  "umax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumax\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5918[] = {
  "smin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5919[] = {
  "umin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumin\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5920[] = {
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5921[] = {
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5922[] = {
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5923[] = {
  "and\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tand\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5924[] = {
  "orr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\torr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5925[] = {
  "eor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\teor\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5926[] = {
  "sqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5927[] = {
  "uqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5928[] = {
  "sqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5929[] = {
  "uqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_5930[] = {
  "add\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5931[] = {
  "sub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5932[] = {
  "mul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5933[] = {
  "smax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5934[] = {
  "umax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5935[] = {
  "smin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5936[] = {
  "umin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5937[] = {
  "lsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5938[] = {
  "asr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5939[] = {
  "lsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5940[] = {
  "and\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tand\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5941[] = {
  "orr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\torr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5942[] = {
  "eor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\teor\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5943[] = {
  "sqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5944[] = {
  "uqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5945[] = {
  "sqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5946[] = {
  "uqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5947[] = {
  "add\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5948[] = {
  "sub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5949[] = {
  "mul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5950[] = {
  "smax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5951[] = {
  "umax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5952[] = {
  "smin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5953[] = {
  "umin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5954[] = {
  "lsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5955[] = {
  "asr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5956[] = {
  "lsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5957[] = {
  "and\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tand\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5958[] = {
  "orr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\torr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5959[] = {
  "eor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\teor\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5960[] = {
  "sqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5961[] = {
  "uqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5962[] = {
  "sqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5963[] = {
  "uqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5964[] = {
  "add\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5965[] = {
  "sub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5966[] = {
  "mul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5967[] = {
  "smax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5968[] = {
  "umax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5969[] = {
  "smin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5970[] = {
  "umin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5971[] = {
  "lsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5972[] = {
  "asr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5973[] = {
  "lsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5974[] = {
  "and\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tand\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5975[] = {
  "orr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\torr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5976[] = {
  "eor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\teor\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5977[] = {
  "sqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5978[] = {
  "uqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5979[] = {
  "sqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5980[] = {
  "uqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_5981[] = {
  "add\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5982[] = {
  "sub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5983[] = {
  "mul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tmul\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5984[] = {
  "smax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5985[] = {
  "umax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5986[] = {
  "smin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5987[] = {
  "umin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5988[] = {
  "lsl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5989[] = {
  "asr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tasr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5990[] = {
  "lsr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5991[] = {
  "and\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tand\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5992[] = {
  "orr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\torr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5993[] = {
  "eor\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\teor\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5994[] = {
  "sqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5995[] = {
  "uqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5996[] = {
  "sqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5997[] = {
  "uqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5998[] = {
  "add\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_5999[] = {
  "sub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6000[] = {
  "mul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tmul\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6001[] = {
  "smax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6002[] = {
  "umax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6003[] = {
  "smin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6004[] = {
  "umin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6005[] = {
  "lsl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6006[] = {
  "asr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tasr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6007[] = {
  "lsr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6008[] = {
  "and\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tand\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6009[] = {
  "orr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\torr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6010[] = {
  "eor\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\teor\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6011[] = {
  "sqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6012[] = {
  "uqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6013[] = {
  "sqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6014[] = {
  "uqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6015[] = {
  "add\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6016[] = {
  "sub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6017[] = {
  "mul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tmul\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6018[] = {
  "smax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsmax\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6019[] = {
  "umax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tumax\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6020[] = {
  "smin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsmin\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6021[] = {
  "umin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tumin\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6022[] = {
  "lsl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tlsl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6023[] = {
  "asr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tasr\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6024[] = {
  "lsr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tlsr\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6025[] = {
  "and\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tand\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6026[] = {
  "orr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\torr\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6027[] = {
  "eor\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\teor\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6028[] = {
  "sqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsqadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6029[] = {
  "uqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuqadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6030[] = {
  "sqsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsqsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6031[] = {
  "uqsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuqsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6032[] = {
  "add\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6033[] = {
  "subr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6034[] = {
  "mul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tmul\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6035[] = {
  "smax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6036[] = {
  "umax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6037[] = {
  "smin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6038[] = {
  "umin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6039[] = {
  "lslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6040[] = {
  "asrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6041[] = {
  "lsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6042[] = {
  "and\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tand\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6043[] = {
  "orr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\torr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6044[] = {
  "eor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\teor\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6045[] = {
  "sqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6046[] = {
  "uqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6047[] = {
  "sqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6048[] = {
  "uqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6049[] = {
  "add\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6050[] = {
  "subr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6051[] = {
  "mul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tmul\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6052[] = {
  "smax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6053[] = {
  "umax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6054[] = {
  "smin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6055[] = {
  "umin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6056[] = {
  "lslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6057[] = {
  "asrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6058[] = {
  "lsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6059[] = {
  "and\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tand\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6060[] = {
  "orr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\torr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6061[] = {
  "eor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\teor\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6062[] = {
  "sqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6063[] = {
  "uqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6064[] = {
  "sqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6065[] = {
  "uqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6066[] = {
  "add\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6067[] = {
  "subr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6068[] = {
  "mul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tmul\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6069[] = {
  "smax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6070[] = {
  "umax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6071[] = {
  "smin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6072[] = {
  "umin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6073[] = {
  "lslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6074[] = {
  "asrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6075[] = {
  "lsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6076[] = {
  "and\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tand\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6077[] = {
  "orr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\torr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6078[] = {
  "eor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\teor\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6079[] = {
  "sqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6080[] = {
  "uqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6081[] = {
  "sqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6082[] = {
  "uqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6083[] = {
  "add\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6084[] = {
  "subr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6085[] = {
  "mul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tmul\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6086[] = {
  "smax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6087[] = {
  "umax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumax\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6088[] = {
  "smin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6089[] = {
  "umin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tumin\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6090[] = {
  "lslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6091[] = {
  "asrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6092[] = {
  "lsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6093[] = {
  "and\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tand\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6094[] = {
  "orr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\torr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6095[] = {
  "eor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\teor\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6096[] = {
  "sqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6097[] = {
  "uqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6098[] = {
  "sqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6099[] = {
  "uqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6100[] = {
  "add\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6101[] = {
  "subr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6102[] = {
  "mul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tmul\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6103[] = {
  "smax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsmax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6104[] = {
  "umax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tumax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6105[] = {
  "smin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsmin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6106[] = {
  "umin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tumin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6107[] = {
  "lslr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tlslr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6108[] = {
  "asrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tasrr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6109[] = {
  "lsrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tlsrr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6110[] = {
  "and\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tand\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6111[] = {
  "orr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\torr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6112[] = {
  "eor\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\teor\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6113[] = {
  "sqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6114[] = {
  "uqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6115[] = {
  "sqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6116[] = {
  "uqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6117[] = {
  "add\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6118[] = {
  "subr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6119[] = {
  "mul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tmul\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6120[] = {
  "smax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsmax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6121[] = {
  "umax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tumax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6122[] = {
  "smin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsmin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6123[] = {
  "umin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tumin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6124[] = {
  "lslr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tlslr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6125[] = {
  "asrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tasrr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6126[] = {
  "lsrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tlsrr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6127[] = {
  "and\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tand\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6128[] = {
  "orr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\torr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6129[] = {
  "eor\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\teor\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6130[] = {
  "sqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6131[] = {
  "uqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6132[] = {
  "sqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6133[] = {
  "uqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6134[] = {
  "add\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6135[] = {
  "subr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6136[] = {
  "mul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tmul\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6137[] = {
  "smax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsmax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6138[] = {
  "umax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tumax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6139[] = {
  "smin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsmin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6140[] = {
  "umin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tumin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6141[] = {
  "lslr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tlslr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6142[] = {
  "asrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tasrr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6143[] = {
  "lsrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tlsrr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6144[] = {
  "and\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tand\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6145[] = {
  "orr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\torr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6146[] = {
  "eor\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\teor\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6147[] = {
  "sqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6148[] = {
  "uqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6149[] = {
  "sqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6150[] = {
  "uqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6151[] = {
  "add\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6152[] = {
  "subr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6153[] = {
  "mul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tmul\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6154[] = {
  "smax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsmax\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6155[] = {
  "umax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tumax\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6156[] = {
  "smin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsmin\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6157[] = {
  "umin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tumin\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6158[] = {
  "lslr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tlslr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6159[] = {
  "asrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tasrr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6160[] = {
  "lsrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tlsrr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6161[] = {
  "and\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tand\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6162[] = {
  "orr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\torr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6163[] = {
  "eor\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\teor\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6164[] = {
  "sqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsqadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6165[] = {
  "uqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuqadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6166[] = {
  "sqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsqsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6167[] = {
  "uqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuqsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6168[] = {
  "add\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6169[] = {
  "subr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6170[] = {
  "mul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tmul\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6171[] = {
  "smax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsmax\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6172[] = {
  "umax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tumax\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6173[] = {
  "smin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsmin\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6174[] = {
  "umin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tumin\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6175[] = {
  "lslr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tlslr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6176[] = {
  "asrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tasrr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6177[] = {
  "lsrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tlsrr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6178[] = {
  "and\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tand\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6179[] = {
  "orr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\torr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6180[] = {
  "eor\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\teor\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6181[] = {
  "sqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsqadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6182[] = {
  "uqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuqadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6183[] = {
  "sqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsqsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6184[] = {
  "uqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuqsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6185[] = {
  "add\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6186[] = {
  "subr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsubr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6187[] = {
  "mul\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tmul\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6188[] = {
  "smax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsmax\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6189[] = {
  "umax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tumax\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6190[] = {
  "smin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsmin\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6191[] = {
  "umin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tumin\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6192[] = {
  "lslr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tlslr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6193[] = {
  "asrr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tasrr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6194[] = {
  "lsrr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tlsrr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6195[] = {
  "and\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tand\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6196[] = {
  "orr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\torr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6197[] = {
  "eor\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\teor\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6198[] = {
  "sqadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsqadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6199[] = {
  "uqadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tuqadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6200[] = {
  "sqsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsqsubr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6201[] = {
  "uqsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tuqsubr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6202[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6203[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6204[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6205[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6206[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6207[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6208[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6209[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6210[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6211[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6212[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6213[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6214[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6215[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6216[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6217[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6218[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6219[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6220[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6221[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6222[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6223[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6224[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6225[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6226[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6227[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6228[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6229[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6230[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6231[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6232[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6233[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6234[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6235[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6236[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6237[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6238[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6239[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6240[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6241[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6242[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6243[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6244[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6245[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6246[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6247[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6248[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6249[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6250[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6251[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6252[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6253[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6254[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6255[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmul\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tmul\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6256[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6257[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumax\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumax\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6258[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsmin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsmin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6259[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tumin\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tumin\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6260[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlslr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6261[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tasrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6262[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tlsrr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6263[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tand\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tand\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6264[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\torr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\torr\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6265[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\teor\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\teor\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6266[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6267[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6268[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6269[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6270[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6271[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6272[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6273[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsmax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6274[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tumax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6275[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsmin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6276[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tumin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6277[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tlslr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6278[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tasrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6279[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tlsrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6280[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tand\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6281[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\torr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6282[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\teor\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6283[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6284[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6285[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6286[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6287[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6288[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6289[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6290[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsmax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6291[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tumax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6292[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsmin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6293[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tumin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6294[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tlslr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6295[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tasrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6296[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tlsrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6297[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tand\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6298[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\torr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6299[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\teor\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6300[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6301[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6302[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6303[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6304[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6305[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6306[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tmul\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6307[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsmax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsmax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6308[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tumax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tumax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6309[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsmin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsmin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6310[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tumin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tumin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6311[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tlslr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6312[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tasrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tasr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6313[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tlsrr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6314[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tand\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tand\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6315[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\torr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\torr\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6316[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\teor\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\teor\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6317[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6318[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6319[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6320[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6321[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6322[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6323[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tmul\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6324[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsmax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6325[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tumax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tumax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tumax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tumax\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6326[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsmin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6327[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tumin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tumin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tumin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tumin\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6328[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tlslr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6329[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tasr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tasrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tasr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tasr\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6330[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tlsrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6331[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tand\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tand\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tand\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tand\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6332[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\torr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\torr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\torr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\torr\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6333[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\teor\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\teor\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\teor\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\teor\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6334[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6335[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6336[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6337[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6338[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6339[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6340[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tmul\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6341[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsmax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsmax\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6342[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tumax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tumax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tumax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tumax\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6343[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsmin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsmin\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6344[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tumin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tumin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tumin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tumin\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6345[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tlslr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6346[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tasr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tasrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tasr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tasr\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6347[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tlsrr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6348[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tand\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tand\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tand\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tand\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6349[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\torr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\torr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\torr\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\torr\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6350[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\teor\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\teor\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\teor\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\teor\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6351[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6352[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuqadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuqadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6353[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6354[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuqsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuqsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6355[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6356[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsub\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6357[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tmul\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tmul\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6358[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsmax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsmax\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6359[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tumax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tumax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tumax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tumax\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6360[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsmin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsmin\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6361[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tumin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tumin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tumin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tumin\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6362[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tlsl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tlslr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tlsl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tlsl\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6363[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tasr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tasrr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tasr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tasr\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6364[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tlsr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tlsrr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tlsr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tlsr\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6365[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tand\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tand\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tand\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tand\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6366[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\torr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\torr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\torr\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\torr\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6367[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\teor\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\teor\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\teor\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\teor\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6368[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsqadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsqadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6369[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tuqadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tuqadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6370[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsqsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsqsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsqsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsqsub\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6371[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuqsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tuqsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuqsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tuqsub\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char *
output_6372 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.b, %0.b, #%D2";
    case 1: return "sub\t%0.b, %0.b, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.b", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.b, %0.b, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.b, %0.b, #%N2";
    case 5: return "add\t%0.b, %1.b, %2.b";
      default: gcc_unreachable ();
    }
}

static const char *
output_6373 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.b, %0.b, #%D2";
    case 1: return "sub\t%0.b, %0.b, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.b", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.b, %0.b, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.b, %0.b, #%N2";
    case 5: return "add\t%0.b, %1.b, %2.b";
      default: gcc_unreachable ();
    }
}

static const char *
output_6374 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.b, %0.b, #%D2";
    case 1: return "sub\t%0.b, %0.b, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.b", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.b, %0.b, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.b, %0.b, #%N2";
    case 5: return "add\t%0.b, %1.b, %2.b";
      default: gcc_unreachable ();
    }
}

static const char *
output_6375 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.b, %0.b, #%D2";
    case 1: return "sub\t%0.b, %0.b, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.b", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.b, %0.b, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.b, %0.b, #%N2";
    case 5: return "add\t%0.b, %1.b, %2.b";
      default: gcc_unreachable ();
    }
}

static const char *
output_6376 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.h, %0.h, #%D2";
    case 1: return "sub\t%0.h, %0.h, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.h", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.h, %0.h, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.h, %0.h, #%N2";
    case 5: return "add\t%0.h, %1.h, %2.h";
      default: gcc_unreachable ();
    }
}

static const char *
output_6377 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.h, %0.h, #%D2";
    case 1: return "sub\t%0.h, %0.h, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.h", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.h, %0.h, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.h, %0.h, #%N2";
    case 5: return "add\t%0.h, %1.h, %2.h";
      default: gcc_unreachable ();
    }
}

static const char *
output_6378 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.h, %0.h, #%D2";
    case 1: return "sub\t%0.h, %0.h, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.h", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.h, %0.h, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.h, %0.h, #%N2";
    case 5: return "add\t%0.h, %1.h, %2.h";
      default: gcc_unreachable ();
    }
}

static const char *
output_6379 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.s, %0.s, #%D2";
    case 1: return "sub\t%0.s, %0.s, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.s", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.s, %0.s, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.s, %0.s, #%N2";
    case 5: return "add\t%0.s, %1.s, %2.s";
      default: gcc_unreachable ();
    }
}

static const char *
output_6380 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.s, %0.s, #%D2";
    case 1: return "sub\t%0.s, %0.s, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.s", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.s, %0.s, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.s, %0.s, #%N2";
    case 5: return "add\t%0.s, %1.s, %2.s";
      default: gcc_unreachable ();
    }
}

static const char *
output_6381 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
  switch (which_alternative)
    {
    case 0: return "add\t%0.d, %0.d, #%D2";
    case 1: return "sub\t%0.d, %0.d, #%N2";
    case 2:
       return aarch64_output_sve_vector_inc_dec ("%0.d", operands[2]);
    case 3: return "movprfx\t%0, %1\n\tadd\t%0.d, %0.d, #%D2";
    case 4: return "movprfx\t%0, %1\n\tsub\t%0.d, %0.d, #%N2";
    case 5: return "add\t%0.d, %1.d, %2.d";
      default: gcc_unreachable ();
    }
}

static const char * const output_6382[] = {
  "sub\t%0.b, %1.b, %2.b",
  "subr\t%0.b, %0.b, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.b, %0.b, #%D1",
};

static const char * const output_6383[] = {
  "sub\t%0.b, %1.b, %2.b",
  "subr\t%0.b, %0.b, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.b, %0.b, #%D1",
};

static const char * const output_6384[] = {
  "sub\t%0.b, %1.b, %2.b",
  "subr\t%0.b, %0.b, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.b, %0.b, #%D1",
};

static const char * const output_6385[] = {
  "sub\t%0.b, %1.b, %2.b",
  "subr\t%0.b, %0.b, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.b, %0.b, #%D1",
};

static const char * const output_6386[] = {
  "sub\t%0.h, %1.h, %2.h",
  "subr\t%0.h, %0.h, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.h, %0.h, #%D1",
};

static const char * const output_6387[] = {
  "sub\t%0.h, %1.h, %2.h",
  "subr\t%0.h, %0.h, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.h, %0.h, #%D1",
};

static const char * const output_6388[] = {
  "sub\t%0.h, %1.h, %2.h",
  "subr\t%0.h, %0.h, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.h, %0.h, #%D1",
};

static const char * const output_6389[] = {
  "sub\t%0.s, %1.s, %2.s",
  "subr\t%0.s, %0.s, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.s, %0.s, #%D1",
};

static const char * const output_6390[] = {
  "sub\t%0.s, %1.s, %2.s",
  "subr\t%0.s, %0.s, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.s, %0.s, #%D1",
};

static const char * const output_6391[] = {
  "sub\t%0.d, %1.d, %2.d",
  "subr\t%0.d, %0.d, #%D1",
  "movprfx\t%0, %2\n\tsubr\t%0.d, %0.d, #%D1",
};

static const char * const output_6406[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6407[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6408[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6409[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6410[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6411[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6412[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6413[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6414[] = {
  "sabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6415[] = {
  "uabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6416[] = {
  "sabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6417[] = {
  "uabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6418[] = {
  "sabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6419[] = {
  "uabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6420[] = {
  "sabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6421[] = {
  "uabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6422[] = {
  "sabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6423[] = {
  "uabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6424[] = {
  "sabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6425[] = {
  "uabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6426[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6427[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6428[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6429[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6430[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6431[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6432[] = {
  "sabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6433[] = {
  "uabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6434[] = {
  "sabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6435[] = {
  "uabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6436[] = {
  "sabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6437[] = {
  "uabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6438[] = {
  "sabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6439[] = {
  "uabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6440[] = {
  "sabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6441[] = {
  "uabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6442[] = {
  "sabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6443[] = {
  "uabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6444[] = {
  "sabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6445[] = {
  "uabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6446[] = {
  "sabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6447[] = {
  "uabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6448[] = {
  "sabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6449[] = {
  "uabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6450[] = {
  "sabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6451[] = {
  "uabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6452[] = {
  "sabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6453[] = {
  "uabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_6454[] = {
  "sabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6455[] = {
  "uabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6456[] = {
  "sabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6457[] = {
  "uabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6458[] = {
  "sabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6459[] = {
  "uabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6460[] = {
  "sabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsabd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6461[] = {
  "uabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuabd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6462[] = {
  "sabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsabd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6463[] = {
  "uabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuabd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6464[] = {
  "sabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsabd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6465[] = {
  "uabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tuabd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6466[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6467[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6468[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6469[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6470[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6471[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6472[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6473[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuabd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuabd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6474[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6475[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6476[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6477[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6478[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6479[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6480[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6481[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6482[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsabd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6483[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuabd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6484[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsabd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6485[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tuabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tuabd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6486[] = {
  "sqadd\t%0.b, %0.b, #%D2",
  "sqsub\t%0.b, %0.b, #%N2",
  "movprfx\t%0, %1\n\tsqadd\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tsqsub\t%0.b, %0.b, #%N2",
  "sqadd\t%0.b, %1.b, %2.b",
};

static const char * const output_6487[] = {
  "sqsub\t%0.b, %0.b, #%D2",
  "sqadd\t%0.b, %0.b, #%N2",
  "movprfx\t%0, %1\n\tsqsub\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.b, %0.b, #%N2",
  "sqsub\t%0.b, %1.b, %2.b",
};

static const char * const output_6488[] = {
  "sqadd\t%0.h, %0.h, #%D2",
  "sqsub\t%0.h, %0.h, #%N2",
  "movprfx\t%0, %1\n\tsqadd\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tsqsub\t%0.h, %0.h, #%N2",
  "sqadd\t%0.h, %1.h, %2.h",
};

static const char * const output_6489[] = {
  "sqsub\t%0.h, %0.h, #%D2",
  "sqadd\t%0.h, %0.h, #%N2",
  "movprfx\t%0, %1\n\tsqsub\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.h, %0.h, #%N2",
  "sqsub\t%0.h, %1.h, %2.h",
};

static const char * const output_6490[] = {
  "sqadd\t%0.s, %0.s, #%D2",
  "sqsub\t%0.s, %0.s, #%N2",
  "movprfx\t%0, %1\n\tsqadd\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tsqsub\t%0.s, %0.s, #%N2",
  "sqadd\t%0.s, %1.s, %2.s",
};

static const char * const output_6491[] = {
  "sqsub\t%0.s, %0.s, #%D2",
  "sqadd\t%0.s, %0.s, #%N2",
  "movprfx\t%0, %1\n\tsqsub\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.s, %0.s, #%N2",
  "sqsub\t%0.s, %1.s, %2.s",
};

static const char * const output_6492[] = {
  "sqadd\t%0.d, %0.d, #%D2",
  "sqsub\t%0.d, %0.d, #%N2",
  "movprfx\t%0, %1\n\tsqadd\t%0.d, %0.d, #%D2",
  "movprfx\t%0, %1\n\tsqsub\t%0.d, %0.d, #%N2",
  "sqadd\t%0.d, %1.d, %2.d",
};

static const char * const output_6493[] = {
  "sqsub\t%0.d, %0.d, #%D2",
  "sqadd\t%0.d, %0.d, #%N2",
  "movprfx\t%0, %1\n\tsqsub\t%0.d, %0.d, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.d, %0.d, #%N2",
  "sqsub\t%0.d, %1.d, %2.d",
};

static const char * const output_6494[] = {
  "uqadd\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tuqadd\t%0.b, %0.b, #%D2",
  "uqadd\t%0.b, %1.b, %2.b",
};

static const char * const output_6495[] = {
  "uqsub\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tuqsub\t%0.b, %0.b, #%D2",
  "uqsub\t%0.b, %1.b, %2.b",
};

static const char * const output_6496[] = {
  "uqadd\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tuqadd\t%0.h, %0.h, #%D2",
  "uqadd\t%0.h, %1.h, %2.h",
};

static const char * const output_6497[] = {
  "uqsub\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tuqsub\t%0.h, %0.h, #%D2",
  "uqsub\t%0.h, %1.h, %2.h",
};

static const char * const output_6498[] = {
  "uqadd\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tuqadd\t%0.s, %0.s, #%D2",
  "uqadd\t%0.s, %1.s, %2.s",
};

static const char * const output_6499[] = {
  "uqsub\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tuqsub\t%0.s, %0.s, #%D2",
  "uqsub\t%0.s, %1.s, %2.s",
};

static const char * const output_6500[] = {
  "uqadd\t%0.d, %0.d, #%D2",
  "movprfx\t%0, %1\n\tuqadd\t%0.d, %0.d, #%D2",
  "uqadd\t%0.d, %1.d, %2.d",
};

static const char * const output_6501[] = {
  "uqsub\t%0.d, %0.d, #%D2",
  "movprfx\t%0, %1\n\tuqsub\t%0.d, %0.d, #%D2",
  "uqsub\t%0.d, %1.d, %2.d",
};

static const char * const output_6502[] = {
  "smulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6503[] = {
  "umulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6504[] = {
  "smulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6505[] = {
  "umulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6506[] = {
  "smulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6507[] = {
  "umulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6508[] = {
  "smulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6509[] = {
  "umulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6510[] = {
  "smulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6511[] = {
  "umulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6512[] = {
  "smulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6513[] = {
  "umulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6514[] = {
  "smulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6515[] = {
  "umulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6516[] = {
  "smulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6517[] = {
  "umulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6518[] = {
  "smulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6519[] = {
  "umulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6520[] = {
  "smulh\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsmulh\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6521[] = {
  "umulh\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tumulh\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6522[] = {
  "smulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6523[] = {
  "umulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6524[] = {
  "smulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6525[] = {
  "umulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6526[] = {
  "smulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6527[] = {
  "umulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6528[] = {
  "smulh\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsmulh\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6529[] = {
  "umulh\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tumulh\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6530[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsmulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsmulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6531[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tumulh\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tumulh\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6532[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsmulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsmulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6533[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tumulh\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tumulh\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6534[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsmulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsmulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6535[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tumulh\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tumulh\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6536[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsmulh\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsmulh\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6537[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tumulh\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tumulh\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6538[] = {
  "sdiv\t%0.s, %1/m, %0.s, %3.s",
  "sdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tsdiv\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6539[] = {
  "udiv\t%0.s, %1/m, %0.s, %3.s",
  "udivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tudiv\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6540[] = {
  "sdiv\t%0.d, %1/m, %0.d, %3.d",
  "sdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tsdiv\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6541[] = {
  "udiv\t%0.d, %1/m, %0.d, %3.d",
  "udivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tudiv\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6542[] = {
  "sdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsdiv\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6543[] = {
  "udiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tudiv\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6544[] = {
  "sdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsdiv\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6545[] = {
  "udiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tudiv\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6546[] = {
  "sdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsdivr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6547[] = {
  "udivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tudivr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6548[] = {
  "sdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsdivr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6549[] = {
  "udivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tudivr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6550[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsdiv\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6551[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tudiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tudivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tudiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tudiv\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6552[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsdiv\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6553[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tudiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tudivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tudiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tudiv\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6554[] = {
  "and\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.b, %0.b, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6555[] = {
  "orr\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.b, %0.b, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6556[] = {
  "eor\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.b, %0.b, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6557[] = {
  "and\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.b, %0.b, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6558[] = {
  "orr\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.b, %0.b, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6559[] = {
  "eor\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.b, %0.b, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6560[] = {
  "and\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.b, %0.b, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6561[] = {
  "orr\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.b, %0.b, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6562[] = {
  "eor\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.b, %0.b, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6563[] = {
  "and\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.b, %0.b, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6564[] = {
  "orr\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.b, %0.b, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6565[] = {
  "eor\t%0.b, %0.b, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.b, %0.b, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6566[] = {
  "and\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.h, %0.h, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6567[] = {
  "orr\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.h, %0.h, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6568[] = {
  "eor\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.h, %0.h, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6569[] = {
  "and\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.h, %0.h, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6570[] = {
  "orr\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.h, %0.h, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6571[] = {
  "eor\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.h, %0.h, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6572[] = {
  "and\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.h, %0.h, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6573[] = {
  "orr\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.h, %0.h, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6574[] = {
  "eor\t%0.h, %0.h, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.h, %0.h, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6575[] = {
  "and\t%0.s, %0.s, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.s, %0.s, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6576[] = {
  "orr\t%0.s, %0.s, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.s, %0.s, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6577[] = {
  "eor\t%0.s, %0.s, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.s, %0.s, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6578[] = {
  "and\t%0.s, %0.s, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.s, %0.s, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6579[] = {
  "orr\t%0.s, %0.s, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.s, %0.s, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6580[] = {
  "eor\t%0.s, %0.s, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.s, %0.s, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6581[] = {
  "and\t%0.d, %0.d, #%C2",
  "movprfx\t%0, %1\n\tand\t%0.d, %0.d, #%C2",
  "and\t%0.d, %1.d, %2.d",
};

static const char * const output_6582[] = {
  "orr\t%0.d, %0.d, #%C2",
  "movprfx\t%0, %1\n\torr\t%0.d, %0.d, #%C2",
  "orr\t%0.d, %1.d, %2.d",
};

static const char * const output_6583[] = {
  "eor\t%0.d, %0.d, #%C2",
  "movprfx\t%0, %1\n\teor\t%0.d, %0.d, #%C2",
  "eor\t%0.d, %1.d, %2.d",
};

static const char * const output_6594[] = {
  "bic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tbic\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6595[] = {
  "bic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tbic\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6596[] = {
  "bic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tbic\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6597[] = {
  "bic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tbic\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6598[] = {
  "bic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tbic\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6599[] = {
  "bic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tbic\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6600[] = {
  "bic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tbic\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6601[] = {
  "bic\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tbic\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6602[] = {
  "bic\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tbic\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6603[] = {
  "bic\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tbic\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6604[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6605[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6606[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6607[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tbic\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_6608[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6609[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6610[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tbic\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6611[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tbic\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tbic\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tbic\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6612[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tbic\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tbic\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tbic\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6613[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tbic\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tbic\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tbic\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6614[] = {
  "#",
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "lslr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6615[] = {
  "#",
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "asrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6616[] = {
  "#",
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "lsrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6617[] = {
  "#",
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "lslr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6618[] = {
  "#",
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "asrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6619[] = {
  "#",
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "lsrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6620[] = {
  "#",
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "lslr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6621[] = {
  "#",
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "asrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6622[] = {
  "#",
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "lsrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6623[] = {
  "#",
  "lsl\t%0.b, %1/m, %0.b, %3.b",
  "lslr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6624[] = {
  "#",
  "asr\t%0.b, %1/m, %0.b, %3.b",
  "asrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6625[] = {
  "#",
  "lsr\t%0.b, %1/m, %0.b, %3.b",
  "lsrr\t%0.b, %1/m, %3.b, %2.b",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_6626[] = {
  "#",
  "lsl\t%0.h, %1/m, %0.h, %3.h",
  "lslr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6627[] = {
  "#",
  "asr\t%0.h, %1/m, %0.h, %3.h",
  "asrr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6628[] = {
  "#",
  "lsr\t%0.h, %1/m, %0.h, %3.h",
  "lsrr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6629[] = {
  "#",
  "lsl\t%0.h, %1/m, %0.h, %3.h",
  "lslr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6630[] = {
  "#",
  "asr\t%0.h, %1/m, %0.h, %3.h",
  "asrr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6631[] = {
  "#",
  "lsr\t%0.h, %1/m, %0.h, %3.h",
  "lsrr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6632[] = {
  "#",
  "lsl\t%0.h, %1/m, %0.h, %3.h",
  "lslr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6633[] = {
  "#",
  "asr\t%0.h, %1/m, %0.h, %3.h",
  "asrr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6634[] = {
  "#",
  "lsr\t%0.h, %1/m, %0.h, %3.h",
  "lsrr\t%0.h, %1/m, %3.h, %2.h",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6635[] = {
  "#",
  "lsl\t%0.s, %1/m, %0.s, %3.s",
  "lslr\t%0.s, %1/m, %3.s, %2.s",
  "movprfx\t%0, %2\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6636[] = {
  "#",
  "asr\t%0.s, %1/m, %0.s, %3.s",
  "asrr\t%0.s, %1/m, %3.s, %2.s",
  "movprfx\t%0, %2\n\tasr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6637[] = {
  "#",
  "lsr\t%0.s, %1/m, %0.s, %3.s",
  "lsrr\t%0.s, %1/m, %3.s, %2.s",
  "movprfx\t%0, %2\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6638[] = {
  "#",
  "lsl\t%0.s, %1/m, %0.s, %3.s",
  "lslr\t%0.s, %1/m, %3.s, %2.s",
  "movprfx\t%0, %2\n\tlsl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6639[] = {
  "#",
  "asr\t%0.s, %1/m, %0.s, %3.s",
  "asrr\t%0.s, %1/m, %3.s, %2.s",
  "movprfx\t%0, %2\n\tasr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6640[] = {
  "#",
  "lsr\t%0.s, %1/m, %0.s, %3.s",
  "lsrr\t%0.s, %1/m, %3.s, %2.s",
  "movprfx\t%0, %2\n\tlsr\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6641[] = {
  "#",
  "lsl\t%0.d, %1/m, %0.d, %3.d",
  "lslr\t%0.d, %1/m, %3.d, %2.d",
  "movprfx\t%0, %2\n\tlsl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6642[] = {
  "#",
  "asr\t%0.d, %1/m, %0.d, %3.d",
  "asrr\t%0.d, %1/m, %3.d, %2.d",
  "movprfx\t%0, %2\n\tasr\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6643[] = {
  "#",
  "lsr\t%0.d, %1/m, %0.d, %3.d",
  "lsrr\t%0.d, %1/m, %3.d, %2.d",
  "movprfx\t%0, %2\n\tlsr\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6674[] = {
  "lsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6675[] = {
  "asr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6676[] = {
  "lsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6677[] = {
  "lsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6678[] = {
  "asr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6679[] = {
  "lsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6680[] = {
  "lsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6681[] = {
  "asr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6682[] = {
  "lsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6683[] = {
  "lsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6684[] = {
  "asr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6685[] = {
  "lsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6686[] = {
  "lsl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6687[] = {
  "asr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6688[] = {
  "lsr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6689[] = {
  "lsl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6690[] = {
  "asr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6691[] = {
  "lsr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6692[] = {
  "lsl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6693[] = {
  "asr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6694[] = {
  "lsr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6695[] = {
  "lsl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6696[] = {
  "asr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6697[] = {
  "lsr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6698[] = {
  "lsl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6699[] = {
  "asr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6700[] = {
  "lsr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6701[] = {
  "lsl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tlsl\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6702[] = {
  "asr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tasr\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6703[] = {
  "lsr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tlsr\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6704[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6705[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6706[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6707[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6708[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6709[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6710[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6711[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6712[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6713[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsl\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6714[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6715[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tlsr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6716[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tlsl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsl\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6717[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tasr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tasr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6718[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tlsr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6719[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tlsl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsl\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6720[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tasr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tasr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6721[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tlsr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6722[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tlsl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsl\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6723[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tasr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tasr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6724[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tlsr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tlsr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6725[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tlsl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsl\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6726[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tasr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tasr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6727[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tlsr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6728[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tlsl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsl\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6729[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tasr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tasr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6730[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tlsr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tlsr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6731[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tlsl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tlsl\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_6732[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tasr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tasr\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_6733[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tlsr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tlsr\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_6743[] = {
  "lsl\t%0.b, %1/m, %0.b, %3.d",
  "movprfx\t%0, %2\n\tlsl\t%0.b, %1/m, %0.b, %3.d",
};

static const char * const output_6744[] = {
  "asr\t%0.b, %1/m, %0.b, %3.d",
  "movprfx\t%0, %2\n\tasr\t%0.b, %1/m, %0.b, %3.d",
};

static const char * const output_6745[] = {
  "lsr\t%0.b, %1/m, %0.b, %3.d",
  "movprfx\t%0, %2\n\tlsr\t%0.b, %1/m, %0.b, %3.d",
};

static const char * const output_6746[] = {
  "lsl\t%0.h, %1/m, %0.h, %3.d",
  "movprfx\t%0, %2\n\tlsl\t%0.h, %1/m, %0.h, %3.d",
};

static const char * const output_6747[] = {
  "asr\t%0.h, %1/m, %0.h, %3.d",
  "movprfx\t%0, %2\n\tasr\t%0.h, %1/m, %0.h, %3.d",
};

static const char * const output_6748[] = {
  "lsr\t%0.h, %1/m, %0.h, %3.d",
  "movprfx\t%0, %2\n\tlsr\t%0.h, %1/m, %0.h, %3.d",
};

static const char * const output_6749[] = {
  "lsl\t%0.s, %1/m, %0.s, %3.d",
  "movprfx\t%0, %2\n\tlsl\t%0.s, %1/m, %0.s, %3.d",
};

static const char * const output_6750[] = {
  "asr\t%0.s, %1/m, %0.s, %3.d",
  "movprfx\t%0, %2\n\tasr\t%0.s, %1/m, %0.s, %3.d",
};

static const char * const output_6751[] = {
  "lsr\t%0.s, %1/m, %0.s, %3.d",
  "movprfx\t%0, %2\n\tlsr\t%0.s, %1/m, %0.s, %3.d",
};

static const char * const output_6752[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsl\t%0.b, %1/m, %0.b, %3.d",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsl\t%0.b, %1/m, %0.b, %3.d",
};

static const char * const output_6753[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tasr\t%0.b, %1/m, %0.b, %3.d",
  "movprfx\t%0.b, %1/z, %2.b\n\tasr\t%0.b, %1/m, %0.b, %3.d",
};

static const char * const output_6754[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tlsr\t%0.b, %1/m, %0.b, %3.d",
  "movprfx\t%0.b, %1/z, %2.b\n\tlsr\t%0.b, %1/m, %0.b, %3.d",
};

static const char * const output_6755[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsl\t%0.h, %1/m, %0.h, %3.d",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsl\t%0.h, %1/m, %0.h, %3.d",
};

static const char * const output_6756[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tasr\t%0.h, %1/m, %0.h, %3.d",
  "movprfx\t%0.h, %1/z, %2.h\n\tasr\t%0.h, %1/m, %0.h, %3.d",
};

static const char * const output_6757[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tlsr\t%0.h, %1/m, %0.h, %3.d",
  "movprfx\t%0.h, %1/z, %2.h\n\tlsr\t%0.h, %1/m, %0.h, %3.d",
};

static const char * const output_6758[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tlsl\t%0.s, %1/m, %0.s, %3.d",
  "movprfx\t%0.s, %1/z, %2.s\n\tlsl\t%0.s, %1/m, %0.s, %3.d",
};

static const char * const output_6759[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tasr\t%0.s, %1/m, %0.s, %3.d",
  "movprfx\t%0.s, %1/z, %2.s\n\tasr\t%0.s, %1/m, %0.s, %3.d",
};

static const char * const output_6760[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tlsr\t%0.s, %1/m, %0.s, %3.d",
  "movprfx\t%0.s, %1/z, %2.s\n\tlsr\t%0.s, %1/m, %0.s, %3.d",
};

static const char * const output_6761[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6762[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6763[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6764[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6765[] = {
  "asrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6766[] = {
  "asrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6767[] = {
  "asrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6768[] = {
  "asrd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6769[] = {
  "asrd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6770[] = {
  "asrd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6771[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6772[] = {
  "sqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6773[] = {
  "srshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6774[] = {
  "urshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6775[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6776[] = {
  "sqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6777[] = {
  "srshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6778[] = {
  "urshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6779[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6780[] = {
  "sqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6781[] = {
  "srshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6782[] = {
  "urshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6783[] = {
  "asrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6784[] = {
  "sqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6785[] = {
  "srshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6786[] = {
  "urshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.b, %1/m, %0.b, #%3",
};

static const char * const output_6787[] = {
  "asrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6788[] = {
  "sqshlu\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6789[] = {
  "srshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6790[] = {
  "urshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6791[] = {
  "asrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6792[] = {
  "sqshlu\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6793[] = {
  "srshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6794[] = {
  "urshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6795[] = {
  "asrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6796[] = {
  "sqshlu\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6797[] = {
  "srshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6798[] = {
  "urshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6799[] = {
  "asrd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6800[] = {
  "sqshlu\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6801[] = {
  "srshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6802[] = {
  "urshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6803[] = {
  "asrd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6804[] = {
  "sqshlu\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6805[] = {
  "srshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6806[] = {
  "urshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6807[] = {
  "asrd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tasrd\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6808[] = {
  "sqshlu\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tsqshlu\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6809[] = {
  "srshr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tsrshr\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6810[] = {
  "urshr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\turshr\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6811[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6812[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6813[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6814[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6815[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6816[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6817[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6818[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6819[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6820[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6821[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6822[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6823[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tasrd\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6824[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqshlu\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6825[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsrshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6826[] = {
  "movprfx\t%0.b, %1/z, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\turshr\t%0.b, %1/m, %0.b, #%3",
  "#",
};

static const char * const output_6827[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tasrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tasrd\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6828[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6829[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6830[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\turshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\turshr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6831[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tasrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tasrd\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6832[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6833[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6834[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\turshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\turshr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6835[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tasrd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tasrd\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6836[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqshlu\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6837[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tsrshr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6838[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\turshr\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\turshr\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_6839[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tasrd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tasrd\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6840[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tsqshlu\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqshlu\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6841[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tsrshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tsrshr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6842[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\turshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\turshr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6843[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tasrd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tasrd\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6844[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tsqshlu\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqshlu\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6845[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tsrshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tsrshr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6846[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\turshr\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\turshr\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_6847[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tasrd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tasrd\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_6848[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tsqshlu\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tsqshlu\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_6849[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tsrshr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tsrshr\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_6850[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\turshr\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\turshr\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_6857[] = {
  "fscale\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6858[] = {
  "fscale\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6859[] = {
  "fscale\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6860[] = {
  "fscale\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6861[] = {
  "fscale\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6862[] = {
  "fscale\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6863[] = {
  "fscale\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6864[] = {
  "fscale\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6865[] = {
  "fscale\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6866[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6867[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6868[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6869[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfscale\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_6870[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfscale\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_6871[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfscale\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_6887[] = {
  "fdiv\t%0.h, %1/m, %0.h, %3.h",
  "fdivr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6888[] = {
  "fmulx\t%0.h, %1/m, %0.h, %3.h",
  "fmulx\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6889[] = {
  "fdiv\t%0.s, %1/m, %0.s, %3.s",
  "fdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6890[] = {
  "fmulx\t%0.s, %1/m, %0.s, %3.s",
  "fmulx\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6891[] = {
  "fdiv\t%0.d, %1/m, %0.d, %3.d",
  "fdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6892[] = {
  "fmulx\t%0.d, %1/m, %0.d, %3.d",
  "fmulx\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6893[] = {
  "fadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6894[] = {
  "fdiv\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6895[] = {
  "fmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6896[] = {
  "fmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6897[] = {
  "fmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6898[] = {
  "fminnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6899[] = {
  "fmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6900[] = {
  "fmulx\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6901[] = {
  "fsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6902[] = {
  "fadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6903[] = {
  "fdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6904[] = {
  "fmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6905[] = {
  "fmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6906[] = {
  "fmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6907[] = {
  "fminnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6908[] = {
  "fmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6909[] = {
  "fmulx\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6910[] = {
  "fsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6911[] = {
  "fadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6912[] = {
  "fdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6913[] = {
  "fmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6914[] = {
  "fmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6915[] = {
  "fmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6916[] = {
  "fminnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6917[] = {
  "fmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6918[] = {
  "fmulx\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6919[] = {
  "fsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6920[] = {
  "fadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6921[] = {
  "fdiv\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6922[] = {
  "fmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6923[] = {
  "fmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6924[] = {
  "fmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6925[] = {
  "fminnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6926[] = {
  "fmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6927[] = {
  "fmulx\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6928[] = {
  "fsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_6929[] = {
  "fadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6930[] = {
  "fdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6931[] = {
  "fmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6932[] = {
  "fmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6933[] = {
  "fmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6934[] = {
  "fminnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6935[] = {
  "fmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6936[] = {
  "fmulx\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6937[] = {
  "fsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_6938[] = {
  "fadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6939[] = {
  "fdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6940[] = {
  "fmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6941[] = {
  "fmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6942[] = {
  "fmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6943[] = {
  "fminnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6944[] = {
  "fmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6945[] = {
  "fmulx\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6946[] = {
  "fsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_6947[] = {
  "fmax\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6948[] = {
  "fmaxnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6949[] = {
  "fmin\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6950[] = {
  "fminnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6951[] = {
  "fmul\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6952[] = {
  "fmax\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6953[] = {
  "fmaxnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6954[] = {
  "fmin\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6955[] = {
  "fminnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6956[] = {
  "fmul\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6957[] = {
  "fmax\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6958[] = {
  "fmaxnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6959[] = {
  "fmin\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6960[] = {
  "fminnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6961[] = {
  "fmul\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6962[] = {
  "fmax\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6963[] = {
  "fmaxnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6964[] = {
  "fmin\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6965[] = {
  "fminnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6966[] = {
  "fmul\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.h, %1/m, %0.h, #%3",
};

static const char * const output_6967[] = {
  "fmax\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6968[] = {
  "fmaxnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6969[] = {
  "fmin\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6970[] = {
  "fminnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6971[] = {
  "fmul\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.s, %1/m, %0.s, #%3",
};

static const char * const output_6972[] = {
  "fmax\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6973[] = {
  "fmaxnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6974[] = {
  "fmin\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6975[] = {
  "fminnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6976[] = {
  "fmul\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.d, %1/m, %0.d, #%3",
};

static const char * const output_6977[] = {
  "fadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6978[] = {
  "fdivr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfdivr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6979[] = {
  "fmax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6980[] = {
  "fmaxnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmaxnm\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6981[] = {
  "fmin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6982[] = {
  "fminnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfminnm\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6983[] = {
  "fmul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmul\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6984[] = {
  "fmulx\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmulx\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6985[] = {
  "fsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_6986[] = {
  "fadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6987[] = {
  "fdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfdivr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6988[] = {
  "fmax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmax\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6989[] = {
  "fmaxnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmaxnm\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6990[] = {
  "fmin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmin\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6991[] = {
  "fminnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfminnm\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6992[] = {
  "fmul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmul\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6993[] = {
  "fmulx\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmulx\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6994[] = {
  "fsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_6995[] = {
  "fadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6996[] = {
  "fdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfdivr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6997[] = {
  "fmax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmax\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6998[] = {
  "fmaxnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmaxnm\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_6999[] = {
  "fmin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmin\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7000[] = {
  "fminnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfminnm\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7001[] = {
  "fmul\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmul\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7002[] = {
  "fmulx\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmulx\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7003[] = {
  "fsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfsubr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7004[] = {
  "fadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7005[] = {
  "fdivr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfdivr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7006[] = {
  "fmax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmax\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7007[] = {
  "fmaxnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmaxnm\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7008[] = {
  "fmin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmin\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7009[] = {
  "fminnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfminnm\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7010[] = {
  "fmul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmul\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7011[] = {
  "fmulx\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfmulx\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7012[] = {
  "fsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7013[] = {
  "fadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7014[] = {
  "fdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfdivr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7015[] = {
  "fmax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmax\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7016[] = {
  "fmaxnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmaxnm\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7017[] = {
  "fmin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmin\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7018[] = {
  "fminnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfminnm\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7019[] = {
  "fmul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmul\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7020[] = {
  "fmulx\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfmulx\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7021[] = {
  "fsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7022[] = {
  "fadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7023[] = {
  "fdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfdivr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7024[] = {
  "fmax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmax\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7025[] = {
  "fmaxnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmaxnm\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7026[] = {
  "fmin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmin\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7027[] = {
  "fminnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfminnm\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7028[] = {
  "fmul\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmul\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7029[] = {
  "fmulx\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfmulx\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7030[] = {
  "fsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfsubr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7031[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7032[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfdivr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7033[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7034[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7035[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7036[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfminnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7037[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7038[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmulx\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7039[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7040[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7041[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7042[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7043[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7044[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7045[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfminnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7046[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7047[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmulx\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7048[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7049[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7050[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7051[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7052[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7053[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7054[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfminnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7055[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmul\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7056[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmulx\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7057[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7058[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7059[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfdivr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfdiv\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7060[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmax\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7061[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7062[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmin\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7063[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfminnm\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7064[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmul\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7065[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmulx\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmulx\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7066[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7067[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7068[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfdivr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfdiv\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7069[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmax\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7070[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7071[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmin\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7072[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfminnm\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7073[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmul\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7074[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmulx\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmulx\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7075[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7076[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7077[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfdivr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfdiv\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7078[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmax\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7079[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7080[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmin\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7081[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfminnm\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7082[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmul\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7083[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmulx\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmulx\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7084[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7085[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmax\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmax\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7086[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7087[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmin\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmin\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7088[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7089[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmul\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmul\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7090[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmax\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmax\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7091[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7092[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmin\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmin\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7093[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7094[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmul\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmul\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7095[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmax\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmax\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7096[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7097[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmin\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmin\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7098[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7099[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmul\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmul\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7100[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmax\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmax\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7101[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmaxnm\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7102[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmin\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmin\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7103[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfminnm\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7104[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfmul\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfmul\t%0.h, %1/m, %0.h, #%3",
  "#",
};

static const char * const output_7105[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmax\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmax\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7106[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmaxnm\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7107[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmin\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmin\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7108[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfminnm\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7109[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfmul\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfmul\t%0.s, %1/m, %0.s, #%3",
  "#",
};

static const char * const output_7110[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmax\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmax\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7111[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmaxnm\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7112[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmin\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmin\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7113[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfminnm\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7114[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfmul\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfmul\t%0.d, %1/m, %0.d, #%3",
  "#",
};

static const char * const output_7115[] = {
  "fadd\t%0.h, %1/m, %0.h, #%3",
  "fsub\t%0.h, %1/m, %0.h, #%N3",
  "#",
  "fadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfadd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.h, %1/m, %0.h, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7116[] = {
  "fadd\t%0.s, %1/m, %0.s, #%3",
  "fsub\t%0.s, %1/m, %0.s, #%N3",
  "#",
  "fadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfadd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.s, %1/m, %0.s, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7117[] = {
  "fadd\t%0.d, %1/m, %0.d, #%3",
  "fsub\t%0.d, %1/m, %0.d, #%N3",
  "#",
  "fadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfadd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.d, %1/m, %0.d, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7118[] = {
  "fadd\t%0.h, %1/m, %0.h, #%3",
  "fsub\t%0.h, %1/m, %0.h, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.h, %1/m, %0.h, #%N3",
};

static const char * const output_7119[] = {
  "fadd\t%0.s, %1/m, %0.s, #%3",
  "fsub\t%0.s, %1/m, %0.s, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.s, %1/m, %0.s, #%N3",
};

static const char * const output_7120[] = {
  "fadd\t%0.d, %1/m, %0.d, #%3",
  "fsub\t%0.d, %1/m, %0.d, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.d, %1/m, %0.d, #%N3",
};

static const char * const output_7121[] = {
  "fadd\t%0.h, %1/m, %0.h, #%3",
  "fsub\t%0.h, %1/m, %0.h, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.h, %1/m, %0.h, #%N3",
};

static const char * const output_7122[] = {
  "fadd\t%0.s, %1/m, %0.s, #%3",
  "fsub\t%0.s, %1/m, %0.s, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.s, %1/m, %0.s, #%N3",
};

static const char * const output_7123[] = {
  "fadd\t%0.d, %1/m, %0.d, #%3",
  "fsub\t%0.d, %1/m, %0.d, #%N3",
  "movprfx\t%0, %2\n\tfadd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfsub\t%0.d, %1/m, %0.d, #%N3",
};

static const char * const output_7124[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfadd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/z, %2.h\n\tfsub\t%0.h, %1/m, %0.h, #%N3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfadd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfsub\t%0.h, %1/m, %0.h, #%N3",
  "#",
  "#",
};

static const char * const output_7125[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfadd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/z, %2.s\n\tfsub\t%0.s, %1/m, %0.s, #%N3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfadd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfsub\t%0.s, %1/m, %0.s, #%N3",
  "#",
  "#",
};

static const char * const output_7126[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfadd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/z, %2.d\n\tfsub\t%0.d, %1/m, %0.d, #%N3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfadd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfsub\t%0.d, %1/m, %0.d, #%N3",
  "#",
  "#",
};

static const char * const output_7127[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfadd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/z, %2.h\n\tfsub\t%0.h, %1/m, %0.h, #%N3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfadd\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tfsub\t%0.h, %1/m, %0.h, #%N3",
  "#",
  "#",
};

static const char * const output_7128[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfadd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/z, %2.s\n\tfsub\t%0.s, %1/m, %0.s, #%N3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfadd\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tfsub\t%0.s, %1/m, %0.s, #%N3",
  "#",
  "#",
};

static const char * const output_7129[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfadd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/z, %2.d\n\tfsub\t%0.d, %1/m, %0.d, #%N3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfadd\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tfsub\t%0.d, %1/m, %0.d, #%N3",
  "#",
  "#",
};

static const char * const output_7130[] = {
  "fcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
};

static const char * const output_7131[] = {
  "fcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
};

static const char * const output_7132[] = {
  "fcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
};

static const char * const output_7133[] = {
  "fcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
};

static const char * const output_7134[] = {
  "fcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
};

static const char * const output_7135[] = {
  "fcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
};

static const char * const output_7136[] = {
  "fcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
};

static const char * const output_7137[] = {
  "fcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
};

static const char * const output_7138[] = {
  "fcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
};

static const char * const output_7139[] = {
  "fcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
};

static const char * const output_7140[] = {
  "fcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
};

static const char * const output_7141[] = {
  "fcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
};

static const char * const output_7142[] = {
  "fcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
};

static const char * const output_7143[] = {
  "fcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
};

static const char * const output_7144[] = {
  "fcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
};

static const char * const output_7145[] = {
  "fcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
};

static const char * const output_7146[] = {
  "fcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "movprfx\t%0, %2\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
};

static const char * const output_7147[] = {
  "fcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "movprfx\t%0, %2\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
};

static const char * const output_7148[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "movprfx\t%0.h, %1/m, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "#",
};

static const char * const output_7149[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "movprfx\t%0.h, %1/m, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "#",
};

static const char * const output_7150[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "movprfx\t%0.s, %1/m, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "#",
};

static const char * const output_7151[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "movprfx\t%0.s, %1/m, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "#",
};

static const char * const output_7152[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "movprfx\t%0.d, %1/m, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "#",
};

static const char * const output_7153[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "movprfx\t%0.d, %1/m, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "#",
};

static const char * const output_7154[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "movprfx\t%0.h, %1/m, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #90",
  "#",
};

static const char * const output_7155[] = {
  "movprfx\t%0.h, %1/z, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "movprfx\t%0.h, %1/m, %2.h\n\tfcadd\t%0.h, %1/m, %0.h, %3.h, #270",
  "#",
};

static const char * const output_7156[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "movprfx\t%0.s, %1/m, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #90",
  "#",
};

static const char * const output_7157[] = {
  "movprfx\t%0.s, %1/z, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "movprfx\t%0.s, %1/m, %2.s\n\tfcadd\t%0.s, %1/m, %0.s, %3.s, #270",
  "#",
};

static const char * const output_7158[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "movprfx\t%0.d, %1/m, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #90",
  "#",
};

static const char * const output_7159[] = {
  "movprfx\t%0.d, %1/z, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "movprfx\t%0.d, %1/m, %2.d\n\tfcadd\t%0.d, %1/m, %0.d, %3.d, #270",
  "#",
};

static const char * const output_7160[] = {
  "fsubr\t%0.h, %1/m, %0.h, #%2",
  "#",
  "fsub\t%0.h, %1/m, %0.h, %3.h",
  "fsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfsubr\t%0.h, %1/m, %0.h, #%2",
  "movprfx\t%0, %2\n\tfsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7161[] = {
  "fsubr\t%0.s, %1/m, %0.s, #%2",
  "#",
  "fsub\t%0.s, %1/m, %0.s, %3.s",
  "fsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfsubr\t%0.s, %1/m, %0.s, #%2",
  "movprfx\t%0, %2\n\tfsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7162[] = {
  "fsubr\t%0.d, %1/m, %0.d, #%2",
  "#",
  "fsub\t%0.d, %1/m, %0.d, %3.d",
  "fsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfsubr\t%0.d, %1/m, %0.d, #%2",
  "movprfx\t%0, %2\n\tfsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7163[] = {
  "fsubr\t%0.h, %1/m, %0.h, #%2",
  "movprfx\t%0, %3\n\tfsubr\t%0.h, %1/m, %0.h, #%2",
};

static const char * const output_7164[] = {
  "fsubr\t%0.s, %1/m, %0.s, #%2",
  "movprfx\t%0, %3\n\tfsubr\t%0.s, %1/m, %0.s, #%2",
};

static const char * const output_7165[] = {
  "fsubr\t%0.d, %1/m, %0.d, #%2",
  "movprfx\t%0, %3\n\tfsubr\t%0.d, %1/m, %0.d, #%2",
};

static const char * const output_7166[] = {
  "fsubr\t%0.h, %1/m, %0.h, #%2",
  "movprfx\t%0, %3\n\tfsubr\t%0.h, %1/m, %0.h, #%2",
};

static const char * const output_7167[] = {
  "fsubr\t%0.s, %1/m, %0.s, #%2",
  "movprfx\t%0, %3\n\tfsubr\t%0.s, %1/m, %0.s, #%2",
};

static const char * const output_7168[] = {
  "fsubr\t%0.d, %1/m, %0.d, #%2",
  "movprfx\t%0, %3\n\tfsubr\t%0.d, %1/m, %0.d, #%2",
};

static const char * const output_7169[] = {
  "movprfx\t%0.h, %1/z, %3.h\n\tfsubr\t%0.h, %1/m, %0.h, #%2",
  "movprfx\t%0.h, %1/m, %3.h\n\tfsubr\t%0.h, %1/m, %0.h, #%2",
  "#",
};

static const char * const output_7170[] = {
  "movprfx\t%0.s, %1/z, %3.s\n\tfsubr\t%0.s, %1/m, %0.s, #%2",
  "movprfx\t%0.s, %1/m, %3.s\n\tfsubr\t%0.s, %1/m, %0.s, #%2",
  "#",
};

static const char * const output_7171[] = {
  "movprfx\t%0.d, %1/z, %3.d\n\tfsubr\t%0.d, %1/m, %0.d, #%2",
  "movprfx\t%0.d, %1/m, %3.d\n\tfsubr\t%0.d, %1/m, %0.d, #%2",
  "#",
};

static const char * const output_7172[] = {
  "movprfx\t%0.h, %1/z, %3.h\n\tfsubr\t%0.h, %1/m, %0.h, #%2",
  "movprfx\t%0.h, %1/m, %3.h\n\tfsubr\t%0.h, %1/m, %0.h, #%2",
  "#",
};

static const char * const output_7173[] = {
  "movprfx\t%0.s, %1/z, %3.s\n\tfsubr\t%0.s, %1/m, %0.s, #%2",
  "movprfx\t%0.s, %1/m, %3.s\n\tfsubr\t%0.s, %1/m, %0.s, #%2",
  "#",
};

static const char * const output_7174[] = {
  "movprfx\t%0.d, %1/z, %3.d\n\tfsubr\t%0.d, %1/m, %0.d, #%2",
  "movprfx\t%0.d, %1/m, %3.d\n\tfsubr\t%0.d, %1/m, %0.d, #%2",
  "#",
};

static const char * const output_7175[] = {
  "fabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7176[] = {
  "fabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7177[] = {
  "fabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7178[] = {
  "fabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7179[] = {
  "fabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7180[] = {
  "fabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7181[] = {
  "fabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7182[] = {
  "fabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7183[] = {
  "fabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7184[] = {
  "fabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7185[] = {
  "fabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7186[] = {
  "fabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7187[] = {
  "fabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7188[] = {
  "fabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfabd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7189[] = {
  "fabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfabd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7190[] = {
  "fabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tfabd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_7191[] = {
  "fabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tfabd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_7192[] = {
  "fabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tfabd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_7193[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7194[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7195[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7196[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfabd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tfabd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_7197[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfabd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tfabd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_7198[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfabd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tfabd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_7199[] = {
  "fmul\t%0.h, %1/m, %0.h, #%3",
  "#",
  "fmul\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmul\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7200[] = {
  "fmul\t%0.s, %1/m, %0.s, #%3",
  "#",
  "fmul\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmul\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7201[] = {
  "fmul\t%0.d, %1/m, %0.d, #%3",
  "#",
  "fmul\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmul\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmul\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7214[] = {
  "fmax\t%0.h, %1/m, %0.h, #%3",
  "fmax\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmax\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7215[] = {
  "fmaxnm\t%0.h, %1/m, %0.h, #%3",
  "fmaxnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7216[] = {
  "fmin\t%0.h, %1/m, %0.h, #%3",
  "fmin\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmin\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7217[] = {
  "fminnm\t%0.h, %1/m, %0.h, #%3",
  "fminnm\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfminnm\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_7218[] = {
  "fmax\t%0.s, %1/m, %0.s, #%3",
  "fmax\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmax\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7219[] = {
  "fmaxnm\t%0.s, %1/m, %0.s, #%3",
  "fmaxnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7220[] = {
  "fmin\t%0.s, %1/m, %0.s, #%3",
  "fmin\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmin\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7221[] = {
  "fminnm\t%0.s, %1/m, %0.s, #%3",
  "fminnm\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfminnm\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_7222[] = {
  "fmax\t%0.d, %1/m, %0.d, #%3",
  "fmax\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmax\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmax\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7223[] = {
  "fmaxnm\t%0.d, %1/m, %0.d, #%3",
  "fmaxnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmaxnm\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7224[] = {
  "fmin\t%0.d, %1/m, %0.d, #%3",
  "fmin\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmin\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfmin\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7225[] = {
  "fminnm\t%0.d, %1/m, %0.d, #%3",
  "fminnm\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfminnm\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tfminnm\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_7314[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7315[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7316[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7317[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7318[] = {
  "mad\t%0.h, %1/m, %3.h, %4.h",
  "mla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7319[] = {
  "mad\t%0.h, %1/m, %3.h, %4.h",
  "mla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7320[] = {
  "mad\t%0.h, %1/m, %3.h, %4.h",
  "mla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7321[] = {
  "mad\t%0.s, %1/m, %3.s, %4.s",
  "mla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7322[] = {
  "mad\t%0.s, %1/m, %3.s, %4.s",
  "mla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7323[] = {
  "mad\t%0.d, %1/m, %3.d, %4.d",
  "mla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7324[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmad\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7325[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmad\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7326[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmad\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7327[] = {
  "mad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmad\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7328[] = {
  "mad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tmad\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7329[] = {
  "mad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tmad\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7330[] = {
  "mad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tmad\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7331[] = {
  "mad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tmad\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7332[] = {
  "mad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tmad\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7333[] = {
  "mad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tmad\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7334[] = {
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7335[] = {
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7336[] = {
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7337[] = {
  "mla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmla\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7338[] = {
  "mla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7339[] = {
  "mla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7340[] = {
  "mla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7341[] = {
  "mla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7342[] = {
  "mla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7343[] = {
  "mla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7344[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7345[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7346[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7347[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmad\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmla\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7348[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmad\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7349[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmad\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7350[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmad\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tmla\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7351[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmad\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tmla\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7352[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmad\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tmla\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7353[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tmad\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tmla\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7354[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7355[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7356[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7357[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7358[] = {
  "msb\t%0.h, %1/m, %3.h, %4.h",
  "mls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7359[] = {
  "msb\t%0.h, %1/m, %3.h, %4.h",
  "mls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7360[] = {
  "msb\t%0.h, %1/m, %3.h, %4.h",
  "mls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7361[] = {
  "msb\t%0.s, %1/m, %3.s, %4.s",
  "mls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7362[] = {
  "msb\t%0.s, %1/m, %3.s, %4.s",
  "mls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7363[] = {
  "msb\t%0.d, %1/m, %3.d, %4.d",
  "mls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7364[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7365[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7366[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7367[] = {
  "msb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0, %2\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
};

static const char * const output_7368[] = {
  "msb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tmsb\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7369[] = {
  "msb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tmsb\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7370[] = {
  "msb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tmsb\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7371[] = {
  "msb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tmsb\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7372[] = {
  "msb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tmsb\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7373[] = {
  "msb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tmsb\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7374[] = {
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7375[] = {
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7376[] = {
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7377[] = {
  "mls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0, %4\n\tmls\t%0.b, %1/m, %2.b, %3.b",
};

static const char * const output_7378[] = {
  "mls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7379[] = {
  "mls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7380[] = {
  "mls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7381[] = {
  "mls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7382[] = {
  "mls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7383[] = {
  "mls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7384[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7385[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7386[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7387[] = {
  "movprfx\t%0.b, %1/z, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %3.b, %4.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tmsb\t%0.b, %1/m, %2.b, %4.b",
  "movprfx\t%0.b, %1/m, %4.b\n\tmls\t%0.b, %1/m, %2.b, %3.b",
  "#",
};

static const char * const output_7388[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmsb\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7389[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmsb\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7390[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tmsb\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tmls\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7391[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmsb\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tmls\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7392[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tmsb\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tmls\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7393[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tmsb\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tmls\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7394[] = {
  "sdot\t%0.s, %1.b, %2.b",
  "movprfx\t%0, %3\n\tsdot\t%0.s, %1.b, %2.b",
};

static const char * const output_7395[] = {
  "udot\t%0.s, %1.b, %2.b",
  "movprfx\t%0, %3\n\tudot\t%0.s, %1.b, %2.b",
};

static const char * const output_7396[] = {
  "sdot\t%0.d, %1.h, %2.h",
  "movprfx\t%0, %3\n\tsdot\t%0.d, %1.h, %2.h",
};

static const char * const output_7397[] = {
  "udot\t%0.d, %1.h, %2.h",
  "movprfx\t%0, %3\n\tudot\t%0.d, %1.h, %2.h",
};

static const char * const output_7398[] = {
  "sdot\t%0.s, %1.b, %2.b[%3]",
  "movprfx\t%0, %4\n\tsdot\t%0.s, %1.b, %2.b[%3]",
};

static const char * const output_7399[] = {
  "udot\t%0.s, %1.b, %2.b[%3]",
  "movprfx\t%0, %4\n\tudot\t%0.s, %1.b, %2.b[%3]",
};

static const char * const output_7400[] = {
  "sdot\t%0.d, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tsdot\t%0.d, %1.h, %2.h[%3]",
};

static const char * const output_7401[] = {
  "udot\t%0.d, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tudot\t%0.d, %1.h, %2.h[%3]",
};

static const char * const output_7402[] = {
  "usdot\t%0.s, %1.b, %2.b",
  "movprfx\t%0, %3\n\tusdot\t%0.s, %1.b, %2.b",
};

static const char * const output_7403[] = {
  "usdot\t%0.s, %1.b, %2.b[%3]",
  "movprfx\t%0, %4\n\tusdot\t%0.s, %1.b, %2.b[%3]",
};

static const char * const output_7404[] = {
  "sudot\t%0.s, %1.b, %2.b[%3]",
  "movprfx\t%0, %4\n\tsudot\t%0.s, %1.b, %2.b[%3]",
};

static const char * const output_7405[] = {
  "smmla\t%0.s, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsmmla\t%0.s, %2.b, %3.b",
};

static const char * const output_7406[] = {
  "ummla\t%0.s, %2.b, %3.b",
  "movprfx\t%0, %1\n\tummla\t%0.s, %2.b, %3.b",
};

static const char * const output_7407[] = {
  "usmmla\t%0.s, %2.b, %3.b",
  "movprfx\t%0, %1\n\tusmmla\t%0.s, %2.b, %3.b",
};

static const char * const output_7408[] = {
  "fmla\t%0.h, %1/m, %2.h, %3.h",
  "fmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %4\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7409[] = {
  "fmls\t%0.h, %1/m, %2.h, %3.h",
  "fmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %4\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7410[] = {
  "fnmla\t%0.h, %1/m, %2.h, %3.h",
  "fnmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %4\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7411[] = {
  "fnmls\t%0.h, %1/m, %2.h, %3.h",
  "fnmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %4\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7412[] = {
  "fmla\t%0.s, %1/m, %2.s, %3.s",
  "fmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %4\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7413[] = {
  "fmls\t%0.s, %1/m, %2.s, %3.s",
  "fmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %4\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7414[] = {
  "fnmla\t%0.s, %1/m, %2.s, %3.s",
  "fnmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %4\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7415[] = {
  "fnmls\t%0.s, %1/m, %2.s, %3.s",
  "fnmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %4\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7416[] = {
  "fmla\t%0.d, %1/m, %2.d, %3.d",
  "fmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %4\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7417[] = {
  "fmls\t%0.d, %1/m, %2.d, %3.d",
  "fmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %4\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7418[] = {
  "fnmla\t%0.d, %1/m, %2.d, %3.d",
  "fnmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %4\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7419[] = {
  "fnmls\t%0.d, %1/m, %2.d, %3.d",
  "fnmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %4\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7420[] = {
  "fmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfmad\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7421[] = {
  "fmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfmsb\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7422[] = {
  "fnmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfnmad\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7423[] = {
  "fnmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfnmsb\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7424[] = {
  "fmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfmad\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7425[] = {
  "fmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfmsb\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7426[] = {
  "fnmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfnmad\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7427[] = {
  "fnmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfnmsb\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7428[] = {
  "fmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfmad\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7429[] = {
  "fmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfmsb\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7430[] = {
  "fnmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfnmad\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7431[] = {
  "fnmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfnmsb\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7432[] = {
  "fmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfmad\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7433[] = {
  "fmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfmsb\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7434[] = {
  "fnmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfnmad\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7435[] = {
  "fnmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0, %2\n\tfnmsb\t%0.h, %1/m, %3.h, %4.h",
};

static const char * const output_7436[] = {
  "fmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfmad\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7437[] = {
  "fmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfmsb\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7438[] = {
  "fnmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfnmad\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7439[] = {
  "fnmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0, %2\n\tfnmsb\t%0.s, %1/m, %3.s, %4.s",
};

static const char * const output_7440[] = {
  "fmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfmad\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7441[] = {
  "fmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfmsb\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7442[] = {
  "fnmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfnmad\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7443[] = {
  "fnmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0, %2\n\tfnmsb\t%0.d, %1/m, %3.d, %4.d",
};

static const char * const output_7444[] = {
  "fmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7445[] = {
  "fmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7446[] = {
  "fnmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7447[] = {
  "fnmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7448[] = {
  "fmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7449[] = {
  "fmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7450[] = {
  "fnmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7451[] = {
  "fnmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7452[] = {
  "fmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7453[] = {
  "fmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7454[] = {
  "fnmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7455[] = {
  "fnmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7456[] = {
  "fmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7457[] = {
  "fmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7458[] = {
  "fnmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7459[] = {
  "fnmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0, %4\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
};

static const char * const output_7460[] = {
  "fmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7461[] = {
  "fmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7462[] = {
  "fnmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7463[] = {
  "fnmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0, %4\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
};

static const char * const output_7464[] = {
  "fmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7465[] = {
  "fmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7466[] = {
  "fnmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7467[] = {
  "fnmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0, %4\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
};

static const char * const output_7468[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmad\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7469[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmsb\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7470[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmad\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7471[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmsb\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7472[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmad\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7473[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmsb\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7474[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmad\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7475[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmsb\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7476[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmad\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7477[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmsb\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7478[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmad\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7479[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmsb\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7480[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmad\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfmla\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7481[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfmsb\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfmls\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7482[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmad\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmad\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfnmla\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7483[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmsb\t%0.h, %1/m, %3.h, %4.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tfnmsb\t%0.h, %1/m, %2.h, %4.h",
  "movprfx\t%0.h, %1/m, %4.h\n\tfnmls\t%0.h, %1/m, %2.h, %3.h",
  "#",
};

static const char * const output_7484[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmad\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfmla\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7485[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfmsb\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfmls\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7486[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmad\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmad\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfnmla\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7487[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmsb\t%0.s, %1/m, %3.s, %4.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tfnmsb\t%0.s, %1/m, %2.s, %4.s",
  "movprfx\t%0.s, %1/m, %4.s\n\tfnmls\t%0.s, %1/m, %2.s, %3.s",
  "#",
};

static const char * const output_7488[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmad\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfmla\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7489[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfmsb\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfmls\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7490[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmad\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmad\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfnmla\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7491[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmsb\t%0.d, %1/m, %3.d, %4.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tfnmsb\t%0.d, %1/m, %2.d, %4.d",
  "movprfx\t%0.d, %1/m, %4.d\n\tfnmls\t%0.d, %1/m, %2.d, %3.d",
  "#",
};

static const char * const output_7492[] = {
  "fmla\t%0.h, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tfmla\t%0.h, %1.h, %2.h[%3]",
};

static const char * const output_7493[] = {
  "fmls\t%0.h, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tfmls\t%0.h, %1.h, %2.h[%3]",
};

static const char * const output_7494[] = {
  "fmla\t%0.s, %1.s, %2.s[%3]",
  "movprfx\t%0, %4\n\tfmla\t%0.s, %1.s, %2.s[%3]",
};

static const char * const output_7495[] = {
  "fmls\t%0.s, %1.s, %2.s[%3]",
  "movprfx\t%0, %4\n\tfmls\t%0.s, %1.s, %2.s[%3]",
};

static const char * const output_7496[] = {
  "fmla\t%0.d, %1.d, %2.d[%3]",
  "movprfx\t%0, %4\n\tfmla\t%0.d, %1.d, %2.d[%3]",
};

static const char * const output_7497[] = {
  "fmls\t%0.d, %1.d, %2.d[%3]",
  "movprfx\t%0, %4\n\tfmls\t%0.d, %1.d, %2.d[%3]",
};

static const char * const output_7498[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
};

static const char * const output_7499[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
};

static const char * const output_7500[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
};

static const char * const output_7501[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
};

static const char * const output_7502[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
};

static const char * const output_7503[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
};

static const char * const output_7504[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
};

static const char * const output_7505[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
};

static const char * const output_7506[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
};

static const char * const output_7507[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
};

static const char * const output_7508[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
};

static const char * const output_7509[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
};

static const char * const output_7510[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
};

static const char * const output_7511[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
};

static const char * const output_7512[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
};

static const char * const output_7513[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
};

static const char * const output_7514[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
};

static const char * const output_7515[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
};

static const char * const output_7516[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
};

static const char * const output_7517[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
};

static const char * const output_7518[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
};

static const char * const output_7519[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
};

static const char * const output_7520[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
};

static const char * const output_7521[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
};

static const char * const output_7522[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
};

static const char * const output_7523[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
};

static const char * const output_7524[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
};

static const char * const output_7525[] = {
  "fcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
};

static const char * const output_7526[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
};

static const char * const output_7527[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
};

static const char * const output_7528[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
};

static const char * const output_7529[] = {
  "fcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
};

static const char * const output_7530[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
};

static const char * const output_7531[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
};

static const char * const output_7532[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
};

static const char * const output_7533[] = {
  "fcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
};

static const char * const output_7534[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "#",
};

static const char * const output_7535[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "#",
};

static const char * const output_7536[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "#",
};

static const char * const output_7537[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "#",
};

static const char * const output_7538[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "#",
};

static const char * const output_7539[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "#",
};

static const char * const output_7540[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "#",
};

static const char * const output_7541[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "#",
};

static const char * const output_7542[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "#",
};

static const char * const output_7543[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "#",
};

static const char * const output_7544[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "#",
};

static const char * const output_7545[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "#",
};

static const char * const output_7546[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #0",
  "#",
};

static const char * const output_7547[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #90",
  "#",
};

static const char * const output_7548[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #180",
  "#",
};

static const char * const output_7549[] = {
  "movprfx\t%0.h, %1/z, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "movprfx\t%0.h, %1/z, %0.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "movprfx\t%0.h, %1/m, %4.h\n\tfcmla\t%0.h, %1/m, %2.h, %3.h, #270",
  "#",
};

static const char * const output_7550[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #0",
  "#",
};

static const char * const output_7551[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #90",
  "#",
};

static const char * const output_7552[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #180",
  "#",
};

static const char * const output_7553[] = {
  "movprfx\t%0.s, %1/z, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "movprfx\t%0.s, %1/z, %0.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "movprfx\t%0.s, %1/m, %4.s\n\tfcmla\t%0.s, %1/m, %2.s, %3.s, #270",
  "#",
};

static const char * const output_7554[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #0",
  "#",
};

static const char * const output_7555[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #90",
  "#",
};

static const char * const output_7556[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #180",
  "#",
};

static const char * const output_7557[] = {
  "movprfx\t%0.d, %1/z, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "movprfx\t%0.d, %1/z, %0.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "movprfx\t%0.d, %1/m, %4.d\n\tfcmla\t%0.d, %1/m, %2.d, %3.d, #270",
  "#",
};

static const char * const output_7558[] = {
  "fcmla\t%0.h, %1.h, %2.h[%3], #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1.h, %2.h[%3], #0",
};

static const char * const output_7559[] = {
  "fcmla\t%0.h, %1.h, %2.h[%3], #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1.h, %2.h[%3], #90",
};

static const char * const output_7560[] = {
  "fcmla\t%0.h, %1.h, %2.h[%3], #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1.h, %2.h[%3], #180",
};

static const char * const output_7561[] = {
  "fcmla\t%0.h, %1.h, %2.h[%3], #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.h, %1.h, %2.h[%3], #270",
};

static const char * const output_7562[] = {
  "fcmla\t%0.s, %1.s, %2.s[%3], #0",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1.s, %2.s[%3], #0",
};

static const char * const output_7563[] = {
  "fcmla\t%0.s, %1.s, %2.s[%3], #90",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1.s, %2.s[%3], #90",
};

static const char * const output_7564[] = {
  "fcmla\t%0.s, %1.s, %2.s[%3], #180",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1.s, %2.s[%3], #180",
};

static const char * const output_7565[] = {
  "fcmla\t%0.s, %1.s, %2.s[%3], #270",
  "movprfx\t%0, %4\n\tfcmla\t%0.s, %1.s, %2.s[%3], #270",
};

static const char * const output_7566[] = {
  "ftmad\t%0.h, %0.h, %2.h, #%3",
  "movprfx\t%0, %1\n\tftmad\t%0.h, %0.h, %2.h, #%3",
};

static const char * const output_7567[] = {
  "ftmad\t%0.s, %0.s, %2.s, #%3",
  "movprfx\t%0, %1\n\tftmad\t%0.s, %0.s, %2.s, #%3",
};

static const char * const output_7568[] = {
  "ftmad\t%0.d, %0.d, %2.d, #%3",
  "movprfx\t%0, %1\n\tftmad\t%0.d, %0.d, %2.d, #%3",
};

static const char * const output_7569[] = {
  "bfdot\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tbfdot\t%0.s, %2.h, %3.h",
};

static const char * const output_7570[] = {
  "bfmlalb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tbfmlalb\t%0.s, %2.h, %3.h",
};

static const char * const output_7571[] = {
  "bfmlalt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tbfmlalt\t%0.s, %2.h, %3.h",
};

static const char * const output_7572[] = {
  "bfmmla\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tbfmmla\t%0.s, %2.h, %3.h",
};

static const char * const output_7573[] = {
  "bfdot\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tbfdot\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_7574[] = {
  "bfmlalb\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tbfmlalb\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_7575[] = {
  "bfmlalt\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tbfmlalt\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_7576[] = {
  "fmmla\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tfmmla\t%0.s, %2.s, %3.s",
};

static const char * const output_7577[] = {
  "fmmla\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tfmmla\t%0.d, %2.d, %3.d",
};

static const char * const output_7578[] = {
  "sel\t%0.b, %3, %1.b, %2.b",
  "mov\t%0.b, %3/m, #%I1",
  "mov\t%0.b, %3/z, #%I1",
  "fmov\t%0.b, %3/m, #%1",
  "movprfx\t%0.b, %3/z, %0.b\n\tfmov\t%0.b, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.b, %3/m, #%1",
};

static const char * const output_7579[] = {
  "sel\t%0.b, %3, %1.b, %2.b",
  "mov\t%0.b, %3/m, #%I1",
  "mov\t%0.b, %3/z, #%I1",
  "fmov\t%0.b, %3/m, #%1",
  "movprfx\t%0.b, %3/z, %0.b\n\tfmov\t%0.b, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.b, %3/m, #%1",
};

static const char * const output_7580[] = {
  "sel\t%0.b, %3, %1.b, %2.b",
  "mov\t%0.b, %3/m, #%I1",
  "mov\t%0.b, %3/z, #%I1",
  "fmov\t%0.b, %3/m, #%1",
  "movprfx\t%0.b, %3/z, %0.b\n\tfmov\t%0.b, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.b, %3/m, #%1",
};

static const char * const output_7581[] = {
  "sel\t%0.b, %3, %1.b, %2.b",
  "mov\t%0.b, %3/m, #%I1",
  "mov\t%0.b, %3/z, #%I1",
  "fmov\t%0.b, %3/m, #%1",
  "movprfx\t%0.b, %3/z, %0.b\n\tfmov\t%0.b, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.b, %3/m, #%1",
};

static const char * const output_7582[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7583[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7584[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7585[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7586[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7587[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7588[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7589[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7590[] = {
  "sel\t%0.h, %3, %1.h, %2.h",
  "mov\t%0.h, %3/m, #%I1",
  "mov\t%0.h, %3/z, #%I1",
  "fmov\t%0.h, %3/m, #%1",
  "movprfx\t%0.h, %3/z, %0.h\n\tfmov\t%0.h, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.h, %3/m, #%1",
};

static const char * const output_7591[] = {
  "sel\t%0.s, %3, %1.s, %2.s",
  "mov\t%0.s, %3/m, #%I1",
  "mov\t%0.s, %3/z, #%I1",
  "fmov\t%0.s, %3/m, #%1",
  "movprfx\t%0.s, %3/z, %0.s\n\tfmov\t%0.s, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.s, %3/m, #%1",
};

static const char * const output_7592[] = {
  "sel\t%0.s, %3, %1.s, %2.s",
  "mov\t%0.s, %3/m, #%I1",
  "mov\t%0.s, %3/z, #%I1",
  "fmov\t%0.s, %3/m, #%1",
  "movprfx\t%0.s, %3/z, %0.s\n\tfmov\t%0.s, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.s, %3/m, #%1",
};

static const char * const output_7593[] = {
  "sel\t%0.s, %3, %1.s, %2.s",
  "mov\t%0.s, %3/m, #%I1",
  "mov\t%0.s, %3/z, #%I1",
  "fmov\t%0.s, %3/m, #%1",
  "movprfx\t%0.s, %3/z, %0.s\n\tfmov\t%0.s, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.s, %3/m, #%1",
};

static const char * const output_7594[] = {
  "sel\t%0.s, %3, %1.s, %2.s",
  "mov\t%0.s, %3/m, #%I1",
  "mov\t%0.s, %3/z, #%I1",
  "fmov\t%0.s, %3/m, #%1",
  "movprfx\t%0.s, %3/z, %0.s\n\tfmov\t%0.s, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.s, %3/m, #%1",
};

static const char * const output_7595[] = {
  "sel\t%0.d, %3, %1.d, %2.d",
  "mov\t%0.d, %3/m, #%I1",
  "mov\t%0.d, %3/z, #%I1",
  "fmov\t%0.d, %3/m, #%1",
  "movprfx\t%0.d, %3/z, %0.d\n\tfmov\t%0.d, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.d, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.d, %3/m, #%1",
};

static const char * const output_7596[] = {
  "sel\t%0.d, %3, %1.d, %2.d",
  "mov\t%0.d, %3/m, #%I1",
  "mov\t%0.d, %3/z, #%I1",
  "fmov\t%0.d, %3/m, #%1",
  "movprfx\t%0.d, %3/z, %0.d\n\tfmov\t%0.d, %3/m, #%1",
  "movprfx\t%0, %2\n\tmov\t%0.d, %3/m, #%I1",
  "movprfx\t%0, %2\n\tfmov\t%0.d, %3/m, #%1",
};

static const char * const output_7597[] = {
  "mov\t%0.b, %3/m, %w1",
  "mov\t%0.b, %3/m, %b1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %b1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %b1",
};

static const char * const output_7598[] = {
  "mov\t%0.b, %3/m, %w1",
  "mov\t%0.b, %3/m, %b1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %b1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %b1",
};

static const char * const output_7599[] = {
  "mov\t%0.b, %3/m, %w1",
  "mov\t%0.b, %3/m, %b1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %b1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %b1",
};

static const char * const output_7600[] = {
  "mov\t%0.b, %3/m, %w1",
  "mov\t%0.b, %3/m, %b1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0.b, %3/z, %0.b\n\tmov\t%0.b, %3/m, %b1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.b, %3/m, %b1",
};

static const char * const output_7601[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7602[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7603[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7604[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7605[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7606[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7607[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7608[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7609[] = {
  "mov\t%0.h, %3/m, %w1",
  "mov\t%0.h, %3/m, %h1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0.h, %3/z, %0.h\n\tmov\t%0.h, %3/m, %h1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.h, %3/m, %h1",
};

static const char * const output_7610[] = {
  "mov\t%0.s, %3/m, %w1",
  "mov\t%0.s, %3/m, %s1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %s1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %s1",
};

static const char * const output_7611[] = {
  "mov\t%0.s, %3/m, %w1",
  "mov\t%0.s, %3/m, %s1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %s1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %s1",
};

static const char * const output_7612[] = {
  "mov\t%0.s, %3/m, %w1",
  "mov\t%0.s, %3/m, %s1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %s1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %s1",
};

static const char * const output_7613[] = {
  "mov\t%0.s, %3/m, %w1",
  "mov\t%0.s, %3/m, %s1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0.s, %3/z, %0.s\n\tmov\t%0.s, %3/m, %s1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %w1",
  "movprfx\t%0, %2\n\tmov\t%0.s, %3/m, %s1",
};

static const char * const output_7614[] = {
  "mov\t%0.d, %3/m, %x1",
  "mov\t%0.d, %3/m, %d1",
  "movprfx\t%0.d, %3/z, %0.d\n\tmov\t%0.d, %3/m, %x1",
  "movprfx\t%0.d, %3/z, %0.d\n\tmov\t%0.d, %3/m, %d1",
  "movprfx\t%0, %2\n\tmov\t%0.d, %3/m, %x1",
  "movprfx\t%0, %2\n\tmov\t%0.d, %3/m, %d1",
};

static const char * const output_7615[] = {
  "mov\t%0.d, %3/m, %x1",
  "mov\t%0.d, %3/m, %d1",
  "movprfx\t%0.d, %3/z, %0.d\n\tmov\t%0.d, %3/m, %x1",
  "movprfx\t%0.d, %3/z, %0.d\n\tmov\t%0.d, %3/m, %d1",
  "movprfx\t%0, %2\n\tmov\t%0.d, %3/m, %x1",
  "movprfx\t%0, %2\n\tmov\t%0.d, %3/m, %d1",
};

static const char * const output_7616[] = {
  "cmplt\t%0.b, %1/z, %3.b, #%4",
  "cmplt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7617[] = {
  "cmple\t%0.b, %1/z, %3.b, #%4",
  "cmple\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7618[] = {
  "cmpeq\t%0.b, %1/z, %3.b, #%4",
  "cmpeq\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7619[] = {
  "cmpne\t%0.b, %1/z, %3.b, #%4",
  "cmpne\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7620[] = {
  "cmpge\t%0.b, %1/z, %3.b, #%4",
  "cmpge\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7621[] = {
  "cmpgt\t%0.b, %1/z, %3.b, #%4",
  "cmpgt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7622[] = {
  "cmplo\t%0.b, %1/z, %3.b, #%4",
  "cmplo\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7623[] = {
  "cmpls\t%0.b, %1/z, %3.b, #%4",
  "cmpls\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7624[] = {
  "cmphs\t%0.b, %1/z, %3.b, #%4",
  "cmphs\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7625[] = {
  "cmphi\t%0.b, %1/z, %3.b, #%4",
  "cmphi\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7626[] = {
  "cmplt\t%0.b, %1/z, %3.b, #%4",
  "cmplt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7627[] = {
  "cmple\t%0.b, %1/z, %3.b, #%4",
  "cmple\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7628[] = {
  "cmpeq\t%0.b, %1/z, %3.b, #%4",
  "cmpeq\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7629[] = {
  "cmpne\t%0.b, %1/z, %3.b, #%4",
  "cmpne\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7630[] = {
  "cmpge\t%0.b, %1/z, %3.b, #%4",
  "cmpge\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7631[] = {
  "cmpgt\t%0.b, %1/z, %3.b, #%4",
  "cmpgt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7632[] = {
  "cmplo\t%0.b, %1/z, %3.b, #%4",
  "cmplo\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7633[] = {
  "cmpls\t%0.b, %1/z, %3.b, #%4",
  "cmpls\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7634[] = {
  "cmphs\t%0.b, %1/z, %3.b, #%4",
  "cmphs\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7635[] = {
  "cmphi\t%0.b, %1/z, %3.b, #%4",
  "cmphi\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7636[] = {
  "cmplt\t%0.b, %1/z, %3.b, #%4",
  "cmplt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7637[] = {
  "cmple\t%0.b, %1/z, %3.b, #%4",
  "cmple\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7638[] = {
  "cmpeq\t%0.b, %1/z, %3.b, #%4",
  "cmpeq\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7639[] = {
  "cmpne\t%0.b, %1/z, %3.b, #%4",
  "cmpne\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7640[] = {
  "cmpge\t%0.b, %1/z, %3.b, #%4",
  "cmpge\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7641[] = {
  "cmpgt\t%0.b, %1/z, %3.b, #%4",
  "cmpgt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7642[] = {
  "cmplo\t%0.b, %1/z, %3.b, #%4",
  "cmplo\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7643[] = {
  "cmpls\t%0.b, %1/z, %3.b, #%4",
  "cmpls\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7644[] = {
  "cmphs\t%0.b, %1/z, %3.b, #%4",
  "cmphs\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7645[] = {
  "cmphi\t%0.b, %1/z, %3.b, #%4",
  "cmphi\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7646[] = {
  "cmplt\t%0.b, %1/z, %3.b, #%4",
  "cmplt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7647[] = {
  "cmple\t%0.b, %1/z, %3.b, #%4",
  "cmple\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7648[] = {
  "cmpeq\t%0.b, %1/z, %3.b, #%4",
  "cmpeq\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7649[] = {
  "cmpne\t%0.b, %1/z, %3.b, #%4",
  "cmpne\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7650[] = {
  "cmpge\t%0.b, %1/z, %3.b, #%4",
  "cmpge\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7651[] = {
  "cmpgt\t%0.b, %1/z, %3.b, #%4",
  "cmpgt\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7652[] = {
  "cmplo\t%0.b, %1/z, %3.b, #%4",
  "cmplo\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7653[] = {
  "cmpls\t%0.b, %1/z, %3.b, #%4",
  "cmpls\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7654[] = {
  "cmphs\t%0.b, %1/z, %3.b, #%4",
  "cmphs\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7655[] = {
  "cmphi\t%0.b, %1/z, %3.b, #%4",
  "cmphi\t%0.b, %1/z, %3.b, %4.b",
};

static const char * const output_7656[] = {
  "cmplt\t%0.h, %1/z, %3.h, #%4",
  "cmplt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7657[] = {
  "cmple\t%0.h, %1/z, %3.h, #%4",
  "cmple\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7658[] = {
  "cmpeq\t%0.h, %1/z, %3.h, #%4",
  "cmpeq\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7659[] = {
  "cmpne\t%0.h, %1/z, %3.h, #%4",
  "cmpne\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7660[] = {
  "cmpge\t%0.h, %1/z, %3.h, #%4",
  "cmpge\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7661[] = {
  "cmpgt\t%0.h, %1/z, %3.h, #%4",
  "cmpgt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7662[] = {
  "cmplo\t%0.h, %1/z, %3.h, #%4",
  "cmplo\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7663[] = {
  "cmpls\t%0.h, %1/z, %3.h, #%4",
  "cmpls\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7664[] = {
  "cmphs\t%0.h, %1/z, %3.h, #%4",
  "cmphs\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7665[] = {
  "cmphi\t%0.h, %1/z, %3.h, #%4",
  "cmphi\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7666[] = {
  "cmplt\t%0.h, %1/z, %3.h, #%4",
  "cmplt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7667[] = {
  "cmple\t%0.h, %1/z, %3.h, #%4",
  "cmple\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7668[] = {
  "cmpeq\t%0.h, %1/z, %3.h, #%4",
  "cmpeq\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7669[] = {
  "cmpne\t%0.h, %1/z, %3.h, #%4",
  "cmpne\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7670[] = {
  "cmpge\t%0.h, %1/z, %3.h, #%4",
  "cmpge\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7671[] = {
  "cmpgt\t%0.h, %1/z, %3.h, #%4",
  "cmpgt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7672[] = {
  "cmplo\t%0.h, %1/z, %3.h, #%4",
  "cmplo\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7673[] = {
  "cmpls\t%0.h, %1/z, %3.h, #%4",
  "cmpls\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7674[] = {
  "cmphs\t%0.h, %1/z, %3.h, #%4",
  "cmphs\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7675[] = {
  "cmphi\t%0.h, %1/z, %3.h, #%4",
  "cmphi\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7676[] = {
  "cmplt\t%0.h, %1/z, %3.h, #%4",
  "cmplt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7677[] = {
  "cmple\t%0.h, %1/z, %3.h, #%4",
  "cmple\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7678[] = {
  "cmpeq\t%0.h, %1/z, %3.h, #%4",
  "cmpeq\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7679[] = {
  "cmpne\t%0.h, %1/z, %3.h, #%4",
  "cmpne\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7680[] = {
  "cmpge\t%0.h, %1/z, %3.h, #%4",
  "cmpge\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7681[] = {
  "cmpgt\t%0.h, %1/z, %3.h, #%4",
  "cmpgt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7682[] = {
  "cmplo\t%0.h, %1/z, %3.h, #%4",
  "cmplo\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7683[] = {
  "cmpls\t%0.h, %1/z, %3.h, #%4",
  "cmpls\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7684[] = {
  "cmphs\t%0.h, %1/z, %3.h, #%4",
  "cmphs\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7685[] = {
  "cmphi\t%0.h, %1/z, %3.h, #%4",
  "cmphi\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_7686[] = {
  "cmplt\t%0.s, %1/z, %3.s, #%4",
  "cmplt\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7687[] = {
  "cmple\t%0.s, %1/z, %3.s, #%4",
  "cmple\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7688[] = {
  "cmpeq\t%0.s, %1/z, %3.s, #%4",
  "cmpeq\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7689[] = {
  "cmpne\t%0.s, %1/z, %3.s, #%4",
  "cmpne\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7690[] = {
  "cmpge\t%0.s, %1/z, %3.s, #%4",
  "cmpge\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7691[] = {
  "cmpgt\t%0.s, %1/z, %3.s, #%4",
  "cmpgt\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7692[] = {
  "cmplo\t%0.s, %1/z, %3.s, #%4",
  "cmplo\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7693[] = {
  "cmpls\t%0.s, %1/z, %3.s, #%4",
  "cmpls\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7694[] = {
  "cmphs\t%0.s, %1/z, %3.s, #%4",
  "cmphs\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7695[] = {
  "cmphi\t%0.s, %1/z, %3.s, #%4",
  "cmphi\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7696[] = {
  "cmplt\t%0.s, %1/z, %3.s, #%4",
  "cmplt\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7697[] = {
  "cmple\t%0.s, %1/z, %3.s, #%4",
  "cmple\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7698[] = {
  "cmpeq\t%0.s, %1/z, %3.s, #%4",
  "cmpeq\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7699[] = {
  "cmpne\t%0.s, %1/z, %3.s, #%4",
  "cmpne\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7700[] = {
  "cmpge\t%0.s, %1/z, %3.s, #%4",
  "cmpge\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7701[] = {
  "cmpgt\t%0.s, %1/z, %3.s, #%4",
  "cmpgt\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7702[] = {
  "cmplo\t%0.s, %1/z, %3.s, #%4",
  "cmplo\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7703[] = {
  "cmpls\t%0.s, %1/z, %3.s, #%4",
  "cmpls\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7704[] = {
  "cmphs\t%0.s, %1/z, %3.s, #%4",
  "cmphs\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7705[] = {
  "cmphi\t%0.s, %1/z, %3.s, #%4",
  "cmphi\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_7706[] = {
  "cmplt\t%0.d, %1/z, %3.d, #%4",
  "cmplt\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7707[] = {
  "cmple\t%0.d, %1/z, %3.d, #%4",
  "cmple\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7708[] = {
  "cmpeq\t%0.d, %1/z, %3.d, #%4",
  "cmpeq\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7709[] = {
  "cmpne\t%0.d, %1/z, %3.d, #%4",
  "cmpne\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7710[] = {
  "cmpge\t%0.d, %1/z, %3.d, #%4",
  "cmpge\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7711[] = {
  "cmpgt\t%0.d, %1/z, %3.d, #%4",
  "cmpgt\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7712[] = {
  "cmplo\t%0.d, %1/z, %3.d, #%4",
  "cmplo\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7713[] = {
  "cmpls\t%0.d, %1/z, %3.d, #%4",
  "cmpls\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7714[] = {
  "cmphs\t%0.d, %1/z, %3.d, #%4",
  "cmphs\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7715[] = {
  "cmphi\t%0.d, %1/z, %3.d, #%4",
  "cmphi\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_7716[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7717[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7718[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7719[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7720[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7721[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7722[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7723[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7724[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7725[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7726[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7727[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7728[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7729[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7730[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7731[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7732[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7733[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7734[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7735[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7736[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7737[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7738[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7739[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7740[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7741[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7742[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7743[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7744[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7745[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7746[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7747[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7748[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7749[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7750[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7751[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7752[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7753[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7754[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7755[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7756[] = {
  "cmplt\t%0.h, %1/z, %2.h, #%3",
  "cmplt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7757[] = {
  "cmple\t%0.h, %1/z, %2.h, #%3",
  "cmple\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7758[] = {
  "cmpeq\t%0.h, %1/z, %2.h, #%3",
  "cmpeq\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7759[] = {
  "cmpne\t%0.h, %1/z, %2.h, #%3",
  "cmpne\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7760[] = {
  "cmpge\t%0.h, %1/z, %2.h, #%3",
  "cmpge\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7761[] = {
  "cmpgt\t%0.h, %1/z, %2.h, #%3",
  "cmpgt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7762[] = {
  "cmplo\t%0.h, %1/z, %2.h, #%3",
  "cmplo\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7763[] = {
  "cmpls\t%0.h, %1/z, %2.h, #%3",
  "cmpls\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7764[] = {
  "cmphs\t%0.h, %1/z, %2.h, #%3",
  "cmphs\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7765[] = {
  "cmphi\t%0.h, %1/z, %2.h, #%3",
  "cmphi\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7766[] = {
  "cmplt\t%0.h, %1/z, %2.h, #%3",
  "cmplt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7767[] = {
  "cmple\t%0.h, %1/z, %2.h, #%3",
  "cmple\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7768[] = {
  "cmpeq\t%0.h, %1/z, %2.h, #%3",
  "cmpeq\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7769[] = {
  "cmpne\t%0.h, %1/z, %2.h, #%3",
  "cmpne\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7770[] = {
  "cmpge\t%0.h, %1/z, %2.h, #%3",
  "cmpge\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7771[] = {
  "cmpgt\t%0.h, %1/z, %2.h, #%3",
  "cmpgt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7772[] = {
  "cmplo\t%0.h, %1/z, %2.h, #%3",
  "cmplo\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7773[] = {
  "cmpls\t%0.h, %1/z, %2.h, #%3",
  "cmpls\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7774[] = {
  "cmphs\t%0.h, %1/z, %2.h, #%3",
  "cmphs\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7775[] = {
  "cmphi\t%0.h, %1/z, %2.h, #%3",
  "cmphi\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7776[] = {
  "cmplt\t%0.h, %1/z, %2.h, #%3",
  "cmplt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7777[] = {
  "cmple\t%0.h, %1/z, %2.h, #%3",
  "cmple\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7778[] = {
  "cmpeq\t%0.h, %1/z, %2.h, #%3",
  "cmpeq\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7779[] = {
  "cmpne\t%0.h, %1/z, %2.h, #%3",
  "cmpne\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7780[] = {
  "cmpge\t%0.h, %1/z, %2.h, #%3",
  "cmpge\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7781[] = {
  "cmpgt\t%0.h, %1/z, %2.h, #%3",
  "cmpgt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7782[] = {
  "cmplo\t%0.h, %1/z, %2.h, #%3",
  "cmplo\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7783[] = {
  "cmpls\t%0.h, %1/z, %2.h, #%3",
  "cmpls\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7784[] = {
  "cmphs\t%0.h, %1/z, %2.h, #%3",
  "cmphs\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7785[] = {
  "cmphi\t%0.h, %1/z, %2.h, #%3",
  "cmphi\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7786[] = {
  "cmplt\t%0.s, %1/z, %2.s, #%3",
  "cmplt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7787[] = {
  "cmple\t%0.s, %1/z, %2.s, #%3",
  "cmple\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7788[] = {
  "cmpeq\t%0.s, %1/z, %2.s, #%3",
  "cmpeq\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7789[] = {
  "cmpne\t%0.s, %1/z, %2.s, #%3",
  "cmpne\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7790[] = {
  "cmpge\t%0.s, %1/z, %2.s, #%3",
  "cmpge\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7791[] = {
  "cmpgt\t%0.s, %1/z, %2.s, #%3",
  "cmpgt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7792[] = {
  "cmplo\t%0.s, %1/z, %2.s, #%3",
  "cmplo\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7793[] = {
  "cmpls\t%0.s, %1/z, %2.s, #%3",
  "cmpls\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7794[] = {
  "cmphs\t%0.s, %1/z, %2.s, #%3",
  "cmphs\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7795[] = {
  "cmphi\t%0.s, %1/z, %2.s, #%3",
  "cmphi\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7796[] = {
  "cmplt\t%0.s, %1/z, %2.s, #%3",
  "cmplt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7797[] = {
  "cmple\t%0.s, %1/z, %2.s, #%3",
  "cmple\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7798[] = {
  "cmpeq\t%0.s, %1/z, %2.s, #%3",
  "cmpeq\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7799[] = {
  "cmpne\t%0.s, %1/z, %2.s, #%3",
  "cmpne\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7800[] = {
  "cmpge\t%0.s, %1/z, %2.s, #%3",
  "cmpge\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7801[] = {
  "cmpgt\t%0.s, %1/z, %2.s, #%3",
  "cmpgt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7802[] = {
  "cmplo\t%0.s, %1/z, %2.s, #%3",
  "cmplo\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7803[] = {
  "cmpls\t%0.s, %1/z, %2.s, #%3",
  "cmpls\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7804[] = {
  "cmphs\t%0.s, %1/z, %2.s, #%3",
  "cmphs\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7805[] = {
  "cmphi\t%0.s, %1/z, %2.s, #%3",
  "cmphi\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7806[] = {
  "cmplt\t%0.d, %1/z, %2.d, #%3",
  "cmplt\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7807[] = {
  "cmple\t%0.d, %1/z, %2.d, #%3",
  "cmple\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7808[] = {
  "cmpeq\t%0.d, %1/z, %2.d, #%3",
  "cmpeq\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7809[] = {
  "cmpne\t%0.d, %1/z, %2.d, #%3",
  "cmpne\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7810[] = {
  "cmpge\t%0.d, %1/z, %2.d, #%3",
  "cmpge\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7811[] = {
  "cmpgt\t%0.d, %1/z, %2.d, #%3",
  "cmpgt\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7812[] = {
  "cmplo\t%0.d, %1/z, %2.d, #%3",
  "cmplo\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7813[] = {
  "cmpls\t%0.d, %1/z, %2.d, #%3",
  "cmpls\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7814[] = {
  "cmphs\t%0.d, %1/z, %2.d, #%3",
  "cmphs\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7815[] = {
  "cmphi\t%0.d, %1/z, %2.d, #%3",
  "cmphi\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7816[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7817[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7818[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7819[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7820[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7821[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7822[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7823[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7824[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7825[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7826[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7827[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7828[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7829[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7830[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7831[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7832[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7833[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7834[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7835[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7836[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7837[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7838[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7839[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7840[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7841[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7842[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7843[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7844[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7845[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7846[] = {
  "cmplt\t%0.b, %1/z, %2.b, #%3",
  "cmplt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7847[] = {
  "cmple\t%0.b, %1/z, %2.b, #%3",
  "cmple\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7848[] = {
  "cmpeq\t%0.b, %1/z, %2.b, #%3",
  "cmpeq\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7849[] = {
  "cmpne\t%0.b, %1/z, %2.b, #%3",
  "cmpne\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7850[] = {
  "cmpge\t%0.b, %1/z, %2.b, #%3",
  "cmpge\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7851[] = {
  "cmpgt\t%0.b, %1/z, %2.b, #%3",
  "cmpgt\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7852[] = {
  "cmplo\t%0.b, %1/z, %2.b, #%3",
  "cmplo\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7853[] = {
  "cmpls\t%0.b, %1/z, %2.b, #%3",
  "cmpls\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7854[] = {
  "cmphs\t%0.b, %1/z, %2.b, #%3",
  "cmphs\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7855[] = {
  "cmphi\t%0.b, %1/z, %2.b, #%3",
  "cmphi\t%0.b, %1/z, %2.b, %3.b",
};

static const char * const output_7856[] = {
  "cmplt\t%0.h, %1/z, %2.h, #%3",
  "cmplt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7857[] = {
  "cmple\t%0.h, %1/z, %2.h, #%3",
  "cmple\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7858[] = {
  "cmpeq\t%0.h, %1/z, %2.h, #%3",
  "cmpeq\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7859[] = {
  "cmpne\t%0.h, %1/z, %2.h, #%3",
  "cmpne\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7860[] = {
  "cmpge\t%0.h, %1/z, %2.h, #%3",
  "cmpge\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7861[] = {
  "cmpgt\t%0.h, %1/z, %2.h, #%3",
  "cmpgt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7862[] = {
  "cmplo\t%0.h, %1/z, %2.h, #%3",
  "cmplo\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7863[] = {
  "cmpls\t%0.h, %1/z, %2.h, #%3",
  "cmpls\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7864[] = {
  "cmphs\t%0.h, %1/z, %2.h, #%3",
  "cmphs\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7865[] = {
  "cmphi\t%0.h, %1/z, %2.h, #%3",
  "cmphi\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7866[] = {
  "cmplt\t%0.h, %1/z, %2.h, #%3",
  "cmplt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7867[] = {
  "cmple\t%0.h, %1/z, %2.h, #%3",
  "cmple\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7868[] = {
  "cmpeq\t%0.h, %1/z, %2.h, #%3",
  "cmpeq\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7869[] = {
  "cmpne\t%0.h, %1/z, %2.h, #%3",
  "cmpne\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7870[] = {
  "cmpge\t%0.h, %1/z, %2.h, #%3",
  "cmpge\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7871[] = {
  "cmpgt\t%0.h, %1/z, %2.h, #%3",
  "cmpgt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7872[] = {
  "cmplo\t%0.h, %1/z, %2.h, #%3",
  "cmplo\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7873[] = {
  "cmpls\t%0.h, %1/z, %2.h, #%3",
  "cmpls\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7874[] = {
  "cmphs\t%0.h, %1/z, %2.h, #%3",
  "cmphs\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7875[] = {
  "cmphi\t%0.h, %1/z, %2.h, #%3",
  "cmphi\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7876[] = {
  "cmplt\t%0.h, %1/z, %2.h, #%3",
  "cmplt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7877[] = {
  "cmple\t%0.h, %1/z, %2.h, #%3",
  "cmple\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7878[] = {
  "cmpeq\t%0.h, %1/z, %2.h, #%3",
  "cmpeq\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7879[] = {
  "cmpne\t%0.h, %1/z, %2.h, #%3",
  "cmpne\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7880[] = {
  "cmpge\t%0.h, %1/z, %2.h, #%3",
  "cmpge\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7881[] = {
  "cmpgt\t%0.h, %1/z, %2.h, #%3",
  "cmpgt\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7882[] = {
  "cmplo\t%0.h, %1/z, %2.h, #%3",
  "cmplo\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7883[] = {
  "cmpls\t%0.h, %1/z, %2.h, #%3",
  "cmpls\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7884[] = {
  "cmphs\t%0.h, %1/z, %2.h, #%3",
  "cmphs\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7885[] = {
  "cmphi\t%0.h, %1/z, %2.h, #%3",
  "cmphi\t%0.h, %1/z, %2.h, %3.h",
};

static const char * const output_7886[] = {
  "cmplt\t%0.s, %1/z, %2.s, #%3",
  "cmplt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7887[] = {
  "cmple\t%0.s, %1/z, %2.s, #%3",
  "cmple\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7888[] = {
  "cmpeq\t%0.s, %1/z, %2.s, #%3",
  "cmpeq\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7889[] = {
  "cmpne\t%0.s, %1/z, %2.s, #%3",
  "cmpne\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7890[] = {
  "cmpge\t%0.s, %1/z, %2.s, #%3",
  "cmpge\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7891[] = {
  "cmpgt\t%0.s, %1/z, %2.s, #%3",
  "cmpgt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7892[] = {
  "cmplo\t%0.s, %1/z, %2.s, #%3",
  "cmplo\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7893[] = {
  "cmpls\t%0.s, %1/z, %2.s, #%3",
  "cmpls\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7894[] = {
  "cmphs\t%0.s, %1/z, %2.s, #%3",
  "cmphs\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7895[] = {
  "cmphi\t%0.s, %1/z, %2.s, #%3",
  "cmphi\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7896[] = {
  "cmplt\t%0.s, %1/z, %2.s, #%3",
  "cmplt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7897[] = {
  "cmple\t%0.s, %1/z, %2.s, #%3",
  "cmple\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7898[] = {
  "cmpeq\t%0.s, %1/z, %2.s, #%3",
  "cmpeq\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7899[] = {
  "cmpne\t%0.s, %1/z, %2.s, #%3",
  "cmpne\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7900[] = {
  "cmpge\t%0.s, %1/z, %2.s, #%3",
  "cmpge\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7901[] = {
  "cmpgt\t%0.s, %1/z, %2.s, #%3",
  "cmpgt\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7902[] = {
  "cmplo\t%0.s, %1/z, %2.s, #%3",
  "cmplo\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7903[] = {
  "cmpls\t%0.s, %1/z, %2.s, #%3",
  "cmpls\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7904[] = {
  "cmphs\t%0.s, %1/z, %2.s, #%3",
  "cmphs\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7905[] = {
  "cmphi\t%0.s, %1/z, %2.s, #%3",
  "cmphi\t%0.s, %1/z, %2.s, %3.s",
};

static const char * const output_7906[] = {
  "cmplt\t%0.d, %1/z, %2.d, #%3",
  "cmplt\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7907[] = {
  "cmple\t%0.d, %1/z, %2.d, #%3",
  "cmple\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7908[] = {
  "cmpeq\t%0.d, %1/z, %2.d, #%3",
  "cmpeq\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7909[] = {
  "cmpne\t%0.d, %1/z, %2.d, #%3",
  "cmpne\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7910[] = {
  "cmpge\t%0.d, %1/z, %2.d, #%3",
  "cmpge\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7911[] = {
  "cmpgt\t%0.d, %1/z, %2.d, #%3",
  "cmpgt\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7912[] = {
  "cmplo\t%0.d, %1/z, %2.d, #%3",
  "cmplo\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7913[] = {
  "cmpls\t%0.d, %1/z, %2.d, #%3",
  "cmpls\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7914[] = {
  "cmphs\t%0.d, %1/z, %2.d, #%3",
  "cmphs\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_7915[] = {
  "cmphi\t%0.d, %1/z, %2.d, #%3",
  "cmphi\t%0.d, %1/z, %2.d, %3.d",
};

static const char * const output_8346[] = {
  "fcmeq\t%0.h, %1/z, %3.h, #0.0",
  "fcmeq\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_8347[] = {
  "fcmge\t%0.h, %1/z, %3.h, #0.0",
  "fcmge\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_8348[] = {
  "fcmgt\t%0.h, %1/z, %3.h, #0.0",
  "fcmgt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_8349[] = {
  "fcmle\t%0.h, %1/z, %3.h, #0.0",
  "fcmle\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_8350[] = {
  "fcmlt\t%0.h, %1/z, %3.h, #0.0",
  "fcmlt\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_8351[] = {
  "fcmne\t%0.h, %1/z, %3.h, #0.0",
  "fcmne\t%0.h, %1/z, %3.h, %4.h",
};

static const char * const output_8352[] = {
  "fcmeq\t%0.s, %1/z, %3.s, #0.0",
  "fcmeq\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_8353[] = {
  "fcmge\t%0.s, %1/z, %3.s, #0.0",
  "fcmge\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_8354[] = {
  "fcmgt\t%0.s, %1/z, %3.s, #0.0",
  "fcmgt\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_8355[] = {
  "fcmle\t%0.s, %1/z, %3.s, #0.0",
  "fcmle\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_8356[] = {
  "fcmlt\t%0.s, %1/z, %3.s, #0.0",
  "fcmlt\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_8357[] = {
  "fcmne\t%0.s, %1/z, %3.s, #0.0",
  "fcmne\t%0.s, %1/z, %3.s, %4.s",
};

static const char * const output_8358[] = {
  "fcmeq\t%0.d, %1/z, %3.d, #0.0",
  "fcmeq\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_8359[] = {
  "fcmge\t%0.d, %1/z, %3.d, #0.0",
  "fcmge\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_8360[] = {
  "fcmgt\t%0.d, %1/z, %3.d, #0.0",
  "fcmgt\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_8361[] = {
  "fcmle\t%0.d, %1/z, %3.d, #0.0",
  "fcmle\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_8362[] = {
  "fcmlt\t%0.d, %1/z, %3.d, #0.0",
  "fcmlt\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_8363[] = {
  "fcmne\t%0.d, %1/z, %3.d, #0.0",
  "fcmne\t%0.d, %1/z, %3.d, %4.d",
};

static const char * const output_8462[] = {
  "clasta\t%w0, %2, %w0, %3.b",
  "clasta\t%b0, %2, %b0, %3.b",
};

static const char * const output_8463[] = {
  "clastb\t%w0, %2, %w0, %3.b",
  "clastb\t%b0, %2, %b0, %3.b",
};

static const char * const output_8464[] = {
  "clasta\t%w0, %2, %w0, %3.h",
  "clasta\t%h0, %2, %h0, %3.h",
};

static const char * const output_8465[] = {
  "clastb\t%w0, %2, %w0, %3.h",
  "clastb\t%h0, %2, %h0, %3.h",
};

static const char * const output_8466[] = {
  "clasta\t%w0, %2, %w0, %3.s",
  "clasta\t%s0, %2, %s0, %3.s",
};

static const char * const output_8467[] = {
  "clastb\t%w0, %2, %w0, %3.s",
  "clastb\t%s0, %2, %s0, %3.s",
};

static const char * const output_8468[] = {
  "clasta\t%x0, %2, %x0, %3.d",
  "clasta\t%d0, %2, %d0, %3.d",
};

static const char * const output_8469[] = {
  "clastb\t%x0, %2, %x0, %3.d",
  "clastb\t%d0, %2, %d0, %3.d",
};

static const char * const output_8470[] = {
  "clasta\t%w0, %2, %w0, %3.h",
  "clasta\t%h0, %2, %h0, %3.h",
};

static const char * const output_8471[] = {
  "clastb\t%w0, %2, %w0, %3.h",
  "clastb\t%h0, %2, %h0, %3.h",
};

static const char * const output_8472[] = {
  "clasta\t%w0, %2, %w0, %3.h",
  "clasta\t%h0, %2, %h0, %3.h",
};

static const char * const output_8473[] = {
  "clastb\t%w0, %2, %w0, %3.h",
  "clastb\t%h0, %2, %h0, %3.h",
};

static const char * const output_8474[] = {
  "clasta\t%w0, %2, %w0, %3.s",
  "clasta\t%s0, %2, %s0, %3.s",
};

static const char * const output_8475[] = {
  "clastb\t%w0, %2, %w0, %3.s",
  "clastb\t%s0, %2, %s0, %3.s",
};

static const char * const output_8476[] = {
  "clasta\t%x0, %2, %x0, %3.d",
  "clasta\t%d0, %2, %d0, %3.d",
};

static const char * const output_8477[] = {
  "clastb\t%x0, %2, %x0, %3.d",
  "clastb\t%d0, %2, %d0, %3.d",
};

static const char * const output_8478[] = {
  "clasta\t%0.b, %2, %0.b, %3.b",
  "movprfx\t%0, %1\n\tclasta\t%0.b, %2, %0.b, %3.b",
};

static const char * const output_8479[] = {
  "clastb\t%0.b, %2, %0.b, %3.b",
  "movprfx\t%0, %1\n\tclastb\t%0.b, %2, %0.b, %3.b",
};

static const char * const output_8480[] = {
  "clasta\t%0.h, %2, %0.h, %3.h",
  "movprfx\t%0, %1\n\tclasta\t%0.h, %2, %0.h, %3.h",
};

static const char * const output_8481[] = {
  "clastb\t%0.h, %2, %0.h, %3.h",
  "movprfx\t%0, %1\n\tclastb\t%0.h, %2, %0.h, %3.h",
};

static const char * const output_8482[] = {
  "clasta\t%0.s, %2, %0.s, %3.s",
  "movprfx\t%0, %1\n\tclasta\t%0.s, %2, %0.s, %3.s",
};

static const char * const output_8483[] = {
  "clastb\t%0.s, %2, %0.s, %3.s",
  "movprfx\t%0, %1\n\tclastb\t%0.s, %2, %0.s, %3.s",
};

static const char * const output_8484[] = {
  "clasta\t%0.d, %2, %0.d, %3.d",
  "movprfx\t%0, %1\n\tclasta\t%0.d, %2, %0.d, %3.d",
};

static const char * const output_8485[] = {
  "clastb\t%0.d, %2, %0.d, %3.d",
  "movprfx\t%0, %1\n\tclastb\t%0.d, %2, %0.d, %3.d",
};

static const char * const output_8486[] = {
  "clasta\t%0.h, %2, %0.h, %3.h",
  "movprfx\t%0, %1\n\tclasta\t%0.h, %2, %0.h, %3.h",
};

static const char * const output_8487[] = {
  "clastb\t%0.h, %2, %0.h, %3.h",
  "movprfx\t%0, %1\n\tclastb\t%0.h, %2, %0.h, %3.h",
};

static const char * const output_8488[] = {
  "clasta\t%0.h, %2, %0.h, %3.h",
  "movprfx\t%0, %1\n\tclasta\t%0.h, %2, %0.h, %3.h",
};

static const char * const output_8489[] = {
  "clastb\t%0.h, %2, %0.h, %3.h",
  "movprfx\t%0, %1\n\tclastb\t%0.h, %2, %0.h, %3.h",
};

static const char * const output_8490[] = {
  "clasta\t%0.s, %2, %0.s, %3.s",
  "movprfx\t%0, %1\n\tclasta\t%0.s, %2, %0.s, %3.s",
};

static const char * const output_8491[] = {
  "clastb\t%0.s, %2, %0.s, %3.s",
  "movprfx\t%0, %1\n\tclastb\t%0.s, %2, %0.s, %3.s",
};

static const char * const output_8492[] = {
  "clasta\t%0.d, %2, %0.d, %3.d",
  "movprfx\t%0, %1\n\tclasta\t%0.d, %2, %0.d, %3.d",
};

static const char * const output_8493[] = {
  "clastb\t%0.d, %2, %0.d, %3.d",
  "movprfx\t%0, %1\n\tclastb\t%0.d, %2, %0.d, %3.d",
};

static const char *
output_8578 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (QImode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char *
output_8579 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (HImode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char *
output_8580 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (SImode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char *
output_8581 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (DImode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char *
output_8582 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (BFmode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char *
output_8583 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (HFmode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char *
output_8584 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (SFmode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char *
output_8585 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8715 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    unsigned int byte = (INTVAL (XVECEXP (operands[2], 0, 0))
			 * GET_MODE_SIZE (DFmode));
    operands[2] = gen_int_mode (byte / 16, DImode);
    return "dup\t%0.q, %1.q[%2]";
  }
}

static const char * const output_8605[] = {
  "splice\t%0.b, %1, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsplice\t%0.b, %1, %0.b, %3.b",
};

static const char * const output_8606[] = {
  "splice\t%0.h, %1, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsplice\t%0.h, %1, %0.h, %3.h",
};

static const char * const output_8607[] = {
  "splice\t%0.s, %1, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsplice\t%0.s, %1, %0.s, %3.s",
};

static const char * const output_8608[] = {
  "splice\t%0.d, %1, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsplice\t%0.d, %1, %0.d, %3.d",
};

static const char * const output_8609[] = {
  "splice\t%0.h, %1, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsplice\t%0.h, %1, %0.h, %3.h",
};

static const char * const output_8610[] = {
  "splice\t%0.h, %1, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsplice\t%0.h, %1, %0.h, %3.h",
};

static const char * const output_8611[] = {
  "splice\t%0.s, %1, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsplice\t%0.s, %1, %0.s, %3.s",
};

static const char * const output_8612[] = {
  "splice\t%0.d, %1, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsplice\t%0.d, %1, %0.d, %3.d",
};

static const char *
output_8775 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 8 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8776 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 16 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8777 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 32 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8778 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8779 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 16 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8780 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 32 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8781 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8782 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 16 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8783 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 32 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8784 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8785 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 16 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8786 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 32 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8787 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8788 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 32 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8789 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8790 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 32 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8791 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8792 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char *
output_8793 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 8796 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    operands[3] = GEN_INT (INTVAL (operands[3]) * 64 / 8);
    return (which_alternative == 0
	    ? "ext\t%0.b, %0.b, %2.b, #%3"
	    : "movprfx\t%0, %1\n\text\t%0.b, %0.b, %2.b, #%3");
  }
}

static const char * const output_8841[] = {
  "fcvtzs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvtzs\t%0.h, %1/m, %2.h",
};

static const char * const output_8842[] = {
  "fcvtzu\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvtzu\t%0.h, %1/m, %2.h",
};

static const char * const output_8843[] = {
  "fcvtzs\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvtzs\t%0.s, %1/m, %2.h",
};

static const char * const output_8844[] = {
  "fcvtzu\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvtzu\t%0.s, %1/m, %2.h",
};

static const char * const output_8845[] = {
  "fcvtzs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfcvtzs\t%0.s, %1/m, %2.s",
};

static const char * const output_8846[] = {
  "fcvtzu\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfcvtzu\t%0.s, %1/m, %2.s",
};

static const char * const output_8847[] = {
  "fcvtzs\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvtzs\t%0.d, %1/m, %2.h",
};

static const char * const output_8848[] = {
  "fcvtzu\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvtzu\t%0.d, %1/m, %2.h",
};

static const char * const output_8849[] = {
  "fcvtzs\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfcvtzs\t%0.d, %1/m, %2.s",
};

static const char * const output_8850[] = {
  "fcvtzu\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfcvtzu\t%0.d, %1/m, %2.s",
};

static const char * const output_8851[] = {
  "fcvtzs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfcvtzs\t%0.d, %1/m, %2.d",
};

static const char * const output_8852[] = {
  "fcvtzu\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfcvtzu\t%0.d, %1/m, %2.d",
};

static const char * const output_8853[] = {
  "fcvtzs\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfcvtzs\t%0.s, %1/m, %2.d",
};

static const char * const output_8854[] = {
  "fcvtzu\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfcvtzu\t%0.s, %1/m, %2.d",
};

static const char * const output_8855[] = {
  "fcvtzs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfcvtzs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.h, %1/m, %2.h",
};

static const char * const output_8856[] = {
  "fcvtzu\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfcvtzu\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.h, %1/m, %2.h",
};

static const char * const output_8857[] = {
  "fcvtzs\t%0.s, %1/m, %2.h",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzs\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.s, %1/m, %2.h",
};

static const char * const output_8858[] = {
  "fcvtzu\t%0.s, %1/m, %2.h",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzu\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.s, %1/m, %2.h",
};

static const char * const output_8859[] = {
  "fcvtzs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.s, %1/m, %2.s",
};

static const char * const output_8860[] = {
  "fcvtzu\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzu\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.s, %1/m, %2.s",
};

static const char * const output_8861[] = {
  "fcvtzs\t%0.d, %1/m, %2.h",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzs\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.d, %1/m, %2.h",
};

static const char * const output_8862[] = {
  "fcvtzu\t%0.d, %1/m, %2.h",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzu\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.d, %1/m, %2.h",
};

static const char * const output_8863[] = {
  "fcvtzs\t%0.d, %1/m, %2.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzs\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.d, %1/m, %2.s",
};

static const char * const output_8864[] = {
  "fcvtzu\t%0.d, %1/m, %2.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzu\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.d, %1/m, %2.s",
};

static const char * const output_8865[] = {
  "fcvtzs\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.d, %1/m, %2.d",
};

static const char * const output_8866[] = {
  "fcvtzu\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzu\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.d, %1/m, %2.d",
};

static const char * const output_8867[] = {
  "fcvtzs\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfcvtzs\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.h, %1/m, %2.h",
};

static const char * const output_8868[] = {
  "fcvtzu\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tfcvtzu\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.h, %1/m, %2.h",
};

static const char * const output_8869[] = {
  "fcvtzs\t%0.s, %1/m, %2.h",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzs\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.s, %1/m, %2.h",
};

static const char * const output_8870[] = {
  "fcvtzu\t%0.s, %1/m, %2.h",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzu\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.s, %1/m, %2.h",
};

static const char * const output_8871[] = {
  "fcvtzs\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzs\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.s, %1/m, %2.s",
};

static const char * const output_8872[] = {
  "fcvtzu\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvtzu\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.s, %1/m, %2.s",
};

static const char * const output_8873[] = {
  "fcvtzs\t%0.d, %1/m, %2.h",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzs\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.d, %1/m, %2.h",
};

static const char * const output_8874[] = {
  "fcvtzu\t%0.d, %1/m, %2.h",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzu\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.d, %1/m, %2.h",
};

static const char * const output_8875[] = {
  "fcvtzs\t%0.d, %1/m, %2.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzs\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.d, %1/m, %2.s",
};

static const char * const output_8876[] = {
  "fcvtzu\t%0.d, %1/m, %2.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzu\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.d, %1/m, %2.s",
};

static const char * const output_8877[] = {
  "fcvtzs\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzs\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.d, %1/m, %2.d",
};

static const char * const output_8878[] = {
  "fcvtzu\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzu\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.d, %1/m, %2.d",
};

static const char * const output_8879[] = {
  "fcvtzs\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzs\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtzs\t%0.s, %1/m, %2.d",
};

static const char * const output_8880[] = {
  "fcvtzu\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtzu\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtzu\t%0.s, %1/m, %2.d",
};

static const char * const output_8881[] = {
  "scvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tscvtf\t%0.h, %1/m, %2.h",
};

static const char * const output_8882[] = {
  "ucvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tucvtf\t%0.h, %1/m, %2.h",
};

static const char * const output_8883[] = {
  "scvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %2\n\tscvtf\t%0.h, %1/m, %2.s",
};

static const char * const output_8884[] = {
  "ucvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %2\n\tucvtf\t%0.h, %1/m, %2.s",
};

static const char * const output_8885[] = {
  "scvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tscvtf\t%0.s, %1/m, %2.s",
};

static const char * const output_8886[] = {
  "ucvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tucvtf\t%0.s, %1/m, %2.s",
};

static const char * const output_8887[] = {
  "scvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %2\n\tscvtf\t%0.h, %1/m, %2.d",
};

static const char * const output_8888[] = {
  "ucvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %2\n\tucvtf\t%0.h, %1/m, %2.d",
};

static const char * const output_8889[] = {
  "scvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %2\n\tscvtf\t%0.s, %1/m, %2.d",
};

static const char * const output_8890[] = {
  "ucvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %2\n\tucvtf\t%0.s, %1/m, %2.d",
};

static const char * const output_8891[] = {
  "scvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tscvtf\t%0.d, %1/m, %2.d",
};

static const char * const output_8892[] = {
  "ucvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tucvtf\t%0.d, %1/m, %2.d",
};

static const char * const output_8893[] = {
  "scvtf\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %2\n\tscvtf\t%0.d, %1/m, %2.s",
};

static const char * const output_8894[] = {
  "ucvtf\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %2\n\tucvtf\t%0.d, %1/m, %2.s",
};

static const char * const output_8895[] = {
  "scvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tscvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tscvtf\t%0.h, %1/m, %2.h",
};

static const char * const output_8896[] = {
  "ucvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tucvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tucvtf\t%0.h, %1/m, %2.h",
};

static const char * const output_8897[] = {
  "scvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tscvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %3\n\tscvtf\t%0.h, %1/m, %2.s",
};

static const char * const output_8898[] = {
  "ucvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tucvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %3\n\tucvtf\t%0.h, %1/m, %2.s",
};

static const char * const output_8899[] = {
  "scvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tscvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tscvtf\t%0.s, %1/m, %2.s",
};

static const char * const output_8900[] = {
  "ucvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tucvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tucvtf\t%0.s, %1/m, %2.s",
};

static const char * const output_8901[] = {
  "scvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tscvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %3\n\tscvtf\t%0.h, %1/m, %2.d",
};

static const char * const output_8902[] = {
  "ucvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tucvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %3\n\tucvtf\t%0.h, %1/m, %2.d",
};

static const char * const output_8903[] = {
  "scvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tscvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tscvtf\t%0.s, %1/m, %2.d",
};

static const char * const output_8904[] = {
  "ucvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tucvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tucvtf\t%0.s, %1/m, %2.d",
};

static const char * const output_8905[] = {
  "scvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tscvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tscvtf\t%0.d, %1/m, %2.d",
};

static const char * const output_8906[] = {
  "ucvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tucvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tucvtf\t%0.d, %1/m, %2.d",
};

static const char * const output_8907[] = {
  "scvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tscvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tscvtf\t%0.h, %1/m, %2.h",
};

static const char * const output_8908[] = {
  "ucvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tucvtf\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tucvtf\t%0.h, %1/m, %2.h",
};

static const char * const output_8909[] = {
  "scvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tscvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %3\n\tscvtf\t%0.h, %1/m, %2.s",
};

static const char * const output_8910[] = {
  "ucvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tucvtf\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %3\n\tucvtf\t%0.h, %1/m, %2.s",
};

static const char * const output_8911[] = {
  "scvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tscvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tscvtf\t%0.s, %1/m, %2.s",
};

static const char * const output_8912[] = {
  "ucvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tucvtf\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tucvtf\t%0.s, %1/m, %2.s",
};

static const char * const output_8913[] = {
  "scvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tscvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %3\n\tscvtf\t%0.h, %1/m, %2.d",
};

static const char * const output_8914[] = {
  "ucvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tucvtf\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %3\n\tucvtf\t%0.h, %1/m, %2.d",
};

static const char * const output_8915[] = {
  "scvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tscvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tscvtf\t%0.s, %1/m, %2.d",
};

static const char * const output_8916[] = {
  "ucvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tucvtf\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tucvtf\t%0.s, %1/m, %2.d",
};

static const char * const output_8917[] = {
  "scvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tscvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tscvtf\t%0.d, %1/m, %2.d",
};

static const char * const output_8918[] = {
  "ucvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tucvtf\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tucvtf\t%0.d, %1/m, %2.d",
};

static const char * const output_8919[] = {
  "scvtf\t%0.d, %1/m, %2.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tscvtf\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %3\n\tscvtf\t%0.d, %1/m, %2.s",
};

static const char * const output_8920[] = {
  "ucvtf\t%0.d, %1/m, %2.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tucvtf\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %3\n\tucvtf\t%0.d, %1/m, %2.s",
};

static const char * const output_8921[] = {
  "fcvt\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfcvt\t%0.h, %1/m, %2.s",
};

static const char * const output_8922[] = {
  "fcvt\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfcvt\t%0.h, %1/m, %2.d",
};

static const char * const output_8923[] = {
  "fcvt\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfcvt\t%0.s, %1/m, %2.d",
};

static const char * const output_8924[] = {
  "fcvt\t%0.h, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvt\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvt\t%0.h, %1/m, %2.s",
};

static const char * const output_8925[] = {
  "fcvt\t%0.h, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvt\t%0.h, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvt\t%0.h, %1/m, %2.d",
};

static const char * const output_8926[] = {
  "fcvt\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvt\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvt\t%0.s, %1/m, %2.d",
};

static const char * const output_8927[] = {
  "bfcvt\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %2\n\tbfcvt\t%0.h, %1/m, %2.s",
};

static const char * const output_8928[] = {
  "bfcvt\t%0.h, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tbfcvt\t%0.h, %1/m, %2.s",
  "movprfx\t%0, %3\n\tbfcvt\t%0.h, %1/m, %2.s",
};

static const char * const output_8930[] = {
  "fcvt\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvt\t%0.s, %1/m, %2.h",
};

static const char * const output_8931[] = {
  "fcvt\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %2\n\tfcvt\t%0.d, %1/m, %2.h",
};

static const char * const output_8932[] = {
  "fcvt\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %2\n\tfcvt\t%0.d, %1/m, %2.s",
};

static const char * const output_8933[] = {
  "fcvt\t%0.s, %1/m, %2.h",
  "movprfx\t%0.s, %1/z, %2.s\n\tfcvt\t%0.s, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvt\t%0.s, %1/m, %2.h",
};

static const char * const output_8934[] = {
  "fcvt\t%0.d, %1/m, %2.h",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvt\t%0.d, %1/m, %2.h",
  "movprfx\t%0, %3\n\tfcvt\t%0.d, %1/m, %2.h",
};

static const char * const output_8935[] = {
  "fcvt\t%0.d, %1/m, %2.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvt\t%0.d, %1/m, %2.s",
  "movprfx\t%0, %3\n\tfcvt\t%0.d, %1/m, %2.s",
};

static const char * const output_8945[] = {
  "brka\t%0.b, %1/z, %2.b",
  "brka\t%0.b, %1/m, %2.b",
};

static const char * const output_8946[] = {
  "brkb\t%0.b, %1/z, %2.b",
  "brkb\t%0.b, %1/m, %2.b",
};

static const char * const output_8947[] = {
  "brkas\t%0.b, %1/z, %2.b",
  "brkas\t%0.b, %1/m, %2.b",
};

static const char * const output_8948[] = {
  "brkbs\t%0.b, %1/z, %2.b",
  "brkbs\t%0.b, %1/m, %2.b",
};

static const char * const output_8949[] = {
  "brkas\t%0.b, %1/z, %2.b",
  "brkas\t%0.b, %1/m, %2.b",
};

static const char * const output_8950[] = {
  "brkbs\t%0.b, %1/z, %2.b",
  "brkbs\t%0.b, %1/m, %2.b",
};

static const char *
output_8975 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9823 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("cnt", "%x0", operands + 1);
  }
}

static const char *
output_8976 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9848 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("inc", "%x0",
						 operands + 2);
  }
}

static const char *
output_8977 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9848 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("sqinc", "%x0",
						 operands + 2);
  }
}

static const char *
output_8978 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9848 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("uqinc", "%x0",
						 operands + 2);
  }
}

static const char *
output_8979 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9865 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("inc", "%x0", operands + 2);
  }
}

static const char *
output_8980 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9884 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    const char *registers = (SS_PLUS == SS_PLUS ? "%x0, %w0" : "%w0");
    return aarch64_output_sve_cnt_pat_immediate ("sqinc", registers,
						 operands + 2);
  }
}

static const char *
output_8981 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9884 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    const char *registers = (US_PLUS == SS_PLUS ? "%x0, %w0" : "%w0");
    return aarch64_output_sve_cnt_pat_immediate ("uqinc", registers,
						 operands + 2);
  }
}

static const char *
output_8982 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9913 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("inc", "%0.d",
						 operands + 2);
  }
}

static const char *
output_8983 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9913 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("sqinc", "%0.d",
						 operands + 2);
  }
}

static const char *
output_8984 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9913 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("uqinc", "%0.d",
						 operands + 2);
  }
}

static const char *
output_8985 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9934 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("inc", "%0.s",
						 operands + 2);
  }
}

static const char *
output_8986 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9934 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("sqinc", "%0.s",
						 operands + 2);
  }
}

static const char *
output_8987 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9934 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("uqinc", "%0.s",
						 operands + 2);
  }
}

static const char *
output_8988 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9969 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("inc", "%0.h",
						 operands + 2);
  }
}

static const char *
output_8989 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9969 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("sqinc", "%0.h",
						 operands + 2);
  }
}

static const char *
output_8990 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9969 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("uqinc", "%0.h",
						 operands + 2);
  }
}

static const char *
output_8991 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9998 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("dec", "%x0",
						 operands + 2);
  }
}

static const char *
output_8992 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9998 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("sqdec", "%x0",
						 operands + 2);
  }
}

static const char *
output_8993 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 9998 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("uqdec", "%x0",
						 operands + 2);
  }
}

static const char *
output_8994 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10015 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    return aarch64_output_sve_cnt_pat_immediate ("dec", "%x0", operands + 2);
  }
}

static const char *
output_8995 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10034 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    const char *registers = (SS_MINUS == SS_MINUS ? "%x0, %w0" : "%w0");
    return aarch64_output_sve_cnt_pat_immediate ("sqdec", registers,
						 operands + 2);
  }
}

static const char *
output_8996 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10034 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    const char *registers = (US_MINUS == SS_MINUS ? "%x0, %w0" : "%w0");
    return aarch64_output_sve_cnt_pat_immediate ("uqdec", registers,
						 operands + 2);
  }
}

static const char *
output_8997 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10063 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("dec", "%0.d",
						 operands + 2);
  }
}

static const char *
output_8998 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10063 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("sqdec", "%0.d",
						 operands + 2);
  }
}

static const char *
output_8999 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10063 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("uqdec", "%0.d",
						 operands + 2);
  }
}

static const char *
output_9000 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10084 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("dec", "%0.s",
						 operands + 2);
  }
}

static const char *
output_9001 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10084 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("sqdec", "%0.s",
						 operands + 2);
  }
}

static const char *
output_9002 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10084 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("uqdec", "%0.s",
						 operands + 2);
  }
}

static const char *
output_9003 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10119 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("dec", "%0.h",
						 operands + 2);
  }
}

static const char *
output_9004 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10119 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("sqdec", "%0.h",
						 operands + 2);
  }
}

static const char *
output_9005 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10119 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (which_alternative == 1)
      output_asm_insn ("movprfx\t%0, %1", operands);
    return aarch64_output_sve_cnt_pat_immediate ("uqdec", "%0.h",
						 operands + 2);
  }
}

static const char *
output_9026 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_PLUS == SS_PLUS)
      return "sqincp\t%x0, %2.b, %w0";
    else
      return "sqincp\t%w0, %2.b";
  }
}

static const char *
output_9027 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_PLUS == SS_PLUS)
      return "uqincp\t%x0, %2.b, %w0";
    else
      return "uqincp\t%w0, %2.b";
  }
}

static const char *
output_9028 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_PLUS == SS_PLUS)
      return "sqincp\t%x0, %2.h, %w0";
    else
      return "sqincp\t%w0, %2.h";
  }
}

static const char *
output_9029 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_PLUS == SS_PLUS)
      return "uqincp\t%x0, %2.h, %w0";
    else
      return "uqincp\t%w0, %2.h";
  }
}

static const char *
output_9030 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_PLUS == SS_PLUS)
      return "sqincp\t%x0, %2.s, %w0";
    else
      return "sqincp\t%w0, %2.s";
  }
}

static const char *
output_9031 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_PLUS == SS_PLUS)
      return "uqincp\t%x0, %2.s, %w0";
    else
      return "uqincp\t%w0, %2.s";
  }
}

static const char *
output_9032 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_PLUS == SS_PLUS)
      return "sqincp\t%x0, %2.d, %w0";
    else
      return "sqincp\t%w0, %2.d";
  }
}

static const char *
output_9033 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10238 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_PLUS == SS_PLUS)
      return "uqincp\t%x0, %2.d, %w0";
    else
      return "uqincp\t%w0, %2.d";
  }
}

static const char * const output_9034[] = {
  "incp\t%0.d, %2",
  "movprfx\t%0, %1\n\tincp\t%0.d, %2",
};

static const char * const output_9035[] = {
  "sqincp\t%0.d, %2",
  "movprfx\t%0, %1\n\tsqincp\t%0.d, %2",
};

static const char * const output_9036[] = {
  "uqincp\t%0.d, %2",
  "movprfx\t%0, %1\n\tuqincp\t%0.d, %2",
};

static const char * const output_9037[] = {
  "incp\t%0.s, %2",
  "movprfx\t%0, %1\n\tincp\t%0.s, %2",
};

static const char * const output_9038[] = {
  "sqincp\t%0.s, %2",
  "movprfx\t%0, %1\n\tsqincp\t%0.s, %2",
};

static const char * const output_9039[] = {
  "uqincp\t%0.s, %2",
  "movprfx\t%0, %1\n\tuqincp\t%0.s, %2",
};

static const char * const output_9040[] = {
  "incp\t%0.h, %2",
  "movprfx\t%0, %1\n\tincp\t%0.h, %2",
};

static const char * const output_9041[] = {
  "sqincp\t%0.h, %2",
  "movprfx\t%0, %1\n\tsqincp\t%0.h, %2",
};

static const char * const output_9042[] = {
  "uqincp\t%0.h, %2",
  "movprfx\t%0, %1\n\tuqincp\t%0.h, %2",
};

static const char *
output_9059 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_MINUS == SS_MINUS)
      return "sqdecp\t%x0, %2.b, %w0";
    else
      return "sqdecp\t%w0, %2.b";
  }
}

static const char *
output_9060 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_MINUS == SS_MINUS)
      return "uqdecp\t%x0, %2.b, %w0";
    else
      return "uqdecp\t%w0, %2.b";
  }
}

static const char *
output_9061 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_MINUS == SS_MINUS)
      return "sqdecp\t%x0, %2.h, %w0";
    else
      return "sqdecp\t%w0, %2.h";
  }
}

static const char *
output_9062 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_MINUS == SS_MINUS)
      return "uqdecp\t%x0, %2.h, %w0";
    else
      return "uqdecp\t%w0, %2.h";
  }
}

static const char *
output_9063 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_MINUS == SS_MINUS)
      return "sqdecp\t%x0, %2.s, %w0";
    else
      return "sqdecp\t%w0, %2.s";
  }
}

static const char *
output_9064 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_MINUS == SS_MINUS)
      return "uqdecp\t%x0, %2.s, %w0";
    else
      return "uqdecp\t%w0, %2.s";
  }
}

static const char *
output_9065 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (SS_MINUS == SS_MINUS)
      return "sqdecp\t%x0, %2.d, %w0";
    else
      return "sqdecp\t%w0, %2.d";
  }
}

static const char *
output_9066 (rtx *operands ATTRIBUTE_UNUSED, rtx_insn *insn ATTRIBUTE_UNUSED)
{
#line 10471 "../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md"
{
    if (US_MINUS == SS_MINUS)
      return "uqdecp\t%x0, %2.d, %w0";
    else
      return "uqdecp\t%w0, %2.d";
  }
}

static const char * const output_9067[] = {
  "decp\t%0.d, %2",
  "movprfx\t%0, %1\n\tdecp\t%0.d, %2",
};

static const char * const output_9068[] = {
  "sqdecp\t%0.d, %2",
  "movprfx\t%0, %1\n\tsqdecp\t%0.d, %2",
};

static const char * const output_9069[] = {
  "uqdecp\t%0.d, %2",
  "movprfx\t%0, %1\n\tuqdecp\t%0.d, %2",
};

static const char * const output_9070[] = {
  "decp\t%0.s, %2",
  "movprfx\t%0, %1\n\tdecp\t%0.s, %2",
};

static const char * const output_9071[] = {
  "sqdecp\t%0.s, %2",
  "movprfx\t%0, %1\n\tsqdecp\t%0.s, %2",
};

static const char * const output_9072[] = {
  "uqdecp\t%0.s, %2",
  "movprfx\t%0, %1\n\tuqdecp\t%0.s, %2",
};

static const char * const output_9073[] = {
  "decp\t%0.h, %2",
  "movprfx\t%0, %1\n\tdecp\t%0.h, %2",
};

static const char * const output_9074[] = {
  "sqdecp\t%0.h, %2",
  "movprfx\t%0, %1\n\tsqdecp\t%0.h, %2",
};

static const char * const output_9075[] = {
  "uqdecp\t%0.h, %2",
  "movprfx\t%0, %1\n\tuqdecp\t%0.h, %2",
};

static const char * const output_9076[] = {
  "ldnt1w\t%0.s, %1/z, [%3.s]",
  "ldnt1w\t%0.s, %1/z, [%3.s, %2]",
};

static const char * const output_9077[] = {
  "ldnt1d\t%0.d, %1/z, [%3.d]",
  "ldnt1d\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9078[] = {
  "ldnt1w\t%0.s, %1/z, [%3.s]",
  "ldnt1w\t%0.s, %1/z, [%3.s, %2]",
};

static const char * const output_9079[] = {
  "ldnt1d\t%0.d, %1/z, [%3.d]",
  "ldnt1d\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9080[] = {
  "ldnt1sb\t%0.s, %1/z, [%3.s]",
  "ldnt1sb\t%0.s, %1/z, [%3.s, %2]",
};

static const char * const output_9081[] = {
  "ldnt1b\t%0.s, %1/z, [%3.s]",
  "ldnt1b\t%0.s, %1/z, [%3.s, %2]",
};

static const char * const output_9082[] = {
  "ldnt1sb\t%0.d, %1/z, [%3.d]",
  "ldnt1sb\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9083[] = {
  "ldnt1b\t%0.d, %1/z, [%3.d]",
  "ldnt1b\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9084[] = {
  "ldnt1sh\t%0.s, %1/z, [%3.s]",
  "ldnt1sh\t%0.s, %1/z, [%3.s, %2]",
};

static const char * const output_9085[] = {
  "ldnt1h\t%0.s, %1/z, [%3.s]",
  "ldnt1h\t%0.s, %1/z, [%3.s, %2]",
};

static const char * const output_9086[] = {
  "ldnt1sh\t%0.d, %1/z, [%3.d]",
  "ldnt1sh\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9087[] = {
  "ldnt1h\t%0.d, %1/z, [%3.d]",
  "ldnt1h\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9088[] = {
  "ldnt1sw\t%0.d, %1/z, [%3.d]",
  "ldnt1sw\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9089[] = {
  "ldnt1w\t%0.d, %1/z, [%3.d]",
  "ldnt1w\t%0.d, %1/z, [%3.d, %2]",
};

static const char * const output_9090[] = {
  "stnt1w\t%3.s, %0, [%2.s]",
  "stnt1w\t%3.s, %0, [%2.s, %1]",
};

static const char * const output_9091[] = {
  "stnt1d\t%3.d, %0, [%2.d]",
  "stnt1d\t%3.d, %0, [%2.d, %1]",
};

static const char * const output_9092[] = {
  "stnt1w\t%3.s, %0, [%2.s]",
  "stnt1w\t%3.s, %0, [%2.s, %1]",
};

static const char * const output_9093[] = {
  "stnt1d\t%3.d, %0, [%2.d]",
  "stnt1d\t%3.d, %0, [%2.d, %1]",
};

static const char * const output_9094[] = {
  "stnt1b\t%3.s, %0, [%2.s]",
  "stnt1b\t%3.s, %0, [%2.s, %1]",
};

static const char * const output_9095[] = {
  "stnt1b\t%3.d, %0, [%2.d]",
  "stnt1b\t%3.d, %0, [%2.d, %1]",
};

static const char * const output_9096[] = {
  "stnt1h\t%3.s, %0, [%2.s]",
  "stnt1h\t%3.s, %0, [%2.s, %1]",
};

static const char * const output_9097[] = {
  "stnt1h\t%3.d, %0, [%2.d]",
  "stnt1h\t%3.d, %0, [%2.d, %1]",
};

static const char * const output_9098[] = {
  "stnt1w\t%3.d, %0, [%2.d]",
  "stnt1w\t%3.d, %0, [%2.d, %1]",
};

static const char * const output_9102[] = {
  "sqadd\t%0.b, %0.b, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.b, %0.b, #%D2",
};

static const char * const output_9103[] = {
  "sqadd\t%0.h, %0.h, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.h, %0.h, #%D2",
};

static const char * const output_9104[] = {
  "sqadd\t%0.s, %0.s, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.s, %0.s, #%D2",
};

static const char * const output_9105[] = {
  "sqadd\t%0.d, %0.d, #%D2",
  "movprfx\t%0, %1\n\tsqadd\t%0.d, %0.d, #%D2",
};

static const char * const output_9106[] = {
  "shadd\t%0.b, %1/m, %0.b, %3.b",
  "shadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tshadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9107[] = {
  "shsub\t%0.b, %1/m, %0.b, %3.b",
  "shsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tshsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9108[] = {
  "sqrshl\t%0.b, %1/m, %0.b, %3.b",
  "sqrshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tsqrshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9109[] = {
  "srhadd\t%0.b, %1/m, %0.b, %3.b",
  "srhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tsrhadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9110[] = {
  "srshl\t%0.b, %1/m, %0.b, %3.b",
  "srshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tsrshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9111[] = {
  "uhadd\t%0.b, %1/m, %0.b, %3.b",
  "uhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tuhadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9112[] = {
  "uhsub\t%0.b, %1/m, %0.b, %3.b",
  "uhsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tuhsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9113[] = {
  "uqrshl\t%0.b, %1/m, %0.b, %3.b",
  "uqrshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tuqrshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9114[] = {
  "urhadd\t%0.b, %1/m, %0.b, %3.b",
  "urhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\turhadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9115[] = {
  "urshl\t%0.b, %1/m, %0.b, %3.b",
  "urshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\turshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9116[] = {
  "shadd\t%0.h, %1/m, %0.h, %3.h",
  "shadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tshadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9117[] = {
  "shsub\t%0.h, %1/m, %0.h, %3.h",
  "shsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tshsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9118[] = {
  "sqrshl\t%0.h, %1/m, %0.h, %3.h",
  "sqrshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tsqrshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9119[] = {
  "srhadd\t%0.h, %1/m, %0.h, %3.h",
  "srhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tsrhadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9120[] = {
  "srshl\t%0.h, %1/m, %0.h, %3.h",
  "srshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tsrshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9121[] = {
  "uhadd\t%0.h, %1/m, %0.h, %3.h",
  "uhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tuhadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9122[] = {
  "uhsub\t%0.h, %1/m, %0.h, %3.h",
  "uhsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tuhsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9123[] = {
  "uqrshl\t%0.h, %1/m, %0.h, %3.h",
  "uqrshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tuqrshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9124[] = {
  "urhadd\t%0.h, %1/m, %0.h, %3.h",
  "urhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\turhadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9125[] = {
  "urshl\t%0.h, %1/m, %0.h, %3.h",
  "urshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\turshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9126[] = {
  "shadd\t%0.s, %1/m, %0.s, %3.s",
  "shadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tshadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9127[] = {
  "shsub\t%0.s, %1/m, %0.s, %3.s",
  "shsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tshsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9128[] = {
  "sqrshl\t%0.s, %1/m, %0.s, %3.s",
  "sqrshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tsqrshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9129[] = {
  "srhadd\t%0.s, %1/m, %0.s, %3.s",
  "srhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tsrhadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9130[] = {
  "srshl\t%0.s, %1/m, %0.s, %3.s",
  "srshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tsrshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9131[] = {
  "uhadd\t%0.s, %1/m, %0.s, %3.s",
  "uhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tuhadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9132[] = {
  "uhsub\t%0.s, %1/m, %0.s, %3.s",
  "uhsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tuhsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9133[] = {
  "uqrshl\t%0.s, %1/m, %0.s, %3.s",
  "uqrshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tuqrshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9134[] = {
  "urhadd\t%0.s, %1/m, %0.s, %3.s",
  "urhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\turhadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9135[] = {
  "urshl\t%0.s, %1/m, %0.s, %3.s",
  "urshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\turshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9136[] = {
  "shadd\t%0.d, %1/m, %0.d, %3.d",
  "shadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tshadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9137[] = {
  "shsub\t%0.d, %1/m, %0.d, %3.d",
  "shsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tshsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9138[] = {
  "sqrshl\t%0.d, %1/m, %0.d, %3.d",
  "sqrshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tsqrshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9139[] = {
  "srhadd\t%0.d, %1/m, %0.d, %3.d",
  "srhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tsrhadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9140[] = {
  "srshl\t%0.d, %1/m, %0.d, %3.d",
  "srshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tsrshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9141[] = {
  "uhadd\t%0.d, %1/m, %0.d, %3.d",
  "uhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tuhadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9142[] = {
  "uhsub\t%0.d, %1/m, %0.d, %3.d",
  "uhsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tuhsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9143[] = {
  "uqrshl\t%0.d, %1/m, %0.d, %3.d",
  "uqrshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tuqrshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9144[] = {
  "urhadd\t%0.d, %1/m, %0.d, %3.d",
  "urhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\turhadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9145[] = {
  "urshl\t%0.d, %1/m, %0.d, %3.d",
  "urshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\turshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9146[] = {
  "shadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tshadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9147[] = {
  "shsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tshsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9148[] = {
  "sqrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqrshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9149[] = {
  "srhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsrhadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9150[] = {
  "srshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsrshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9151[] = {
  "suqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsuqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9152[] = {
  "uhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuhadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9153[] = {
  "uhsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuhsub\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9154[] = {
  "uqrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqrshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9155[] = {
  "urhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\turhadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9156[] = {
  "urshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\turshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9157[] = {
  "usqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tusqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9158[] = {
  "shadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tshadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9159[] = {
  "shsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tshsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9160[] = {
  "sqrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqrshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9161[] = {
  "srhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsrhadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9162[] = {
  "srshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsrshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9163[] = {
  "suqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsuqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9164[] = {
  "uhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuhadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9165[] = {
  "uhsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuhsub\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9166[] = {
  "uqrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqrshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9167[] = {
  "urhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\turhadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9168[] = {
  "urshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\turshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9169[] = {
  "usqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tusqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9170[] = {
  "shadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tshadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9171[] = {
  "shsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tshsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9172[] = {
  "sqrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsqrshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9173[] = {
  "srhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsrhadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9174[] = {
  "srshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsrshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9175[] = {
  "suqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsuqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9176[] = {
  "uhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuhadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9177[] = {
  "uhsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuhsub\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9178[] = {
  "uqrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuqrshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9179[] = {
  "urhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\turhadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9180[] = {
  "urshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\turshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9181[] = {
  "usqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tusqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9182[] = {
  "shadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tshadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9183[] = {
  "shsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tshsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9184[] = {
  "sqrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsqrshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9185[] = {
  "srhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsrhadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9186[] = {
  "srshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsrshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9187[] = {
  "suqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsuqadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9188[] = {
  "uhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuhadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9189[] = {
  "uhsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuhsub\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9190[] = {
  "uqrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuqrshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9191[] = {
  "urhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\turhadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9192[] = {
  "urshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\turshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9193[] = {
  "usqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tusqadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9194[] = {
  "shadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tshadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9195[] = {
  "shsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tshsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9196[] = {
  "sqrshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqrshlr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9197[] = {
  "srhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsrhadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9198[] = {
  "srshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsrshlr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9199[] = {
  "uhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuhadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9200[] = {
  "uhsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuhsubr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9201[] = {
  "uqrshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqrshlr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9202[] = {
  "urhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\turhadd\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9203[] = {
  "urshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\turshlr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9204[] = {
  "shadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tshadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9205[] = {
  "shsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tshsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9206[] = {
  "sqrshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqrshlr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9207[] = {
  "srhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsrhadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9208[] = {
  "srshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsrshlr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9209[] = {
  "uhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuhadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9210[] = {
  "uhsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuhsubr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9211[] = {
  "uqrshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqrshlr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9212[] = {
  "urhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\turhadd\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9213[] = {
  "urshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\turshlr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9214[] = {
  "shadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tshadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9215[] = {
  "shsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tshsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9216[] = {
  "sqrshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsqrshlr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9217[] = {
  "srhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsrhadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9218[] = {
  "srshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsrshlr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9219[] = {
  "uhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuhadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9220[] = {
  "uhsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuhsubr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9221[] = {
  "uqrshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuqrshlr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9222[] = {
  "urhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\turhadd\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9223[] = {
  "urshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\turshlr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9224[] = {
  "shadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tshadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9225[] = {
  "shsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tshsubr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9226[] = {
  "sqrshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsqrshlr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9227[] = {
  "srhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsrhadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9228[] = {
  "srshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsrshlr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9229[] = {
  "uhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tuhadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9230[] = {
  "uhsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tuhsubr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9231[] = {
  "uqrshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tuqrshlr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9232[] = {
  "urhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\turhadd\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9233[] = {
  "urshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\turshlr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9234[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tshadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tshadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tshadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tshadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9235[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tshsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tshsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tshsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tshsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9236[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqrshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqrshl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9237[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsrhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsrhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsrhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsrhadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9238[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsrshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsrshl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9239[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuhadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9240[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuhsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuhsubr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuhsub\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuhsub\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9241[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqrshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqrshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqrshl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9242[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\turhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\turhadd\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\turhadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\turhadd\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9243[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\turshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\turshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\turshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\turshl\t%0.b, %1/m, %0.b, %3.b",
  "#",
};

static const char * const output_9244[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tshadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tshadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tshadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tshadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9245[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tshsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tshsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tshsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tshsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9246[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqrshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqrshl\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9247[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsrhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsrhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsrhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsrhadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9248[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsrshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsrshl\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9249[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuhadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9250[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuhsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuhsubr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuhsub\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuhsub\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9251[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqrshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqrshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqrshl\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9252[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\turhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\turhadd\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\turhadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\turhadd\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9253[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\turshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\turshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\turshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\turshl\t%0.h, %1/m, %0.h, %3.h",
  "#",
};

static const char * const output_9254[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tshadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tshadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tshadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tshadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9255[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tshsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tshsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tshsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tshsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9256[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsqrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsqrshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqrshl\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9257[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsrhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsrhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsrhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsrhadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9258[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsrshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsrshl\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9259[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuhadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9260[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuhsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuhsubr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuhsub\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuhsub\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9261[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuqrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuqrshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuqrshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuqrshl\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9262[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\turhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\turhadd\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\turhadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\turhadd\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9263[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\turshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\turshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\turshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\turshl\t%0.s, %1/m, %0.s, %3.s",
  "#",
};

static const char * const output_9264[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tshadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tshadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tshadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tshadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9265[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tshsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tshsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tshsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tshsub\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9266[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsqrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsqrshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsqrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsqrshl\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9267[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsrhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsrhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsrhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsrhadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9268[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsrshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsrshl\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9269[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tuhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tuhadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9270[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuhsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tuhsubr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuhsub\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tuhsub\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9271[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuqrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tuqrshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuqrshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tuqrshl\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9272[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\turhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\turhadd\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\turhadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\turhadd\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9273[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\turshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\turshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\turshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\turshl\t%0.d, %1/m, %0.d, %3.d",
  "#",
};

static const char * const output_9274[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsuqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsuqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9275[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tusqadd\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tusqadd\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9276[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsuqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsuqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9277[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tusqadd\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tusqadd\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9278[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsuqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsuqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9279[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tusqadd\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tusqadd\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9280[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsuqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsuqadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9281[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tusqadd\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tusqadd\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9296[] = {
  "sqshl\t%0.b, %1/m, %0.b, #%3",
  "sqshl\t%0.b, %1/m, %0.b, %3.b",
  "sqshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tsqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9297[] = {
  "uqshl\t%0.b, %1/m, %0.b, #%3",
  "uqshl\t%0.b, %1/m, %0.b, %3.b",
  "uqshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %2\n\tuqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9298[] = {
  "sqshl\t%0.h, %1/m, %0.h, #%3",
  "sqshl\t%0.h, %1/m, %0.h, %3.h",
  "sqshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tsqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9299[] = {
  "uqshl\t%0.h, %1/m, %0.h, #%3",
  "uqshl\t%0.h, %1/m, %0.h, %3.h",
  "uqshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %2\n\tuqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9300[] = {
  "sqshl\t%0.s, %1/m, %0.s, #%3",
  "sqshl\t%0.s, %1/m, %0.s, %3.s",
  "sqshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tsqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9301[] = {
  "uqshl\t%0.s, %1/m, %0.s, #%3",
  "uqshl\t%0.s, %1/m, %0.s, %3.s",
  "uqshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %2\n\tuqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9302[] = {
  "sqshl\t%0.d, %1/m, %0.d, #%3",
  "sqshl\t%0.d, %1/m, %0.d, %3.d",
  "sqshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tsqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9303[] = {
  "uqshl\t%0.d, %1/m, %0.d, #%3",
  "uqshl\t%0.d, %1/m, %0.d, %3.d",
  "uqshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %2\n\tuqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9304[] = {
  "sqshl\t%0.b, %1/m, %0.b, #%3",
  "sqshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9305[] = {
  "uqshl\t%0.b, %1/m, %0.b, #%3",
  "uqshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9306[] = {
  "sqshl\t%0.h, %1/m, %0.h, #%3",
  "sqshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9307[] = {
  "uqshl\t%0.h, %1/m, %0.h, #%3",
  "uqshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9308[] = {
  "sqshl\t%0.s, %1/m, %0.s, #%3",
  "sqshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9309[] = {
  "uqshl\t%0.s, %1/m, %0.s, #%3",
  "uqshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9310[] = {
  "sqshl\t%0.d, %1/m, %0.d, #%3",
  "sqshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tsqshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9311[] = {
  "uqshl\t%0.d, %1/m, %0.d, #%3",
  "uqshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0, %2\n\tuqshl\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9312[] = {
  "sqshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tsqshlr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9313[] = {
  "uqshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0, %3\n\tuqshlr\t%0.b, %1/m, %0.b, %2.b",
};

static const char * const output_9314[] = {
  "sqshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tsqshlr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9315[] = {
  "uqshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0, %3\n\tuqshlr\t%0.h, %1/m, %0.h, %2.h",
};

static const char * const output_9316[] = {
  "sqshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tsqshlr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9317[] = {
  "uqshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0, %3\n\tuqshlr\t%0.s, %1/m, %0.s, %2.s",
};

static const char * const output_9318[] = {
  "sqshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tsqshlr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9319[] = {
  "uqshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0, %3\n\tuqshlr\t%0.d, %1/m, %0.d, %2.d",
};

static const char * const output_9320[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tsqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tsqshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/z, %2.b\n\tsqshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tsqshl\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "#",
};

static const char * const output_9321[] = {
  "movprfx\t%0.b, %1/z, %0.b\n\tuqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/z, %0.b\n\tuqshlr\t%0.b, %1/m, %0.b, %2.b",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/z, %2.b\n\tuqshl\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqshl\t%0.b, %1/m, %0.b, #%3",
  "movprfx\t%0.b, %1/m, %2.b\n\tuqshl\t%0.b, %1/m, %0.b, %3.b",
  "#",
  "#",
};

static const char * const output_9322[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tsqshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/z, %2.h\n\tsqshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tsqshl\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "#",
};

static const char * const output_9323[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/z, %0.h\n\tuqshlr\t%0.h, %1/m, %0.h, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/z, %2.h\n\tuqshl\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqshl\t%0.h, %1/m, %0.h, #%3",
  "movprfx\t%0.h, %1/m, %2.h\n\tuqshl\t%0.h, %1/m, %0.h, %3.h",
  "#",
  "#",
};

static const char * const output_9324[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/z, %0.s\n\tsqshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tsqshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/z, %2.s\n\tsqshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tsqshl\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "#",
};

static const char * const output_9325[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/z, %0.s\n\tuqshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/z, %0.s\n\tuqshlr\t%0.s, %1/m, %0.s, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tuqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/z, %2.s\n\tuqshl\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0.s, %1/m, %2.s\n\tuqshl\t%0.s, %1/m, %0.s, #%3",
  "movprfx\t%0.s, %1/m, %2.s\n\tuqshl\t%0.s, %1/m, %0.s, %3.s",
  "#",
  "#",
};

static const char * const output_9326[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/z, %0.d\n\tsqshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tsqshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tsqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/z, %2.d\n\tsqshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tsqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tsqshl\t%0.d, %1/m, %0.d, %3.d",
  "#",
  "#",
};

static const char * const output_9327[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/z, %0.d\n\tuqshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/z, %0.d\n\tuqshlr\t%0.d, %1/m, %0.d, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tuqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/z, %2.d\n\tuqshl\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0.d, %1/m, %2.d\n\tuqshl\t%0.d, %1/m, %0.d, #%3",
  "movprfx\t%0.d, %1/m, %2.d\n\tuqshl\t%0.d, %1/m, %0.d, %3.d",
  "#",
  "#",
};

static const char * const output_9328[] = {
  "adclb\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tadclb\t%0.b, %2.b, %3.b",
};

static const char * const output_9329[] = {
  "adclt\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tadclt\t%0.b, %2.b, %3.b",
};

static const char * const output_9330[] = {
  "eorbt\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\teorbt\t%0.b, %2.b, %3.b",
};

static const char * const output_9331[] = {
  "eortb\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\teortb\t%0.b, %2.b, %3.b",
};

static const char * const output_9332[] = {
  "sbclb\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsbclb\t%0.b, %2.b, %3.b",
};

static const char * const output_9333[] = {
  "sbclt\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsbclt\t%0.b, %2.b, %3.b",
};

static const char * const output_9334[] = {
  "sqrdmlah\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqrdmlah\t%0.b, %2.b, %3.b",
};

static const char * const output_9335[] = {
  "sqrdmlsh\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqrdmlsh\t%0.b, %2.b, %3.b",
};

static const char * const output_9336[] = {
  "adclb\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tadclb\t%0.h, %2.h, %3.h",
};

static const char * const output_9337[] = {
  "adclt\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tadclt\t%0.h, %2.h, %3.h",
};

static const char * const output_9338[] = {
  "eorbt\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\teorbt\t%0.h, %2.h, %3.h",
};

static const char * const output_9339[] = {
  "eortb\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\teortb\t%0.h, %2.h, %3.h",
};

static const char * const output_9340[] = {
  "sbclb\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsbclb\t%0.h, %2.h, %3.h",
};

static const char * const output_9341[] = {
  "sbclt\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsbclt\t%0.h, %2.h, %3.h",
};

static const char * const output_9342[] = {
  "sqrdmlah\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqrdmlah\t%0.h, %2.h, %3.h",
};

static const char * const output_9343[] = {
  "sqrdmlsh\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqrdmlsh\t%0.h, %2.h, %3.h",
};

static const char * const output_9344[] = {
  "adclb\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tadclb\t%0.s, %2.s, %3.s",
};

static const char * const output_9345[] = {
  "adclt\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tadclt\t%0.s, %2.s, %3.s",
};

static const char * const output_9346[] = {
  "eorbt\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\teorbt\t%0.s, %2.s, %3.s",
};

static const char * const output_9347[] = {
  "eortb\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\teortb\t%0.s, %2.s, %3.s",
};

static const char * const output_9348[] = {
  "sbclb\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsbclb\t%0.s, %2.s, %3.s",
};

static const char * const output_9349[] = {
  "sbclt\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsbclt\t%0.s, %2.s, %3.s",
};

static const char * const output_9350[] = {
  "sqrdmlah\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqrdmlah\t%0.s, %2.s, %3.s",
};

static const char * const output_9351[] = {
  "sqrdmlsh\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqrdmlsh\t%0.s, %2.s, %3.s",
};

static const char * const output_9352[] = {
  "adclb\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tadclb\t%0.d, %2.d, %3.d",
};

static const char * const output_9353[] = {
  "adclt\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tadclt\t%0.d, %2.d, %3.d",
};

static const char * const output_9354[] = {
  "eorbt\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\teorbt\t%0.d, %2.d, %3.d",
};

static const char * const output_9355[] = {
  "eortb\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\teortb\t%0.d, %2.d, %3.d",
};

static const char * const output_9356[] = {
  "sbclb\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tsbclb\t%0.d, %2.d, %3.d",
};

static const char * const output_9357[] = {
  "sbclt\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tsbclt\t%0.d, %2.d, %3.d",
};

static const char * const output_9358[] = {
  "sqrdmlah\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tsqrdmlah\t%0.d, %2.d, %3.d",
};

static const char * const output_9359[] = {
  "sqrdmlsh\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tsqrdmlsh\t%0.d, %2.d, %3.d",
};

static const char * const output_9360[] = {
  "sqrdmlah\t%0.h, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsqrdmlah\t%0.h, %2.h, %3.h[%4]",
};

static const char * const output_9361[] = {
  "sqrdmlsh\t%0.h, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsqrdmlsh\t%0.h, %2.h, %3.h[%4]",
};

static const char * const output_9362[] = {
  "sqrdmlah\t%0.s, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsqrdmlah\t%0.s, %2.s, %3.s[%4]",
};

static const char * const output_9363[] = {
  "sqrdmlsh\t%0.s, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsqrdmlsh\t%0.s, %2.s, %3.s[%4]",
};

static const char * const output_9364[] = {
  "sqrdmlah\t%0.d, %2.d, %3.d[%4]",
  "movprfx\t%0, %1\n\tsqrdmlah\t%0.d, %2.d, %3.d[%4]",
};

static const char * const output_9365[] = {
  "sqrdmlsh\t%0.d, %2.d, %3.d[%4]",
  "movprfx\t%0, %1\n\tsqrdmlsh\t%0.d, %2.d, %3.d[%4]",
};

static const char * const output_9366[] = {
  "mla\t%0.h, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tmla\t%0.h, %2.h, %3.h[%4]",
};

static const char * const output_9367[] = {
  "mla\t%0.s, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tmla\t%0.s, %2.s, %3.s[%4]",
};

static const char * const output_9368[] = {
  "mla\t%0.d, %2.d, %3.d[%4]",
  "movprfx\t%0, %1\n\tmla\t%0.d, %2.d, %3.d[%4]",
};

static const char * const output_9369[] = {
  "mls\t%0.h, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tmls\t%0.h, %2.h, %3.h[%4]",
};

static const char * const output_9370[] = {
  "mls\t%0.s, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tmls\t%0.s, %2.s, %3.s[%4]",
};

static const char * const output_9371[] = {
  "mls\t%0.d, %2.d, %3.d[%4]",
  "movprfx\t%0, %1\n\tmls\t%0.d, %2.d, %3.d[%4]",
};

static const char * const output_9372[] = {
  "xar\t%0.b, %0.b, %2.b, #%3",
  "movprfx\t%0, %1\n\txar\t%0.b, %0.b, %2.b, #%3",
};

static const char * const output_9373[] = {
  "xar\t%0.h, %0.h, %2.h, #%3",
  "movprfx\t%0, %1\n\txar\t%0.h, %0.h, %2.h, #%3",
};

static const char * const output_9374[] = {
  "xar\t%0.s, %0.s, %2.s, #%3",
  "movprfx\t%0, %1\n\txar\t%0.s, %0.s, %2.s, #%3",
};

static const char * const output_9375[] = {
  "xar\t%0.d, %0.d, %2.d, #%3",
  "movprfx\t%0, %1\n\txar\t%0.d, %0.d, %2.d, #%3",
};

static const char * const output_9376[] = {
  "bcax\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbcax\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9377[] = {
  "bcax\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbcax\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9378[] = {
  "bcax\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbcax\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9379[] = {
  "bcax\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbcax\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9380[] = {
  "eor3\t%0.d, %0.d, %2.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %2.d",
  "movprfx\t%0, %1\n\teor3\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9381[] = {
  "eor3\t%0.d, %0.d, %2.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %2.d",
  "movprfx\t%0, %1\n\teor3\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9382[] = {
  "eor3\t%0.d, %0.d, %2.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %2.d",
  "movprfx\t%0, %1\n\teor3\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9383[] = {
  "eor3\t%0.d, %0.d, %2.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %3.d",
  "eor3\t%0.d, %0.d, %1.d, %2.d",
  "movprfx\t%0, %1\n\teor3\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9384[] = {
  "nbsl\t%0.d, %0.d, %2.d, %0.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %0.d",
};

static const char * const output_9385[] = {
  "nbsl\t%0.d, %0.d, %2.d, %0.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %0.d",
};

static const char * const output_9386[] = {
  "nbsl\t%0.d, %0.d, %2.d, %0.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %0.d",
};

static const char * const output_9387[] = {
  "nbsl\t%0.d, %0.d, %2.d, %0.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %0.d",
};

static const char * const output_9388[] = {
  "nbsl\t%0.d, %0.d, %2.d, %2.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %2.d",
};

static const char * const output_9389[] = {
  "nbsl\t%0.d, %0.d, %2.d, %2.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %2.d",
};

static const char * const output_9390[] = {
  "nbsl\t%0.d, %0.d, %2.d, %2.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %2.d",
};

static const char * const output_9391[] = {
  "nbsl\t%0.d, %0.d, %2.d, %2.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %2.d",
};

static const char * const output_9392[] = {
  "bsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9393[] = {
  "bsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9394[] = {
  "bsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9395[] = {
  "bsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9396[] = {
  "bsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9397[] = {
  "bsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9398[] = {
  "bsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9399[] = {
  "bsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9400[] = {
  "nbsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tnbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9401[] = {
  "nbsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9402[] = {
  "nbsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tnbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9403[] = {
  "nbsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9404[] = {
  "nbsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tnbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9405[] = {
  "nbsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9406[] = {
  "nbsl\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tnbsl\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9407[] = {
  "nbsl\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tnbsl\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9408[] = {
  "bsl1n\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl1n\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9409[] = {
  "bsl1n\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl1n\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9410[] = {
  "bsl1n\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl1n\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9411[] = {
  "bsl1n\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl1n\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9412[] = {
  "bsl1n\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl1n\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9413[] = {
  "bsl1n\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl1n\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9414[] = {
  "bsl1n\t%0.d, %0.d, %1.d, %3.d",
  "movprfx\t%0, %2\n\tbsl1n\t%0.d, %0.d, %1.d, %3.d",
};

static const char * const output_9415[] = {
  "bsl1n\t%0.d, %0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tbsl1n\t%0.d, %0.d, %2.d, %3.d",
};

static const char * const output_9416[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9417[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9418[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9419[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9420[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9421[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9422[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9423[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9424[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9425[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9426[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9427[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9428[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9429[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9430[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %1.d",
  "movprfx\t%0, %2\n\tbsl2n\t%0.d, %0.d, %3.d, %1.d",
};

static const char * const output_9431[] = {
  "bsl2n\t%0.d, %0.d, %3.d, %2.d",
  "movprfx\t%0, %1\n\tbsl2n\t%0.d, %0.d, %3.d, %2.d",
};

static const char * const output_9432[] = {
  "ssra\t%0.b, %2.b, #%3",
  "movprfx\t%0, %1\n\tssra\t%0.b, %2.b, #%3",
};

static const char * const output_9433[] = {
  "usra\t%0.b, %2.b, #%3",
  "movprfx\t%0, %1\n\tusra\t%0.b, %2.b, #%3",
};

static const char * const output_9434[] = {
  "ssra\t%0.h, %2.h, #%3",
  "movprfx\t%0, %1\n\tssra\t%0.h, %2.h, #%3",
};

static const char * const output_9435[] = {
  "usra\t%0.h, %2.h, #%3",
  "movprfx\t%0, %1\n\tusra\t%0.h, %2.h, #%3",
};

static const char * const output_9436[] = {
  "ssra\t%0.s, %2.s, #%3",
  "movprfx\t%0, %1\n\tssra\t%0.s, %2.s, #%3",
};

static const char * const output_9437[] = {
  "usra\t%0.s, %2.s, #%3",
  "movprfx\t%0, %1\n\tusra\t%0.s, %2.s, #%3",
};

static const char * const output_9438[] = {
  "ssra\t%0.d, %2.d, #%3",
  "movprfx\t%0, %1\n\tssra\t%0.d, %2.d, #%3",
};

static const char * const output_9439[] = {
  "usra\t%0.d, %2.d, #%3",
  "movprfx\t%0, %1\n\tusra\t%0.d, %2.d, #%3",
};

static const char * const output_9440[] = {
  "srsra\t%0.b, %2.b, #%3",
  "movprfx\t%0, %1\n\tsrsra\t%0.b, %2.b, #%3",
};

static const char * const output_9441[] = {
  "ursra\t%0.b, %2.b, #%3",
  "movprfx\t%0, %1\n\tursra\t%0.b, %2.b, #%3",
};

static const char * const output_9442[] = {
  "srsra\t%0.h, %2.h, #%3",
  "movprfx\t%0, %1\n\tsrsra\t%0.h, %2.h, #%3",
};

static const char * const output_9443[] = {
  "ursra\t%0.h, %2.h, #%3",
  "movprfx\t%0, %1\n\tursra\t%0.h, %2.h, #%3",
};

static const char * const output_9444[] = {
  "srsra\t%0.s, %2.s, #%3",
  "movprfx\t%0, %1\n\tsrsra\t%0.s, %2.s, #%3",
};

static const char * const output_9445[] = {
  "ursra\t%0.s, %2.s, #%3",
  "movprfx\t%0, %1\n\tursra\t%0.s, %2.s, #%3",
};

static const char * const output_9446[] = {
  "srsra\t%0.d, %2.d, #%3",
  "movprfx\t%0, %1\n\tsrsra\t%0.d, %2.d, #%3",
};

static const char * const output_9447[] = {
  "ursra\t%0.d, %2.d, #%3",
  "movprfx\t%0, %1\n\tursra\t%0.d, %2.d, #%3",
};

static const char * const output_9456[] = {
  "saba\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsaba\t%0.b, %2.b, %3.b",
};

static const char * const output_9457[] = {
  "uaba\t%0.b, %2.b, %3.b",
  "movprfx\t%0, %1\n\tuaba\t%0.b, %2.b, %3.b",
};

static const char * const output_9458[] = {
  "saba\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsaba\t%0.h, %2.h, %3.h",
};

static const char * const output_9459[] = {
  "uaba\t%0.h, %2.h, %3.h",
  "movprfx\t%0, %1\n\tuaba\t%0.h, %2.h, %3.h",
};

static const char * const output_9460[] = {
  "saba\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsaba\t%0.s, %2.s, %3.s",
};

static const char * const output_9461[] = {
  "uaba\t%0.s, %2.s, %3.s",
  "movprfx\t%0, %1\n\tuaba\t%0.s, %2.s, %3.s",
};

static const char * const output_9462[] = {
  "saba\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tsaba\t%0.d, %2.d, %3.d",
};

static const char * const output_9463[] = {
  "uaba\t%0.d, %2.d, %3.d",
  "movprfx\t%0, %1\n\tuaba\t%0.d, %2.d, %3.d",
};

static const char * const output_9575[] = {
  "sabalb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsabalb\t%0.h, %2.b, %3.b",
};

static const char * const output_9576[] = {
  "sabalt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsabalt\t%0.h, %2.b, %3.b",
};

static const char * const output_9577[] = {
  "smlalb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsmlalb\t%0.h, %2.b, %3.b",
};

static const char * const output_9578[] = {
  "smlalt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsmlalt\t%0.h, %2.b, %3.b",
};

static const char * const output_9579[] = {
  "uabalb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tuabalb\t%0.h, %2.b, %3.b",
};

static const char * const output_9580[] = {
  "uabalt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tuabalt\t%0.h, %2.b, %3.b",
};

static const char * const output_9581[] = {
  "umlalb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tumlalb\t%0.h, %2.b, %3.b",
};

static const char * const output_9582[] = {
  "umlalt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tumlalt\t%0.h, %2.b, %3.b",
};

static const char * const output_9583[] = {
  "sabalb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsabalb\t%0.s, %2.h, %3.h",
};

static const char * const output_9584[] = {
  "sabalt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsabalt\t%0.s, %2.h, %3.h",
};

static const char * const output_9585[] = {
  "smlalb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsmlalb\t%0.s, %2.h, %3.h",
};

static const char * const output_9586[] = {
  "smlalt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsmlalt\t%0.s, %2.h, %3.h",
};

static const char * const output_9587[] = {
  "uabalb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tuabalb\t%0.s, %2.h, %3.h",
};

static const char * const output_9588[] = {
  "uabalt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tuabalt\t%0.s, %2.h, %3.h",
};

static const char * const output_9589[] = {
  "umlalb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tumlalb\t%0.s, %2.h, %3.h",
};

static const char * const output_9590[] = {
  "umlalt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tumlalt\t%0.s, %2.h, %3.h",
};

static const char * const output_9591[] = {
  "sabalb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsabalb\t%0.d, %2.s, %3.s",
};

static const char * const output_9592[] = {
  "sabalt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsabalt\t%0.d, %2.s, %3.s",
};

static const char * const output_9593[] = {
  "smlalb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsmlalb\t%0.d, %2.s, %3.s",
};

static const char * const output_9594[] = {
  "smlalt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsmlalt\t%0.d, %2.s, %3.s",
};

static const char * const output_9595[] = {
  "uabalb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tuabalb\t%0.d, %2.s, %3.s",
};

static const char * const output_9596[] = {
  "uabalt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tuabalt\t%0.d, %2.s, %3.s",
};

static const char * const output_9597[] = {
  "umlalb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tumlalb\t%0.d, %2.s, %3.s",
};

static const char * const output_9598[] = {
  "umlalt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tumlalt\t%0.d, %2.s, %3.s",
};

static const char * const output_9599[] = {
  "smlalb\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsmlalb\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9600[] = {
  "smlalt\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsmlalt\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9601[] = {
  "umlalb\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tumlalb\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9602[] = {
  "umlalt\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tumlalt\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9603[] = {
  "smlalb\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsmlalb\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9604[] = {
  "smlalt\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsmlalt\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9605[] = {
  "umlalb\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tumlalb\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9606[] = {
  "umlalt\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tumlalt\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9607[] = {
  "sqdmlalb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqdmlalb\t%0.h, %2.b, %3.b",
};

static const char * const output_9608[] = {
  "sqdmlalbt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqdmlalbt\t%0.h, %2.b, %3.b",
};

static const char * const output_9609[] = {
  "sqdmlalt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqdmlalt\t%0.h, %2.b, %3.b",
};

static const char * const output_9610[] = {
  "sqdmlalb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqdmlalb\t%0.s, %2.h, %3.h",
};

static const char * const output_9611[] = {
  "sqdmlalbt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqdmlalbt\t%0.s, %2.h, %3.h",
};

static const char * const output_9612[] = {
  "sqdmlalt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqdmlalt\t%0.s, %2.h, %3.h",
};

static const char * const output_9613[] = {
  "sqdmlalb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqdmlalb\t%0.d, %2.s, %3.s",
};

static const char * const output_9614[] = {
  "sqdmlalbt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqdmlalbt\t%0.d, %2.s, %3.s",
};

static const char * const output_9615[] = {
  "sqdmlalt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqdmlalt\t%0.d, %2.s, %3.s",
};

static const char * const output_9616[] = {
  "sqdmlalb\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsqdmlalb\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9617[] = {
  "sqdmlalt\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsqdmlalt\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9618[] = {
  "sqdmlalb\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsqdmlalb\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9619[] = {
  "sqdmlalt\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsqdmlalt\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9620[] = {
  "smlslb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsmlslb\t%0.h, %2.b, %3.b",
};

static const char * const output_9621[] = {
  "smlslt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsmlslt\t%0.h, %2.b, %3.b",
};

static const char * const output_9622[] = {
  "umlslb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tumlslb\t%0.h, %2.b, %3.b",
};

static const char * const output_9623[] = {
  "umlslt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tumlslt\t%0.h, %2.b, %3.b",
};

static const char * const output_9624[] = {
  "smlslb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsmlslb\t%0.s, %2.h, %3.h",
};

static const char * const output_9625[] = {
  "smlslt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsmlslt\t%0.s, %2.h, %3.h",
};

static const char * const output_9626[] = {
  "umlslb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tumlslb\t%0.s, %2.h, %3.h",
};

static const char * const output_9627[] = {
  "umlslt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tumlslt\t%0.s, %2.h, %3.h",
};

static const char * const output_9628[] = {
  "smlslb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsmlslb\t%0.d, %2.s, %3.s",
};

static const char * const output_9629[] = {
  "smlslt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsmlslt\t%0.d, %2.s, %3.s",
};

static const char * const output_9630[] = {
  "umlslb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tumlslb\t%0.d, %2.s, %3.s",
};

static const char * const output_9631[] = {
  "umlslt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tumlslt\t%0.d, %2.s, %3.s",
};

static const char * const output_9632[] = {
  "smlslb\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsmlslb\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9633[] = {
  "smlslt\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsmlslt\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9634[] = {
  "umlslb\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tumlslb\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9635[] = {
  "umlslt\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tumlslt\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9636[] = {
  "smlslb\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsmlslb\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9637[] = {
  "smlslt\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsmlslt\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9638[] = {
  "umlslb\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tumlslb\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9639[] = {
  "umlslt\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tumlslt\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9640[] = {
  "sqdmlslb\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqdmlslb\t%0.h, %2.b, %3.b",
};

static const char * const output_9641[] = {
  "sqdmlslbt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqdmlslbt\t%0.h, %2.b, %3.b",
};

static const char * const output_9642[] = {
  "sqdmlslt\t%0.h, %2.b, %3.b",
  "movprfx\t%0, %1\n\tsqdmlslt\t%0.h, %2.b, %3.b",
};

static const char * const output_9643[] = {
  "sqdmlslb\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqdmlslb\t%0.s, %2.h, %3.h",
};

static const char * const output_9644[] = {
  "sqdmlslbt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqdmlslbt\t%0.s, %2.h, %3.h",
};

static const char * const output_9645[] = {
  "sqdmlslt\t%0.s, %2.h, %3.h",
  "movprfx\t%0, %1\n\tsqdmlslt\t%0.s, %2.h, %3.h",
};

static const char * const output_9646[] = {
  "sqdmlslb\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqdmlslb\t%0.d, %2.s, %3.s",
};

static const char * const output_9647[] = {
  "sqdmlslbt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqdmlslbt\t%0.d, %2.s, %3.s",
};

static const char * const output_9648[] = {
  "sqdmlslt\t%0.d, %2.s, %3.s",
  "movprfx\t%0, %1\n\tsqdmlslt\t%0.d, %2.s, %3.s",
};

static const char * const output_9649[] = {
  "sqdmlslb\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsqdmlslb\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9650[] = {
  "sqdmlslt\t%0.s, %2.h, %3.h[%4]",
  "movprfx\t%0, %1\n\tsqdmlslt\t%0.s, %2.h, %3.h[%4]",
};

static const char * const output_9651[] = {
  "sqdmlslb\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsqdmlslb\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9652[] = {
  "sqdmlslt\t%0.d, %2.s, %3.s[%4]",
  "movprfx\t%0, %1\n\tsqdmlslt\t%0.d, %2.s, %3.s[%4]",
};

static const char * const output_9653[] = {
  "fmlalb\t%0.s, %1.h, %2.h",
  "movprfx\t%0, %3\n\tfmlalb\t%0.s, %1.h, %2.h",
};

static const char * const output_9654[] = {
  "fmlalt\t%0.s, %1.h, %2.h",
  "movprfx\t%0, %3\n\tfmlalt\t%0.s, %1.h, %2.h",
};

static const char * const output_9655[] = {
  "fmlslb\t%0.s, %1.h, %2.h",
  "movprfx\t%0, %3\n\tfmlslb\t%0.s, %1.h, %2.h",
};

static const char * const output_9656[] = {
  "fmlslt\t%0.s, %1.h, %2.h",
  "movprfx\t%0, %3\n\tfmlslt\t%0.s, %1.h, %2.h",
};

static const char * const output_9657[] = {
  "fmlalb\t%0.s, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tfmlalb\t%0.s, %1.h, %2.h[%3]",
};

static const char * const output_9658[] = {
  "fmlalt\t%0.s, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tfmlalt\t%0.s, %1.h, %2.h[%3]",
};

static const char * const output_9659[] = {
  "fmlslb\t%0.s, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tfmlslb\t%0.s, %1.h, %2.h[%3]",
};

static const char * const output_9660[] = {
  "fmlslt\t%0.s, %1.h, %2.h[%3]",
  "movprfx\t%0, %4\n\tfmlslt\t%0.s, %1.h, %2.h[%3]",
};

static const char * const output_9751[] = {
  "addp\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\taddp\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9752[] = {
  "smaxp\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsmaxp\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9753[] = {
  "sminp\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tsminp\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9754[] = {
  "umaxp\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tumaxp\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9755[] = {
  "uminp\t%0.b, %1/m, %0.b, %3.b",
  "movprfx\t%0, %2\n\tuminp\t%0.b, %1/m, %0.b, %3.b",
};

static const char * const output_9756[] = {
  "addp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\taddp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9757[] = {
  "smaxp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsmaxp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9758[] = {
  "sminp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tsminp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9759[] = {
  "umaxp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tumaxp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9760[] = {
  "uminp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tuminp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9761[] = {
  "addp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\taddp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9762[] = {
  "smaxp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsmaxp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9763[] = {
  "sminp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tsminp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9764[] = {
  "umaxp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tumaxp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9765[] = {
  "uminp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tuminp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9766[] = {
  "addp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\taddp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9767[] = {
  "smaxp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsmaxp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9768[] = {
  "sminp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tsminp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9769[] = {
  "umaxp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tumaxp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9770[] = {
  "uminp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tuminp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9771[] = {
  "faddp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfaddp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9772[] = {
  "fmaxp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmaxp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9773[] = {
  "fmaxnmp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfmaxnmp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9774[] = {
  "fminp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfminp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9775[] = {
  "fminnmp\t%0.h, %1/m, %0.h, %3.h",
  "movprfx\t%0, %2\n\tfminnmp\t%0.h, %1/m, %0.h, %3.h",
};

static const char * const output_9776[] = {
  "faddp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfaddp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9777[] = {
  "fmaxp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmaxp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9778[] = {
  "fmaxnmp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfmaxnmp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9779[] = {
  "fminp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfminp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9780[] = {
  "fminnmp\t%0.s, %1/m, %0.s, %3.s",
  "movprfx\t%0, %2\n\tfminnmp\t%0.s, %1/m, %0.s, %3.s",
};

static const char * const output_9781[] = {
  "faddp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfaddp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9782[] = {
  "fmaxp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmaxp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9783[] = {
  "fmaxnmp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfmaxnmp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9784[] = {
  "fminp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfminp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9785[] = {
  "fminnmp\t%0.d, %1/m, %0.d, %3.d",
  "movprfx\t%0, %2\n\tfminnmp\t%0.d, %1/m, %0.d, %3.d",
};

static const char * const output_9786[] = {
  "sadalp\t%0.h, %1/m, %3.b",
  "movprfx\t%0, %2\n\tsadalp\t%0.h, %1/m, %3.b",
};

static const char * const output_9787[] = {
  "uadalp\t%0.h, %1/m, %3.b",
  "movprfx\t%0, %2\n\tuadalp\t%0.h, %1/m, %3.b",
};

static const char * const output_9788[] = {
  "sadalp\t%0.s, %1/m, %3.h",
  "movprfx\t%0, %2\n\tsadalp\t%0.s, %1/m, %3.h",
};

static const char * const output_9789[] = {
  "uadalp\t%0.s, %1/m, %3.h",
  "movprfx\t%0, %2\n\tuadalp\t%0.s, %1/m, %3.h",
};

static const char * const output_9790[] = {
  "sadalp\t%0.d, %1/m, %3.s",
  "movprfx\t%0, %2\n\tsadalp\t%0.d, %1/m, %3.s",
};

static const char * const output_9791[] = {
  "uadalp\t%0.d, %1/m, %3.s",
  "movprfx\t%0, %2\n\tuadalp\t%0.d, %1/m, %3.s",
};

static const char * const output_9792[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tsadalp\t%0.h, %1/m, %3.b",
  "movprfx\t%0.h, %1/z, %2.h\n\tsadalp\t%0.h, %1/m, %3.b",
};

static const char * const output_9793[] = {
  "movprfx\t%0.h, %1/z, %0.h\n\tuadalp\t%0.h, %1/m, %3.b",
  "movprfx\t%0.h, %1/z, %2.h\n\tuadalp\t%0.h, %1/m, %3.b",
};

static const char * const output_9794[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tsadalp\t%0.s, %1/m, %3.h",
  "movprfx\t%0.s, %1/z, %2.s\n\tsadalp\t%0.s, %1/m, %3.h",
};

static const char * const output_9795[] = {
  "movprfx\t%0.s, %1/z, %0.s\n\tuadalp\t%0.s, %1/m, %3.h",
  "movprfx\t%0.s, %1/z, %2.s\n\tuadalp\t%0.s, %1/m, %3.h",
};

static const char * const output_9796[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tsadalp\t%0.d, %1/m, %3.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tsadalp\t%0.d, %1/m, %3.s",
};

static const char * const output_9797[] = {
  "movprfx\t%0.d, %1/z, %0.d\n\tuadalp\t%0.d, %1/m, %3.s",
  "movprfx\t%0.d, %1/z, %2.d\n\tuadalp\t%0.d, %1/m, %3.s",
};

static const char * const output_9798[] = {
  "cadd\t%0.b, %0.b, %2.b, #90",
  "movprfx\t%0, %1\n\tcadd\t%0.b, %0.b, %2.b, #90",
};

static const char * const output_9799[] = {
  "cadd\t%0.b, %0.b, %2.b, #270",
  "movprfx\t%0, %1\n\tcadd\t%0.b, %0.b, %2.b, #270",
};

static const char * const output_9800[] = {
  "sqcadd\t%0.b, %0.b, %2.b, #90",
  "movprfx\t%0, %1\n\tsqcadd\t%0.b, %0.b, %2.b, #90",
};

static const char * const output_9801[] = {
  "sqcadd\t%0.b, %0.b, %2.b, #270",
  "movprfx\t%0, %1\n\tsqcadd\t%0.b, %0.b, %2.b, #270",
};

static const char * const output_9802[] = {
  "cadd\t%0.h, %0.h, %2.h, #90",
  "movprfx\t%0, %1\n\tcadd\t%0.h, %0.h, %2.h, #90",
};

static const char * const output_9803[] = {
  "cadd\t%0.h, %0.h, %2.h, #270",
  "movprfx\t%0, %1\n\tcadd\t%0.h, %0.h, %2.h, #270",
};

static const char * const output_9804[] = {
  "sqcadd\t%0.h, %0.h, %2.h, #90",
  "movprfx\t%0, %1\n\tsqcadd\t%0.h, %0.h, %2.h, #90",
};

static const char * const output_9805[] = {
  "sqcadd\t%0.h, %0.h, %2.h, #270",
  "movprfx\t%0, %1\n\tsqcadd\t%0.h, %0.h, %2.h, #270",
};

static const char * const output_9806[] = {
  "cadd\t%0.s, %0.s, %2.s, #90",
  "movprfx\t%0, %1\n\tcadd\t%0.s, %0.s, %2.s, #90",
};

static const char * const output_9807[] = {
  "cadd\t%0.s, %0.s, %2.s, #270",
  "movprfx\t%0, %1\n\tcadd\t%0.s, %0.s, %2.s, #270",
};

static const char * const output_9808[] = {
  "sqcadd\t%0.s, %0.s, %2.s, #90",
  "movprfx\t%0, %1\n\tsqcadd\t%0.s, %0.s, %2.s, #90",
};

static const char * const output_9809[] = {
  "sqcadd\t%0.s, %0.s, %2.s, #270",
  "movprfx\t%0, %1\n\tsqcadd\t%0.s, %0.s, %2.s, #270",
};

static const char * const output_9810[] = {
  "cadd\t%0.d, %0.d, %2.d, #90",
  "movprfx\t%0, %1\n\tcadd\t%0.d, %0.d, %2.d, #90",
};

static const char * const output_9811[] = {
  "cadd\t%0.d, %0.d, %2.d, #270",
  "movprfx\t%0, %1\n\tcadd\t%0.d, %0.d, %2.d, #270",
};

static const char * const output_9812[] = {
  "sqcadd\t%0.d, %0.d, %2.d, #90",
  "movprfx\t%0, %1\n\tsqcadd\t%0.d, %0.d, %2.d, #90",
};

static const char * const output_9813[] = {
  "sqcadd\t%0.d, %0.d, %2.d, #270",
  "movprfx\t%0, %1\n\tsqcadd\t%0.d, %0.d, %2.d, #270",
};

static const char * const output_9814[] = {
  "cmla\t%0.b, %2.b, %3.b, #0",
  "movprfx\t%0, %1\n\tcmla\t%0.b, %2.b, %3.b, #0",
};

static const char * const output_9815[] = {
  "cmla\t%0.b, %2.b, %3.b, #90",
  "movprfx\t%0, %1\n\tcmla\t%0.b, %2.b, %3.b, #90",
};

static const char * const output_9816[] = {
  "cmla\t%0.b, %2.b, %3.b, #180",
  "movprfx\t%0, %1\n\tcmla\t%0.b, %2.b, %3.b, #180",
};

static const char * const output_9817[] = {
  "cmla\t%0.b, %2.b, %3.b, #270",
  "movprfx\t%0, %1\n\tcmla\t%0.b, %2.b, %3.b, #270",
};

static const char * const output_9818[] = {
  "sqrdcmlah\t%0.b, %2.b, %3.b, #0",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.b, %2.b, %3.b, #0",
};

static const char * const output_9819[] = {
  "sqrdcmlah\t%0.b, %2.b, %3.b, #90",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.b, %2.b, %3.b, #90",
};

static const char * const output_9820[] = {
  "sqrdcmlah\t%0.b, %2.b, %3.b, #180",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.b, %2.b, %3.b, #180",
};

static const char * const output_9821[] = {
  "sqrdcmlah\t%0.b, %2.b, %3.b, #270",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.b, %2.b, %3.b, #270",
};

static const char * const output_9822[] = {
  "cmla\t%0.h, %2.h, %3.h, #0",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h, #0",
};

static const char * const output_9823[] = {
  "cmla\t%0.h, %2.h, %3.h, #90",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h, #90",
};

static const char * const output_9824[] = {
  "cmla\t%0.h, %2.h, %3.h, #180",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h, #180",
};

static const char * const output_9825[] = {
  "cmla\t%0.h, %2.h, %3.h, #270",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h, #270",
};

static const char * const output_9826[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h, #0",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h, #0",
};

static const char * const output_9827[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h, #90",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h, #90",
};

static const char * const output_9828[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h, #180",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h, #180",
};

static const char * const output_9829[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h, #270",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h, #270",
};

static const char * const output_9830[] = {
  "cmla\t%0.s, %2.s, %3.s, #0",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s, #0",
};

static const char * const output_9831[] = {
  "cmla\t%0.s, %2.s, %3.s, #90",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s, #90",
};

static const char * const output_9832[] = {
  "cmla\t%0.s, %2.s, %3.s, #180",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s, #180",
};

static const char * const output_9833[] = {
  "cmla\t%0.s, %2.s, %3.s, #270",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s, #270",
};

static const char * const output_9834[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s, #0",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s, #0",
};

static const char * const output_9835[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s, #90",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s, #90",
};

static const char * const output_9836[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s, #180",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s, #180",
};

static const char * const output_9837[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s, #270",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s, #270",
};

static const char * const output_9838[] = {
  "cmla\t%0.d, %2.d, %3.d, #0",
  "movprfx\t%0, %1\n\tcmla\t%0.d, %2.d, %3.d, #0",
};

static const char * const output_9839[] = {
  "cmla\t%0.d, %2.d, %3.d, #90",
  "movprfx\t%0, %1\n\tcmla\t%0.d, %2.d, %3.d, #90",
};

static const char * const output_9840[] = {
  "cmla\t%0.d, %2.d, %3.d, #180",
  "movprfx\t%0, %1\n\tcmla\t%0.d, %2.d, %3.d, #180",
};

static const char * const output_9841[] = {
  "cmla\t%0.d, %2.d, %3.d, #270",
  "movprfx\t%0, %1\n\tcmla\t%0.d, %2.d, %3.d, #270",
};

static const char * const output_9842[] = {
  "sqrdcmlah\t%0.d, %2.d, %3.d, #0",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.d, %2.d, %3.d, #0",
};

static const char * const output_9843[] = {
  "sqrdcmlah\t%0.d, %2.d, %3.d, #90",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.d, %2.d, %3.d, #90",
};

static const char * const output_9844[] = {
  "sqrdcmlah\t%0.d, %2.d, %3.d, #180",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.d, %2.d, %3.d, #180",
};

static const char * const output_9845[] = {
  "sqrdcmlah\t%0.d, %2.d, %3.d, #270",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.d, %2.d, %3.d, #270",
};

static const char * const output_9846[] = {
  "cmla\t%0.h, %2.h, %3.h[%4], #0",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h[%4], #0",
};

static const char * const output_9847[] = {
  "cmla\t%0.h, %2.h, %3.h[%4], #90",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h[%4], #90",
};

static const char * const output_9848[] = {
  "cmla\t%0.h, %2.h, %3.h[%4], #180",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h[%4], #180",
};

static const char * const output_9849[] = {
  "cmla\t%0.h, %2.h, %3.h[%4], #270",
  "movprfx\t%0, %1\n\tcmla\t%0.h, %2.h, %3.h[%4], #270",
};

static const char * const output_9850[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h[%4], #0",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h[%4], #0",
};

static const char * const output_9851[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h[%4], #90",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h[%4], #90",
};

static const char * const output_9852[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h[%4], #180",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h[%4], #180",
};

static const char * const output_9853[] = {
  "sqrdcmlah\t%0.h, %2.h, %3.h[%4], #270",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.h, %2.h, %3.h[%4], #270",
};

static const char * const output_9854[] = {
  "cmla\t%0.s, %2.s, %3.s[%4], #0",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s[%4], #0",
};

static const char * const output_9855[] = {
  "cmla\t%0.s, %2.s, %3.s[%4], #90",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s[%4], #90",
};

static const char * const output_9856[] = {
  "cmla\t%0.s, %2.s, %3.s[%4], #180",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s[%4], #180",
};

static const char * const output_9857[] = {
  "cmla\t%0.s, %2.s, %3.s[%4], #270",
  "movprfx\t%0, %1\n\tcmla\t%0.s, %2.s, %3.s[%4], #270",
};

static const char * const output_9858[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s[%4], #0",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s[%4], #0",
};

static const char * const output_9859[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s[%4], #90",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s[%4], #90",
};

static const char * const output_9860[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s[%4], #180",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s[%4], #180",
};

static const char * const output_9861[] = {
  "sqrdcmlah\t%0.s, %2.s, %3.s[%4], #270",
  "movprfx\t%0, %1\n\tsqrdcmlah\t%0.s, %2.s, %3.s[%4], #270",
};

static const char * const output_9862[] = {
  "cdot\t%0.s, %2.b, %3.b, #0",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b, #0",
};

static const char * const output_9863[] = {
  "cdot\t%0.s, %2.b, %3.b, #90",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b, #90",
};

static const char * const output_9864[] = {
  "cdot\t%0.s, %2.b, %3.b, #180",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b, #180",
};

static const char * const output_9865[] = {
  "cdot\t%0.s, %2.b, %3.b, #270",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b, #270",
};

static const char * const output_9866[] = {
  "cdot\t%0.d, %2.h, %3.h, #0",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h, #0",
};

static const char * const output_9867[] = {
  "cdot\t%0.d, %2.h, %3.h, #90",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h, #90",
};

static const char * const output_9868[] = {
  "cdot\t%0.d, %2.h, %3.h, #180",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h, #180",
};

static const char * const output_9869[] = {
  "cdot\t%0.d, %2.h, %3.h, #270",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h, #270",
};

static const char * const output_9870[] = {
  "cdot\t%0.s, %2.b, %3.b[%4], #0",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b[%4], #0",
};

static const char * const output_9871[] = {
  "cdot\t%0.s, %2.b, %3.b[%4], #90",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b[%4], #90",
};

static const char * const output_9872[] = {
  "cdot\t%0.s, %2.b, %3.b[%4], #180",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b[%4], #180",
};

static const char * const output_9873[] = {
  "cdot\t%0.s, %2.b, %3.b[%4], #270",
  "movprfx\t%0, %1\n\tcdot\t%0.s, %2.b, %3.b[%4], #270",
};

static const char * const output_9874[] = {
  "cdot\t%0.d, %2.h, %3.h[%4], #0",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h[%4], #0",
};

static const char * const output_9875[] = {
  "cdot\t%0.d, %2.h, %3.h[%4], #90",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h[%4], #90",
};

static const char * const output_9876[] = {
  "cdot\t%0.d, %2.h, %3.h[%4], #180",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h[%4], #180",
};

static const char * const output_9877[] = {
  "cdot\t%0.d, %2.h, %3.h[%4], #270",
  "movprfx\t%0, %1\n\tcdot\t%0.d, %2.h, %3.h[%4], #270",
};

static const char * const output_9886[] = {
  "fcvtx\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %2\n\tfcvtx\t%0.s, %1/m, %2.d",
};

static const char * const output_9887[] = {
  "fcvtx\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtx\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtx\t%0.s, %1/m, %2.d",
};

static const char * const output_9888[] = {
  "fcvtx\t%0.s, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tfcvtx\t%0.s, %1/m, %2.d",
  "movprfx\t%0, %3\n\tfcvtx\t%0.s, %1/m, %2.d",
};

static const char * const output_9890[] = {
  "urecpe\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\turecpe\t%0.s, %1/m, %2.s",
};

static const char * const output_9891[] = {
  "ursqrte\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tursqrte\t%0.s, %1/m, %2.s",
};

static const char * const output_9892[] = {
  "urecpe\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\turecpe\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\turecpe\t%0.s, %1/m, %2.s",
};

static const char * const output_9893[] = {
  "ursqrte\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tursqrte\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tursqrte\t%0.s, %1/m, %2.s",
};

static const char * const output_9894[] = {
  "flogb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %2\n\tflogb\t%0.h, %1/m, %2.h",
};

static const char * const output_9895[] = {
  "flogb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %2\n\tflogb\t%0.s, %1/m, %2.s",
};

static const char * const output_9896[] = {
  "flogb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %2\n\tflogb\t%0.d, %1/m, %2.d",
};

static const char * const output_9897[] = {
  "flogb\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tflogb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tflogb\t%0.h, %1/m, %2.h",
};

static const char * const output_9898[] = {
  "flogb\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tflogb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tflogb\t%0.s, %1/m, %2.s",
};

static const char * const output_9899[] = {
  "flogb\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tflogb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tflogb\t%0.d, %1/m, %2.d",
};

static const char * const output_9900[] = {
  "flogb\t%0.h, %1/m, %2.h",
  "movprfx\t%0.h, %1/z, %2.h\n\tflogb\t%0.h, %1/m, %2.h",
  "movprfx\t%0, %3\n\tflogb\t%0.h, %1/m, %2.h",
};

static const char * const output_9901[] = {
  "flogb\t%0.s, %1/m, %2.s",
  "movprfx\t%0.s, %1/z, %2.s\n\tflogb\t%0.s, %1/m, %2.s",
  "movprfx\t%0, %3\n\tflogb\t%0.s, %1/m, %2.s",
};

static const char * const output_9902[] = {
  "flogb\t%0.d, %1/m, %2.d",
  "movprfx\t%0.d, %1/z, %2.d\n\tflogb\t%0.d, %1/m, %2.d",
  "movprfx\t%0, %3\n\tflogb\t%0.d, %1/m, %2.d",
};



static const struct insn_operand_data operand_data[] = 
{
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_CCmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_ccmp_operand,
    "r,Uss,Usn",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_CCmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_ccmp_operand,
    "r,Uss,Usn",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_CCFPmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_CCFPmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_CCFPEmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    cc_register,
    "",
    E_CCFPEmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm24,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm24,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_prefetch_operand,
    "Dp",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_call_insn_operand,
    "Ucr,Usf",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_call_insn_operand,
    "Ucs,Usf",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_call_insn_operand,
    "Ucs,Usf",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "=r,r,w,r,r,w,m,m,r,w,w",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "r,M,Dq,Usv,m,m,rZ,w,w,r,w",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=r,r,w,r,r,w,m,m,r,w,w",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "r,M,Dh,Usv,m,m,rZ,w,w,r,w",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=r,k,r,r,r,r,r,w,m,m,r,r,r,w,r,w,w",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "r,r,k,M,n,Usv,m,m,rZ,w,Usw,Usa,Ush,rZ,w,w,Ds",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=r,k,r,r,r,r,r,r,w,m,m,r,r,r,w,r,w,w",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "r,r,k,N,M,n,Usv,m,m,rZ,w,Usw,Usa,Ush,rZ,w,w,Dd",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "=r,w,w,r,w,r,m,m,w,m",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_movti_operand,
    "rUti,Z,r,w,w,m,r,Z,m,w",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,w,?r,w,w,w,w,m,r,m,r",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "Y,?rY,?r,w,w,Ufc,Uvi,m,w,m,rY,r",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,w,?r,w,w,w,w,m,r,m,r",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "Y,?rY,?r,w,w,Ufc,Uvi,m,w,m,rY,r",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,?r,w,w,w,w,m,r,m,r,r",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "Y,?rY,w,w,Ufc,Uvi,m,w,m,rY,r,M",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,?r,w,w,w,w,m,r,m,r,r",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "Y,?rY,w,w,Ufc,Uvi,m,w,m,rY,r,N",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,?r,w,?r,w,?w,w,m,?r,m,m",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,?rY,?r,w,Y,Y,m,w,m,?r,Y",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "+&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump,Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m,m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_zero_or_fp_zero,
    "rYZ,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&k",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_offset,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,w,w,r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,r,m,w,w",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump,Ump",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,w",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,w",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,w",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,w",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,w,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,m,w",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,w,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,m,w",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,m,w",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m,m,w",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=r,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "r,m",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=rk,rk,w,rk,r,r,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,w,rk,rk,0,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_pluslong_operand,
    "I,r,w,J,Uaa,Uai,Uav",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk,rk,w,rk,r,r,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,w,rk,rk,0,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_pluslong_operand,
    "I,r,w,J,Uaa,Uai,Uav",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk,rk,rk,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,rk,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_pluslong_operand,
    "I,r,J,Uaa",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r,r,r,r,&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,rk,rk,0,rk,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_pluslong_or_poly_operand,
    "I,r,J,Uaa,Uai,Uav,Uat",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r,r,r,r,&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,rk,rk,0,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_pluslong_or_poly_operand,
    "I,r,J,Uaa,Uai,Uav,Uat",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%rk,rk,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_scalar_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_scalar_int_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "I,J",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "I,J",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm_si,
    "n",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm_di,
    "n",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm_si,
    "n",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm_di,
    "n",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r,I,J",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm_si,
    "n",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_scalar_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_scalar_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_scalar_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_carry_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_scalar_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "I,J",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "J,I",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "I,J",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "J,I",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rkZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rkZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm3,
    "Ui3",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_borrow_operation,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "Y,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "Y,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm_si,
    "n",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm_di,
    "n",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_QImode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_HImode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_DImode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm24,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm24,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r,r,r,r,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,rZ,UsM,rZ,Ui1,UsM,Ui1",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,UsM,rZ,Ui1,rZ,UsM,Ui1",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r,r,r,r,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,rZ,UsM,rZ,Ui1,UsM,Ui1",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,UsM,rZ,Ui1,rZ,UsM,Ui1",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r,r,r,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,rZ,UsM,rZ,Ui1,UsM,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,UsM,rZ,Ui1,rZ,UsM,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r,r,r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,rZ,UsM,rZ,Ui1,UsM,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,UsM,rZ,Ui1,rZ,UsM,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,r,r,r,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,rZ,UsM,rZ,Ui1,UsM,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_zero_or_m1_or_1,
    "rZ,UsM,rZ,Ui1,rZ,UsM,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operation,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operation,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operation,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operation,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operation,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operation,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cnt_immediate,
    "Usv",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cnt_immediate,
    "Usv",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_and_immediate,
    "UsO",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_and_immediate,
    "UsP",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,rk,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_operand,
    "r,K,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,rk,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_operand,
    "r,L,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_operand,
    "r,K",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_operand,
    "r,K",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_operand,
    "r,L",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_logical_operand,
    "r,K",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,?w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,?w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,w,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,w,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_si,
    "Uss,r,Uss,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,w,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,w,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_di,
    "Usd,r,Usd,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,w,&w,&w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,w,w,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_si,
    "Uss,r,Usg,w,0",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,w,&w,&w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,w,w,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_di,
    "Usd,r,Usj,w,0",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r,w,&w,&w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r,w,w,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_di,
    "Uss,r,Usg,w,0",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_si,
    "Uss,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_di,
    "Usd,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_shift_imm_si,
    "Uss,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n,Ulc",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ulc,n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n,Ulc",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ulc,n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n,Ulc",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ulc,n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2,
    "F",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2,
    "F",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2,
    "F",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2,
    "F",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2_recip,
    "Dt,Dt",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2_recip,
    "Dt,Dt",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2_recip,
    "Dt",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_pow2_recip,
    "Dt",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,0",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,X",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,0",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,X",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_ie_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_ie_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_ie_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_ie_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_le_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_le_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_le_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_tls_le_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_valid_symref,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "L",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_immediate,
    "L",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    memory_operand,
    "=m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=&r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    memory_operand,
    "m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    memory_operand,
    "m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=&r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_granule16_uimm6,
    "i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_memtag_tag_offset,
    "i",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_granule16_simm9,
    "i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_granule16_simm9,
    "i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_V8DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_V8DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_V8DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,?r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "=w,m,m,w,?r,?w,?r,w",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,m,w,?r,?w,?r,w",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,m,w,?r,?w,?r,w",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,m,w,?r,?w,?r,w",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,m,w,?r,?w,?r,w",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,m,w,?r,?w,?r,w",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,Umn,m,w,?r,?w,?r,w",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "m,Dz,w,w,w,r,r,Dn",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "=m",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_operand,
    "=Ump",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "=m",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?r",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_bic_imm,
    "w,Db",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_bic_imm,
    "w,Db",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_bic_imm,
    "w,Db",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_bic_imm,
    "w,Db",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_bic_imm,
    "w,Db",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_bic_imm,
    "w,Db",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_bic_imm,
    "w,Db",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_orr_imm,
    "w,Do",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_orr_imm,
    "w,Do",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_orr_imm,
    "w,Do",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_orr_imm,
    "w,Do",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_orr_imm,
    "w,Do",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_orr_imm,
    "w,Do",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_orr_imm,
    "w,Do",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,0",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "D1,Dr",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "D1,Dr",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "D1,Dr",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "D1,Dr",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "D1,Dr",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "D1,Dr",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "D1,Dr",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "Dr",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "Dl",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "Dl",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "Dl",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "Dl",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "Dl",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "Dl",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "Dl",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_qi,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_hi,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_si,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_qi,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_hi,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_si,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_qi,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_hi,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_si,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_exact_top,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_exact_top,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_vec_exact_top,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_vec_pow2,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_vec_pow2,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_vec_pow2,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=?r,w,Utv",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i,i,i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "Utq",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_mem_pair_lanes_operand,
    "=Umn,Umn",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,w,?r",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_mem_pair_operand,
    "=w,w,w,Umn,Umn",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0,0,0,?w,?r",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "w,?r,Utv,?w,?r",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,?r,m",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_or_scalar_imm_zero,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,ZDz",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_minus_one,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,YDz",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "0",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_CImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_CImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=w,Utv,w",
    E_XImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_general_operand,
    "w,w,Utv",
    E_XImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=r,m,r",
    E_V8DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "r,r,m",
    E_V8DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "=Utv",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,m,w",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,m",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_CImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_CImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,o,w",
    E_XImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "w,w,o",
    E_XImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "Utv",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "Usd",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm2,
    "Ui2",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm2,
    "Ui2",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm2,
    "Ui2",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_lane_imm3,
    "Ui7",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_lane_imm3,
    "Ui7",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_lane_imm3,
    "Ui7",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_lane_imm3,
    "Ui7",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_lo_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm2,
    "Ui2",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    vect_par_cnst_hi_half,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm2,
    "Ui2",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "n",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_imm,
    "rn",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plushi_operand,
    "rUph",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "+r",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_QImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_QImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_HImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_HImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rL",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=r",
    E_QImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=r",
    E_HImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_QImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_QImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_HImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_HImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rL",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rK",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "rIJ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "+Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "rL",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&r",
    E_SImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_rcpc_memory_operand,
    "=Q,Ust",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "rZ,rZ",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_rcpc_memory_operand,
    "=Q,Ust",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "rZ,rZ",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_rcpc_memory_operand,
    "=Q,Ust",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "rZ,rZ",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_rcpc_memory_operand,
    "=Q,Ust",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "rZ,rZ",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "Q",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "=Q",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "=Q",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "=Q",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "=Q",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "=Q",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_BLKmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=w,w,m",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "w,m,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "w",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_nonimmediate_operand,
    "=w,Utr,w,w",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_general_operand,
    "Utr,w,w,Dn",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w",
    E_VNx32QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx32QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx16HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx16HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx8SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx16BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx16BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx16HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx16HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx8SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx4DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx48QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx48QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx24HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx24HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx12SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx12SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx6DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx6DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx24BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx24BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx24HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx24HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx12SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx12SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx6DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx6DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx64QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx64QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx32HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx32HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx16SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx16SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx8DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx32BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx32BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx32HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx32HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx16SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx16SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx8DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_nonmemory_operand,
    "w,Dn",
    E_VNx8DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "=w,w,Utx",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_struct_nonimmediate_operand,
    "w,Utx,w",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=Upa,m,Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "Upa,Upa,m,Dn",
    E_VNx16BImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=Upa,m,Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "Upa,Upa,m,Dn",
    E_VNx8BImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=Upa,m,Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "Upa,Upa,m,Dn",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "=Upa,m,Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_mov_operand,
    "Upa,Upa,m,Dn",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_sve_ptrue_svpattern_immediate,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_minus_one,
    "Dm,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx32QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx48QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx24HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx12SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx6DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx24BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx24HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx12SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx6DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx64QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx32HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx32BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx32HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx8BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "m",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx8BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx8BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldff1_operand,
    "Utf",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ldnf1_operand,
    "Utn",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm,UplDnm,UplDnm,UplDnm,UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_prefetch_operand,
    "UPb",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_prefetch_operand,
    "UPh",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_prefetch_operand,
    "UPw",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_prefetch_operand,
    "UPd",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "Z,vgd,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "i,i,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx32QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx16HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx16BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx16HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx48QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx24HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx12SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx6DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx24BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx24HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx12SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx6DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx64QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx32HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx16SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx32BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx32HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx16SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "+m",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "Z,vgd,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "Ui1,Ui1,Z,Ui1,Z,Ui1",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,Ui1,i,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "Z,vgb,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "Z,vgh,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "Z,vgw,rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,Ui1,Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rk,rk",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "Ui1,i",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "r,w,Uty",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    scratch_operand,
    "=X,X,Upl",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    descending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1r_operand,
    "Uty",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1rq_operand,
    "UtQ",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_b,
    "UOb",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_h,
    "UOh",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_w,
    "UOw",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_d,
    "UOd",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_h,
    "UOh",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_h,
    "UOh",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_w,
    "UOw",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ld1ro_operand_d,
    "UOd",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ,w,rZ,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "Usi,r,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_index_operand,
    "r,Usi,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "=r,w,Utv",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxt_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_one,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "vsm,w,vsm,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "vsb,w,vsb,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?w,?w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_add_operand,
    "vsa,vsn,vsi,vsa,vsn,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "w,vsa,vsa",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_uxtw_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_sqadd_operand,
    "vsQ,vsS,vsQ,vsS,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_sqadd_operand,
    "vsQ,vsS,vsQ,vsS,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_sqadd_operand,
    "vsQ,vsS,vsQ,vsS,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_sqadd_operand,
    "vsQ,vsS,vsQ,vsS,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "vsa,vsa,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "vsa,vsa,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "vsa,vsa,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_operand,
    "vsa,vsa,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_logical_operand,
    "vsl,vsl,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "Dr,w,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_immediate,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_immediate,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_immediate,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_immediate,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_immediate,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_immediate,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_immediate,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_immediate,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_immediate,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_immediate,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_immediate,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_immediate,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?&w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,0,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "vsA,vsN,w,w,vsA,vsN,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,i,Z,Ui1,i,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?&w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,0,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "vsA,vsN,w,w,vsA,vsN,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,i,Z,Ui1,i,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?&w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,0,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "vsA,vsN,w,w,vsA,vsN,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,i,Z,Ui1,i,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_immediate,
    "vsA,vsN,vsA,vsN",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_immediate,
    "vsA,vsN,vsA,vsN",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_immediate,
    "vsA,vsN,vsA,vsN",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_immediate,
    "vsA,vsN,vsA,vsN,vsA,vsN",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_immediate,
    "vsA,vsN,vsA,vsN,vsA,vsN",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_immediate,
    "vsA,vsN,vsA,vsN,vsA,vsN",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "vsA,w,0,w,vsA,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,Z,Ui1,Ui1,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "vsA,w,0,w,vsA,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,Z,Ui1,Ui1,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "vsA,w,0,w,vsA,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,Z,Ui1,Ui1,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_immediate,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_immediate,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_immediate,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_immediate,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_immediate,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_immediate,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "vsM,w,w,vsM,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,Z,Ui1,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "vsM,w,w,vsM,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,Z,Ui1,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "vsM,w,w,vsM,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "i,Z,Ui1,i,Ui1",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "vsB,w,vsB,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "vsB,w,vsB,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "vsB,w,vsB,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x,x",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%w,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%w,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%w,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x,x",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x,x",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,w,?w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "w,vss,vss,Ufc,Ufc,vss,Ufc",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "w,0,Dz,0,Dz,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa,Upa,Upa,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?w,w,??w,?&w,??&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r,w,r,w,r,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,0,Dz,Dz,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsc_operand,
    "vsc,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_cmp_vsd_operand,
    "vsd,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "rZ",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "wDz",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&Upl",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "wDz",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&Upl",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "wDz",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=&Upl",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=?r,w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,0",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx4BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx2BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_HImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upa,Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    subreg_lowpart_operator,
    "",
    E_HImode,
    0,
    1,
    0,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "=w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "UplDnm,UplDnm",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "Z,r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_immediate,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_immediate,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_immediate,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_arith_immediate,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,Dl,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,Dl,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,Dl,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,Dl,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,&w,&w,?&w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w,w,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w,Dl,w,Dl,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,Dz,0,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,&w,&w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w,w,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w,Dl,w,Dl,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,Dz,0,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,&w,&w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w,w,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w,Dl,w,Dl,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,Dz,0,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w,&w,&w,&w,&w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,0,w,w,w,w,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "Dl,w,0,Dl,w,Dl,w,Dl,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "Dz,Dz,Dz,Dz,Dz,0,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x,x",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,w,w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,0,w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x,x",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_imm_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "y,y",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "x,x",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,&w,&w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&w,?&w,?&w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl,Upl,Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w,w,w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "0,Dz,w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx32QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "0",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx16BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "=Upa",
    E_VNx8BImode,
    0,
    0,
    0,
    0
  },
  {
    register_operand,
    "Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "%0",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const0_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    scratch_operand,
    "",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    scratch_operand,
    "",
    E_DImode,
    0,
    0,
    0,
    0
  },
  {
    memory_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_TFmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    memory_operand,
    "",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_BLKmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    nonmemory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_pluslong_or_poly_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_pluslong_or_poly_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_imm,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    cc_register,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const0_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator_mode,
    "",
    E_SImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_plus_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_fp_compare_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_comparison_operator,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_imm,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_imm,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_di,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_constant_pool_symref,
    "S",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_TFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=&r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_valid_symref,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    ascending_int_parallel,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_shift_imm64_di,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_qi,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_qi,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_qi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_hi,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_bitsize_si,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "w",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "i",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_hi,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_si,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_shift_imm_offset_di,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_struct_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x1DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x1DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x1DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x1DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_OImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_CImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_CImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_XImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_XImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_V8DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_V8DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=w",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "r",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x1DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x1DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V3x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4x8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2DImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_nonimmediate_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V16QImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SImode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8BFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V1DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2DFmode,
    0,
    0,
    1,
    0
  },
  {
    immediate_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm2,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_lane_imm3,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_lane_imm3,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_V4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_imm2,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    nonmemory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    nonmemory_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    nonmemory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    1
  },
  {
    nonmemory_operand,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_reg_or_zero,
    "",
    E_TImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_reg_or_zero,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_plus_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sync_memory_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    aarch64_logical_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    1
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "=Upl",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_any_register_operand,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    nonimmediate_operand,
    "",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    1
  },
  {
    nonimmediate_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    general_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx48QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx24HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx12SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx6DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx24BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx24HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx12SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx6DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx64QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx4DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx4DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx48QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx48QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx24HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx24HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx12SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx12SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx6DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx6DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx24BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx24BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx24HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx24HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx12SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx12SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx6DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx6DFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx64QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx64QImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32HImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16SImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8DImode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32BFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx32HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx32HFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx16SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16SFmode,
    0,
    0,
    1,
    0
  },
  {
    memory_operand,
    "",
    E_VNx8DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_d,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_d,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_b,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_h,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gather_offset_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_gather_scale_operand_w,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_dup_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsm_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vsb_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_pred_and_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    const_1_to_3_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_rshift_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_lshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_with_sub_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_maxmin_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_mul_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_float_arith_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_gp_strictness,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    general_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    1
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_reg_or_dup_imm,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx16BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx8BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx4BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx2BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx8BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx4BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx2BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx4BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx2BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx2BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    nonmemory_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx8BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx4BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    comparison_operator,
    "",
    E_VNx2BImode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_ptrue_flag,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_equality_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_equality_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_equality_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_equality_operator,
    "",
    E_VOIDmode,
    0,
    1,
    0,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    0,
    "",
    E_VOIDmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_vec_perm_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8BFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_sve_lshift_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_rshift_imm,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx16QImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_simd_reg_or_zero,
    "",
    E_VNx2DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx8HFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2BImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx4SFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_VNx2DFmode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_bytes_per_sve_vector_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_SImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    register_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    aarch64_bytes_per_sve_vector_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
  {
    const_int_operand,
    "",
    E_DImode,
    0,
    0,
    1,
    0
  },
};


#if GCC_VERSION >= 2007
__extension__
#endif

const struct insn_data_d insn_data[] = 
{
  /* <internal>:0 */
  {
    "*placeholder_for_nothing",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { 0 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:484 */
  {
    "indirect_jump",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1 },
#else
    { 0, 0, output_1 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_indirect_jump },
    &operand_data[1],
    1,
    1,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:495 */
  {
    "jump",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "b\t%l0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_jump },
    &operand_data[2],
    1,
    1,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:540 */
  {
    "ccmpccsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3 },
#else
    { 0, output_3, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccsi },
    &operand_data[3],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:540 */
  {
    "ccmpccdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4 },
#else
    { 0, output_4, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccdi },
    &operand_data[9],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:560 */
  {
    "ccmpccfpsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmp\t%s2, %s3, %k5, %m4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpsf },
    &operand_data[15],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:560 */
  {
    "ccmpccfpdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmp\t%d2, %d3, %k5, %m4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpdf },
    &operand_data[21],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:560 */
  {
    "ccmpccfpesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmpe\t%s2, %s3, %k5, %m4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpesf },
    &operand_data[27],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:560 */
  {
    "ccmpccfpedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmpe\t%d2, %d3, %k5, %m4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpedf },
    &operand_data[33],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:577 */
  {
    "ccmpccsi_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9 },
#else
    { 0, output_9, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccsi_rev },
    &operand_data[3],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:577 */
  {
    "ccmpccdi_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_10 },
#else
    { 0, output_10, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccdi_rev },
    &operand_data[9],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:597 */
  {
    "ccmpccfpsf_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmp\t%s2, %s3, %k5, %M4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpsf_rev },
    &operand_data[15],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:597 */
  {
    "ccmpccfpdf_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmp\t%d2, %d3, %k5, %M4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpdf_rev },
    &operand_data[21],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:597 */
  {
    "ccmpccfpesf_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmpe\t%s2, %s3, %k5, %M4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpesf_rev },
    &operand_data[27],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:597 */
  {
    "ccmpccfpedf_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fccmpe\t%d2, %d3, %k5, %M4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ccmpccfpedf_rev },
    &operand_data[33],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:670 */
  {
    "condjump",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_15 },
#else
    { 0, 0, output_15 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_condjump },
    &operand_data[39],
    3,
    3,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[42],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[42],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[42],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[42],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[45],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[45],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[45],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:709 */
  {
    "*compare_condjumpdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[45],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:796 */
  {
    "*casesi_dispatch",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_24 },
#else
    { 0, 0, output_24 },
#endif
    { 0 },
    &operand_data[48],
    3,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:814 */
  {
    "nop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nop },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:821 */
  {
    "prefetch",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_26 },
#else
    { 0, 0, output_26 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_prefetch },
    &operand_data[53],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:852 */
  {
    "trap",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brk #1000",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_trap },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:885 */
  {
    "*do_return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_28 },
#else
    { 0, 0, output_28 },
#endif
    { 0 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:913 */
  {
    "simple_return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_29 },
#else
    { 0, 0, output_29 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_simple_return },
    &operand_data[0],
    0,
    0,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:924 */
  {
    "*cbeqsi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_30 },
#else
    { 0, 0, output_30 },
#endif
    { 0 },
    &operand_data[49],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:924 */
  {
    "*cbnesi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_31 },
#else
    { 0, 0, output_31 },
#endif
    { 0 },
    &operand_data[49],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:924 */
  {
    "*cbeqdi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_32 },
#else
    { 0, 0, output_32 },
#endif
    { 0 },
    &operand_data[1],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:924 */
  {
    "*cbnedi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_33 },
#else
    { 0, 0, output_33 },
#endif
    { 0 },
    &operand_data[1],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:949 */
  {
    "*tbeqsi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_34 },
#else
    { 0, 0, output_34 },
#endif
    { 0 },
    &operand_data[56],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:949 */
  {
    "*tbnesi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_35 },
#else
    { 0, 0, output_35 },
#endif
    { 0 },
    &operand_data[56],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:949 */
  {
    "*tbeqdi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_36 },
#else
    { 0, 0, output_36 },
#endif
    { 0 },
    &operand_data[59],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:949 */
  {
    "*tbnedi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_37 },
#else
    { 0, 0, output_37 },
#endif
    { 0 },
    &operand_data[59],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cbltqi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_38 },
#else
    { 0, 0, output_38 },
#endif
    { 0 },
    &operand_data[62],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cbgeqi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_39 },
#else
    { 0, 0, output_39 },
#endif
    { 0 },
    &operand_data[62],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cblthi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_40 },
#else
    { 0, 0, output_40 },
#endif
    { 0 },
    &operand_data[64],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cbgehi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_41 },
#else
    { 0, 0, output_41 },
#endif
    { 0 },
    &operand_data[64],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cbltsi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_42 },
#else
    { 0, 0, output_42 },
#endif
    { 0 },
    &operand_data[49],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cbgesi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_43 },
#else
    { 0, 0, output_43 },
#endif
    { 0 },
    &operand_data[49],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cbltdi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_44 },
#else
    { 0, 0, output_44 },
#endif
    { 0 },
    &operand_data[1],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:989 */
  {
    "*cbgedi1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_45 },
#else
    { 0, 0, output_45 },
#endif
    { 0 },
    &operand_data[1],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1046 */
  {
    "*call_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_46 },
#else
    { 0, 0, output_46 },
#endif
    { 0 },
    &operand_data[66],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1072 */
  {
    "*call_value_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_47 },
#else
    { 0, 0, output_47 },
#endif
    { 0 },
    &operand_data[65],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1112 */
  {
    "*sibcall_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_48 },
#else
    { 0, 0, output_48 },
#endif
    { 0 },
    &operand_data[69],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1130 */
  {
    "*sibcall_value_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_49 },
#else
    { 0, 0, output_49 },
#endif
    { 0 },
    &operand_data[72],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1199 */
  {
    "*movqi_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_50 },
#else
    { 0, 0, output_50 },
#endif
    { 0 },
    &operand_data[76],
    2,
    2,
    0,
    11,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1199 */
  {
    "*movhi_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_51 },
#else
    { 0, 0, output_51 },
#endif
    { 0 },
    &operand_data[78],
    2,
    2,
    0,
    11,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1273 */
  {
    "*movsi_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_52 },
#else
    { 0, 0, output_52 },
#endif
    { 0 },
    &operand_data[80],
    2,
    2,
    0,
    17,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1311 */
  {
    "*movdi_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_53 },
#else
    { 0, 0, output_53 },
#endif
    { 0 },
    &operand_data[82],
    2,
    2,
    0,
    18,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1350 */
  {
    "insv_immsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "movk\t%w0, %X2, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_insv_immsi },
    &operand_data[84],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1350 */
  {
    "insv_immdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "movk\t%x0, %X2, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_insv_immdi },
    &operand_data[87],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1362 */
  {
    "aarch64_movksi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_56 },
#else
    { 0, 0, output_56 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movksi },
    &operand_data[90],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1362 */
  {
    "aarch64_movkdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_57 },
#else
    { 0, 0, output_57 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movkdi },
    &operand_data[94],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1397 */
  {
    "*movti_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_58 },
#else
    { 0, output_58, 0 },
#endif
    { 0 },
    &operand_data[98],
    2,
    2,
    0,
    10,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1457 */
  {
    "*movhf_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_59 },
#else
    { 0, 0, output_59 },
#endif
    { 0 },
    &operand_data[100],
    2,
    2,
    0,
    12,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1457 */
  {
    "*movbf_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_60 },
#else
    { 0, 0, output_60 },
#endif
    { 0 },
    &operand_data[102],
    2,
    2,
    0,
    12,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1480 */
  {
    "*movsf_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_61 },
#else
    { 0, 0, output_61 },
#endif
    { 0 },
    &operand_data[104],
    2,
    2,
    0,
    12,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1504 */
  {
    "*movdf_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_62 },
#else
    { 0, 0, output_62 },
#endif
    { 0 },
    &operand_data[106],
    2,
    2,
    0,
    12,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1548 */
  {
    "*movtf_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_63 },
#else
    { 0, output_63, 0 },
#endif
    { 0 },
    &operand_data[108],
    2,
    2,
    0,
    11,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1598 */
  {
    "*aarch64_cpymemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cpyfp\t[%x0]!, [%x1]!, %x2!\n\tcpyfm\t[%x0]!, [%x1]!, %x2!\n\tcpyfe\t[%x0]!, [%x1]!, %x2!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[110],
    3,
    3,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1627 */
  {
    "aarch64_movmemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cpyp\t[%x0]!, [%x1]!, %x2!\n\tcpym\t[%x0]!, [%x1]!, %x2!\n\tcpye\t[%x0]!, [%x1]!, %x2!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movmemdi },
    &operand_data[110],
    3,
    3,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1686 */
  {
    "*aarch64_setmemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "setp\t[%x0]!, %x2!, %x1\n\tsetm\t[%x0]!, %x2!, %x1\n\tsete\t[%x0]!, %x2!, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[112],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1716 */
  {
    "load_pair_sw_sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_67 },
#else
    { 0, output_67, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_sw_sisi },
    &operand_data[115],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1716 */
  {
    "load_pair_sw_sfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_68 },
#else
    { 0, output_68, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_sw_sfsi },
    &operand_data[119],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1716 */
  {
    "load_pair_sw_sisf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_69 },
#else
    { 0, output_69, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_sw_sisf },
    &operand_data[123],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1716 */
  {
    "load_pair_sw_sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_70 },
#else
    { 0, output_70, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_sw_sfsf },
    &operand_data[127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1733 */
  {
    "load_pair_dw_didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_71 },
#else
    { 0, output_71, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_dw_didi },
    &operand_data[131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1733 */
  {
    "load_pair_dw_didf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_72 },
#else
    { 0, output_72, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_dw_didf },
    &operand_data[135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1733 */
  {
    "load_pair_dw_dfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_73 },
#else
    { 0, output_73, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_dw_dfdi },
    &operand_data[139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1733 */
  {
    "load_pair_dw_dfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_74 },
#else
    { 0, output_74, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_dw_dfdf },
    &operand_data[143],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1749 */
  {
    "load_pair_dw_tftf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_dw_tftf },
    &operand_data[147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1766 */
  {
    "store_pair_sw_sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_76 },
#else
    { 0, output_76, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_sw_sisi },
    &operand_data[151],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1766 */
  {
    "store_pair_sw_sfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_77 },
#else
    { 0, output_77, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_sw_sfsi },
    &operand_data[155],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1766 */
  {
    "store_pair_sw_sisf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_78 },
#else
    { 0, output_78, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_sw_sisf },
    &operand_data[159],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1766 */
  {
    "store_pair_sw_sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_79 },
#else
    { 0, output_79, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_sw_sfsf },
    &operand_data[163],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1783 */
  {
    "store_pair_dw_didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_80 },
#else
    { 0, output_80, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_dw_didi },
    &operand_data[167],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1783 */
  {
    "store_pair_dw_didf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_81 },
#else
    { 0, output_81, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_dw_didf },
    &operand_data[171],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1783 */
  {
    "store_pair_dw_dfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_82 },
#else
    { 0, output_82, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_dw_dfdi },
    &operand_data[175],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1783 */
  {
    "store_pair_dw_dfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_83 },
#else
    { 0, output_83, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_dw_dfdf },
    &operand_data[179],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1799 */
  {
    "store_pair_dw_tftf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_dw_tftf },
    &operand_data[183],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1816 */
  {
    "loadwb_pairsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%w2, %w3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairsi_si },
    &operand_data[187],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1816 */
  {
    "loadwb_pairsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%w2, %w3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairsi_di },
    &operand_data[193],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1816 */
  {
    "loadwb_pairdi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%x2, %x3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairdi_si },
    &operand_data[199],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1816 */
  {
    "loadwb_pairdi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%x2, %x3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairdi_di },
    &operand_data[205],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1831 */
  {
    "loadwb_pairsf_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%s2, %s3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairsf_si },
    &operand_data[211],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1831 */
  {
    "loadwb_pairdf_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d2, %d3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairdf_si },
    &operand_data[217],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1831 */
  {
    "loadwb_pairsf_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%s2, %s3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairsf_di },
    &operand_data[223],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1831 */
  {
    "loadwb_pairdf_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d2, %d3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairdf_di },
    &operand_data[229],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1846 */
  {
    "loadwb_pairti_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q2, %q3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairti_si },
    &operand_data[235],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1846 */
  {
    "loadwb_pairtf_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q2, %q3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairtf_si },
    &operand_data[241],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1846 */
  {
    "loadwb_pairti_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q2, %q3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairti_di },
    &operand_data[247],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1846 */
  {
    "loadwb_pairtf_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q2, %q3, [%1], %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_loadwb_pairtf_di },
    &operand_data[253],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1863 */
  {
    "storewb_pairsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%w2, %w3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairsi_si },
    &operand_data[259],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1863 */
  {
    "storewb_pairsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%w2, %w3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairsi_di },
    &operand_data[265],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1863 */
  {
    "storewb_pairdi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%x2, %x3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairdi_si },
    &operand_data[271],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1863 */
  {
    "storewb_pairdi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%x2, %x3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairdi_di },
    &operand_data[277],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1879 */
  {
    "storewb_pairsf_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%s2, %s3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairsf_si },
    &operand_data[283],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1879 */
  {
    "storewb_pairdf_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d2, %d3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairdf_si },
    &operand_data[289],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1879 */
  {
    "storewb_pairsf_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%s2, %s3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairsf_di },
    &operand_data[295],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1879 */
  {
    "storewb_pairdf_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d2, %d3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairdf_di },
    &operand_data[301],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1895 */
  {
    "storewb_pairti_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q2, %q3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairti_si },
    &operand_data[307],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1895 */
  {
    "storewb_pairtf_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q2, %q3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairtf_si },
    &operand_data[313],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1895 */
  {
    "storewb_pairti_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q2, %q3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairti_di },
    &operand_data[319],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1895 */
  {
    "storewb_pairtf_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q2, %q3, [%0, %4]!",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_storewb_pairtf_di },
    &operand_data[325],
    6,
    6,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1923 */
  {
    "*extendsidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_109 },
#else
    { 0, output_109, 0 },
#endif
    { 0 },
    &operand_data[331],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1933 */
  {
    "*load_pair_extendsidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldpsw\t%0, %2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[333],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1946 */
  {
    "*zero_extendsidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_111 },
#else
    { 0, output_111, 0 },
#endif
    { 0 },
    &operand_data[337],
    2,
    2,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1961 */
  {
    "*load_pair_zero_extendsidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_112 },
#else
    { 0, output_112, 0 },
#endif
    { 0 },
    &operand_data[339],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1983 */
  {
    "*extendqisi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_113 },
#else
    { 0, output_113, 0 },
#endif
    { 0 },
    &operand_data[343],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1983 */
  {
    "*extendhisi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_114 },
#else
    { 0, output_114, 0 },
#endif
    { 0 },
    &operand_data[345],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1983 */
  {
    "*extendqidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_115 },
#else
    { 0, output_115, 0 },
#endif
    { 0 },
    &operand_data[347],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1983 */
  {
    "*extendhidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_116 },
#else
    { 0, output_116, 0 },
#endif
    { 0 },
    &operand_data[349],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1995 */
  {
    "*zero_extendqisi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_117 },
#else
    { 0, output_117, 0 },
#endif
    { 0 },
    &operand_data[351],
    2,
    2,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1995 */
  {
    "*zero_extendhisi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_118 },
#else
    { 0, output_118, 0 },
#endif
    { 0 },
    &operand_data[353],
    2,
    2,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1995 */
  {
    "*zero_extendqidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_119 },
#else
    { 0, output_119, 0 },
#endif
    { 0 },
    &operand_data[355],
    2,
    2,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1995 */
  {
    "*zero_extendhidi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_120 },
#else
    { 0, output_120, 0 },
#endif
    { 0 },
    &operand_data[357],
    2,
    2,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2014 */
  {
    "*extendqihi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_121 },
#else
    { 0, output_121, 0 },
#endif
    { 0 },
    &operand_data[359],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2024 */
  {
    "*zero_extendqihi2_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_122 },
#else
    { 0, output_122, 0 },
#endif
    { 0 },
    &operand_data[359],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2075 */
  {
    "*addsi3_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_123 },
#else
    { 0, 0, output_123 },
#endif
    { 0 },
    &operand_data[361],
    3,
    3,
    0,
    7,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2075 */
  {
    "*adddi3_aarch64",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_124 },
#else
    { 0, 0, output_124 },
#endif
    { 0 },
    &operand_data[364],
    3,
    3,
    0,
    7,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2096 */
  {
    "*addsi3_aarch64_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_125 },
#else
    { 0, output_125, 0 },
#endif
    { 0 },
    &operand_data[367],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2169 */
  {
    "*addsi3_poly_1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_126 },
#else
    { 0, 0, output_126 },
#endif
    { 0 },
    &operand_data[370],
    3,
    3,
    0,
    7,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2169 */
  {
    "*adddi3_poly_1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_127 },
#else
    { 0, 0, output_127 },
#endif
    { 0 },
    &operand_data[373],
    3,
    3,
    0,
    7,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2346 */
  {
    "addsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_128 },
#else
    { 0, output_128, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3_compare0 },
    &operand_data[376],
    3,
    3,
    2,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2346 */
  {
    "adddi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_129 },
#else
    { 0, output_129, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_compare0 },
    &operand_data[379],
    3,
    3,
    2,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2363 */
  {
    "*addsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_130 },
#else
    { 0, output_130, 0 },
#endif
    { 0 },
    &operand_data[382],
    3,
    3,
    2,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2379 */
  {
    "*addsi3_compareC_cconly",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_131 },
#else
    { 0, output_131, 0 },
#endif
    { 0 },
    &operand_data[385],
    2,
    2,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2379 */
  {
    "*adddi3_compareC_cconly",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_132 },
#else
    { 0, output_132, 0 },
#endif
    { 0 },
    &operand_data[387],
    2,
    2,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2394 */
  {
    "addsi3_compareC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_133 },
#else
    { 0, output_133, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3_compareC },
    &operand_data[389],
    3,
    3,
    3,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2394 */
  {
    "adddi3_compareC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_134 },
#else
    { 0, output_134, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_compareC },
    &operand_data[392],
    3,
    3,
    3,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2411 */
  {
    "*addsi3_compareV_cconly_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_135 },
#else
    { 0, output_135, 0 },
#endif
    { 0 },
    &operand_data[395],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2411 */
  {
    "*adddi3_compareV_cconly_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_136 },
#else
    { 0, output_136, 0 },
#endif
    { 0 },
    &operand_data[398],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2428 */
  {
    "*addsi3_compareV_cconly",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmn\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[261],
    2,
    2,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2428 */
  {
    "*adddi3_compareV_cconly",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmn\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[273],
    2,
    2,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2440 */
  {
    "addsi3_compareV_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_139 },
#else
    { 0, output_139, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3_compareV_imm },
    &operand_data[401],
    3,
    3,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2440 */
  {
    "adddi3_compareV_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_140 },
#else
    { 0, output_140, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_compareV_imm },
    &operand_data[404],
    3,
    3,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2458 */
  {
    "addsi3_compareV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3_compareV },
    &operand_data[407],
    3,
    3,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2458 */
  {
    "adddi3_compareV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_compareV },
    &operand_data[410],
    3,
    3,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2472 */
  {
    "*adds_shift_imm_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2472 */
  {
    "*adds_shift_imm_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2472 */
  {
    "*adds_shift_imm_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2472 */
  {
    "*adds_shift_imm_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2472 */
  {
    "*adds_shift_imm_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2472 */
  {
    "*adds_shift_imm_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2488 */
  {
    "*subs_shift_imm_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, lsl %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[421],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2488 */
  {
    "*subs_shift_imm_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, asr %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[421],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2488 */
  {
    "*subs_shift_imm_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, lsr %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[421],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2488 */
  {
    "*subs_shift_imm_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %x2, lsl %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[425],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2488 */
  {
    "*subs_shift_imm_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %x2, asr %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[425],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2488 */
  {
    "*subs_shift_imm_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %x2, lsr %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[425],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w2, %w1, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[429],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_zero_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w2, %w1, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[429],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x2, %w1, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[432],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_zero_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x2, %w1, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[432],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w2, %w1, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[435],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_zero_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w2, %w1, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[435],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x2, %w1, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[438],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_zero_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x2, %w1, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[438],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w2, %w1, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[441],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_zero_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w2, %w1, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[441],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x2, %w1, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[444],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2504 */
  {
    "*adds_zero_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x2, %w1, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[444],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[447],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_zero_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[447],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[450],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_zero_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[450],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[453],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_zero_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[453],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[456],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_zero_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[456],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[407],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_zero_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[407],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[459],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2518 */
  {
    "*subs_zero_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[459],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_extendqi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, sxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[462],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_zero_extendqi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, uxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[462],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_extendqi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %w1, sxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[466],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_zero_extendqi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %w1, uxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[466],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_extendhi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, sxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[470],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_zero_extendhi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, uxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[470],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_extendhi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %w1, sxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[474],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_zero_extendhi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %w1, uxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[474],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_extendsi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, sxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[478],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_zero_extendsi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%w0, %w3, %w1, uxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[478],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_extendsi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %w1, sxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[482],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2532 */
  {
    "*adds_zero_extendsi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adds\t%x0, %x3, %w1, uxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[482],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_extendqi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, sxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[486],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_zero_extendqi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, uxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[486],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_extendqi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, sxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[490],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_zero_extendqi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, uxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[490],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_extendhi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, sxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[494],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_zero_extendhi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, uxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[494],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_extendhi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, sxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[498],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_zero_extendhi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, uxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[498],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_extendsi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, sxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[502],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_zero_extendsi_shift_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2, uxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[502],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_extendsi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, sxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[506],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2550 */
  {
    "*subs_zero_extendsi_shift_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %w2, uxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[506],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2568 */
  {
    "*addsi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_203 },
#else
    { 0, output_203, 0 },
#endif
    { 0 },
    &operand_data[510],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2568 */
  {
    "*adddi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_204 },
#else
    { 0, output_204, 0 },
#endif
    { 0 },
    &operand_data[512],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2582 */
  {
    "aarch64_subsi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subsi_compare0 },
    &operand_data[514],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2582 */
  {
    "aarch64_subdi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subdi_compare0 },
    &operand_data[516],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2593 */
  {
    "*compare_negsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmn\t%w1, %w0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[261],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2593 */
  {
    "*compare_negdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmn\t%x1, %x0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[273],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2603 */
  {
    "*add_lsl_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2603 */
  {
    "*add_asr_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2603 */
  {
    "*add_lsr_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2603 */
  {
    "*add_lsl_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2603 */
  {
    "*add_asr_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2603 */
  {
    "*add_lsr_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2614 */
  {
    "*add_lsl_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2614 */
  {
    "*add_asr_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2614 */
  {
    "*add_lsr_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[522],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_zero_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[522],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x2, %w1, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[525],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_zero_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x2, %w1, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[525],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[528],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_zero_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[528],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x2, %w1, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_zero_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x2, %w1, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[534],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_zero_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[534],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x2, %w1, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[537],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2625 */
  {
    "*add_zero_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x2, %w1, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[537],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_extendqi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[540],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_zero_extendqi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[540],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_extendhi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[543],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_zero_extendhi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[543],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_extendqi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[525],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_zero_extendqi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[525],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_extendhi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2635 */
  {
    "*add_zero_extendhi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w2, %w1, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, sxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[546],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_zero_extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, uxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[546],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %w1, sxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[550],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_zero_extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %w1, uxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[550],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, sxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[554],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_zero_extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, uxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[554],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %w1, sxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[558],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_zero_extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %w1, uxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[558],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, sxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[562],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_zero_extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, uxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[562],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %w1, sxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[566],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2645 */
  {
    "*add_zero_extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x3, %w1, uxtw %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[566],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2657 */
  {
    "*add_extendqi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, sxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[570],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2657 */
  {
    "*add_zero_extendqi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, uxtb %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[570],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2657 */
  {
    "*add_extendhi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, sxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[574],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2657 */
  {
    "*add_zero_extendhi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w3, %w1, uxth %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[574],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2683 */
  {
    "*addsi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adc\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[578],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2683 */
  {
    "*adddi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adc\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[582],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2696 */
  {
    "*addsi3_carryin_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adc\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2736 */
  {
    "*addsi3_carryinC_zero",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%w0, %w1, wzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[590],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2736 */
  {
    "*adddi3_carryinC_zero",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%x0, %x1, xzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[595],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2752 */
  {
    "*addsi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[600],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2752 */
  {
    "*adddi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[606],
    6,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2798 */
  {
    "*addsi3_carryinV_zero",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%w0, %w1, wzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[590],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2798 */
  {
    "*adddi3_carryinV_zero",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%x0, %x1, xzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[595],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2815 */
  {
    "*addsi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[600],
    5,
    5,
    5,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2815 */
  {
    "*adddi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adcs\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[606],
    5,
    5,
    5,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2838 */
  {
    "*add_uxtsi_shift2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_265 },
#else
    { 0, 0, output_265 },
#endif
    { 0 },
    &operand_data[612],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2838 */
  {
    "*add_uxtdi_shift2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_266 },
#else
    { 0, 0, output_266 },
#endif
    { 0 },
    &operand_data[617],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2854 */
  {
    "*add_uxtsi_shift2_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_267 },
#else
    { 0, 0, output_267 },
#endif
    { 0 },
    &operand_data[622],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2870 */
  {
    "subsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsi3 },
    &operand_data[502],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2880 */
  {
    "*subsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[627],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2890 */
  {
    "subdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_270 },
#else
    { 0, output_270, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi3 },
    &operand_data[630],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2918 */
  {
    "subvsi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvsi_insn },
    &operand_data[407],
    3,
    3,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2918 */
  {
    "subvdi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvdi_insn },
    &operand_data[410],
    3,
    3,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2934 */
  {
    "subvsi_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_273 },
#else
    { 0, output_273, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvsi_imm },
    &operand_data[401],
    3,
    3,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2934 */
  {
    "subvdi_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_274 },
#else
    { 0, output_274, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvdi_imm },
    &operand_data[404],
    3,
    3,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2965 */
  {
    "negvsi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvsi_insn },
    &operand_data[413],
    2,
    2,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2965 */
  {
    "negvdi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvdi_insn },
    &operand_data[417],
    2,
    2,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2978 */
  {
    "negvsi_cmp_only",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%wzr, %w0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvsi_cmp_only },
    &operand_data[42],
    1,
    1,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2978 */
  {
    "negvdi_cmp_only",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%xzr, %x0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvdi_cmp_only },
    &operand_data[1],
    1,
    1,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2989 */
  {
    "*cmpvsi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_279 },
#else
    { 0, output_279, 0 },
#endif
    { 0 },
    &operand_data[385],
    2,
    2,
    2,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2989 */
  {
    "*cmpvdi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_280 },
#else
    { 0, output_280, 0 },
#endif
    { 0 },
    &operand_data[387],
    2,
    2,
    2,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3092 */
  {
    "negdi_carryout",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negdi_carryout },
    &operand_data[417],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3103 */
  {
    "negvdi_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ngcs\t%0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvdi_carryinV },
    &operand_data[417],
    2,
    2,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3120 */
  {
    "*subsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[407],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3120 */
  {
    "*subdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[410],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3133 */
  {
    "*subsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[633],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3145 */
  {
    "subsi3_compare1_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_286 },
#else
    { 0, output_286, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsi3_compare1_imm },
    &operand_data[636],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3145 */
  {
    "subdi3_compare1_imm",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_287 },
#else
    { 0, output_287, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi3_compare1_imm },
    &operand_data[640],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3161 */
  {
    "subsi3_compare1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsi3_compare1 },
    &operand_data[644],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3161 */
  {
    "subdi3_compare1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subs\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi3_compare1 },
    &operand_data[647],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3249 */
  {
    "*sub_lsl_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3249 */
  {
    "*sub_asr_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3249 */
  {
    "*sub_lsr_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3249 */
  {
    "*sub_lsl_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3249 */
  {
    "*sub_asr_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3249 */
  {
    "*sub_lsr_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3261 */
  {
    "*sub_lsl_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3261 */
  {
    "*sub_asr_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3261 */
  {
    "*sub_lsr_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[486],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_zero_extendqi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[486],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[490],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_zero_extendqi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[490],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[494],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_zero_extendhi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[494],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_zero_extendhi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[502],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_zero_extendsi_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[502],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[506],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3273 */
  {
    "*sub_zero_extendsi_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[506],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3284 */
  {
    "*sub_extendqi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3284 */
  {
    "*sub_zero_extendqi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3284 */
  {
    "*sub_extendhi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[653],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3284 */
  {
    "*sub_zero_extendhi_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[653],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[486],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_zero_extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[486],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, sxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[490],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_zero_extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, uxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[490],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[494],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_zero_extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[494],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, sxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[498],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_zero_extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, uxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[498],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[502],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_zero_extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[502],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, sxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[506],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3295 */
  {
    "*sub_zero_extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%x0, %x1, %w2, uxtw %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[506],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3307 */
  {
    "*sub_extendqi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[656],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3307 */
  {
    "*sub_zero_extendqi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxtb %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[656],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3307 */
  {
    "*sub_extendhi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, sxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[660],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3307 */
  {
    "*sub_zero_extendhi_shft_si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%w0, %w1, %w2, uxth %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[660],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3325 */
  {
    "*subsi3_carryin0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%w0, %w1, wzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[664],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3325 */
  {
    "*subdi3_carryin0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%x0, %x1, xzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[667],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3336 */
  {
    "*subsi3_carryin_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%w0, %w1, wzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[670],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3358 */
  {
    "*subsi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[673],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3358 */
  {
    "*subdi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[677],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3372 */
  {
    "*subsi3_carryin_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[681],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3386 */
  {
    "*subsi3_carryin_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[673],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3386 */
  {
    "*subdi3_carryin_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[677],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3399 */
  {
    "*subsi3_carryin_alt_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbc\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[681],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3429 */
  {
    "*usubsi3_carryinC_z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%w0, wzr, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[685],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3429 */
  {
    "*usubdi3_carryinC_z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%x0, xzr, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[689],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3446 */
  {
    "*usubsi3_carryinC_z2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%w0, %w1, wzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[685],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3446 */
  {
    "*usubdi3_carryinC_z2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%x0, %x1, xzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[689],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3461 */
  {
    "*usubsi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[693],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3461 */
  {
    "*usubdi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[698],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3501 */
  {
    "*subsi3_carryinV_z2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%w0, %w1, wzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[685],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3501 */
  {
    "*subdi3_carryinV_z2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%x0, %x1, xzr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[689],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3518 */
  {
    "*subsi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[693],
    5,
    5,
    5,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3518 */
  {
    "*subdi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbcs\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[698],
    5,
    5,
    5,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3542 */
  {
    "*sub_uxtsi_shift2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_350 },
#else
    { 0, 0, output_350 },
#endif
    { 0 },
    &operand_data[703],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3542 */
  {
    "*sub_uxtdi_shift2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_351 },
#else
    { 0, 0, output_351 },
#endif
    { 0 },
    &operand_data[708],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3558 */
  {
    "*sub_uxtsi_shift2_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_352 },
#else
    { 0, 0, output_352 },
#endif
    { 0 },
    &operand_data[713],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3586 */
  {
    "negsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_353 },
#else
    { 0, output_353, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negsi2 },
    &operand_data[718],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3586 */
  {
    "negdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_354 },
#else
    { 0, output_354, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negdi2 },
    &operand_data[720],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3598 */
  {
    "*negsi2_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[444],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3606 */
  {
    "*ngcsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ngc\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[722],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3606 */
  {
    "*ngcdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ngc\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[725],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3616 */
  {
    "*ngcsi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ngc\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[728],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3627 */
  {
    "negsi2_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negsi2_compare0 },
    &operand_data[413],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3627 */
  {
    "negdi2_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negdi2_compare0 },
    &operand_data[417],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3639 */
  {
    "*negsi2_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[444],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3650 */
  {
    "*neg_lslsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%w0, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3650 */
  {
    "*neg_asrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%w0, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3650 */
  {
    "*neg_lsrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%w0, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3650 */
  {
    "*neg_lsldi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%x0, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3650 */
  {
    "*neg_asrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%x0, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3650 */
  {
    "*neg_lsrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "negs\t%x0, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3664 */
  {
    "*neg_lsl_si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3664 */
  {
    "*neg_asr_si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3664 */
  {
    "*neg_lsr_si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3664 */
  {
    "*neg_lsl_di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%x0, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3664 */
  {
    "*neg_asr_di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%x0, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3664 */
  {
    "*neg_lsr_di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%x0, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3675 */
  {
    "*neg_lsl_si2_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3675 */
  {
    "*neg_asr_si2_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3675 */
  {
    "*neg_lsr_si2_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3686 */
  {
    "*neg_asr_si2_extr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%w0, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[731],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3698 */
  {
    "mulsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulsi3 },
    &operand_data[421],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3698 */
  {
    "muldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_muldi3 },
    &operand_data[425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3708 */
  {
    "*mulsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3718 */
  {
    "maddsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "madd\t%w0, %w1, %w2, %w3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maddsi },
    &operand_data[736],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3718 */
  {
    "madddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "madd\t%x0, %x1, %x2, %x3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_madddi },
    &operand_data[740],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3729 */
  {
    "*maddsi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "madd\t%w0, %w1, %w2, %w3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[744],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3740 */
  {
    "*msubsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "msub\t%w0, %w1, %w2, %w3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[736],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3740 */
  {
    "*msubdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "msub\t%x0, %x1, %x2, %x3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[740],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3752 */
  {
    "*msubsi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "msub\t%w0, %w1, %w2, %w3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[744],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3764 */
  {
    "*mulsi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mneg\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[421],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3764 */
  {
    "*muldi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mneg\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3775 */
  {
    "*mulsi_neg_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mneg\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3786 */
  {
    "mulsidi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulsidi3 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3786 */
  {
    "umulsidi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulsidi3 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3795 */
  {
    "maddsidi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaddl\t%0, %w1, %w2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maddsidi4 },
    &operand_data[748],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3795 */
  {
    "umaddsidi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaddl\t%0, %w1, %w2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaddsidi4 },
    &operand_data[748],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3806 */
  {
    "msubsidi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smsubl\t%0, %w1, %w2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_msubsidi4 },
    &operand_data[748],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3806 */
  {
    "umsubsidi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umsubl\t%0, %w1, %w2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umsubsidi4 },
    &operand_data[748],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3818 */
  {
    "*mulsidi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smnegl\t%0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3818 */
  {
    "*umulsidi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umnegl\t%0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3870 */
  {
    "smuldi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smulh\t%0, %1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smuldi3_highpart },
    &operand_data[425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3870 */
  {
    "umuldi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umulh\t%0, %1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umuldi3_highpart },
    &operand_data[425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3883 */
  {
    "divsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sdiv\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divsi3 },
    &operand_data[421],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3883 */
  {
    "udivsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "udiv\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udivsi3 },
    &operand_data[421],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3883 */
  {
    "divdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sdiv\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divdi3 },
    &operand_data[425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3883 */
  {
    "udivdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "udiv\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udivdi3 },
    &operand_data[425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3893 */
  {
    "*divsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sdiv\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3893 */
  {
    "*udivsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "udiv\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3907 */
  {
    "cmpsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_406 },
#else
    { 0, output_406, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmpsi },
    &operand_data[390],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3907 */
  {
    "cmpdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_407 },
#else
    { 0, output_407, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmpdi },
    &operand_data[393],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3919 */
  {
    "fcmpsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_408 },
#else
    { 0, output_408, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcmpsf },
    &operand_data[752],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3919 */
  {
    "fcmpdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_409 },
#else
    { 0, output_409, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcmpdf },
    &operand_data[754],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3930 */
  {
    "fcmpesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_410 },
#else
    { 0, output_410, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcmpesf },
    &operand_data[752],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3930 */
  {
    "fcmpedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_411 },
#else
    { 0, output_411, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcmpedf },
    &operand_data[754],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3941 */
  {
    "*cmp_swp_lsl_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[756],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3941 */
  {
    "*cmp_swp_asr_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, asr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[756],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3941 */
  {
    "*cmp_swp_lsr_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, lsr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[756],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3941 */
  {
    "*cmp_swp_lsl_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %x0, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[759],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3941 */
  {
    "*cmp_swp_asr_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %x0, asr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[759],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3941 */
  {
    "*cmp_swp_lsr_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %x0, lsr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[759],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_extendqi_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w1, %w0, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[523],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_zero_extendqi_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w1, %w0, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[523],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_extendqi_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x1, %w0, sxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[526],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_zero_extendqi_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x1, %w0, uxtb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[526],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_extendhi_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w1, %w0, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[529],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_zero_extendhi_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w1, %w0, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[529],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_extendhi_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x1, %w0, sxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[532],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_zero_extendhi_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x1, %w0, uxth",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[532],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_extendsi_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w1, %w0, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[261],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_zero_extendsi_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w1, %w0, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[261],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_extendsi_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x1, %w0, sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[538],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3952 */
  {
    "*cmp_swp_zero_extendsi_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x1, %w0, uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[538],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, sxtb %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[547],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_zero_extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, uxtb %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[547],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %w0, sxtb %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[551],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_zero_extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %w0, uxtb %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[551],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, sxth %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[555],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_zero_extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, uxth %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[555],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %w0, sxth %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[559],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_zero_extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %w0, uxth %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[559],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, sxtw %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[563],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_zero_extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%w2, %w0, uxtw %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[563],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %w0, sxtw %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[567],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3962 */
  {
    "*cmp_swp_zero_extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmp\t%x2, %w0, uxtw %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[567],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4016 */
  {
    "aarch64_cstoreqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cset\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cstoreqi },
    &operand_data[762],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4016 */
  {
    "aarch64_cstorehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cset\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cstorehi },
    &operand_data[765],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4016 */
  {
    "aarch64_cstoresi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cset\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cstoresi },
    &operand_data[768],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4016 */
  {
    "aarch64_cstoredi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cset\t%x0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cstoredi },
    &operand_data[771],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4035 */
  {
    "*compare_cstoresi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[774],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4035 */
  {
    "*compare_cstoresi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[774],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4035 */
  {
    "*compare_cstoredi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[777],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4035 */
  {
    "*compare_cstoredi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[777],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4061 */
  {
    "*cstoresi_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cset\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[780],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4071 */
  {
    "cstoreqi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csetm\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoreqi_neg },
    &operand_data[762],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4071 */
  {
    "cstorehi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csetm\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstorehi_neg },
    &operand_data[765],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4071 */
  {
    "cstoresi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csetm\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoresi_neg },
    &operand_data[768],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4071 */
  {
    "cstoredi_neg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csetm\t%x0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoredi_neg },
    &operand_data[771],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4081 */
  {
    "*cstoresi_neg_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csetm\t%w0, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[780],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4123 */
  {
    "*cmovqi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_456 },
#else
    { 0, output_456, 0 },
#endif
    { 0 },
    &operand_data[783],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4123 */
  {
    "*cmovhi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_457 },
#else
    { 0, output_457, 0 },
#endif
    { 0 },
    &operand_data[788],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4123 */
  {
    "*cmovsi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_458 },
#else
    { 0, output_458, 0 },
#endif
    { 0 },
    &operand_data[793],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4123 */
  {
    "*cmovdi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_459 },
#else
    { 0, output_459, 0 },
#endif
    { 0 },
    &operand_data[798],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4145 */
  {
    "*cmovsi_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_460 },
#else
    { 0, output_460, 0 },
#endif
    { 0 },
    &operand_data[803],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4167 */
  {
    "*cmovdi_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csel\t%w0, %w3, %w4, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[808],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4179 */
  {
    "*cmovsf_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcsel\t%s0, %s3, %s4, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[813],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4179 */
  {
    "*cmovdf_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcsel\t%d0, %d3, %d4, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[818],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_464 },
#else
    { 0, 0, output_464 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32b },
    &operand_data[823],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_465 },
#else
    { 0, 0, output_465 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32h },
    &operand_data[826],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32w",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_466 },
#else
    { 0, 0, output_466 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32w },
    &operand_data[421],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32x",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_467 },
#else
    { 0, 0, output_467 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32x },
    &operand_data[829],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32cb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_468 },
#else
    { 0, 0, output_468 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32cb },
    &operand_data[823],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32ch",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_469 },
#else
    { 0, 0, output_469 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32ch },
    &operand_data[826],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32cw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_470 },
#else
    { 0, 0, output_470 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32cw },
    &operand_data[421],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4268 */
  {
    "aarch64_crc32cx",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_471 },
#else
    { 0, 0, output_471 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crc32cx },
    &operand_data[829],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4283 */
  {
    "*csinc2si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cinc\t%w0, %w1, %m2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[832],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4283 */
  {
    "*csinc2di_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cinc\t%x0, %x1, %m2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[835],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4292 */
  {
    "csinc3si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinc\t%w0, %w3, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_csinc3si_insn },
    &operand_data[838],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4292 */
  {
    "csinc3di_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinc\t%x0, %x3, %x2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_csinc3di_insn },
    &operand_data[842],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4304 */
  {
    "*csinv3si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinv\t%w0, %w3, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[838],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4304 */
  {
    "*csinv3di_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinv\t%x0, %x3, %x2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[842],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4315 */
  {
    "*csneg3_uxtw_insn4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csneg\t%w0, %w3, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[846],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4315 */
  {
    "*csinv3_uxtw_insn4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinv\t%w0, %w3, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[846],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4327 */
  {
    "csneg3si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csneg\t%w0, %w3, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_csneg3si_insn },
    &operand_data[838],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4327 */
  {
    "csneg3di_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csneg\t%x0, %x3, %x2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_csneg3di_insn },
    &operand_data[842],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4338 */
  {
    "*csinv3_uxtw_insn1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csneg\t%w0, %w2, %w3, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[850],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4338 */
  {
    "*csinv3_uxtw_insn1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinv\t%w0, %w2, %w3, %m1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[850],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4351 */
  {
    "*csinv3_uxtw_insn2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csneg\t%w0, %w3, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[850],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4351 */
  {
    "*csinv3_uxtw_insn2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinv\t%w0, %w3, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[850],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4364 */
  {
    "*csinv3_uxtw_insn3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csneg\t%w0, wzr, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[846],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4364 */
  {
    "*csinv3_uxtw_insn3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "csinv\t%w0, wzr, %w2, %M1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[846],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4421 */
  {
    "aarch64_uqdecsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_488 },
#else
    { 0, 0, output_488 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqdecsi },
    &operand_data[854],
    3,
    3,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4421 */
  {
    "aarch64_uqdecdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_489 },
#else
    { 0, 0, output_489 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqdecdi },
    &operand_data[857],
    3,
    3,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[860],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[860],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[860],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[860],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[864],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[864],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[864],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4435 */
  {
    "*aarch64_minmax_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[864],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4465 */
  {
    "*aarch64_andsi_imm2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[868],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4465 */
  {
    "*aarch64_anddi_imm2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[871],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4484 */
  {
    "andsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_500 },
#else
    { 0, output_500, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andsi3 },
    &operand_data[874],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4484 */
  {
    "iorsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_501 },
#else
    { 0, output_501, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorsi3 },
    &operand_data[874],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4484 */
  {
    "xorsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_502 },
#else
    { 0, output_502, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsi3 },
    &operand_data[874],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4484 */
  {
    "anddi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_503 },
#else
    { 0, output_503, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_anddi3 },
    &operand_data[877],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4484 */
  {
    "iordi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_504 },
#else
    { 0, output_504, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iordi3 },
    &operand_data[877],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4484 */
  {
    "xordi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_505 },
#else
    { 0, output_505, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xordi3 },
    &operand_data[877],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4498 */
  {
    "*andsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_506 },
#else
    { 0, output_506, 0 },
#endif
    { 0 },
    &operand_data[880],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4498 */
  {
    "*iorsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_507 },
#else
    { 0, output_507, 0 },
#endif
    { 0 },
    &operand_data[880],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4498 */
  {
    "*xorsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_508 },
#else
    { 0, output_508, 0 },
#endif
    { 0 },
    &operand_data[880],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4510 */
  {
    "*andsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_509 },
#else
    { 0, output_509, 0 },
#endif
    { 0 },
    &operand_data[883],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4510 */
  {
    "*anddi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_510 },
#else
    { 0, output_510, 0 },
#endif
    { 0 },
    &operand_data[886],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4526 */
  {
    "*andsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_511 },
#else
    { 0, output_511, 0 },
#endif
    { 0 },
    &operand_data[889],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_ashlsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_ashrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_lshrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_rotrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_ashldi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_ashrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_lshrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4541 */
  {
    "*and_rotrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4557 */
  {
    "*and_ashlsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4557 */
  {
    "*and_ashrsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4557 */
  {
    "*and_lshrsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4557 */
  {
    "*and_rotrsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_rotrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_rotrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_rotrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*and_rotrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*ior_rotrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4573 */
  {
    "*xor_rotrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4650 */
  {
    "*and_rolsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, ror #(32 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4650 */
  {
    "*ior_rolsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, ror #(32 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4650 */
  {
    "*xor_rolsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, ror #(32 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4650 */
  {
    "*and_roldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%x0, %x3, %x1, ror #(64 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4650 */
  {
    "*ior_roldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%x0, %x3, %x1, ror #(64 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4650 */
  {
    "*xor_roldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%x0, %x3, %x1, ror #(64 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*and_ashlsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*ior_ashlsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*xor_ashlsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*and_ashrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*ior_ashrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*xor_ashrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*and_lshrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*ior_lshrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*xor_lshrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*and_rotrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*ior_rotrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4662 */
  {
    "*xor_rotrsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4674 */
  {
    "*and_rolsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w3, %w1, ror #(32 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4674 */
  {
    "*ior_rolsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%w0, %w3, %w1, ror #(32 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4674 */
  {
    "*xor_rolsi3_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%w0, %w3, %w1, ror #(32 - %2)",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4686 */
  {
    "one_cmplsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_569 },
#else
    { 0, output_569, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplsi2 },
    &operand_data[718],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4686 */
  {
    "one_cmpldi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_570 },
#else
    { 0, output_570, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmpldi2 },
    &operand_data[720],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4697 */
  {
    "*one_cmpl_zero_extend",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[444],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_ashlsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%w0, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_ashrsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%w0, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_lshrsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%w0, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_rotrsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%w0, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_ashldi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%x0, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_ashrdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%x0, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_lshrdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%x0, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4706 */
  {
    "*one_cmpl_rotrdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mvn\t%x0, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4717 */
  {
    "*and_one_cmplsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_580 },
#else
    { 0, output_580, 0 },
#endif
    { 0 },
    &operand_data[892],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4717 */
  {
    "*ior_one_cmplsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_581 },
#else
    { 0, output_581, 0 },
#endif
    { 0 },
    &operand_data[892],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4717 */
  {
    "*and_one_cmpldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_582 },
#else
    { 0, output_582, 0 },
#endif
    { 0 },
    &operand_data[895],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4717 */
  {
    "*ior_one_cmpldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_583 },
#else
    { 0, output_583, 0 },
#endif
    { 0 },
    &operand_data[895],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4729 */
  {
    "*and_one_cmplsidi3_ze",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%w0, %w2, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4729 */
  {
    "*ior_one_cmplsidi3_ze",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%w0, %w2, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4739 */
  {
    "*xor_one_cmplsidi3_ze",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4751 */
  {
    "*xor_one_cmplsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_587 },
#else
    { 0, output_587, 0 },
#endif
    { 0 },
    &operand_data[898],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4751 */
  {
    "*xor_one_cmpldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_588 },
#else
    { 0, output_588, 0 },
#endif
    { 0 },
    &operand_data[901],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4769 */
  {
    "*and_one_cmplsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w2, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[421],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4769 */
  {
    "*and_one_cmpldi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%x0, %x2, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[425],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4784 */
  {
    "*and_one_cmplsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w2, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[586],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4798 */
  {
    "*and_one_cmplsi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\twzr, %w1, %w0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[261],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4798 */
  {
    "*and_one_cmpldi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\txzr, %x1, %x0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[273],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_ashlsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_ashlsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_ashlsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_ashrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_ashrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_ashrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_lshrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_lshrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_lshrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_rotrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_rotrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_rotrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_rotrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_rotrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_rotrsi3 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_ashldi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_ashldi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_ashldi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_ashrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_ashrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_ashrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_lshrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_lshrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_lshrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "and_one_cmpl_rotrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_and_one_cmpl_rotrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "ior_one_cmpl_rotrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ior_one_cmpl_rotrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4810 */
  {
    "xor_one_cmpl_rotrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xor_one_cmpl_rotrdi3 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_ashlsi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_ashrsi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_lshrsi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_rotrsi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_ashldi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_ashrdi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_lshrdi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4822 */
  {
    "*eor_one_cmpl_rotrdi3_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4835 */
  {
    "*eor_one_cmpl_ashlsidi3_alt_ze",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4835 */
  {
    "*eor_one_cmpl_ashrsidi3_alt_ze",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4835 */
  {
    "*eor_one_cmpl_lshrsidi3_alt_ze",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4835 */
  {
    "*eor_one_cmpl_rotrsidi3_alt_ze",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eon\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_ashlsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_ashrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_lshrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_rotrsi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[413],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_ashldi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%x0, %x3, %x1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_ashrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%x0, %x3, %x1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_lshrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%x0, %x3, %x1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4848 */
  {
    "*and_one_cmpl_rotrdi3_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%x0, %x3, %x1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[417],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4867 */
  {
    "*and_one_cmpl_ashlsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, lsl %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4867 */
  {
    "*and_one_cmpl_ashrsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, asr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4867 */
  {
    "*and_one_cmpl_lshrsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, lsr %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4867 */
  {
    "*and_one_cmpl_rotrsi3_compare0_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%w0, %w3, %w1, ror %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[518],
    4,
    4,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_ashlsi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\twzr, %w2, %w0, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_ashrsi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\twzr, %w2, %w0, asr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_lshrsi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\twzr, %w2, %w0, lsr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_rotrsi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\twzr, %w2, %w0, ror %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_ashldi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\txzr, %x2, %x0, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_ashrdi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\txzr, %x2, %x0, asr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_lshrdi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\txzr, %x2, %x0, lsr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4885 */
  {
    "*and_one_cmpl_rotrdi3_compare0_no_reuse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\txzr, %x2, %x0, ror %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4899 */
  {
    "clzsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzsi2 },
    &operand_data[413],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4899 */
  {
    "clzdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzdi2 },
    &operand_data[417],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4953 */
  {
    "clrsbsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbsi2 },
    &operand_data[413],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4953 */
  {
    "clrsbdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbdi2 },
    &operand_data[417],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4961 */
  {
    "aarch64_rbitsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rbit\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rbitsi },
    &operand_data[413],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4961 */
  {
    "aarch64_rbitdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rbit\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rbitdi },
    &operand_data[417],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4974 */
  {
    "ctzsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ctzsi2 },
    &operand_data[413],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4974 */
  {
    "ctzdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ctzdi2 },
    &operand_data[417],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4987 */
  {
    "*andqi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%w0, 255",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[62],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4987 */
  {
    "*andhi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%w0, 65535",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[64],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4997 */
  {
    "*andssi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w1, 255",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[429],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4997 */
  {
    "*andssi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%w0, %w1, 65535",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[435],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4997 */
  {
    "*andsdi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%x0, %x1, 255",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[432],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4997 */
  {
    "*andsdi_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%x0, %x1, 65535",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[438],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5009 */
  {
    "*andsi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_664 },
#else
    { 0, output_664, 0 },
#endif
    { 0 },
    &operand_data[881],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5009 */
  {
    "*anddi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_665 },
#else
    { 0, output_665, 0 },
#endif
    { 0 },
    &operand_data[887],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5038 */
  {
    "*andsi3nr_compare0_zextract",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_666 },
#else
    { 0, 0, output_666 },
#endif
    { 0 },
    &operand_data[904],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5038 */
  {
    "*anddi3nr_compare0_zextract",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_667 },
#else
    { 0, 0, output_667 },
#endif
    { 0 },
    &operand_data[907],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_ashlsi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%w2, %w0, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_ashrsi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%w2, %w0, asr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_lshrsi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%w2, %w0, lsr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_rotrsi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%w2, %w0, ror %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[414],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_ashldi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%x2, %x0, lsl %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_ashrdi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%x2, %x0, asr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_lshrdi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%x2, %x0, lsr %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5060 */
  {
    "*and_rotrdi3nr_compare0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tst\t%x2, %x0, ror %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[418],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_ashl_reg_si3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[910],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_ashr_reg_si3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[910],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_lshr_reg_si3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[910],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_rotr_reg_si3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ror\t%w0, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[910],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_ashl_reg_di3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[915],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_ashr_reg_di3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[915],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_lshr_reg_di3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[915],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5184 */
  {
    "*aarch64_rotr_reg_di3_mask1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ror\t%x0, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[915],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_ashl_reg_si3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[920],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_ashr_reg_si3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[920],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_lshr_reg_si3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[920],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_rotr_reg_si3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[920],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_ashl_reg_di3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[925],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_ashr_reg_di3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[925],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_lshr_reg_di3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[925],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5196 */
  {
    "*aarch64_rotr_reg_di3_neg_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[925],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5220 */
  {
    "*aarch64_ashl_reg_si3_minus_mask",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[930],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5220 */
  {
    "*aarch64_ashl_reg_di3_minus_mask",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[936],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5248 */
  {
    "*aarch64_ashl_reg_di3_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_694 },
#else
    { 0, 0, output_694 },
#endif
    { 0 },
    &operand_data[942],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5248 */
  {
    "*aarch64_ashr_reg_di3_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_695 },
#else
    { 0, 0, output_695 },
#endif
    { 0 },
    &operand_data[942],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5248 */
  {
    "*aarch64_lshr_reg_di3_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_696 },
#else
    { 0, 0, output_696 },
#endif
    { 0 },
    &operand_data[942],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5248 */
  {
    "*aarch64_rotr_reg_di3_mask2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_697 },
#else
    { 0, 0, output_697 },
#endif
    { 0 },
    &operand_data[942],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5267 */
  {
    "*aarch64_ashl_reg_minussi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[947],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5267 */
  {
    "*aarch64_ashr_reg_minussi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[947],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5267 */
  {
    "*aarch64_lshr_reg_minussi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[947],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5267 */
  {
    "*aarch64_ashl_reg_minusdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[951],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5267 */
  {
    "*aarch64_ashr_reg_minusdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[951],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5267 */
  {
    "*aarch64_lshr_reg_minusdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[951],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5297 */
  {
    "*aarch64_ashl_sisd_or_int_si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_704 },
#else
    { 0, output_704, 0 },
#endif
    { 0 },
    &operand_data[955],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5297 */
  {
    "*aarch64_ashl_sisd_or_int_di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_705 },
#else
    { 0, output_705, 0 },
#endif
    { 0 },
    &operand_data[958],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5313 */
  {
    "*aarch64_lshr_sisd_or_int_si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_706 },
#else
    { 0, output_706, 0 },
#endif
    { 0 },
    &operand_data[961],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5313 */
  {
    "*aarch64_lshr_sisd_or_int_di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_707 },
#else
    { 0, output_707, 0 },
#endif
    { 0 },
    &operand_data[964],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5361 */
  {
    "*aarch64_ashr_sisd_or_int_si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_708 },
#else
    { 0, output_708, 0 },
#endif
    { 0 },
    &operand_data[967],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5361 */
  {
    "*aarch64_ashr_sisd_or_int_di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_709 },
#else
    { 0, output_709, 0 },
#endif
    { 0 },
    &operand_data[964],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5408 */
  {
    "*aarch64_sisd_ushl",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[970],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5418 */
  {
    "*aarch64_ushl_2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[973],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5428 */
  {
    "*aarch64_sisd_sshl",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[970],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5438 */
  {
    "*aarch64_sshl_2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[973],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5448 */
  {
    "*aarch64_sisd_neg_qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[976],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5458 */
  {
    "*rorsi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_715 },
#else
    { 0, output_715, 0 },
#endif
    { 0 },
    &operand_data[978],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5458 */
  {
    "*rordi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_716 },
#else
    { 0, output_716, 0 },
#endif
    { 0 },
    &operand_data[981],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5471 */
  {
    "*ashlsi3_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_717 },
#else
    { 0, output_717, 0 },
#endif
    { 0 },
    &operand_data[984],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5471 */
  {
    "*ashrsi3_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_718 },
#else
    { 0, output_718, 0 },
#endif
    { 0 },
    &operand_data[984],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5471 */
  {
    "*lshrsi3_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_719 },
#else
    { 0, output_719, 0 },
#endif
    { 0 },
    &operand_data[984],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5471 */
  {
    "*rotrsi3_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_720 },
#else
    { 0, output_720, 0 },
#endif
    { 0 },
    &operand_data[984],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5483 */
  {
    "*ashlqi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_721 },
#else
    { 0, 0, output_721 },
#endif
    { 0 },
    &operand_data[987],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5483 */
  {
    "*ashrqi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_722 },
#else
    { 0, 0, output_722 },
#endif
    { 0 },
    &operand_data[987],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5483 */
  {
    "*lshrqi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_723 },
#else
    { 0, 0, output_723 },
#endif
    { 0 },
    &operand_data[987],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5483 */
  {
    "*ashlhi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_724 },
#else
    { 0, 0, output_724 },
#endif
    { 0 },
    &operand_data[990],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5483 */
  {
    "*ashrhi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_725 },
#else
    { 0, 0, output_725 },
#endif
    { 0 },
    &operand_data[990],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5483 */
  {
    "*lshrhi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_726 },
#else
    { 0, 0, output_726 },
#endif
    { 0 },
    &operand_data[990],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5495 */
  {
    "*extrsi5_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "extr\t%w0, %w1, %w2, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[993],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5495 */
  {
    "*extrdi5_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "extr\t%x0, %x1, %x2, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[998],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5509 */
  {
    "*extrsi5_insn_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "extr\t%w0, %w1, %w2, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[993],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5509 */
  {
    "*extrdi5_insn_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "extr\t%x0, %x1, %x2, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[998],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5523 */
  {
    "*extrsi5_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "extr\t%w0, %w1, %w2, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1003],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5536 */
  {
    "*extrsi5_insn_uxtw_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "extr\t%w0, %w1, %w2, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1003],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5549 */
  {
    "*extrsi5_insn_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "extr\t%w0, %w1, %w2, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1008],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5565 */
  {
    "*rorsi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_734 },
#else
    { 0, 0, output_734 },
#endif
    { 0 },
    &operand_data[1015],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5565 */
  {
    "*rordi3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_735 },
#else
    { 0, 0, output_735 },
#endif
    { 0 },
    &operand_data[1018],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5578 */
  {
    "*rorsi3_insn_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_736 },
#else
    { 0, 0, output_736 },
#endif
    { 0 },
    &operand_data[1021],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*extendsi_ashlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_737 },
#else
    { 0, 0, output_737 },
#endif
    { 0 },
    &operand_data[1024],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*zero_extendsi_ashlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_738 },
#else
    { 0, 0, output_738 },
#endif
    { 0 },
    &operand_data[1024],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*extendsi_ashlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_739 },
#else
    { 0, 0, output_739 },
#endif
    { 0 },
    &operand_data[1027],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*zero_extendsi_ashlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_740 },
#else
    { 0, 0, output_740 },
#endif
    { 0 },
    &operand_data[1027],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*extenddi_ashlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_741 },
#else
    { 0, 0, output_741 },
#endif
    { 0 },
    &operand_data[1030],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*zero_extenddi_ashlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_742 },
#else
    { 0, 0, output_742 },
#endif
    { 0 },
    &operand_data[1030],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*extenddi_ashlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_743 },
#else
    { 0, 0, output_743 },
#endif
    { 0 },
    &operand_data[1033],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5591 */
  {
    "*zero_extenddi_ashlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_744 },
#else
    { 0, 0, output_744 },
#endif
    { 0 },
    &operand_data[1033],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5604 */
  {
    "*zero_extendsi_lshrqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_745 },
#else
    { 0, 0, output_745 },
#endif
    { 0 },
    &operand_data[1024],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5604 */
  {
    "*zero_extendsi_lshrhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_746 },
#else
    { 0, 0, output_746 },
#endif
    { 0 },
    &operand_data[1027],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5604 */
  {
    "*zero_extenddi_lshrqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_747 },
#else
    { 0, 0, output_747 },
#endif
    { 0 },
    &operand_data[1030],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5604 */
  {
    "*zero_extenddi_lshrhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_748 },
#else
    { 0, 0, output_748 },
#endif
    { 0 },
    &operand_data[1033],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5617 */
  {
    "*extendsi_ashrqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_749 },
#else
    { 0, 0, output_749 },
#endif
    { 0 },
    &operand_data[1024],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5617 */
  {
    "*extendsi_ashrhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_750 },
#else
    { 0, 0, output_750 },
#endif
    { 0 },
    &operand_data[1027],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5617 */
  {
    "*extenddi_ashrqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_751 },
#else
    { 0, 0, output_751 },
#endif
    { 0 },
    &operand_data[1030],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5617 */
  {
    "*extenddi_ashrhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_752 },
#else
    { 0, 0, output_752 },
#endif
    { 0 },
    &operand_data[1033],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5649 */
  {
    "*extvsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbfx\t%w0, %w1, %3, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1036],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5649 */
  {
    "*extzvsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ubfx\t%w0, %w1, %3, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1036],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5649 */
  {
    "*extvdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbfx\t%x0, %x1, %3, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1040],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5649 */
  {
    "*extzvdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ubfx\t%x0, %x1, %3, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1040],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5713 */
  {
    "*insv_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1044],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5713 */
  {
    "*insv_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1048],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5725 */
  {
    "*aarch64_bfisiqi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1052],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5725 */
  {
    "*aarch64_bfidiqi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1056],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5725 */
  {
    "*aarch64_bfisihi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1060],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5725 */
  {
    "*aarch64_bfidihi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1064],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5725 */
  {
    "*aarch64_bfisisi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1044],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5725 */
  {
    "*aarch64_bfidisi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x3, %2, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1068],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5741 */
  {
    "*aarch64_bfisi5_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w3, %4, %P5",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1072],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5741 */
  {
    "*aarch64_bfidi5_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x3, %4, %P5",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1078],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5756 */
  {
    "*aarch64_bfisi5_shift_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w1, %2, %P3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1084],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5756 */
  {
    "*aarch64_bfidi5_shift_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x1, %2, %P3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1090],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5774 */
  {
    "*aarch64_bfisi4_noand",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_769 },
#else
    { 0, 0, output_769 },
#endif
    { 0 },
    &operand_data[1072],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5774 */
  {
    "*aarch64_bfidi4_noand",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_770 },
#else
    { 0, 0, output_770 },
#endif
    { 0 },
    &operand_data[1078],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5791 */
  {
    "*aarch64_bfisi4_noand_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_771 },
#else
    { 0, 0, output_771 },
#endif
    { 0 },
    &operand_data[1096],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5791 */
  {
    "*aarch64_bfidi4_noand_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_772 },
#else
    { 0, 0, output_772 },
#endif
    { 0 },
    &operand_data[1101],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5812 */
  {
    "*aarch64_bfisi4_noshift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w3, 0, %P4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1106],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5812 */
  {
    "*aarch64_bfidi4_noshift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x3, 0, %P4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1111],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5824 */
  {
    "*aarch64_bfisi4_noshift_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%w0, %w3, 0, %P4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1106],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5824 */
  {
    "*aarch64_bfidi4_noshift_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfi\t%x0, %x3, 0, %P4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1111],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5836 */
  {
    "*aarch64_bfxilsi_extr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfxil\t%w0, %w3, %5, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1116],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5836 */
  {
    "*aarch64_bfxildi_extr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfxil\t%x0, %x3, %5, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1122],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5852 */
  {
    "*aarch64_bfxilsi_extrdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfxil\t%w0, %w3, %5, %4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1128],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5868 */
  {
    "*extr_insv_lower_regsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfxil\t%w0, %w2, %3, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1135],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5868 */
  {
    "*extr_insv_lower_regdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfxil\t%x0, %x2, %3, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1139],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_782 },
#else
    { 0, 0, output_782 },
#endif
    { 0 },
    &operand_data[1024],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*zero_extendqi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_783 },
#else
    { 0, 0, output_783 },
#endif
    { 0 },
    &operand_data[1024],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_784 },
#else
    { 0, 0, output_784 },
#endif
    { 0 },
    &operand_data[1030],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*zero_extendqi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_785 },
#else
    { 0, 0, output_785 },
#endif
    { 0 },
    &operand_data[1030],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_786 },
#else
    { 0, 0, output_786 },
#endif
    { 0 },
    &operand_data[1027],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*zero_extendhi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_787 },
#else
    { 0, 0, output_787 },
#endif
    { 0 },
    &operand_data[1027],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_788 },
#else
    { 0, 0, output_788 },
#endif
    { 0 },
    &operand_data[1033],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*zero_extendhi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_789 },
#else
    { 0, 0, output_789 },
#endif
    { 0 },
    &operand_data[1033],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_790 },
#else
    { 0, 0, output_790 },
#endif
    { 0 },
    &operand_data[1015],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*zero_extendsi_shft_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_791 },
#else
    { 0, 0, output_791 },
#endif
    { 0 },
    &operand_data[1015],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_792 },
#else
    { 0, 0, output_792 },
#endif
    { 0 },
    &operand_data[1021],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5882 */
  {
    "*zero_extendsi_shft_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_793 },
#else
    { 0, 0, output_793 },
#endif
    { 0 },
    &operand_data[1021],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5899 */
  {
    "*andim_ashiftsi_bfiz",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ubfiz\t%w0, %w1, %2, %P3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5899 */
  {
    "*andim_ashiftdi_bfiz",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ubfiz\t%x0, %x1, %2, %P3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5911 */
  {
    "*ashiftsi_extv_bfiz",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbfiz\t%w0, %w1, %3, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1036],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5911 */
  {
    "*ashiftdi_extv_bfiz",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbfiz\t%x0, %x1, %3, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1040],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5923 */
  {
    "*ashiftsi_extvdi_bfiz",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sbfiz\t%w0, %w1, %3, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1151],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5956 */
  {
    "bswapsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapsi2 },
    &operand_data[413],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5956 */
  {
    "bswapdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapdi2 },
    &operand_data[417],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5964 */
  {
    "bswaphi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswaphi2 },
    &operand_data[990],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5972 */
  {
    "aarch64_rev16si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16si },
    &operand_data[413],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5972 */
  {
    "aarch64_rev16di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16di },
    &operand_data[417],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5979 */
  {
    "*aarch64_bfxilsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_804 },
#else
    { 0, 0, output_804 },
#endif
    { 0 },
    &operand_data[1156],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5979 */
  {
    "*aarch64_bfxildi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_805 },
#else
    { 0, 0, output_805 },
#endif
    { 0 },
    &operand_data[1161],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6005 */
  {
    "*aarch64_bfxilsi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_806 },
#else
    { 0, 0, output_806 },
#endif
    { 0 },
    &operand_data[1166],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6035 */
  {
    "rev16si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rev16si2 },
    &operand_data[1171],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6035 */
  {
    "rev16di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rev16di2 },
    &operand_data[1175],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6049 */
  {
    "rev16si2_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rev16si2_alt },
    &operand_data[1171],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6049 */
  {
    "rev16di2_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%x0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rev16di2_alt },
    &operand_data[1175],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6064 */
  {
    "*bswapsi2_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%w0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[444],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "btrunchf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btrunchf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "ceilhf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilhf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "floorhf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorhf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "roundevenhf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevenhf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "nearbyinthf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyinthf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "rinthf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rinthf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "roundhf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundhf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "btruncsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncsf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "ceilsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilsf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "floorsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorsf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "roundevensf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevensf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "nearbyintsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintsf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "rintsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintsf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "roundsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundsf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "btruncdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncdf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "ceildf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceildf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "floordf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floordf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "roundevendf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevendf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "nearbyintdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintdf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "rintdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintdf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6079 */
  {
    "rounddf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rounddf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtrunchfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtrunchfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceilhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncuhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceiluhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lflooruhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lrounduhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnuhfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuhfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncsfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceilsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilsfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorsfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundsfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnsfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncusfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncusfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceilusfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilusfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorusfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorusfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundusfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundusfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnusfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnusfsi2 },
    &operand_data[1187],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncdfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncdfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceildfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceildfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloordfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloordfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lrounddfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounddfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintndfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintndfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncudfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncudfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceiludfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiludfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorudfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorudfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundudfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundudfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnudfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnudfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtrunchfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtrunchfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceilhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncuhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceiluhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lflooruhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lrounduhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnuhfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuhfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncsfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceilsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilsfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorsfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundsfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnsfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncusfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncusfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceilusfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilusfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorusfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorusfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundusfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundusfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnusfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnusfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncdfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncdfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceildfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceildfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloordfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloordfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lrounddfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounddfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintndfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintndfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lbtruncudfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncudfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lceiludfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiludfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfloorudfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorudfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lroundudfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundudfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6090 */
  {
    "lfrintnudfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnudfdi2 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtsfsi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_893 },
#else
    { 0, 0, output_893 },
#endif
    { 0 },
    &operand_data[1197],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtusfsi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_894 },
#else
    { 0, 0, output_894 },
#endif
    { 0 },
    &operand_data[1197],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtdfsi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_895 },
#else
    { 0, 0, output_895 },
#endif
    { 0 },
    &operand_data[1200],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtudfsi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_896 },
#else
    { 0, 0, output_896 },
#endif
    { 0 },
    &operand_data[1200],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtsfdi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_897 },
#else
    { 0, 0, output_897 },
#endif
    { 0 },
    &operand_data[1203],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtusfdi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_898 },
#else
    { 0, 0, output_898 },
#endif
    { 0 },
    &operand_data[1203],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtdfdi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_899 },
#else
    { 0, 0, output_899 },
#endif
    { 0 },
    &operand_data[1206],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6100 */
  {
    "*aarch64_fcvtudfdi2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_900 },
#else
    { 0, 0, output_900 },
#endif
    { 0 },
    &operand_data[1206],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6132 */
  {
    "*aarch64_fmahf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmadd\t%h0, %h2, %h3, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1209],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6132 */
  {
    "*aarch64_fmasf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmadd\t%s0, %s2, %s3, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6132 */
  {
    "*aarch64_fmadf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmadd\t%d0, %d2, %d3, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6151 */
  {
    "*aarch64_fnmahf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmsub\t%h0, %h2, %h3, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1209],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6151 */
  {
    "*aarch64_fnmasf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmsub\t%s0, %s2, %s3, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6151 */
  {
    "*aarch64_fnmadf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmsub\t%d0, %d2, %d3, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6171 */
  {
    "*aarch64_fmssf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmsub\t%s0, %s2, %s3, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6171 */
  {
    "*aarch64_fmsdf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmsub\t%d0, %d2, %d3, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6189 */
  {
    "*aarch64_fnmssf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmadd\t%s0, %s2, %s3, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6189 */
  {
    "*aarch64_fnmsdf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmadd\t%d0, %d2, %d3, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6200 */
  {
    "*aarch64_fnmaddsf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmadd\t%s0, %s2, %s3, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6200 */
  {
    "*aarch64_fnmadddf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmadd\t%d0, %d2, %d3, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6214 */
  {
    "extendsfdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvt\t%d0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendsfdf2 },
    &operand_data[1221],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6222 */
  {
    "extendhfsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvt\t%s0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendhfsf2 },
    &operand_data[1223],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6230 */
  {
    "extendhfdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvt\t%d0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendhfdf2 },
    &operand_data[1225],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6238 */
  {
    "truncdfsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvt\t%s0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncdfsf2 },
    &operand_data[1227],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6246 */
  {
    "truncsfhf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvt\t%h0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncsfhf2 },
    &operand_data[1229],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6254 */
  {
    "truncdfhf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvt\t%h0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncdfhf2 },
    &operand_data[1231],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6265 */
  {
    "fix_truncsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_919 },
#else
    { 0, output_919, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncsfsi2 },
    &operand_data[1233],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6265 */
  {
    "fixuns_truncsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_920 },
#else
    { 0, output_920, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncsfsi2 },
    &operand_data[1233],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6265 */
  {
    "fix_truncdfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_921 },
#else
    { 0, output_921, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncdfdi2 },
    &operand_data[1235],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6265 */
  {
    "fixuns_truncdfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_922 },
#else
    { 0, output_922, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncdfdi2 },
    &operand_data[1235],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6278 */
  {
    "fix_trunchfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_trunchfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6278 */
  {
    "fixuns_trunchfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_trunchfsi2 },
    &operand_data[1185],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6278 */
  {
    "fix_trunchfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_trunchfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6278 */
  {
    "fixuns_trunchfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%x0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_trunchfdi2 },
    &operand_data[1191],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6289 */
  {
    "fix_truncdfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncdfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6289 */
  {
    "fixuns_truncdfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncdfsi2 },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6289 */
  {
    "fix_truncsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncsfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6289 */
  {
    "fixuns_truncsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%x0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncsfdi2 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6297 */
  {
    "*fix_to_zero_extendsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1193],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6297 */
  {
    "*fix_to_zero_extenddfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1195],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6308 */
  {
    "*aarch64_scvtfsisf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_933 },
#else
    { 0, 0, output_933 },
#endif
    { 0 },
    &operand_data[1237],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6308 */
  {
    "*aarch64_ucvtfsisf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_934 },
#else
    { 0, 0, output_934 },
#endif
    { 0 },
    &operand_data[1237],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6308 */
  {
    "*aarch64_scvtfdidf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_935 },
#else
    { 0, 0, output_935 },
#endif
    { 0 },
    &operand_data[1240],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6308 */
  {
    "*aarch64_ucvtfdidf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_936 },
#else
    { 0, 0, output_936 },
#endif
    { 0 },
    &operand_data[1240],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6331 */
  {
    "*aarch64_scvtfdisf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_937 },
#else
    { 0, 0, output_937 },
#endif
    { 0 },
    &operand_data[1243],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6331 */
  {
    "*aarch64_ucvtfdisf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_938 },
#else
    { 0, 0, output_938 },
#endif
    { 0 },
    &operand_data[1243],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6331 */
  {
    "*aarch64_scvtfsidf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_939 },
#else
    { 0, 0, output_939 },
#endif
    { 0 },
    &operand_data[1246],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6331 */
  {
    "*aarch64_ucvtfsidf2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_940 },
#else
    { 0, 0, output_940 },
#endif
    { 0 },
    &operand_data[1246],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6345 */
  {
    "floatsisf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_941 },
#else
    { 0, output_941, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatsisf2 },
    &operand_data[1237],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6345 */
  {
    "floatunssisf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_942 },
#else
    { 0, output_942, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunssisf2 },
    &operand_data[1237],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6345 */
  {
    "floatdidf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_943 },
#else
    { 0, output_943, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatdidf2 },
    &operand_data[1240],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6345 */
  {
    "floatunsdidf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_944 },
#else
    { 0, output_944, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsdidf2 },
    &operand_data[1240],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6357 */
  {
    "floatdisf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%s0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatdisf2 },
    &operand_data[1243],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6357 */
  {
    "floatunsdisf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%s0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsdisf2 },
    &operand_data[1243],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6357 */
  {
    "floatsidf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%d0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatsidf2 },
    &operand_data[1246],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6357 */
  {
    "floatunssidf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%d0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunssidf2 },
    &operand_data[1246],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6372 */
  {
    "aarch64_fp16_floatsihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%h0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fp16_floatsihf2 },
    &operand_data[1249],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6372 */
  {
    "aarch64_fp16_floatunssihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%h0, %w1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fp16_floatunssihf2 },
    &operand_data[1249],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6372 */
  {
    "aarch64_fp16_floatdihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%h0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fp16_floatdihf2 },
    &operand_data[1251],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6372 */
  {
    "aarch64_fp16_floatunsdihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%h0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fp16_floatunsdihf2 },
    &operand_data[1251],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6429 */
  {
    "fcvtzssf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_953 },
#else
    { 0, output_953, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzssf3 },
    &operand_data[1253],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6429 */
  {
    "fcvtzusf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_954 },
#else
    { 0, output_954, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzusf3 },
    &operand_data[1253],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6429 */
  {
    "fcvtzsdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_955 },
#else
    { 0, output_955, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzsdf3 },
    &operand_data[1256],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6429 */
  {
    "fcvtzudf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_956 },
#else
    { 0, output_956, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzudf3 },
    &operand_data[1256],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6442 */
  {
    "scvtfsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_957 },
#else
    { 0, output_957, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfsi3 },
    &operand_data[1259],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6442 */
  {
    "ucvtfsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_958 },
#else
    { 0, output_958, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfsi3 },
    &operand_data[1259],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6442 */
  {
    "scvtfdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_959 },
#else
    { 0, output_959, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfdi3 },
    &operand_data[1262],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6442 */
  {
    "ucvtfdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_960 },
#else
    { 0, output_960, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfdi3 },
    &operand_data[1262],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6455 */
  {
    "fcvtzshfsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%w0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzshfsi3 },
    &operand_data[1265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6455 */
  {
    "fcvtzuhfsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%w0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuhfsi3 },
    &operand_data[1265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6455 */
  {
    "fcvtzshfdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%x0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzshfdi3 },
    &operand_data[1268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6455 */
  {
    "fcvtzuhfdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%x0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuhfdi3 },
    &operand_data[1268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6465 */
  {
    "scvtfsihf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%h0, %w1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfsihf3 },
    &operand_data[1271],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6465 */
  {
    "ucvtfsihf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%h0, %w1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfsihf3 },
    &operand_data[1271],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6465 */
  {
    "scvtfdihf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%h0, %x1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfdihf3 },
    &operand_data[1274],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6465 */
  {
    "ucvtfdihf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%h0, %x1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfdihf3 },
    &operand_data[1274],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6475 */
  {
    "fcvtzshf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%h0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzshf3 },
    &operand_data[1277],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6475 */
  {
    "fcvtzuhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%h0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuhf3 },
    &operand_data[1277],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6485 */
  {
    "scvtfhi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%h0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfhi3 },
    &operand_data[1280],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6485 */
  {
    "ucvtfhi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%h0, %h1, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfhi3 },
    &operand_data[1280],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6499 */
  {
    "addhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6499 */
  {
    "addsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6499 */
  {
    "adddf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6509 */
  {
    "subhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6509 */
  {
    "subsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6509 */
  {
    "subdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6519 */
  {
    "mulhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6519 */
  {
    "mulsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6519 */
  {
    "muldf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_muldf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6529 */
  {
    "*fnmulsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmul\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6529 */
  {
    "*fnmuldf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmul\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6539 */
  {
    "*fnmulsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmul\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6539 */
  {
    "*fnmuldf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fnmul\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6561 */
  {
    "*divhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6561 */
  {
    "*divsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6561 */
  {
    "*divdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6570 */
  {
    "neghf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_neghf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6570 */
  {
    "negsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negsf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6570 */
  {
    "negdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negdf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6587 */
  {
    "*sqrthf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6587 */
  {
    "*sqrtsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6587 */
  {
    "*sqrtdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6595 */
  {
    "abshf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_abshf2 },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6595 */
  {
    "abssf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_abssf2 },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6595 */
  {
    "absdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absdf2 },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6607 */
  {
    "smaxsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6607 */
  {
    "smaxdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxdf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6616 */
  {
    "sminsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6616 */
  {
    "smindf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smindf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmax_nanhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmin_nanhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmaxhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fminhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmax_nansf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nansf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmin_nansf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nansf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmaxsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fminsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmax_nandf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nandf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmin_nandf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nandf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmaxdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxdf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6628 */
  {
    "fmindf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmindf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6682 */
  {
    "copysignsf3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1014 },
#else
    { 0, output_1014, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignsf3_insn },
    &operand_data[1283],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6682 */
  {
    "copysigndf3_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1015 },
#else
    { 0, output_1015, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysigndf3_insn },
    &operand_data[1287],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6785 */
  {
    "aarch64_movdi_tilow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movdi_tilow },
    &operand_data[1291],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6785 */
  {
    "aarch64_movdi_tflow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%x0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movdi_tflow },
    &operand_data[1293],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6795 */
  {
    "aarch64_movdi_tihigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%x0, %1.d[1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movdi_tihigh },
    &operand_data[1291],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6795 */
  {
    "aarch64_movdi_tfhigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%x0, %1.d[1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movdi_tfhigh },
    &operand_data[1293],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6805 */
  {
    "aarch64_movtihigh_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%0.d[1], %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movtihigh_di },
    &operand_data[1295],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6805 */
  {
    "aarch64_movtfhigh_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%0.d[1], %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movtfhigh_di },
    &operand_data[1297],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6815 */
  {
    "aarch64_movtilow_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%d0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movtilow_di },
    &operand_data[1299],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6815 */
  {
    "aarch64_movtflow_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%d0, %x1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movtflow_di },
    &operand_data[1301],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6824 */
  {
    "aarch64_movtilow_tilow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmov\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_movtilow_tilow },
    &operand_data[1303],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6855 */
  {
    "add_losym_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w1, :lo12:%c2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_add_losym_si },
    &operand_data[1305],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6855 */
  {
    "add_losym_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x1, :lo12:%c2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_add_losym_di },
    &operand_data[1308],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6864 */
  {
    "ldr_got_small_28k_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w0, [%1, #:gotpage_lo14:%c2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ldr_got_small_28k_si },
    &operand_data[1311],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6864 */
  {
    "ldr_got_small_28k_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%x0, [%1, #:gotpage_lo15:%c2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ldr_got_small_28k_di },
    &operand_data[1314],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6875 */
  {
    "ldr_got_small_28k_sidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w0, [%1, #:gotpage_lo14:%c2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ldr_got_small_28k_sidi },
    &operand_data[1314],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6887 */
  {
    "ldr_got_tiny_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w0, %L1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ldr_got_tiny_si },
    &operand_data[1317],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6887 */
  {
    "ldr_got_tiny_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%x0, %L1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ldr_got_tiny_di },
    &operand_data[1319],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6896 */
  {
    "ldr_got_tiny_sidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w0, %L1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ldr_got_tiny_sidi },
    &operand_data[1319],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6906 */
  {
    "aarch64_load_tp_hard",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mrs\t%0, tpidr_el0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_tp_hard },
    &operand_data[94],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6928 */
  {
    "*tlsgd_small_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\tx0, %A1\n\tadd\tx0, x0, %L1\n\tbl\t%2\n\tnop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1321],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6928 */
  {
    "*tlsgd_small_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\tx0, %A1\n\tadd\tx0, x0, %L1\n\tbl\t%2\n\tnop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1324],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6940 */
  {
    "tlsie_small_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\t%0, %A1\n\tldr\t%w0, [%0, #%L1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsie_small_si },
    &operand_data[1327],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6940 */
  {
    "tlsie_small_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\t%0, %A1\n\tldr\t%x0, [%0, #%L1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsie_small_di },
    &operand_data[1329],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6950 */
  {
    "tlsie_small_sidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\t%0, %A1\n\tldr\t%w0, [%0, #%L1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsie_small_sidi },
    &operand_data[1329],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6961 */
  {
    "tlsie_tiny_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w0, %L1\n\tadd\t%w0, %w0, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsie_tiny_si },
    &operand_data[1331],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6961 */
  {
    "tlsie_tiny_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%x0, %L1\n\tadd\t%x0, %x0, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsie_tiny_di },
    &operand_data[1334],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6972 */
  {
    "tlsie_tiny_sidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w0, %L1\n\tadd\t%w0, %w0, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsie_tiny_sidi },
    &operand_data[1334],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6985 */
  {
    "tlsle12_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w1, #%L2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle12_si },
    &operand_data[1337],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6985 */
  {
    "tlsle12_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x1, #%L2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle12_di },
    &operand_data[1340],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6996 */
  {
    "tlsle24_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%w0, %w1, #%G2, lsl #12\n\tadd\t%w0, %w0, #%L2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle24_si },
    &operand_data[1337],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6996 */
  {
    "tlsle24_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%x0, %x1, #%G2, lsl #12\n\tadd\t%x0, %x0, #%L2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle24_di },
    &operand_data[1340],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7007 */
  {
    "tlsle32_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "movz\t%w0, #:tprel_g1:%1\n\tmovk\t%w0, #:tprel_g0_nc:%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle32_si },
    &operand_data[1343],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7007 */
  {
    "tlsle32_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "movz\t%x0, #:tprel_g1:%1\n\tmovk\t%x0, #:tprel_g0_nc:%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle32_di },
    &operand_data[1345],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7017 */
  {
    "tlsle48_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "movz\t%w0, #:tprel_g2:%1\n\tmovk\t%w0, #:tprel_g1_nc:%1\n\tmovk\t%w0, #:tprel_g0_nc:%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle48_si },
    &operand_data[1343],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7017 */
  {
    "tlsle48_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "movz\t%x0, #:tprel_g2:%1\n\tmovk\t%x0, #:tprel_g1_nc:%1\n\tmovk\t%x0, #:tprel_g0_nc:%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsle48_di },
    &operand_data[1345],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7046 */
  {
    "tlsdesc_small_advsimd_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\tx0, %A0\n\tldr\t%w1, [x0, #%L0]\n\tadd\tw0, w0, %L0\n\t.tlsdesccall\t%0\n\tblr\t%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsdesc_small_advsimd_si },
    &operand_data[1347],
    1,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7046 */
  {
    "tlsdesc_small_advsimd_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\tx0, %A0\n\tldr\t%x1, [x0, #%L0]\n\tadd\tx0, x0, %L0\n\t.tlsdesccall\t%0\n\tblr\t%1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsdesc_small_advsimd_di },
    &operand_data[1347],
    1,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7062 */
  {
    "tlsdesc_small_sve_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\tx0, %A0\n\tldr\tw30, [x0, #%L0]\n\tadd\tw0, w0, %L0\n\t.tlsdesccall\t%0\n\tblr\tx30",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsdesc_small_sve_si },
    &operand_data[1349],
    2,
    2,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7062 */
  {
    "tlsdesc_small_sve_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adrp\tx0, %A0\n\tldr\tx30, [x0, #%L0]\n\tadd\tx0, x0, %L0\n\t.tlsdesccall\t%0\n\tblr\tx30",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsdesc_small_sve_di },
    &operand_data[1349],
    2,
    2,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7075 */
  {
    "stack_tie",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_tie },
    &operand_data[1351],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7085 */
  {
    "aarch64_fjcvtzs",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fjcvtzs\t%w0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fjcvtzs },
    &operand_data[1189],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7104 */
  {
    "paciasp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t25 // paciasp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_paciasp },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7104 */
  {
    "autiasp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t29 // autiasp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_autiasp },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7104 */
  {
    "pacibsp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t27 // pacibsp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_pacibsp },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7104 */
  {
    "autibsp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t31 // autibsp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_autibsp },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7113 */
  {
    "pacia1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t8 // pacia1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_pacia1716 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7113 */
  {
    "autia1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t12 // autia1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_autia1716 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7113 */
  {
    "pacib1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t10 // pacib1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_pacib1716 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7113 */
  {
    "autib1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t14 // autib1716",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_autib1716 },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7122 */
  {
    "xpaclri",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t7 // xpaclri",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xpaclri },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7141 */
  {
    "blockage",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_blockage },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7149 */
  {
    "probe_stack_range",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1066 },
#else
    { 0, 0, output_1066 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_probe_stack_range },
    &operand_data[1353],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7165 */
  {
    "probe_sve_stack_clash_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1067 },
#else
    { 0, 0, output_1067 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_probe_sve_stack_clash_si },
    &operand_data[1356],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7165 */
  {
    "probe_sve_stack_clash_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1068 },
#else
    { 0, 0, output_1068 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_probe_sve_stack_clash_di },
    &operand_data[1361],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7218 */
  {
    "reg_stack_protect_address_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1069 },
#else
    { 0, 0, output_1069 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reg_stack_protect_address_si },
    &operand_data[1366],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7218 */
  {
    "reg_stack_protect_address_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1070 },
#else
    { 0, 0, output_1070 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reg_stack_protect_address_di },
    &operand_data[1368],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7234 */
  {
    "stack_protect_set_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w2, %1\n\tstr\t%w2, %0\n\tmov\t%w2, 0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_set_si },
    &operand_data[1370],
    2,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7234 */
  {
    "stack_protect_set_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%x2, %1\n\tstr\t%x2, %0\n\tmov\t%x2, 0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_set_di },
    &operand_data[1373],
    2,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7279 */
  {
    "stack_protect_test_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%w2, %0\n\tldr\t%w3, %1\n\tsubs\t%w2, %w2, %w3\n\tmov\t%3, 0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_test_si },
    &operand_data[1376],
    2,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7279 */
  {
    "stack_protect_test_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%x2, %0\n\tldr\t%x3, %1\n\tsubs\t%x2, %x2, %x3\n\tmov\t%3, 0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_test_di },
    &operand_data[1380],
    2,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7292 */
  {
    "aarch64_set_fpsrsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "msr\tfpsr, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_set_fpsrsi },
    &operand_data[42],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7292 */
  {
    "aarch64_set_fpcrsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "msr\tfpcr, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_set_fpcrsi },
    &operand_data[42],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7292 */
  {
    "aarch64_set_fpsrdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "msr\tfpsr, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_set_fpsrdi },
    &operand_data[1],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7292 */
  {
    "aarch64_set_fpcrdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "msr\tfpcr, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_set_fpcrdi },
    &operand_data[1],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7299 */
  {
    "aarch64_get_fpsrsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mrs\t%0, fpsr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_fpsrsi },
    &operand_data[90],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7299 */
  {
    "aarch64_get_fpcrsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mrs\t%0, fpcr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_fpcrsi },
    &operand_data[90],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7299 */
  {
    "aarch64_get_fpsrdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mrs\t%0, fpsr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_fpsrdi },
    &operand_data[94],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7299 */
  {
    "aarch64_get_fpcrdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mrs\t%0, fpcr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_fpcrdi },
    &operand_data[94],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7345 */
  {
    "speculation_tracker",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1083 },
#else
    { 0, 0, output_1083 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_speculation_tracker },
    &operand_data[2],
    1,
    1,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7359 */
  {
    "speculation_tracker_rev",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1084 },
#else
    { 0, 0, output_1084 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_speculation_tracker_rev },
    &operand_data[2],
    1,
    1,
    0,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7373 */
  {
    "bti_noarg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t32 // bti",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bti_noarg },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7380 */
  {
    "bti_c",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t34 // bti c",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bti_c },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7387 */
  {
    "bti_j",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t36 // bti j",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bti_j },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7394 */
  {
    "bti_jc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "hint\t38 // bti jc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bti_jc },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7402 */
  {
    "speculation_barrier",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "isb\n\tdsb\tsy",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_speculation_barrier },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7442 */
  {
    "*despeculate_copyqi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1090 },
#else
    { 0, 0, output_1090 },
#endif
    { 0 },
    &operand_data[1384],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7442 */
  {
    "*despeculate_copyhi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1091 },
#else
    { 0, 0, output_1091 },
#endif
    { 0 },
    &operand_data[1387],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7442 */
  {
    "*despeculate_copysi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1092 },
#else
    { 0, 0, output_1092 },
#endif
    { 0 },
    &operand_data[1390],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7442 */
  {
    "*despeculate_copydi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1093 },
#else
    { 0, 0, output_1093 },
#endif
    { 0 },
    &operand_data[1393],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7462 */
  {
    "*despeculate_copyti_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1094 },
#else
    { 0, 0, output_1094 },
#endif
    { 0 },
    &operand_data[1396],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7482 */
  {
    "despeculate_simpleqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w1, %w2\n\thint\t0x14 // csdb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_simpleqi },
    &operand_data[1399],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7482 */
  {
    "despeculate_simplehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w1, %w2\n\thint\t0x14 // csdb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_simplehi },
    &operand_data[1402],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7482 */
  {
    "despeculate_simplesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%w0, %w1, %w2\n\thint\t0x14 // csdb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_simplesi },
    &operand_data[1405],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7482 */
  {
    "despeculate_simpledi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%x0, %x1, %x2\n\thint\t0x14 // csdb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_simpledi },
    &operand_data[1408],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7495 */
  {
    "despeculate_simpleti",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0, %1, %2\n\tand\t%H0, %H1, %2\n\thint\t0x14 // csdb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_simpleti },
    &operand_data[1411],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32zv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32z\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32zv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32xv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32x\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32xv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64zv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64z\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64zv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64xv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64x\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64xv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32zv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32z\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32zv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32xv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32x\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32xv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64zv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64z\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64zv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64xv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64x\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64xv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32zv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32z\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32zv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32xv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32x\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32xv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64zv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64z\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64zv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64xv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64x\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64xv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32zdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32z\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32zdf },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32xdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32x\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32xdf },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64zdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64z\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64zdf },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64xdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64x\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64xdf },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32zsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32z\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32zsf },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint32xsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint32x\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint32xsf },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64zsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64z\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64zsf },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7508 */
  {
    "aarch64_frint64xsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frint64x\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frint64xsf },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7520 */
  {
    "tstart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tstart\t%0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tstart },
    &operand_data[94],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7529 */
  {
    "ttest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ttest\t%0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ttest },
    &operand_data[94],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7538 */
  {
    "tcommit",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tcommit",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tcommit },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7546 */
  {
    "tcancel",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tcancel\t#%0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tcancel },
    &operand_data[615],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7555 */
  {
    "aarch64_rndr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mrs\t%0, RNDR",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rndr },
    &operand_data[94],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7565 */
  {
    "aarch64_rndrrs",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mrs\t%0, RNDRRS",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rndrrs },
    &operand_data[94],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7577 */
  {
    "irg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "irg\t%0, %1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_irg },
    &operand_data[1420],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7590 */
  {
    "gmi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "gmi\t%0, %1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gmi },
    &operand_data[410],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7603 */
  {
    "addg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addg\t%0, %1, #%2, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addg },
    &operand_data[1423],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7620 */
  {
    "subp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subp\t%0, %1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subp },
    &operand_data[1427],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7633 */
  {
    "ldg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldg\t%0, [%1, #%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ldg },
    &operand_data[1430],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7650 */
  {
    "stg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stg\t%0, [%1, #%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stg },
    &operand_data[1433],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7663 */
  {
    "ld64b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld64b\t%0, [%1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ld64b },
    &operand_data[1436],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7674 */
  {
    "st64b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st64b\t%1, [%0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_st64b },
    &operand_data[1438],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7684 */
  {
    "st64bv",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st64bv\t%0, %2, [%1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_st64bv },
    &operand_data[1440],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7696 */
  {
    "st64bv0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st64bv0\t%0, %2, [%1]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_st64bv0 },
    &operand_data[1440],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:65 */
  {
    "aarch64_simd_dupv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1136 },
#else
    { 0, output_1136, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv8qi },
    &operand_data[1443],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:65 */
  {
    "aarch64_simd_dupv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1137 },
#else
    { 0, output_1137, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv16qi },
    &operand_data[1445],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:65 */
  {
    "aarch64_simd_dupv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1138 },
#else
    { 0, output_1138, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv4hi },
    &operand_data[1447],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:65 */
  {
    "aarch64_simd_dupv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1139 },
#else
    { 0, output_1139, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv8hi },
    &operand_data[1449],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:65 */
  {
    "aarch64_simd_dupv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1140 },
#else
    { 0, output_1140, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv2si },
    &operand_data[1451],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:65 */
  {
    "aarch64_simd_dupv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1141 },
#else
    { 0, output_1141, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv4si },
    &operand_data[1453],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:65 */
  {
    "aarch64_simd_dupv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1142 },
#else
    { 0, output_1142, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv2di },
    &operand_data[1455],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:76 */
  {
    "aarch64_simd_dupv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1143 },
#else
    { 0, output_1143, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv4hf },
    &operand_data[1457],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:76 */
  {
    "aarch64_simd_dupv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1144 },
#else
    { 0, output_1144, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv8hf },
    &operand_data[1459],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:76 */
  {
    "aarch64_simd_dupv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1145 },
#else
    { 0, output_1145, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv2sf },
    &operand_data[1461],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:76 */
  {
    "aarch64_simd_dupv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1146 },
#else
    { 0, output_1146, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv4sf },
    &operand_data[1463],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:76 */
  {
    "aarch64_simd_dupv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1147 },
#else
    { 0, output_1147, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv2df },
    &operand_data[1465],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:76 */
  {
    "aarch64_simd_dupv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1148 },
#else
    { 0, output_1148, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv4bf },
    &operand_data[1467],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:76 */
  {
    "aarch64_simd_dupv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1149 },
#else
    { 0, output_1149, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_dupv8bf },
    &operand_data[1469],
    2,
    2,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1150 },
#else
    { 0, 0, output_1150 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev8qi },
    &operand_data[1471],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1151 },
#else
    { 0, 0, output_1151 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev16qi },
    &operand_data[1474],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1152 },
#else
    { 0, 0, output_1152 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev4hi },
    &operand_data[1477],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1153 },
#else
    { 0, 0, output_1153 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev8hi },
    &operand_data[1480],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1154 },
#else
    { 0, 0, output_1154 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev2si },
    &operand_data[1483],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1155 },
#else
    { 0, 0, output_1155 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev4si },
    &operand_data[1486],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1156 },
#else
    { 0, 0, output_1156 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev2di },
    &operand_data[1489],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1157 },
#else
    { 0, 0, output_1157 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev4hf },
    &operand_data[1492],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1158 },
#else
    { 0, 0, output_1158 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev8hf },
    &operand_data[1495],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1159 },
#else
    { 0, 0, output_1159 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev4bf },
    &operand_data[1498],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1160 },
#else
    { 0, 0, output_1160 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev8bf },
    &operand_data[1501],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1161 },
#else
    { 0, 0, output_1161 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev2sf },
    &operand_data[1504],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1162 },
#else
    { 0, 0, output_1162 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev4sf },
    &operand_data[1507],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:87 */
  {
    "aarch64_dup_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1163 },
#else
    { 0, 0, output_1163 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lanev2df },
    &operand_data[1510],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_128v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1164 },
#else
    { 0, 0, output_1164 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_128v8qi },
    &operand_data[1513],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_64v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1165 },
#else
    { 0, 0, output_1165 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_64v16qi },
    &operand_data[1516],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_128v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1166 },
#else
    { 0, 0, output_1166 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_128v4hi },
    &operand_data[1519],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_64v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1167 },
#else
    { 0, 0, output_1167 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_64v8hi },
    &operand_data[1522],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_128v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1168 },
#else
    { 0, 0, output_1168 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_128v2si },
    &operand_data[1525],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_64v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1169 },
#else
    { 0, 0, output_1169 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_64v4si },
    &operand_data[1528],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_128v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1170 },
#else
    { 0, 0, output_1170 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_128v4hf },
    &operand_data[1531],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_64v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1171 },
#else
    { 0, 0, output_1171 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_64v8hf },
    &operand_data[1534],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_128v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1172 },
#else
    { 0, 0, output_1172 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_128v2sf },
    &operand_data[1537],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:102 */
  {
    "aarch64_dup_lane_to_64v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1173 },
#else
    { 0, 0, output_1173 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_dup_lane_to_64v4sf },
    &operand_data[1540],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:117 */
  {
    "*aarch64_simd_movv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1174 },
#else
    { 0, 0, output_1174 },
#endif
    { 0 },
    &operand_data[1543],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:117 */
  {
    "*aarch64_simd_movv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1175 },
#else
    { 0, 0, output_1175 },
#endif
    { 0 },
    &operand_data[1545],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:117 */
  {
    "*aarch64_simd_movv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1176 },
#else
    { 0, 0, output_1176 },
#endif
    { 0 },
    &operand_data[1547],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:117 */
  {
    "*aarch64_simd_movv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1177 },
#else
    { 0, 0, output_1177 },
#endif
    { 0 },
    &operand_data[1549],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:117 */
  {
    "*aarch64_simd_movv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1178 },
#else
    { 0, 0, output_1178 },
#endif
    { 0 },
    &operand_data[1551],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:117 */
  {
    "*aarch64_simd_movv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1179 },
#else
    { 0, 0, output_1179 },
#endif
    { 0 },
    &operand_data[1553],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1180 },
#else
    { 0, 0, output_1180 },
#endif
    { 0 },
    &operand_data[1555],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1181 },
#else
    { 0, 0, output_1181 },
#endif
    { 0 },
    &operand_data[1557],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1182 },
#else
    { 0, 0, output_1182 },
#endif
    { 0 },
    &operand_data[1559],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1183 },
#else
    { 0, 0, output_1183 },
#endif
    { 0 },
    &operand_data[1561],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1184 },
#else
    { 0, 0, output_1184 },
#endif
    { 0 },
    &operand_data[1563],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1185 },
#else
    { 0, 0, output_1185 },
#endif
    { 0 },
    &operand_data[1565],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1186 },
#else
    { 0, 0, output_1186 },
#endif
    { 0 },
    &operand_data[1567],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:145 */
  {
    "*aarch64_simd_movv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1187 },
#else
    { 0, 0, output_1187 },
#endif
    { 0 },
    &operand_data[1569],
    2,
    2,
    0,
    8,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%b1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v8qi },
    &operand_data[1571],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%b1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v16qi },
    &operand_data[1574],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%h1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v4hi },
    &operand_data[1577],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%h1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v8hi },
    &operand_data[1580],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%s1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v2si },
    &operand_data[1583],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%s1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v4si },
    &operand_data[1586],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%d1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v2di },
    &operand_data[1589],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%h1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v4hf },
    &operand_data[1592],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%h1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v8hf },
    &operand_data[1595],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%h1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v4bf },
    &operand_data[1598],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%h1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v8bf },
    &operand_data[1601],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%s1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v2sf },
    &operand_data[1604],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%s1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v4sf },
    &operand_data[1607],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:183 */
  {
    "aarch64_store_lane0v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "str\t%d1, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_lane0v2df },
    &operand_data[1610],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv8qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8qiv8qi },
    &operand_data[1613],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hiv8qi },
    &operand_data[1617],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hfv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hfv8qi },
    &operand_data[1621],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2siv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2siv8qi },
    &operand_data[1625],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2sfv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2sfv8qi },
    &operand_data[1629],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairdfv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairdfv8qi },
    &operand_data[1633],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv8qiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8qiv4hi },
    &operand_data[1637],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hiv4hi },
    &operand_data[1641],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hfv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hfv4hi },
    &operand_data[1645],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2siv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2siv4hi },
    &operand_data[1649],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2sfv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2sfv4hi },
    &operand_data[1653],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairdfv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairdfv4hi },
    &operand_data[1657],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv8qiv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8qiv4hf },
    &operand_data[1661],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hiv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hiv4hf },
    &operand_data[1665],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hfv4hf },
    &operand_data[1669],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2siv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2siv4hf },
    &operand_data[1673],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2sfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2sfv4hf },
    &operand_data[1677],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairdfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairdfv4hf },
    &operand_data[1681],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv8qiv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8qiv2si },
    &operand_data[1685],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hiv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hiv2si },
    &operand_data[1689],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hfv2si },
    &operand_data[1693],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2siv2si },
    &operand_data[1697],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2sfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2sfv2si },
    &operand_data[1701],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairdfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairdfv2si },
    &operand_data[1705],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv8qiv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8qiv2sf },
    &operand_data[1709],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hiv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hiv2sf },
    &operand_data[1713],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hfv2sf },
    &operand_data[1717],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2siv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2siv2sf },
    &operand_data[1721],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2sfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2sfv2sf },
    &operand_data[1725],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairdfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairdfv2sf },
    &operand_data[1729],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv8qidf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8qidf },
    &operand_data[1733],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hidf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hidf },
    &operand_data[1737],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv4hfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4hfdf },
    &operand_data[1741],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2sidf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2sidf },
    &operand_data[1745],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairv2sfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2sfdf },
    &operand_data[1749],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:193 */
  {
    "load_pairdfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%d0, %d2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairdfdf },
    &operand_data[1753],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv8qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8qiv8qi },
    &operand_data[1757],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hiv8qi },
    &operand_data[1761],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hfv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hfv8qi },
    &operand_data[1765],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2siv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2siv8qi },
    &operand_data[1769],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2sfv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2sfv8qi },
    &operand_data[1773],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairdfv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairdfv8qi },
    &operand_data[1777],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv8qiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8qiv4hi },
    &operand_data[1781],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hiv4hi },
    &operand_data[1785],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hfv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hfv4hi },
    &operand_data[1789],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2siv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2siv4hi },
    &operand_data[1793],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2sfv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2sfv4hi },
    &operand_data[1797],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairdfv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairdfv4hi },
    &operand_data[1801],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv8qiv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8qiv4hf },
    &operand_data[1805],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hiv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hiv4hf },
    &operand_data[1809],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hfv4hf },
    &operand_data[1813],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2siv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2siv4hf },
    &operand_data[1817],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2sfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2sfv4hf },
    &operand_data[1821],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairdfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairdfv4hf },
    &operand_data[1825],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv8qiv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8qiv2si },
    &operand_data[1829],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hiv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hiv2si },
    &operand_data[1833],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hfv2si },
    &operand_data[1837],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2siv2si },
    &operand_data[1841],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2sfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2sfv2si },
    &operand_data[1845],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairdfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairdfv2si },
    &operand_data[1849],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv8qiv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8qiv2sf },
    &operand_data[1853],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hiv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hiv2sf },
    &operand_data[1857],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hfv2sf },
    &operand_data[1861],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2siv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2siv2sf },
    &operand_data[1865],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2sfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2sfv2sf },
    &operand_data[1869],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairdfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairdfv2sf },
    &operand_data[1873],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv8qidf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8qidf },
    &operand_data[1877],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hidf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hidf },
    &operand_data[1881],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv4hfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4hfdf },
    &operand_data[1885],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2sidf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2sidf },
    &operand_data[1889],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairv2sfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2sfdf },
    &operand_data[1893],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:207 */
  {
    "vec_store_pairdfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%d1, %d3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairdfdf },
    &operand_data[1897],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv16qi },
    &operand_data[1901],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv8hi },
    &operand_data[1905],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv4si },
    &operand_data[1909],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv2di },
    &operand_data[1913],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv8hf },
    &operand_data[1917],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv8bf },
    &operand_data[1921],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv4sf },
    &operand_data[1925],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv16qiv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv16qiv2df },
    &operand_data[1929],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv16qi },
    &operand_data[1933],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv8hi },
    &operand_data[1937],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv4si },
    &operand_data[1941],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv2di },
    &operand_data[1945],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv8hf },
    &operand_data[1949],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv8bf },
    &operand_data[1953],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv4sf },
    &operand_data[1957],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hiv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hiv2df },
    &operand_data[1961],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv16qi },
    &operand_data[1965],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv8hi },
    &operand_data[1969],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv4si },
    &operand_data[1973],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv2di },
    &operand_data[1977],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv8hf },
    &operand_data[1981],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv8bf },
    &operand_data[1985],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv4sf },
    &operand_data[1989],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4siv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4siv2df },
    &operand_data[1993],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div16qi },
    &operand_data[1997],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div8hi },
    &operand_data[2001],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div4si },
    &operand_data[2005],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div2di },
    &operand_data[2009],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div8hf },
    &operand_data[2013],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div8bf },
    &operand_data[2017],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div4sf },
    &operand_data[2021],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2div2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2div2df },
    &operand_data[2025],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv16qi },
    &operand_data[2029],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv8hi },
    &operand_data[2033],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv4si },
    &operand_data[2037],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv2di },
    &operand_data[2041],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv8hf },
    &operand_data[2045],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv8bf },
    &operand_data[2049],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv4sf },
    &operand_data[2053],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8hfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8hfv2df },
    &operand_data[2057],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv16qi },
    &operand_data[2061],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv8hi },
    &operand_data[2065],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv4si },
    &operand_data[2069],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv2di },
    &operand_data[2073],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv8hf },
    &operand_data[2077],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv8bf },
    &operand_data[2081],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv4sf },
    &operand_data[2085],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv4sfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv4sfv2df },
    &operand_data[2089],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv16qi },
    &operand_data[2093],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv8hi },
    &operand_data[2097],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv4si },
    &operand_data[2101],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv2di },
    &operand_data[2105],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv8hf },
    &operand_data[2109],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv8bf },
    &operand_data[2113],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv4sf },
    &operand_data[2117],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv2dfv2df },
    &operand_data[2121],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv16qi },
    &operand_data[2125],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv8hi },
    &operand_data[2129],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv4si },
    &operand_data[2133],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv2di },
    &operand_data[2137],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv8hf },
    &operand_data[2141],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv8bf },
    &operand_data[2145],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv4sf },
    &operand_data[2149],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:221 */
  {
    "load_pairv8bfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldp\t%q0, %q2, %z1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pairv8bfv2df },
    &operand_data[2153],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv16qi },
    &operand_data[2157],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv8hi },
    &operand_data[2161],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv4si },
    &operand_data[2165],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv2di },
    &operand_data[2169],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv8hf },
    &operand_data[2173],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv8bf },
    &operand_data[2177],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv4sf },
    &operand_data[2181],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv16qiv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv16qiv2df },
    &operand_data[2185],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv16qi },
    &operand_data[2189],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv8hi },
    &operand_data[2193],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv4si },
    &operand_data[2197],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv2di },
    &operand_data[2201],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv8hf },
    &operand_data[2205],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv8bf },
    &operand_data[2209],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv4sf },
    &operand_data[2213],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hiv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hiv2df },
    &operand_data[2217],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv16qi },
    &operand_data[2221],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv8hi },
    &operand_data[2225],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv4si },
    &operand_data[2229],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv2di },
    &operand_data[2233],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv8hf },
    &operand_data[2237],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv8bf },
    &operand_data[2241],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv4sf },
    &operand_data[2245],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4siv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4siv2df },
    &operand_data[2249],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div16qi },
    &operand_data[2253],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div8hi },
    &operand_data[2257],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div4si },
    &operand_data[2261],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div2di },
    &operand_data[2265],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div8hf },
    &operand_data[2269],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div8bf },
    &operand_data[2273],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div4sf },
    &operand_data[2277],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2div2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2div2df },
    &operand_data[2281],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv16qi },
    &operand_data[2285],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv8hi },
    &operand_data[2289],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv4si },
    &operand_data[2293],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv2di },
    &operand_data[2297],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv8hf },
    &operand_data[2301],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv8bf },
    &operand_data[2305],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv4sf },
    &operand_data[2309],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8hfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8hfv2df },
    &operand_data[2313],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv16qi },
    &operand_data[2317],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv8hi },
    &operand_data[2321],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv4si },
    &operand_data[2325],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv2di },
    &operand_data[2329],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv8hf },
    &operand_data[2333],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv8bf },
    &operand_data[2337],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv4sf },
    &operand_data[2341],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv4sfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv4sfv2df },
    &operand_data[2345],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv16qi },
    &operand_data[2349],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv8hi },
    &operand_data[2353],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv4si },
    &operand_data[2357],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv2di },
    &operand_data[2361],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv8hf },
    &operand_data[2365],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv8bf },
    &operand_data[2369],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv4sf },
    &operand_data[2373],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv2dfv2df },
    &operand_data[2377],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv16qi },
    &operand_data[2381],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv8hi },
    &operand_data[2385],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv4si },
    &operand_data[2389],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv2di },
    &operand_data[2393],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv8hf },
    &operand_data[2397],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv8bf },
    &operand_data[2401],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv4sf },
    &operand_data[2405],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:235 */
  {
    "vec_store_pairv8bfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stp\t%q1, %q3, %z0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_pairv8bfv2df },
    &operand_data[2409],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:334 */
  {
    "aarch64_simd_mov_from_v16qilow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1402 },
#else
    { 0, output_1402, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v16qilow },
    &operand_data[2413],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:334 */
  {
    "aarch64_simd_mov_from_v8hilow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1403 },
#else
    { 0, output_1403, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v8hilow },
    &operand_data[2416],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:334 */
  {
    "aarch64_simd_mov_from_v4silow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1404 },
#else
    { 0, output_1404, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v4silow },
    &operand_data[2419],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:334 */
  {
    "aarch64_simd_mov_from_v8hflow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1405 },
#else
    { 0, output_1405, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v8hflow },
    &operand_data[2422],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:334 */
  {
    "aarch64_simd_mov_from_v8bflow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1406 },
#else
    { 0, output_1406, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v8bflow },
    &operand_data[2425],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:334 */
  {
    "aarch64_simd_mov_from_v4sflow",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1407 },
#else
    { 0, output_1407, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v4sflow },
    &operand_data[2428],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:352 */
  {
    "aarch64_simd_mov_from_v16qihigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1408 },
#else
    { 0, output_1408, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v16qihigh },
    &operand_data[2431],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:352 */
  {
    "aarch64_simd_mov_from_v8hihigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1409 },
#else
    { 0, output_1409, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v8hihigh },
    &operand_data[2434],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:352 */
  {
    "aarch64_simd_mov_from_v4sihigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1410 },
#else
    { 0, output_1410, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v4sihigh },
    &operand_data[2437],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:352 */
  {
    "aarch64_simd_mov_from_v8hfhigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1411 },
#else
    { 0, output_1411, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v8hfhigh },
    &operand_data[2440],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:352 */
  {
    "aarch64_simd_mov_from_v8bfhigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1412 },
#else
    { 0, output_1412, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v8bfhigh },
    &operand_data[2443],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:352 */
  {
    "aarch64_simd_mov_from_v4sfhigh",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1413 },
#else
    { 0, output_1413, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_mov_from_v4sfhigh },
    &operand_data[2446],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:365 */
  {
    "ornv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ornv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:365 */
  {
    "ornv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ornv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:365 */
  {
    "ornv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ornv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:365 */
  {
    "ornv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ornv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:365 */
  {
    "ornv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ornv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:365 */
  {
    "ornv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ornv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:365 */
  {
    "ornv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ornv2di3 },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:374 */
  {
    "bicv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bicv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:374 */
  {
    "bicv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bicv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:374 */
  {
    "bicv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bicv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:374 */
  {
    "bicv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bicv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:374 */
  {
    "bicv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bicv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:374 */
  {
    "bicv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bicv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:374 */
  {
    "bicv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bicv2di3 },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:383 */
  {
    "addv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:383 */
  {
    "addv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:383 */
  {
    "addv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:383 */
  {
    "addv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:383 */
  {
    "addv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:383 */
  {
    "addv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:383 */
  {
    "addv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "add\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv2di3 },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:392 */
  {
    "subv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:392 */
  {
    "subv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:392 */
  {
    "subv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:392 */
  {
    "subv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:392 */
  {
    "subv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:392 */
  {
    "subv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:392 */
  {
    "subv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sub\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv2di3 },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:401 */
  {
    "mulv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:401 */
  {
    "mulv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:401 */
  {
    "mulv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:401 */
  {
    "mulv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:401 */
  {
    "mulv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:401 */
  {
    "mulv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:410 */
  {
    "bswapv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapv4hi2 },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:410 */
  {
    "bswapv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapv8hi2 },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:410 */
  {
    "bswapv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapv2si2 },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:410 */
  {
    "bswapv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapv4si2 },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:410 */
  {
    "bswapv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bswapv2di2 },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:418 */
  {
    "aarch64_rbitv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rbit\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rbitv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:418 */
  {
    "aarch64_rbitv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rbit\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rbitv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd90v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.4h, %1.4h, %2.4h, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd90v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd270v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.4h, %1.4h, %2.4h, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd270v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd90v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.8h, %1.8h, %2.8h, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd90v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd270v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.8h, %1.8h, %2.8h, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd270v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd90v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.2s, %1.2s, %2.2s, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd90v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd270v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.2s, %1.2s, %2.2s, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd270v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd90v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.4s, %1.4s, %2.4s, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd90v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd270v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.4s, %1.4s, %2.4s, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd270v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd90v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.2d, %1.2d, %2.2d, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd90v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:476 */
  {
    "aarch64_fcadd270v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcadd\t%0.2d, %1.2d, %2.2d, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcadd270v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla0v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4h, %2.4h, %3.4h, #0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla0v4hf },
    &operand_data[2485],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla90v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4h, %2.4h, %3.4h, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla90v4hf },
    &operand_data[2485],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla180v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4h, %2.4h, %3.4h, #180",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla180v4hf },
    &operand_data[2485],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla270v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4h, %2.4h, %3.4h, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla270v4hf },
    &operand_data[2485],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla0v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.8h, %2.8h, %3.8h, #0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla0v8hf },
    &operand_data[2489],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla90v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.8h, %2.8h, %3.8h, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla90v8hf },
    &operand_data[2489],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla180v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.8h, %2.8h, %3.8h, #180",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla180v8hf },
    &operand_data[2489],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla270v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.8h, %2.8h, %3.8h, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla270v8hf },
    &operand_data[2489],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla0v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2s, %2.2s, %3.2s, #0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla0v2sf },
    &operand_data[2493],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla90v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2s, %2.2s, %3.2s, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla90v2sf },
    &operand_data[2493],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla180v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2s, %2.2s, %3.2s, #180",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla180v2sf },
    &operand_data[2493],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla270v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2s, %2.2s, %3.2s, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla270v2sf },
    &operand_data[2493],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla0v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4s, %2.4s, %3.4s, #0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla0v4sf },
    &operand_data[2497],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla90v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4s, %2.4s, %3.4s, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla90v4sf },
    &operand_data[2497],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla180v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4s, %2.4s, %3.4s, #180",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla180v4sf },
    &operand_data[2497],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla270v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.4s, %2.4s, %3.4s, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla270v4sf },
    &operand_data[2497],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla0v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2d, %2.2d, %3.2d, #0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla0v2df },
    &operand_data[2501],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla90v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2d, %2.2d, %3.2d, #90",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla90v2df },
    &operand_data[2501],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla180v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2d, %2.2d, %3.2d, #180",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla180v2df },
    &operand_data[2501],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:494 */
  {
    "aarch64_fcmla270v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmla\t%0.2d, %2.2d, %3.2d, #270",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla270v2df },
    &operand_data[2501],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane0v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1485 },
#else
    { 0, 0, output_1485 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane0v4hf },
    &operand_data[2505],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane90v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1486 },
#else
    { 0, 0, output_1486 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane90v4hf },
    &operand_data[2505],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane180v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1487 },
#else
    { 0, 0, output_1487 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane180v4hf },
    &operand_data[2505],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane270v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1488 },
#else
    { 0, 0, output_1488 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane270v4hf },
    &operand_data[2505],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane0v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1489 },
#else
    { 0, 0, output_1489 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane0v8hf },
    &operand_data[2510],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane90v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1490 },
#else
    { 0, 0, output_1490 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane90v8hf },
    &operand_data[2510],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane180v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1491 },
#else
    { 0, 0, output_1491 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane180v8hf },
    &operand_data[2510],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane270v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1492 },
#else
    { 0, 0, output_1492 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane270v8hf },
    &operand_data[2510],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane0v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1493 },
#else
    { 0, 0, output_1493 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane0v2sf },
    &operand_data[2515],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane90v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1494 },
#else
    { 0, 0, output_1494 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane90v2sf },
    &operand_data[2515],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane180v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1495 },
#else
    { 0, 0, output_1495 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane180v2sf },
    &operand_data[2515],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane270v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1496 },
#else
    { 0, 0, output_1496 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane270v2sf },
    &operand_data[2515],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane0v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1497 },
#else
    { 0, 0, output_1497 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane0v4sf },
    &operand_data[2520],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane90v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1498 },
#else
    { 0, 0, output_1498 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane90v4sf },
    &operand_data[2520],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane180v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1499 },
#else
    { 0, 0, output_1499 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane180v4sf },
    &operand_data[2520],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane270v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1500 },
#else
    { 0, 0, output_1500 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane270v4sf },
    &operand_data[2520],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane0v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1501 },
#else
    { 0, 0, output_1501 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane0v2df },
    &operand_data[2525],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane90v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1502 },
#else
    { 0, 0, output_1502 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane90v2df },
    &operand_data[2525],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane180v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1503 },
#else
    { 0, 0, output_1503 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane180v2df },
    &operand_data[2525],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:506 */
  {
    "aarch64_fcmla_lane270v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1504 },
#else
    { 0, 0, output_1504 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane270v2df },
    &operand_data[2525],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:521 */
  {
    "aarch64_fcmla_laneq0v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1505 },
#else
    { 0, 0, output_1505 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_laneq0v4hf },
    &operand_data[2530],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:521 */
  {
    "aarch64_fcmla_laneq90v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1506 },
#else
    { 0, 0, output_1506 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_laneq90v4hf },
    &operand_data[2530],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:521 */
  {
    "aarch64_fcmla_laneq180v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1507 },
#else
    { 0, 0, output_1507 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_laneq180v4hf },
    &operand_data[2530],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:521 */
  {
    "aarch64_fcmla_laneq270v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1508 },
#else
    { 0, 0, output_1508 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_laneq270v4hf },
    &operand_data[2530],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane0v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1509 },
#else
    { 0, 0, output_1509 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane0v8hf },
    &operand_data[2535],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane90v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1510 },
#else
    { 0, 0, output_1510 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane90v8hf },
    &operand_data[2535],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane180v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1511 },
#else
    { 0, 0, output_1511 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane180v8hf },
    &operand_data[2535],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane270v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1512 },
#else
    { 0, 0, output_1512 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane270v8hf },
    &operand_data[2535],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane0v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1513 },
#else
    { 0, 0, output_1513 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane0v4sf },
    &operand_data[2540],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane90v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1514 },
#else
    { 0, 0, output_1514 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane90v4sf },
    &operand_data[2540],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane180v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1515 },
#else
    { 0, 0, output_1515 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane180v4sf },
    &operand_data[2540],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:536 */
  {
    "aarch64_fcmlaq_lane270v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1516 },
#else
    { 0, 0, output_1516 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmlaq_lane270v4sf },
    &operand_data[2540],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:612 */
  {
    "sdot_prodv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sdot\t%0.2s, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdot_prodv8qi },
    &operand_data[2545],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:612 */
  {
    "udot_prodv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "udot\t%0.2s, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udot_prodv8qi },
    &operand_data[2545],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:612 */
  {
    "sdot_prodv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sdot\t%0.4s, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdot_prodv16qi },
    &operand_data[2549],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:612 */
  {
    "udot_prodv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "udot\t%0.4s, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udot_prodv16qi },
    &operand_data[2549],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:626 */
  {
    "usdot_prodv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usdot\t%0.2s, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usdot_prodv8qi },
    &operand_data[2545],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:626 */
  {
    "usdot_prodv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usdot\t%0.4s, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usdot_prodv16qi },
    &operand_data[2549],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:640 */
  {
    "aarch64_sdot_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1523 },
#else
    { 0, 0, output_1523 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sdot_lanev8qi },
    &operand_data[2553],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:640 */
  {
    "aarch64_udot_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1524 },
#else
    { 0, 0, output_1524 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_udot_lanev8qi },
    &operand_data[2553],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:640 */
  {
    "aarch64_sdot_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1525 },
#else
    { 0, 0, output_1525 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sdot_lanev16qi },
    &operand_data[2558],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:640 */
  {
    "aarch64_udot_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1526 },
#else
    { 0, 0, output_1526 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_udot_lanev16qi },
    &operand_data[2558],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:656 */
  {
    "aarch64_sdot_laneqv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1527 },
#else
    { 0, 0, output_1527 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sdot_laneqv8qi },
    &operand_data[2563],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:656 */
  {
    "aarch64_udot_laneqv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1528 },
#else
    { 0, 0, output_1528 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_udot_laneqv8qi },
    &operand_data[2563],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:656 */
  {
    "aarch64_sdot_laneqv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1529 },
#else
    { 0, 0, output_1529 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sdot_laneqv16qi },
    &operand_data[2568],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:656 */
  {
    "aarch64_udot_laneqv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1530 },
#else
    { 0, 0, output_1530 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_udot_laneqv16qi },
    &operand_data[2568],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_usdot_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1531 },
#else
    { 0, 0, output_1531 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usdot_lanev8qi },
    &operand_data[2553],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_sudot_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1532 },
#else
    { 0, 0, output_1532 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sudot_lanev8qi },
    &operand_data[2553],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_usdot_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1533 },
#else
    { 0, 0, output_1533 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usdot_lanev16qi },
    &operand_data[2558],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_sudot_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1534 },
#else
    { 0, 0, output_1534 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sudot_lanev16qi },
    &operand_data[2558],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_usdot_laneqv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1535 },
#else
    { 0, 0, output_1535 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usdot_laneqv8qi },
    &operand_data[2563],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_sudot_laneqv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1536 },
#else
    { 0, 0, output_1536 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sudot_laneqv8qi },
    &operand_data[2563],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_usdot_laneqv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1537 },
#else
    { 0, 0, output_1537 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usdot_laneqv16qi },
    &operand_data[2568],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:674 */
  {
    "aarch64_sudot_laneqv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1538 },
#else
    { 0, 0, output_1538 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sudot_laneqv16qi },
    &operand_data[2568],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1539 },
#else
    { 0, 0, output_1539 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev4hi3 },
    &operand_data[2573],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1540 },
#else
    { 0, 0, output_1540 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev8hi3 },
    &operand_data[2577],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1541 },
#else
    { 0, 0, output_1541 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev2si3 },
    &operand_data[2581],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1542 },
#else
    { 0, 0, output_1542 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev4si3 },
    &operand_data[2585],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1543 },
#else
    { 0, 0, output_1543 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev4hf3 },
    &operand_data[2589],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1544 },
#else
    { 0, 0, output_1544 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev8hf3 },
    &operand_data[2593],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1545 },
#else
    { 0, 0, output_1545 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev2sf3 },
    &operand_data[2597],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:710 */
  {
    "mul_lanev4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1546 },
#else
    { 0, 0, output_1546 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_lanev4sf3 },
    &operand_data[2601],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1547 },
#else
    { 0, 0, output_1547 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv4hi3 },
    &operand_data[2605],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1548 },
#else
    { 0, 0, output_1548 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv8hi3 },
    &operand_data[2609],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1549 },
#else
    { 0, 0, output_1549 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv2si3 },
    &operand_data[2613],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1550 },
#else
    { 0, 0, output_1550 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv4si3 },
    &operand_data[2617],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1551 },
#else
    { 0, 0, output_1551 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv4hf3 },
    &operand_data[2621],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1552 },
#else
    { 0, 0, output_1552 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv8hf3 },
    &operand_data[2625],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1553 },
#else
    { 0, 0, output_1553 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv2sf3 },
    &operand_data[2629],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1554 },
#else
    { 0, 0, output_1554 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv4sf3 },
    &operand_data[2633],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:726 */
  {
    "mul_laneqv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1555 },
#else
    { 0, 0, output_1555 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_laneqv2df3 },
    &operand_data[2637],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.4h, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv4hi3 },
    &operand_data[2641],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.8h, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv8hi3 },
    &operand_data[2644],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.2s, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv2si3 },
    &operand_data[2647],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.4s, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv4si3 },
    &operand_data[2650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.4h, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv4hf3 },
    &operand_data[2653],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.8h, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv8hf3 },
    &operand_data[2656],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.2s, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv2sf3 },
    &operand_data[2659],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.4s, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv4sf3 },
    &operand_data[2662],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:742 */
  {
    "mul_nv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.2d, %1.2d, %2.d[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mul_nv2df3 },
    &operand_data[2665],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtev4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtev8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtev2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtev4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtev2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtehf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtehf },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtesf },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:753 */
  {
    "aarch64_rsqrtedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtedf },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtsv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtsv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtsv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtsv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtsv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtshf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtshf },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtssf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtssf },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:761 */
  {
    "aarch64_rsqrtsdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsdf },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:780 */
  {
    "aarch64_ursqrtev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursqrte\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursqrtev2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:780 */
  {
    "aarch64_ursqrtev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursqrte\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursqrtev4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:788 */
  {
    "*aarch64_mul3_elt_to_64v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1583 },
#else
    { 0, 0, output_1583 },
#endif
    { 0 },
    &operand_data[2668],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:803 */
  {
    "negv8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv8qi2 },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:803 */
  {
    "negv16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv16qi2 },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:803 */
  {
    "negv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv4hi2 },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:803 */
  {
    "negv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv8hi2 },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:803 */
  {
    "negv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv2si2 },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:803 */
  {
    "negv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv4si2 },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:803 */
  {
    "negv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "neg\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv2di2 },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:811 */
  {
    "absv8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv8qi2 },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:811 */
  {
    "absv16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv16qi2 },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:811 */
  {
    "absv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv4hi2 },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:811 */
  {
    "absv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv8hi2 },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:811 */
  {
    "absv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv2si2 },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:811 */
  {
    "absv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv4si2 },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:811 */
  {
    "absv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv2di2 },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absv4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absv8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absv2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absv4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absv2di },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:822 */
  {
    "aarch64_absdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "abs\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_absdi },
    &operand_data[970],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_sabdv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdv8qi },
    &operand_data[2449],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_uabdv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdv8qi },
    &operand_data[2449],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_sabdv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdv16qi },
    &operand_data[2452],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_uabdv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdv16qi },
    &operand_data[2452],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_sabdv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdv4hi },
    &operand_data[2455],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_uabdv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdv4hi },
    &operand_data[2455],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_sabdv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdv8hi },
    &operand_data[2458],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_uabdv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdv8hi },
    &operand_data[2458],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_sabdv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdv2si },
    &operand_data[2461],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_uabdv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdv2si },
    &operand_data[2461],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_sabdv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdv4si },
    &operand_data[2464],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:837 */
  {
    "aarch64_uabdv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdv4si },
    &operand_data[2464],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:852 */
  {
    "aarch64_sabdlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdlv8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:852 */
  {
    "aarch64_uabdlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdlv8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:852 */
  {
    "aarch64_sabdlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdlv4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:852 */
  {
    "aarch64_uabdlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdlv4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:852 */
  {
    "aarch64_sabdlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdlv2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:852 */
  {
    "aarch64_uabdlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdlv2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:862 */
  {
    "aarch64_sabdl2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdl2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdl2v16qi },
    &operand_data[2681],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:862 */
  {
    "aarch64_uabdl2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdl2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdl2v16qi },
    &operand_data[2681],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:862 */
  {
    "aarch64_sabdl2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdl2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdl2v8hi },
    &operand_data[2684],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:862 */
  {
    "aarch64_uabdl2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdl2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdl2v8hi },
    &operand_data[2684],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:862 */
  {
    "aarch64_sabdl2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdl2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabdl2v4si },
    &operand_data[2687],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:862 */
  {
    "aarch64_uabdl2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdl2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabdl2v4si },
    &operand_data[2687],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:872 */
  {
    "aarch64_sabalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabal\t%0.8h, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabalv8qi },
    &operand_data[2690],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:872 */
  {
    "aarch64_uabalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabal\t%0.8h, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabalv8qi },
    &operand_data[2690],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:872 */
  {
    "aarch64_sabalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabal\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabalv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:872 */
  {
    "aarch64_uabalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabal\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabalv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:872 */
  {
    "aarch64_sabalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabal\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabalv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:872 */
  {
    "aarch64_uabalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabal\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabalv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:883 */
  {
    "aarch64_sabal2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabal2\t%0.8h, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabal2v16qi },
    &operand_data[2702],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:883 */
  {
    "aarch64_uabal2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabal2\t%0.8h, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabal2v16qi },
    &operand_data[2702],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:883 */
  {
    "aarch64_sabal2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabal2\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabal2v8hi },
    &operand_data[2706],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:883 */
  {
    "aarch64_uabal2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabal2\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabal2v8hi },
    &operand_data[2706],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:883 */
  {
    "aarch64_sabal2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabal2\t%0.2d, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabal2v4si },
    &operand_data[2710],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:883 */
  {
    "aarch64_uabal2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabal2\t%0.2d, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabal2v4si },
    &operand_data[2710],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_sadalpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sadalp\t%0.4h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sadalpv8qi },
    &operand_data[2714],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_uadalpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uadalp\t%0.4h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uadalpv8qi },
    &operand_data[2714],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_sadalpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sadalp\t%0.8h, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sadalpv16qi },
    &operand_data[2702],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_uadalpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uadalp\t%0.8h, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uadalpv16qi },
    &operand_data[2702],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_sadalpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sadalp\t%0.2s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sadalpv4hi },
    &operand_data[2717],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_uadalpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uadalp\t%0.2s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uadalpv4hi },
    &operand_data[2717],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_sadalpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sadalp\t%0.4s, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sadalpv8hi },
    &operand_data[2706],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_uadalpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uadalp\t%0.4s, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uadalpv8hi },
    &operand_data[2706],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_sadalpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sadalp\t%0.2d, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sadalpv4si },
    &operand_data[2710],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_uadalpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uadalp\t%0.2d, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uadalpv4si },
    &operand_data[2710],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_sadalpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sadalp\t%0.1d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sadalpv2si },
    &operand_data[2720],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:894 */
  {
    "aarch64_uadalpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uadalp\t%0.1d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uadalpv2si },
    &operand_data[2720],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_sabav8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saba\t%0.8b, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabav8qi },
    &operand_data[2723],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_uabav8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaba\t%0.8b, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabav8qi },
    &operand_data[2723],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_sabav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saba\t%0.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabav16qi },
    &operand_data[2727],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_uabav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaba\t%0.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabav16qi },
    &operand_data[2727],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_sabav4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saba\t%0.4h, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabav4hi },
    &operand_data[2731],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_uabav4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaba\t%0.4h, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabav4hi },
    &operand_data[2731],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_sabav8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saba\t%0.8h, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabav8hi },
    &operand_data[2735],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_uabav8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaba\t%0.8h, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabav8hi },
    &operand_data[2735],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_sabav2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saba\t%0.2s, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabav2si },
    &operand_data[2739],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_uabav2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaba\t%0.2s, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabav2si },
    &operand_data[2739],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_sabav4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saba\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sabav4si },
    &operand_data[2743],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:952 */
  {
    "aarch64_uabav4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaba\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uabav4si },
    &operand_data[2743],
    4,
    4,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabdv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabdv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabdv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabdv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabdv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabdv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabdv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabdv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabdv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabdv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabdhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabdhf3 },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabdsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabdsf3 },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:967 */
  {
    "fabddf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabd\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fabddf3 },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:979 */
  {
    "andv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1674 },
#else
    { 0, 0, output_1674 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andv8qi3 },
    &operand_data[2747],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:979 */
  {
    "andv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1675 },
#else
    { 0, 0, output_1675 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andv16qi3 },
    &operand_data[2750],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:979 */
  {
    "andv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1676 },
#else
    { 0, 0, output_1676 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andv4hi3 },
    &operand_data[2753],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:979 */
  {
    "andv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1677 },
#else
    { 0, 0, output_1677 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andv8hi3 },
    &operand_data[2756],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:979 */
  {
    "andv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1678 },
#else
    { 0, 0, output_1678 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andv2si3 },
    &operand_data[2759],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:979 */
  {
    "andv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1679 },
#else
    { 0, 0, output_1679 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andv4si3 },
    &operand_data[2762],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:979 */
  {
    "andv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1680 },
#else
    { 0, 0, output_1680 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andv2di3 },
    &operand_data[2765],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1000 */
  {
    "iorv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1681 },
#else
    { 0, 0, output_1681 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorv8qi3 },
    &operand_data[2768],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1000 */
  {
    "iorv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1682 },
#else
    { 0, 0, output_1682 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorv16qi3 },
    &operand_data[2771],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1000 */
  {
    "iorv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1683 },
#else
    { 0, 0, output_1683 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorv4hi3 },
    &operand_data[2774],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1000 */
  {
    "iorv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1684 },
#else
    { 0, 0, output_1684 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorv8hi3 },
    &operand_data[2777],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1000 */
  {
    "iorv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1685 },
#else
    { 0, 0, output_1685 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorv2si3 },
    &operand_data[2780],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1000 */
  {
    "iorv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1686 },
#else
    { 0, 0, output_1686 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorv4si3 },
    &operand_data[2783],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1000 */
  {
    "iorv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1687 },
#else
    { 0, 0, output_1687 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorv2di3 },
    &operand_data[2786],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1020 */
  {
    "xorv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1020 */
  {
    "xorv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1020 */
  {
    "xorv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1020 */
  {
    "xorv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1020 */
  {
    "xorv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1020 */
  {
    "xorv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1020 */
  {
    "xorv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorv2di3 },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1029 */
  {
    "one_cmplv8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplv8qi2 },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1029 */
  {
    "one_cmplv16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplv16qi2 },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1029 */
  {
    "one_cmplv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplv4hi2 },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1029 */
  {
    "one_cmplv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplv8hi2 },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1029 */
  {
    "one_cmplv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplv2si2 },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1029 */
  {
    "one_cmplv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplv4si2 },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1029 */
  {
    "one_cmplv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplv2di2 },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1702 },
#else
    { 0, 0, output_1702 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv8qi },
    &operand_data[2789],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1703 },
#else
    { 0, 0, output_1703 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv16qi },
    &operand_data[2793],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1704 },
#else
    { 0, 0, output_1704 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv4hi },
    &operand_data[2797],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1705 },
#else
    { 0, 0, output_1705 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv8hi },
    &operand_data[2801],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1706 },
#else
    { 0, 0, output_1706 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv2si },
    &operand_data[2805],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1707 },
#else
    { 0, 0, output_1707 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv4si },
    &operand_data[2809],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1708 },
#else
    { 0, 0, output_1708 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv2di },
    &operand_data[2813],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1709 },
#else
    { 0, 0, output_1709 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv4hf },
    &operand_data[2817],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1710 },
#else
    { 0, 0, output_1710 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv8hf },
    &operand_data[2821],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1711 },
#else
    { 0, 0, output_1711 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv4bf },
    &operand_data[2825],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1712 },
#else
    { 0, 0, output_1712 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv8bf },
    &operand_data[2829],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1713 },
#else
    { 0, 0, output_1713 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv2sf },
    &operand_data[2833],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1714 },
#else
    { 0, 0, output_1714 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv4sf },
    &operand_data[2837],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1037 */
  {
    "aarch64_simd_vec_setv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1715 },
#else
    { 0, 0, output_1715 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_setv2df },
    &operand_data[2841],
    4,
    4,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1716 },
#else
    { 0, 0, output_1716 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev8qi },
    &operand_data[2845],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1717 },
#else
    { 0, 0, output_1717 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev16qi },
    &operand_data[2850],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1718 },
#else
    { 0, 0, output_1718 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev4hi },
    &operand_data[2855],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1719 },
#else
    { 0, 0, output_1719 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev8hi },
    &operand_data[2860],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1720 },
#else
    { 0, 0, output_1720 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev2si },
    &operand_data[2865],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1721 },
#else
    { 0, 0, output_1721 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev4si },
    &operand_data[2870],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1722 },
#else
    { 0, 0, output_1722 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev2di },
    &operand_data[2875],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1723 },
#else
    { 0, 0, output_1723 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev4hf },
    &operand_data[2880],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1724 },
#else
    { 0, 0, output_1724 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev8hf },
    &operand_data[2885],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1725 },
#else
    { 0, 0, output_1725 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev4bf },
    &operand_data[2890],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1726 },
#else
    { 0, 0, output_1726 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev8bf },
    &operand_data[2895],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1727 },
#else
    { 0, 0, output_1727 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev2sf },
    &operand_data[2900],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1728 },
#else
    { 0, 0, output_1728 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev4sf },
    &operand_data[2905],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1063 */
  {
    "aarch64_simd_vec_copy_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1729 },
#else
    { 0, 0, output_1729 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_copy_lanev2df },
    &operand_data[2910],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_128v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1730 },
#else
    { 0, 0, output_1730 },
#endif
    { 0 },
    &operand_data[2915],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_64v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1731 },
#else
    { 0, 0, output_1731 },
#endif
    { 0 },
    &operand_data[2920],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_128v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1732 },
#else
    { 0, 0, output_1732 },
#endif
    { 0 },
    &operand_data[2925],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_64v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1733 },
#else
    { 0, 0, output_1733 },
#endif
    { 0 },
    &operand_data[2930],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_128v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1734 },
#else
    { 0, 0, output_1734 },
#endif
    { 0 },
    &operand_data[2935],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_64v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1735 },
#else
    { 0, 0, output_1735 },
#endif
    { 0 },
    &operand_data[2940],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_128v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1736 },
#else
    { 0, 0, output_1736 },
#endif
    { 0 },
    &operand_data[2945],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_64v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1737 },
#else
    { 0, 0, output_1737 },
#endif
    { 0 },
    &operand_data[2950],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_128v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1738 },
#else
    { 0, 0, output_1738 },
#endif
    { 0 },
    &operand_data[2955],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1084 */
  {
    "*aarch64_simd_vec_copy_lane_to_64v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1739 },
#else
    { 0, 0, output_1739 },
#endif
    { 0 },
    &operand_data[2960],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1121 */
  {
    "aarch64_simd_lshrv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushr\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_lshrv8qi },
    &operand_data[2965],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1121 */
  {
    "aarch64_simd_lshrv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushr\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_lshrv16qi },
    &operand_data[2968],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1121 */
  {
    "aarch64_simd_lshrv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushr\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_lshrv4hi },
    &operand_data[2971],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1121 */
  {
    "aarch64_simd_lshrv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushr\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_lshrv8hi },
    &operand_data[2974],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1121 */
  {
    "aarch64_simd_lshrv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushr\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_lshrv2si },
    &operand_data[2977],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1121 */
  {
    "aarch64_simd_lshrv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushr\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_lshrv4si },
    &operand_data[2980],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1121 */
  {
    "aarch64_simd_lshrv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushr\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_lshrv2di },
    &operand_data[2983],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1130 */
  {
    "aarch64_simd_ashrv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1747 },
#else
    { 0, output_1747, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ashrv8qi },
    &operand_data[2986],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1130 */
  {
    "aarch64_simd_ashrv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1748 },
#else
    { 0, output_1748, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ashrv16qi },
    &operand_data[2989],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1130 */
  {
    "aarch64_simd_ashrv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1749 },
#else
    { 0, output_1749, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ashrv4hi },
    &operand_data[2992],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1130 */
  {
    "aarch64_simd_ashrv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1750 },
#else
    { 0, output_1750, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ashrv8hi },
    &operand_data[2995],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1130 */
  {
    "aarch64_simd_ashrv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1751 },
#else
    { 0, output_1751, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ashrv2si },
    &operand_data[2998],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1130 */
  {
    "aarch64_simd_ashrv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1752 },
#else
    { 0, output_1752, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ashrv4si },
    &operand_data[3001],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1130 */
  {
    "aarch64_simd_ashrv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_1753 },
#else
    { 0, output_1753, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ashrv2di },
    &operand_data[3004],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3007],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3007],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3011],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3011],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3015],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3015],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3019],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3019],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3023],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3023],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3027],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3027],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3031],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1141 */
  {
    "*aarch64_simd_srav2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3031],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1153 */
  {
    "aarch64_simd_imm_shlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_imm_shlv8qi },
    &operand_data[3035],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1153 */
  {
    "aarch64_simd_imm_shlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_imm_shlv16qi },
    &operand_data[3038],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1153 */
  {
    "aarch64_simd_imm_shlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_imm_shlv4hi },
    &operand_data[3041],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1153 */
  {
    "aarch64_simd_imm_shlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_imm_shlv8hi },
    &operand_data[3044],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1153 */
  {
    "aarch64_simd_imm_shlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_imm_shlv2si },
    &operand_data[3047],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1153 */
  {
    "aarch64_simd_imm_shlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_imm_shlv4si },
    &operand_data[3050],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1153 */
  {
    "aarch64_simd_imm_shlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_imm_shlv2di },
    &operand_data[3053],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1162 */
  {
    "aarch64_simd_reg_sshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_sshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1162 */
  {
    "aarch64_simd_reg_sshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_sshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1162 */
  {
    "aarch64_simd_reg_sshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_sshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1162 */
  {
    "aarch64_simd_reg_sshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_sshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1162 */
  {
    "aarch64_simd_reg_sshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_sshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1162 */
  {
    "aarch64_simd_reg_sshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_sshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1162 */
  {
    "aarch64_simd_reg_sshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_sshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1171 */
  {
    "aarch64_simd_reg_shlv8qi_unsigned",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv8qi_unsigned },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1171 */
  {
    "aarch64_simd_reg_shlv16qi_unsigned",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv16qi_unsigned },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1171 */
  {
    "aarch64_simd_reg_shlv4hi_unsigned",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv4hi_unsigned },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1171 */
  {
    "aarch64_simd_reg_shlv8hi_unsigned",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv8hi_unsigned },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1171 */
  {
    "aarch64_simd_reg_shlv2si_unsigned",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv2si_unsigned },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1171 */
  {
    "aarch64_simd_reg_shlv4si_unsigned",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv4si_unsigned },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1171 */
  {
    "aarch64_simd_reg_shlv2di_unsigned",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv2di_unsigned },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1181 */
  {
    "aarch64_simd_reg_shlv8qi_signed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv8qi_signed },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1181 */
  {
    "aarch64_simd_reg_shlv16qi_signed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv16qi_signed },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1181 */
  {
    "aarch64_simd_reg_shlv4hi_signed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv4hi_signed },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1181 */
  {
    "aarch64_simd_reg_shlv8hi_signed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv8hi_signed },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1181 */
  {
    "aarch64_simd_reg_shlv2si_signed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv2si_signed },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1181 */
  {
    "aarch64_simd_reg_shlv4si_signed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv4si_signed },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1181 */
  {
    "aarch64_simd_reg_shlv2di_signed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_reg_shlv2di_signed },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1363 */
  {
    "vec_shr_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1796 },
#else
    { 0, 0, output_1796 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shr_v8qi },
    &operand_data[1471],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1363 */
  {
    "vec_shr_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1797 },
#else
    { 0, 0, output_1797 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shr_v4hi },
    &operand_data[1477],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1363 */
  {
    "vec_shr_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1798 },
#else
    { 0, 0, output_1798 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shr_v4hf },
    &operand_data[1492],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1363 */
  {
    "vec_shr_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1799 },
#else
    { 0, 0, output_1799 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shr_v2si },
    &operand_data[1483],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1363 */
  {
    "vec_shr_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1800 },
#else
    { 0, 0, output_1800 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shr_v2sf },
    &operand_data[1504],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1363 */
  {
    "vec_shr_v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1801 },
#else
    { 0, 0, output_1801 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shr_v4bf },
    &operand_data[1498],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1392 */
  {
    "aarch64_mlav8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.8b, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlav8qi },
    &operand_data[2723],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1392 */
  {
    "aarch64_mlav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlav16qi },
    &operand_data[2727],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1392 */
  {
    "aarch64_mlav4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.4h, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlav4hi },
    &operand_data[2731],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1392 */
  {
    "aarch64_mlav8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.8h, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlav8hi },
    &operand_data[2735],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1392 */
  {
    "aarch64_mlav2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.2s, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlav2si },
    &operand_data[2739],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1392 */
  {
    "aarch64_mlav4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlav4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1403 */
  {
    "*aarch64_mla_eltv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1808 },
#else
    { 0, 0, output_1808 },
#endif
    { 0 },
    &operand_data[3056],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1403 */
  {
    "*aarch64_mla_eltv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1809 },
#else
    { 0, 0, output_1809 },
#endif
    { 0 },
    &operand_data[3061],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1403 */
  {
    "*aarch64_mla_eltv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1810 },
#else
    { 0, 0, output_1810 },
#endif
    { 0 },
    &operand_data[3066],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1403 */
  {
    "*aarch64_mla_eltv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1811 },
#else
    { 0, 0, output_1811 },
#endif
    { 0 },
    &operand_data[3071],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1421 */
  {
    "*aarch64_mla_elt_to_128v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1812 },
#else
    { 0, 0, output_1812 },
#endif
    { 0 },
    &operand_data[3076],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1421 */
  {
    "*aarch64_mla_elt_to_64v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1813 },
#else
    { 0, 0, output_1813 },
#endif
    { 0 },
    &operand_data[3081],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1421 */
  {
    "*aarch64_mla_elt_to_128v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1814 },
#else
    { 0, 0, output_1814 },
#endif
    { 0 },
    &operand_data[3086],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1421 */
  {
    "*aarch64_mla_elt_to_64v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1815 },
#else
    { 0, 0, output_1815 },
#endif
    { 0 },
    &operand_data[3091],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1439 */
  {
    "aarch64_mla_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.4h, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mla_nv4hi },
    &operand_data[3096],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1439 */
  {
    "aarch64_mla_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.8h, %2.8h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mla_nv8hi },
    &operand_data[3100],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1439 */
  {
    "aarch64_mla_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.2s, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mla_nv2si },
    &operand_data[3104],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1439 */
  {
    "aarch64_mla_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mla\t%0.4s, %2.4s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mla_nv4si },
    &operand_data[3108],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1452 */
  {
    "aarch64_mlsv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.8b, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlsv8qi },
    &operand_data[2723],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1452 */
  {
    "aarch64_mlsv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlsv16qi },
    &operand_data[2727],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1452 */
  {
    "aarch64_mlsv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.4h, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlsv4hi },
    &operand_data[2731],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1452 */
  {
    "aarch64_mlsv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.8h, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlsv8hi },
    &operand_data[2735],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1452 */
  {
    "aarch64_mlsv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.2s, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlsv2si },
    &operand_data[2739],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1452 */
  {
    "aarch64_mlsv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mlsv4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1462 */
  {
    "*aarch64_mls_eltv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1826 },
#else
    { 0, 0, output_1826 },
#endif
    { 0 },
    &operand_data[3056],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1462 */
  {
    "*aarch64_mls_eltv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1827 },
#else
    { 0, 0, output_1827 },
#endif
    { 0 },
    &operand_data[3061],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1462 */
  {
    "*aarch64_mls_eltv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1828 },
#else
    { 0, 0, output_1828 },
#endif
    { 0 },
    &operand_data[3066],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1462 */
  {
    "*aarch64_mls_eltv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1829 },
#else
    { 0, 0, output_1829 },
#endif
    { 0 },
    &operand_data[3071],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1480 */
  {
    "*aarch64_mls_elt_to_128v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1830 },
#else
    { 0, 0, output_1830 },
#endif
    { 0 },
    &operand_data[3076],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1480 */
  {
    "*aarch64_mls_elt_to_64v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1831 },
#else
    { 0, 0, output_1831 },
#endif
    { 0 },
    &operand_data[3081],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1480 */
  {
    "*aarch64_mls_elt_to_128v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1832 },
#else
    { 0, 0, output_1832 },
#endif
    { 0 },
    &operand_data[3086],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1480 */
  {
    "*aarch64_mls_elt_to_64v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1833 },
#else
    { 0, 0, output_1833 },
#endif
    { 0 },
    &operand_data[3091],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1498 */
  {
    "aarch64_mls_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.4h, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mls_nv4hi },
    &operand_data[3096],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1498 */
  {
    "aarch64_mls_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.8h, %2.8h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mls_nv8hi },
    &operand_data[3100],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1498 */
  {
    "aarch64_mls_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.2s, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mls_nv2si },
    &operand_data[3104],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1498 */
  {
    "aarch64_mls_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mls\t%0.4s, %2.4s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mls_nv4si },
    &operand_data[3108],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "smaxv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smax\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "sminv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smin\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "umaxv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umax\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "uminv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umin\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminv8qi3 },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "smaxv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smax\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "sminv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smin\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "umaxv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umax\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "uminv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umin\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminv16qi3 },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "smaxv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smax\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "sminv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smin\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "umaxv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umax\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "uminv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umin\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminv4hi3 },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "smaxv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smax\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "sminv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smin\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "umaxv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umax\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "uminv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umin\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminv8hi3 },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "smaxv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smax\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "sminv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smin\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "umaxv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umax\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "uminv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umin\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminv2si3 },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "smaxv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smax\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "sminv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smin\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "umaxv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umax\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1512 */
  {
    "uminv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umin\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminv4si3 },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_umaxpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxp\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umaxpv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_uminpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminp\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uminpv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_smaxpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxp\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_sminpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminp\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_umaxpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxp\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umaxpv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_uminpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminp\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uminpv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_smaxpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxp\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_sminpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminp\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_umaxpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umaxpv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_uminpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uminpv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_smaxpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_sminpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_umaxpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umaxpv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_uminpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uminpv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_smaxpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_sminpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_umaxpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umaxpv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_uminpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uminpv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_smaxpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_sminpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_umaxpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umaxpv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_uminpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uminpv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_smaxpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1555 */
  {
    "aarch64_sminpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smax_nanpv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smax_nanpv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smin_nanpv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smin_nanpv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smaxpv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_sminpv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smax_nanpv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smax_nanpv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smin_nanpv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smin_nanpv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smaxpv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_sminpv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smax_nanpv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smax_nanpv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smin_nanpv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smin_nanpv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smaxpv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_sminpv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smax_nanpv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smax_nanpv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smin_nanpv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smin_nanpv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smaxpv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_sminpv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smax_nanpv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxp\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smax_nanpv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smin_nanpv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminp\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smin_nanpv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_smaxpv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmp\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smaxpv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1566 */
  {
    "aarch64_sminpv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmp\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sminpv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1584 */
  {
    "aarch64_xtnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv8hi_insn_le },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1584 */
  {
    "aarch64_xtnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv4si_insn_le },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1584 */
  {
    "aarch64_xtnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv2di_insn_le },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1594 */
  {
    "aarch64_xtnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv8hi_insn_be },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1594 */
  {
    "aarch64_xtnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv4si_insn_be },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1594 */
  {
    "aarch64_xtnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv2di_insn_be },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1625 */
  {
    "aarch64_xtn2v8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v8hi_insn_le },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1625 */
  {
    "aarch64_xtn2v4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v4si_insn_le },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1625 */
  {
    "aarch64_xtn2v2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v2di_insn_le },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1635 */
  {
    "aarch64_xtn2v8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v8hi_insn_be },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1635 */
  {
    "aarch64_xtn2v4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v4si_insn_be },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1635 */
  {
    "aarch64_xtn2v2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v2di_insn_be },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1661 */
  {
    "*aarch64_narrow_truncv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1918 },
#else
    { 0, 0, output_1918 },
#endif
    { 0 },
    &operand_data[3130],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1661 */
  {
    "*aarch64_narrow_truncv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1919 },
#else
    { 0, 0, output_1919 },
#endif
    { 0 },
    &operand_data[3133],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1661 */
  {
    "*aarch64_narrow_truncv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_1920 },
#else
    { 0, 0, output_1920 },
#endif
    { 0 },
    &operand_data[3136],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1717 */
  {
    "aarch64_shrnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1717 */
  {
    "aarch64_shrnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1717 */
  {
    "aarch64_shrnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1729 */
  {
    "aarch64_shrnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1729 */
  {
    "aarch64_shrnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1729 */
  {
    "aarch64_shrnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1741 */
  {
    "*aarch64_rshrnv8hi_vect",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3151],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1741 */
  {
    "*aarch64_shrnv8hi_vect",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3151],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1741 */
  {
    "*aarch64_rshrnv4si_vect",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3154],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1741 */
  {
    "*aarch64_shrnv4si_vect",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3154],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1741 */
  {
    "*aarch64_rshrnv2di_vect",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3157],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1741 */
  {
    "*aarch64_shrnv2di_vect",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3157],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1751 */
  {
    "*aarch64_rshrnv8hi2_vect_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1751 */
  {
    "*aarch64_shrnv8hi2_vect_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1751 */
  {
    "*aarch64_rshrnv4si2_vect_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1751 */
  {
    "*aarch64_shrnv4si2_vect_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1751 */
  {
    "*aarch64_rshrnv2di2_vect_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1751 */
  {
    "*aarch64_shrnv2di2_vect_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1763 */
  {
    "*aarch64_rshrnv8hi2_vect_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1763 */
  {
    "*aarch64_shrnv8hi2_vect_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1763 */
  {
    "*aarch64_rshrnv4si2_vect_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1763 */
  {
    "*aarch64_shrnv4si2_vect_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1763 */
  {
    "*aarch64_rshrnv2di2_vect_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1763 */
  {
    "*aarch64_shrnv2di2_vect_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1775 */
  {
    "*aarch64_rtopbits_shufflev8hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.16b, %1.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3172],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1775 */
  {
    "*aarch64_topbits_shufflev8hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.16b, %1.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3172],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1775 */
  {
    "*aarch64_rtopbits_shufflev4si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8h, %1.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3176],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1775 */
  {
    "*aarch64_topbits_shufflev4si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8h, %1.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3176],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1775 */
  {
    "*aarch64_rtopbits_shufflev2di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4s, %1.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3180],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1775 */
  {
    "*aarch64_topbits_shufflev2di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4s, %1.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3180],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1789 */
  {
    "*aarch64_rtopbits_shufflev8hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.16b, %1.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3172],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1789 */
  {
    "*aarch64_topbits_shufflev8hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.16b, %1.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3172],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1789 */
  {
    "*aarch64_rtopbits_shufflev4si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8h, %1.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3176],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1789 */
  {
    "*aarch64_topbits_shufflev4si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8h, %1.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3176],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1789 */
  {
    "*aarch64_rtopbits_shufflev2di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4s, %1.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3180],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1789 */
  {
    "*aarch64_topbits_shufflev2di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4s, %1.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3180],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1828 */
  {
    "aarch64_rshrnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1828 */
  {
    "aarch64_rshrnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1828 */
  {
    "aarch64_rshrnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1840 */
  {
    "aarch64_rshrnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1840 */
  {
    "aarch64_rshrnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1840 */
  {
    "aarch64_rshrnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1888 */
  {
    "aarch64_shrn2v8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1888 */
  {
    "aarch64_shrn2v4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1888 */
  {
    "aarch64_shrn2v2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1900 */
  {
    "aarch64_shrn2v8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1900 */
  {
    "aarch64_shrn2v4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1900 */
  {
    "aarch64_shrn2v2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1932 */
  {
    "aarch64_rshrn2v8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1932 */
  {
    "aarch64_rshrn2v4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1932 */
  {
    "aarch64_rshrn2v2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1944 */
  {
    "aarch64_rshrn2v8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1944 */
  {
    "aarch64_rshrn2v4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1944 */
  {
    "aarch64_rshrn2v2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1990 */
  {
    "aarch64_simd_vec_unpacks_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl\t%0.8h, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_lo_v16qi },
    &operand_data[3184],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1990 */
  {
    "aarch64_simd_vec_unpacku_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl\t%0.8h, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacku_lo_v16qi },
    &operand_data[3184],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1990 */
  {
    "aarch64_simd_vec_unpacks_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl\t%0.4s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_lo_v8hi },
    &operand_data[3187],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1990 */
  {
    "aarch64_simd_vec_unpacku_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl\t%0.4s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacku_lo_v8hi },
    &operand_data[3187],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1990 */
  {
    "aarch64_simd_vec_unpacks_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl\t%0.2d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_lo_v4si },
    &operand_data[3190],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1990 */
  {
    "aarch64_simd_vec_unpacku_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl\t%0.2d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacku_lo_v4si },
    &operand_data[3190],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2001 */
  {
    "aarch64_simd_vec_unpacks_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl2\t%0.8h, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_hi_v16qi },
    &operand_data[3193],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2001 */
  {
    "aarch64_simd_vec_unpacku_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl2\t%0.8h, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacku_hi_v16qi },
    &operand_data[3193],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2001 */
  {
    "aarch64_simd_vec_unpacks_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl2\t%0.4s, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_hi_v8hi },
    &operand_data[3196],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2001 */
  {
    "aarch64_simd_vec_unpacku_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl2\t%0.4s, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacku_hi_v8hi },
    &operand_data[3196],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2001 */
  {
    "aarch64_simd_vec_unpacks_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl2\t%0.2d, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_hi_v4si },
    &operand_data[3199],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2001 */
  {
    "aarch64_simd_vec_unpacku_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl2\t%0.2d, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacku_hi_v4si },
    &operand_data[3199],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2038 */
  {
    "*aarch64_smlal_lov16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.8h, %2.8b, %4.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3202],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2038 */
  {
    "*aarch64_umlal_lov16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.8h, %2.8b, %4.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3202],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2038 */
  {
    "*aarch64_smlal_lov8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.4s, %2.4h, %4.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3207],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2038 */
  {
    "*aarch64_umlal_lov8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.4s, %2.4h, %4.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3207],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2038 */
  {
    "*aarch64_smlal_lov4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.2d, %2.2s, %4.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3212],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2038 */
  {
    "*aarch64_umlal_lov4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.2d, %2.2s, %4.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3212],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2054 */
  {
    "aarch64_smlal_hiv16qi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal2\t%0.8h, %2.16b, %4.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hiv16qi_insn },
    &operand_data[3217],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2054 */
  {
    "aarch64_umlal_hiv16qi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal2\t%0.8h, %2.16b, %4.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hiv16qi_insn },
    &operand_data[3217],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2054 */
  {
    "aarch64_smlal_hiv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal2\t%0.4s, %2.8h, %4.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hiv8hi_insn },
    &operand_data[3222],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2054 */
  {
    "aarch64_umlal_hiv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal2\t%0.4s, %2.8h, %4.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hiv8hi_insn },
    &operand_data[3222],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2054 */
  {
    "aarch64_smlal_hiv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal2\t%0.2d, %2.4s, %4.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hiv4si_insn },
    &operand_data[3227],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2054 */
  {
    "aarch64_umlal_hiv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal2\t%0.2d, %2.4s, %4.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hiv4si_insn },
    &operand_data[3227],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2084 */
  {
    "aarch64_smlal_hi_nv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal2\t%0.4s, %2.8h, %4.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_nv8hi_insn },
    &operand_data[3232],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2084 */
  {
    "aarch64_umlal_hi_nv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal2\t%0.4s, %2.8h, %4.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_nv8hi_insn },
    &operand_data[3232],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2084 */
  {
    "aarch64_smlal_hi_nv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal2\t%0.2d, %2.4s, %4.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_nv4si_insn },
    &operand_data[3237],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2084 */
  {
    "aarch64_umlal_hi_nv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal2\t%0.2d, %2.4s, %4.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_nv4si_insn },
    &operand_data[3237],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2115 */
  {
    "*aarch64_smlsl_lov16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.8h, %2.8b, %4.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3202],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2115 */
  {
    "*aarch64_umlsl_lov16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.8h, %2.8b, %4.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3202],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2115 */
  {
    "*aarch64_smlsl_lov8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.4s, %2.4h, %4.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3207],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2115 */
  {
    "*aarch64_umlsl_lov8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.4s, %2.4h, %4.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3207],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2115 */
  {
    "*aarch64_smlsl_lov4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.2d, %2.2s, %4.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3212],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2115 */
  {
    "*aarch64_umlsl_lov4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.2d, %2.2s, %4.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3212],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2131 */
  {
    "aarch64_smlsl_hiv16qi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl2\t%0.8h, %2.16b, %4.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hiv16qi_insn },
    &operand_data[3217],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2131 */
  {
    "aarch64_umlsl_hiv16qi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl2\t%0.8h, %2.16b, %4.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hiv16qi_insn },
    &operand_data[3217],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2131 */
  {
    "aarch64_smlsl_hiv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl2\t%0.4s, %2.8h, %4.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hiv8hi_insn },
    &operand_data[3222],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2131 */
  {
    "aarch64_umlsl_hiv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl2\t%0.4s, %2.8h, %4.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hiv8hi_insn },
    &operand_data[3222],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2131 */
  {
    "aarch64_smlsl_hiv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl2\t%0.2d, %2.4s, %4.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hiv4si_insn },
    &operand_data[3227],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2131 */
  {
    "aarch64_umlsl_hiv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl2\t%0.2d, %2.4s, %4.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hiv4si_insn },
    &operand_data[3227],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2161 */
  {
    "aarch64_smlsl_hi_nv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl2\t%0.4s, %2.8h, %4.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_nv8hi_insn },
    &operand_data[3232],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2161 */
  {
    "aarch64_umlsl_hi_nv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl2\t%0.4s, %2.8h, %4.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_nv8hi_insn },
    &operand_data[3232],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2161 */
  {
    "aarch64_smlsl_hi_nv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl2\t%0.2d, %2.4s, %4.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_nv4si_insn },
    &operand_data[3237],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2161 */
  {
    "aarch64_umlsl_hi_nv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl2\t%0.2d, %2.4s, %4.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_nv4si_insn },
    &operand_data[3237],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2192 */
  {
    "aarch64_smlalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.8h, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlalv8qi },
    &operand_data[2690],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2192 */
  {
    "aarch64_umlalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.8h, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlalv8qi },
    &operand_data[2690],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2192 */
  {
    "aarch64_smlalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlalv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2192 */
  {
    "aarch64_umlalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlalv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2192 */
  {
    "aarch64_smlalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlalv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2192 */
  {
    "aarch64_umlalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlalv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2206 */
  {
    "aarch64_smlal_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.4s, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_nv4hi },
    &operand_data[3242],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2206 */
  {
    "aarch64_umlal_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.4s, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_nv4hi },
    &operand_data[3242],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2206 */
  {
    "aarch64_smlal_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlal\t%0.2d, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_nv2si },
    &operand_data[3246],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2206 */
  {
    "aarch64_umlal_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlal\t%0.2d, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_nv2si },
    &operand_data[3246],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2221 */
  {
    "aarch64_smlslv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.8h, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlslv8qi },
    &operand_data[2690],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2221 */
  {
    "aarch64_umlslv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.8h, %2.8b, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlslv8qi },
    &operand_data[2690],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2221 */
  {
    "aarch64_smlslv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlslv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2221 */
  {
    "aarch64_umlslv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlslv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2221 */
  {
    "aarch64_smlslv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlslv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2221 */
  {
    "aarch64_umlslv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlslv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2235 */
  {
    "aarch64_smlsl_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.4s, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_nv4hi },
    &operand_data[3242],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2235 */
  {
    "aarch64_umlsl_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.4s, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_nv4hi },
    &operand_data[3242],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2235 */
  {
    "aarch64_smlsl_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smlsl\t%0.2d, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_nv2si },
    &operand_data[3246],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2235 */
  {
    "aarch64_umlsl_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umlsl\t%0.2d, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_nv2si },
    &operand_data[3246],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2250 */
  {
    "aarch64_simd_vec_smult_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_smult_lo_v16qi },
    &operand_data[3250],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2250 */
  {
    "aarch64_simd_vec_umult_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_umult_lo_v16qi },
    &operand_data[3250],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2250 */
  {
    "aarch64_simd_vec_smult_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_smult_lo_v8hi },
    &operand_data[3254],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2250 */
  {
    "aarch64_simd_vec_umult_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_umult_lo_v8hi },
    &operand_data[3254],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2250 */
  {
    "aarch64_simd_vec_smult_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_smult_lo_v4si },
    &operand_data[3258],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2250 */
  {
    "aarch64_simd_vec_umult_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_umult_lo_v4si },
    &operand_data[3258],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2263 */
  {
    "aarch64_intrinsic_vec_smult_lo_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_intrinsic_vec_smult_lo_v8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2263 */
  {
    "aarch64_intrinsic_vec_umult_lo_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_intrinsic_vec_umult_lo_v8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2263 */
  {
    "aarch64_intrinsic_vec_smult_lo_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_intrinsic_vec_smult_lo_v4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2263 */
  {
    "aarch64_intrinsic_vec_umult_lo_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_intrinsic_vec_umult_lo_v4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2263 */
  {
    "aarch64_intrinsic_vec_smult_lo_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_intrinsic_vec_smult_lo_v2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2263 */
  {
    "aarch64_intrinsic_vec_umult_lo_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_intrinsic_vec_umult_lo_v2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2288 */
  {
    "aarch64_simd_vec_smult_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_smult_hi_v16qi },
    &operand_data[3262],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2288 */
  {
    "aarch64_simd_vec_umult_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_umult_hi_v16qi },
    &operand_data[3262],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2288 */
  {
    "aarch64_simd_vec_smult_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_smult_hi_v8hi },
    &operand_data[3266],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2288 */
  {
    "aarch64_simd_vec_umult_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_umult_hi_v8hi },
    &operand_data[3266],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2288 */
  {
    "aarch64_simd_vec_smult_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_smult_hi_v4si },
    &operand_data[3270],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2288 */
  {
    "aarch64_simd_vec_umult_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_umult_hi_v4si },
    &operand_data[3270],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_smult_lane_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2057 },
#else
    { 0, 0, output_2057 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smult_lane_v4hi },
    &operand_data[3274],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_umult_lane_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2058 },
#else
    { 0, 0, output_2058 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umult_lane_v4hi },
    &operand_data[3274],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_smult_laneq_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2059 },
#else
    { 0, 0, output_2059 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smult_laneq_v4hi },
    &operand_data[3278],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_umult_laneq_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2060 },
#else
    { 0, 0, output_2060 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umult_laneq_v4hi },
    &operand_data[3278],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_smult_lane_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2061 },
#else
    { 0, 0, output_2061 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smult_lane_v2si },
    &operand_data[3282],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_umult_lane_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2062 },
#else
    { 0, 0, output_2062 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umult_lane_v2si },
    &operand_data[3282],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_smult_laneq_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2063 },
#else
    { 0, 0, output_2063 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smult_laneq_v2si },
    &operand_data[3286],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2317 */
  {
    "aarch64_vec_umult_laneq_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2064 },
#else
    { 0, 0, output_2064 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umult_laneq_v2si },
    &operand_data[3286],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2335 */
  {
    "aarch64_smull_hi_lanev8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2065 },
#else
    { 0, 0, output_2065 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_lanev8hi_insn },
    &operand_data[3290],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2335 */
  {
    "aarch64_umull_hi_lanev8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2066 },
#else
    { 0, 0, output_2066 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_lanev8hi_insn },
    &operand_data[3290],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2335 */
  {
    "aarch64_smull_hi_lanev4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2067 },
#else
    { 0, 0, output_2067 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_lanev4si_insn },
    &operand_data[3295],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2335 */
  {
    "aarch64_umull_hi_lanev4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2068 },
#else
    { 0, 0, output_2068 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_lanev4si_insn },
    &operand_data[3295],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2369 */
  {
    "aarch64_smull_hi_laneqv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2069 },
#else
    { 0, 0, output_2069 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_laneqv8hi_insn },
    &operand_data[3300],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2369 */
  {
    "aarch64_umull_hi_laneqv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2070 },
#else
    { 0, 0, output_2070 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_laneqv8hi_insn },
    &operand_data[3300],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2369 */
  {
    "aarch64_smull_hi_laneqv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2071 },
#else
    { 0, 0, output_2071 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_laneqv4si_insn },
    &operand_data[3305],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2369 */
  {
    "aarch64_umull_hi_laneqv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2072 },
#else
    { 0, 0, output_2072 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_laneqv4si_insn },
    &operand_data[3305],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2403 */
  {
    "aarch64_smull_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.4s, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_nv4hi },
    &operand_data[3310],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2403 */
  {
    "aarch64_umull_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.4s, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_nv4hi },
    &operand_data[3310],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2403 */
  {
    "aarch64_smull_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull\t%0.2d, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_nv2si },
    &operand_data[3313],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2403 */
  {
    "aarch64_umull_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull\t%0.2d, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_nv2si },
    &operand_data[3313],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2416 */
  {
    "aarch64_smull_hi_nv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull2\t%0.4s, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_nv8hi_insn },
    &operand_data[3316],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2416 */
  {
    "aarch64_umull_hi_nv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull2\t%0.4s, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_nv8hi_insn },
    &operand_data[3316],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2416 */
  {
    "aarch64_smull_hi_nv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smull2\t%0.2d, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_nv4si_insn },
    &operand_data[3320],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2416 */
  {
    "aarch64_umull_hi_nv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umull2\t%0.2d, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_nv4si_insn },
    &operand_data[3320],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_smlal_lane_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2081 },
#else
    { 0, 0, output_2081 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlal_lane_v4hi },
    &operand_data[3324],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_umlal_lane_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2082 },
#else
    { 0, 0, output_2082 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlal_lane_v4hi },
    &operand_data[3324],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_smlal_laneq_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2083 },
#else
    { 0, 0, output_2083 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlal_laneq_v4hi },
    &operand_data[3329],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_umlal_laneq_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2084 },
#else
    { 0, 0, output_2084 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlal_laneq_v4hi },
    &operand_data[3329],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_smlal_lane_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2085 },
#else
    { 0, 0, output_2085 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlal_lane_v2si },
    &operand_data[3334],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_umlal_lane_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2086 },
#else
    { 0, 0, output_2086 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlal_lane_v2si },
    &operand_data[3334],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_smlal_laneq_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2087 },
#else
    { 0, 0, output_2087 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlal_laneq_v2si },
    &operand_data[3339],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2445 */
  {
    "aarch64_vec_umlal_laneq_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2088 },
#else
    { 0, 0, output_2088 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlal_laneq_v2si },
    &operand_data[3339],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2465 */
  {
    "aarch64_smlal_hi_lanev8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2089 },
#else
    { 0, 0, output_2089 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_lanev8hi_insn },
    &operand_data[3344],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2465 */
  {
    "aarch64_umlal_hi_lanev8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2090 },
#else
    { 0, 0, output_2090 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_lanev8hi_insn },
    &operand_data[3344],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2465 */
  {
    "aarch64_smlal_hi_lanev4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2091 },
#else
    { 0, 0, output_2091 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_lanev4si_insn },
    &operand_data[3350],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2465 */
  {
    "aarch64_umlal_hi_lanev4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2092 },
#else
    { 0, 0, output_2092 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_lanev4si_insn },
    &operand_data[3350],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2502 */
  {
    "aarch64_smlal_hi_laneqv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2093 },
#else
    { 0, 0, output_2093 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_laneqv8hi_insn },
    &operand_data[3356],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2502 */
  {
    "aarch64_umlal_hi_laneqv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2094 },
#else
    { 0, 0, output_2094 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_laneqv8hi_insn },
    &operand_data[3356],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2502 */
  {
    "aarch64_smlal_hi_laneqv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2095 },
#else
    { 0, 0, output_2095 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_laneqv4si_insn },
    &operand_data[3362],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2502 */
  {
    "aarch64_umlal_hi_laneqv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2096 },
#else
    { 0, 0, output_2096 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_laneqv4si_insn },
    &operand_data[3362],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_smlsl_lane_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2097 },
#else
    { 0, 0, output_2097 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlsl_lane_v4hi },
    &operand_data[3324],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_umlsl_lane_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2098 },
#else
    { 0, 0, output_2098 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlsl_lane_v4hi },
    &operand_data[3324],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_smlsl_laneq_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2099 },
#else
    { 0, 0, output_2099 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlsl_laneq_v4hi },
    &operand_data[3329],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_umlsl_laneq_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2100 },
#else
    { 0, 0, output_2100 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlsl_laneq_v4hi },
    &operand_data[3329],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_smlsl_lane_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2101 },
#else
    { 0, 0, output_2101 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlsl_lane_v2si },
    &operand_data[3334],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_umlsl_lane_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2102 },
#else
    { 0, 0, output_2102 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlsl_lane_v2si },
    &operand_data[3334],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_smlsl_laneq_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2103 },
#else
    { 0, 0, output_2103 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_smlsl_laneq_v2si },
    &operand_data[3339],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2539 */
  {
    "aarch64_vec_umlsl_laneq_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2104 },
#else
    { 0, 0, output_2104 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_umlsl_laneq_v2si },
    &operand_data[3339],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2559 */
  {
    "aarch64_smlsl_hi_lanev8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2105 },
#else
    { 0, 0, output_2105 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_lanev8hi_insn },
    &operand_data[3344],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2559 */
  {
    "aarch64_umlsl_hi_lanev8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2106 },
#else
    { 0, 0, output_2106 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_lanev8hi_insn },
    &operand_data[3344],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2559 */
  {
    "aarch64_smlsl_hi_lanev4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2107 },
#else
    { 0, 0, output_2107 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_lanev4si_insn },
    &operand_data[3350],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2559 */
  {
    "aarch64_umlsl_hi_lanev4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2108 },
#else
    { 0, 0, output_2108 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_lanev4si_insn },
    &operand_data[3350],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2597 */
  {
    "aarch64_smlsl_hi_laneqv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2109 },
#else
    { 0, 0, output_2109 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_laneqv8hi_insn },
    &operand_data[3356],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2597 */
  {
    "aarch64_umlsl_hi_laneqv8hi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2110 },
#else
    { 0, 0, output_2110 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_laneqv8hi_insn },
    &operand_data[3356],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2597 */
  {
    "aarch64_smlsl_hi_laneqv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2111 },
#else
    { 0, 0, output_2111 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_laneqv4si_insn },
    &operand_data[3362],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2597 */
  {
    "aarch64_umlsl_hi_laneqv4si_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2112 },
#else
    { 0, 0, output_2112 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_laneqv4si_insn },
    &operand_data[3362],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2660 */
  {
    "addv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2660 */
  {
    "addv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2660 */
  {
    "addv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2660 */
  {
    "addv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2660 */
  {
    "addv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2669 */
  {
    "subv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2669 */
  {
    "subv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2669 */
  {
    "subv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2669 */
  {
    "subv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2669 */
  {
    "subv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2678 */
  {
    "mulv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2678 */
  {
    "mulv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2678 */
  {
    "mulv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2678 */
  {
    "mulv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2678 */
  {
    "mulv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2699 */
  {
    "*divv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2699 */
  {
    "*divv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2699 */
  {
    "*divv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2699 */
  {
    "*divv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2699 */
  {
    "*divv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fdiv\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2708 */
  {
    "negv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2708 */
  {
    "negv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2708 */
  {
    "negv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2708 */
  {
    "negv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2708 */
  {
    "negv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fneg\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2716 */
  {
    "absv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2716 */
  {
    "absv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2716 */
  {
    "absv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2716 */
  {
    "absv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2716 */
  {
    "absv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fabs\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2870 */
  {
    "fmav4hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmav4hf4 },
    &operand_data[3368],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2870 */
  {
    "fmav8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmav8hf4 },
    &operand_data[3372],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2870 */
  {
    "fmav2sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmav2sf4 },
    &operand_data[3376],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2870 */
  {
    "fmav4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmav4sf4 },
    &operand_data[3380],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2870 */
  {
    "fmav2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmav2df4 },
    &operand_data[3384],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2880 */
  {
    "*aarch64_fma4_eltv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2148 },
#else
    { 0, 0, output_2148 },
#endif
    { 0 },
    &operand_data[3388],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2880 */
  {
    "*aarch64_fma4_eltv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2149 },
#else
    { 0, 0, output_2149 },
#endif
    { 0 },
    &operand_data[3393],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2880 */
  {
    "*aarch64_fma4_eltv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2150 },
#else
    { 0, 0, output_2150 },
#endif
    { 0 },
    &operand_data[3398],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2897 */
  {
    "*aarch64_fma4_elt_to_128v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2151 },
#else
    { 0, 0, output_2151 },
#endif
    { 0 },
    &operand_data[3403],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2897 */
  {
    "*aarch64_fma4_elt_to_64v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2152 },
#else
    { 0, 0, output_2152 },
#endif
    { 0 },
    &operand_data[3408],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.4h, %2.4h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.8h, %2.8h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.2s, %2.2s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3421],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.4s, %2.4s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3425],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.4h, %2.4h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3429],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.8h, %2.8h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3433],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.2s, %2.2s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3437],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.4s, %2.4s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3441],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2914 */
  {
    "*aarch64_fma4_elt_from_dupv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmla\t%0.2d, %2.2d, %1.d[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3445],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2926 */
  {
    "*aarch64_fma4_elt_to_64v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2162 },
#else
    { 0, 0, output_2162 },
#endif
    { 0 },
    &operand_data[3449],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2942 */
  {
    "fnmav4hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmav4hf4 },
    &operand_data[3368],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2942 */
  {
    "fnmav8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmav8hf4 },
    &operand_data[3372],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2942 */
  {
    "fnmav2sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmav2sf4 },
    &operand_data[3376],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2942 */
  {
    "fnmav4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmav4sf4 },
    &operand_data[3380],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2942 */
  {
    "fnmav2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmav2df4 },
    &operand_data[3384],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2953 */
  {
    "*aarch64_fnma4_eltv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2168 },
#else
    { 0, 0, output_2168 },
#endif
    { 0 },
    &operand_data[3388],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2953 */
  {
    "*aarch64_fnma4_eltv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2169 },
#else
    { 0, 0, output_2169 },
#endif
    { 0 },
    &operand_data[3393],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2953 */
  {
    "*aarch64_fnma4_eltv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2170 },
#else
    { 0, 0, output_2170 },
#endif
    { 0 },
    &operand_data[3398],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2971 */
  {
    "*aarch64_fnma4_elt_to_128v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2171 },
#else
    { 0, 0, output_2171 },
#endif
    { 0 },
    &operand_data[3403],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2971 */
  {
    "*aarch64_fnma4_elt_to_64v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2172 },
#else
    { 0, 0, output_2172 },
#endif
    { 0 },
    &operand_data[3408],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.4h, %2.4h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.8h, %2.8h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.2s, %2.2s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3421],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.4s, %2.4s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3425],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.4h, %2.4h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3429],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.8h, %2.8h, %1.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3433],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.2s, %2.2s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3437],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.4s, %2.4s, %1.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3441],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2989 */
  {
    "*aarch64_fnma4_elt_from_dupv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmls\t%0.2d, %2.2d, %1.d[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3445],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3002 */
  {
    "*aarch64_fnma4_elt_to_64v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2182 },
#else
    { 0, 0, output_2182 },
#endif
    { 0 },
    &operand_data[3449],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "btruncv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "ceilv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "floorv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundevenv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevenv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "nearbyintv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "rintv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundv4hf2 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "btruncv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "ceilv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "floorv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundevenv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevenv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "nearbyintv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "rintv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundv8hf2 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "btruncv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "ceilv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "floorv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundevenv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevenv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "nearbyintv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "rintv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundv2sf2 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "btruncv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "ceilv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "floorv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundevenv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevenv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "nearbyintv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "rintv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundv4sf2 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "btruncv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintz\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "ceilv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintp\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "floorv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintm\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundevenv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintn\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundevenv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "nearbyintv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinti\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "rintv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frintx\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3021 */
  {
    "roundv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frinta\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundv2df2 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceilv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfloorv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lroundv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncuv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceiluv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lflooruv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lrounduv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnuv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuv4hfv4hi2 },
    &operand_data[3454],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceilv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfloorv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lroundv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncuv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceiluv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lflooruv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lrounduv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnuv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuv8hfv8hi2 },
    &operand_data[3456],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceilv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfloorv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lroundv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncuv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceiluv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lflooruv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lrounduv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnuv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuv2sfv2si2 },
    &operand_data[3458],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceilv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfloorv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lroundv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncuv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceiluv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lflooruv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lrounduv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnuv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuv4sfv4si2 },
    &operand_data[3460],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceilv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfloorv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lroundv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lbtruncuv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lceiluv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lflooruv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lrounduv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3032 */
  {
    "lfrintnuv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuv2dfv2di2 },
    &operand_data[3462],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lbtrunchfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtrunchfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lceilhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtps\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceilhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lfloorhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtms\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfloorhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lroundhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtas\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lroundhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lfrintnhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtns\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lbtruncuhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lbtruncuhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lceiluhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtpu\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lceiluhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lflooruhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtmu\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lflooruhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lrounduhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtau\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrounduhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3043 */
  {
    "lfrintnuhfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnu\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lfrintnuhfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3052 */
  {
    "fix_trunchfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_trunchfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3052 */
  {
    "fixuns_trunchfhi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_trunchfhi2 },
    &operand_data[1277],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3060 */
  {
    "floathihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floathihf2 },
    &operand_data[1280],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3060 */
  {
    "floatunshihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunshihf2 },
    &operand_data[1280],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3068 */
  {
    "*aarch64_fcvtv2sfv2si2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2282 },
#else
    { 0, 0, output_2282 },
#endif
    { 0 },
    &operand_data[3464],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3068 */
  {
    "*aarch64_fcvtuv2sfv2si2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2283 },
#else
    { 0, 0, output_2283 },
#endif
    { 0 },
    &operand_data[3464],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3068 */
  {
    "*aarch64_fcvtv4sfv4si2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2284 },
#else
    { 0, 0, output_2284 },
#endif
    { 0 },
    &operand_data[3467],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3068 */
  {
    "*aarch64_fcvtuv4sfv4si2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2285 },
#else
    { 0, 0, output_2285 },
#endif
    { 0 },
    &operand_data[3467],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3068 */
  {
    "*aarch64_fcvtv2dfv2di2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2286 },
#else
    { 0, 0, output_2286 },
#endif
    { 0 },
    &operand_data[3470],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3068 */
  {
    "*aarch64_fcvtuv2dfv2di2_mult",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2287 },
#else
    { 0, 0, output_2287 },
#endif
    { 0 },
    &operand_data[3470],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatv4hiv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatv4hiv4hf2 },
    &operand_data[3473],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatunsv4hiv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsv4hiv4hf2 },
    &operand_data[3473],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatv8hiv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatv8hiv8hf2 },
    &operand_data[3475],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatunsv8hiv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsv8hiv8hf2 },
    &operand_data[3475],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatv2siv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatv2siv2sf2 },
    &operand_data[3477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatunsv2siv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsv2siv2sf2 },
    &operand_data[3477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatv4siv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatv4siv4sf2 },
    &operand_data[3479],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatunsv4siv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsv4siv4sf2 },
    &operand_data[3479],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatv2div2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatv2div2df2 },
    &operand_data[3481],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3111 */
  {
    "floatunsv2div2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsv2div2df2 },
    &operand_data[3481],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3126 */
  {
    "aarch64_simd_vec_unpacks_lo_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtl\t%0.4s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_lo_v8hf },
    &operand_data[3483],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3126 */
  {
    "aarch64_simd_vec_unpacks_lo_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtl\t%0.2d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_lo_v4sf },
    &operand_data[3486],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzsv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.4h, %1.4h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzsv4hf3 },
    &operand_data[3489],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzuv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.4h, %1.4h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuv4hf3 },
    &operand_data[3489],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzsv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.8h, %1.8h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzsv8hf3 },
    &operand_data[3492],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzuv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.8h, %1.8h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuv8hf3 },
    &operand_data[3492],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzsv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.2s, %1.2s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzsv2sf3 },
    &operand_data[3495],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzuv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.2s, %1.2s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuv2sf3 },
    &operand_data[3495],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzsv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.4s, %1.4s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzsv4sf3 },
    &operand_data[3498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzuv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.4s, %1.4s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuv4sf3 },
    &operand_data[3498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzsv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzs\t%0.2d, %1.2d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzsv2df3 },
    &operand_data[3501],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3139 */
  {
    "fcvtzuv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtzu\t%0.2d, %1.2d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fcvtzuv2df3 },
    &operand_data[3501],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "scvtfv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.4h, %1.4h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfv4hi3 },
    &operand_data[3504],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "ucvtfv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.4h, %1.4h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfv4hi3 },
    &operand_data[3504],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "scvtfv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.8h, %1.8h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfv8hi3 },
    &operand_data[3507],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "ucvtfv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.8h, %1.8h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfv8hi3 },
    &operand_data[3507],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "scvtfv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.2s, %1.2s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfv2si3 },
    &operand_data[3510],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "ucvtfv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.2s, %1.2s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfv2si3 },
    &operand_data[3510],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "scvtfv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.4s, %1.4s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfv4si3 },
    &operand_data[3513],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "ucvtfv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.4s, %1.4s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfv4si3 },
    &operand_data[3513],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "scvtfv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "scvtf\t%0.2d, %1.2d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scvtfv2di3 },
    &operand_data[3516],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3150 */
  {
    "ucvtfv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ucvtf\t%0.2d, %1.2d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ucvtfv2di3 },
    &operand_data[3516],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3182 */
  {
    "aarch64_simd_vec_unpacks_hi_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtl2\t%0.4s, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_hi_v8hf },
    &operand_data[3519],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3182 */
  {
    "aarch64_simd_vec_unpacks_hi_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtl2\t%0.2d, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_vec_unpacks_hi_v4sf },
    &operand_data[3522],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3204 */
  {
    "aarch64_float_extend_lo_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtl\t%0.2d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_extend_lo_v2df },
    &operand_data[3525],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3204 */
  {
    "aarch64_float_extend_lo_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtl\t%0.4s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_extend_lo_v4sf },
    &operand_data[3527],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3215 */
  {
    "aarch64_float_trunc_rodd_df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtxn\t%s0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_trunc_rodd_df },
    &operand_data[1227],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3224 */
  {
    "aarch64_float_trunc_rodd_lo_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtxn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_trunc_rodd_lo_v2sf },
    &operand_data[3529],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3233 */
  {
    "aarch64_float_trunc_rodd_hi_v4sf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtxn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_trunc_rodd_hi_v4sf_le },
    &operand_data[3531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3244 */
  {
    "aarch64_float_trunc_rodd_hi_v4sf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtxn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_trunc_rodd_hi_v4sf_be },
    &operand_data[3531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3269 */
  {
    "aarch64_float_truncate_lo_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_lo_v2sf },
    &operand_data[3529],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3269 */
  {
    "aarch64_float_truncate_lo_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_lo_v4hf },
    &operand_data[3534],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3278 */
  {
    "aarch64_float_truncate_hi_v4sf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_hi_v4sf_le },
    &operand_data[3531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3278 */
  {
    "aarch64_float_truncate_hi_v8hf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_hi_v8hf_le },
    &operand_data[3536],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3289 */
  {
    "aarch64_float_truncate_hi_v4sf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_hi_v4sf_be },
    &operand_data[3531],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3289 */
  {
    "aarch64_float_truncate_hi_v8hf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_hi_v8hf_be },
    &operand_data[3536],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "smaxv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "sminv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "smaxv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "sminv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "smaxv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "sminv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "smaxv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "sminv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "smaxv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3364 */
  {
    "sminv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmax_nanv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmin_nanv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmaxv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fminv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminv4hf3 },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmax_nanv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmin_nanv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmaxv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fminv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminv8hf3 },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmax_nanv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmin_nanv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmaxv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fminv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminv2sf3 },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmax_nanv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmin_nanv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmaxv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fminv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminv4sf3 },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmax_nanv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmax\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmin_nanv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmin\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fmaxv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnm\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3376 */
  {
    "fminv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnm\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminv2df3 },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3388 */
  {
    "aarch64_faddpv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faddpv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3388 */
  {
    "aarch64_faddpv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faddpv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3388 */
  {
    "aarch64_faddpv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faddpv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3388 */
  {
    "aarch64_faddpv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faddpv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3388 */
  {
    "aarch64_faddpv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddp\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faddpv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3398 */
  {
    "reduc_plus_scal_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%b0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v8qi },
    &operand_data[3539],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3398 */
  {
    "reduc_plus_scal_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%b0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v16qi },
    &operand_data[3541],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3398 */
  {
    "reduc_plus_scal_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v4hi },
    &operand_data[3543],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3398 */
  {
    "reduc_plus_scal_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v8hi },
    &operand_data[3545],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3398 */
  {
    "reduc_plus_scal_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v4si },
    &operand_data[3547],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3398 */
  {
    "reduc_plus_scal_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%d0, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v2di },
    &operand_data[3549],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3407 */
  {
    "reduc_plus_scal_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.2s, %1.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v2si },
    &operand_data[3551],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extendsi_reduc_plus_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%b0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extendsi_reduc_plus_v8qi },
    &operand_data[3553],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extenddi_reduc_plus_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%b0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extenddi_reduc_plus_v8qi },
    &operand_data[3555],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extendsi_reduc_plus_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%b0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extendsi_reduc_plus_v16qi },
    &operand_data[3557],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extenddi_reduc_plus_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%b0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extenddi_reduc_plus_v16qi },
    &operand_data[3559],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extendsi_reduc_plus_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extendsi_reduc_plus_v4hi },
    &operand_data[3561],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extenddi_reduc_plus_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extenddi_reduc_plus_v4hi },
    &operand_data[3563],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extendsi_reduc_plus_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extendsi_reduc_plus_v8hi },
    &operand_data[3565],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3417 */
  {
    "aarch64_zero_extenddi_reduc_plus_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zero_extenddi_reduc_plus_v8hi },
    &operand_data[3567],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3427 */
  {
    "reduc_plus_scal_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddp\t%s0, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v2sf },
    &operand_data[3569],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3427 */
  {
    "reduc_plus_scal_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddp\t%d0, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v2df },
    &operand_data[2668],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_saddlvv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlv\t%h0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlvv8qi },
    &operand_data[3571],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_uaddlvv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlv\t%h0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlvv8qi },
    &operand_data[3571],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_saddlvv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlv\t%h0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlvv16qi },
    &operand_data[3573],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_uaddlvv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlv\t%h0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlvv16qi },
    &operand_data[3573],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_saddlvv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlv\t%s0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlvv4hi },
    &operand_data[3561],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_uaddlvv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlv\t%s0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlvv4hi },
    &operand_data[3561],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_saddlvv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlv\t%s0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlvv8hi },
    &operand_data[3565],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_uaddlvv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlv\t%s0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlvv8hi },
    &operand_data[3565],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_saddlvv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlv\t%d0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlvv4si },
    &operand_data[3575],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_uaddlvv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlv\t%d0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlvv4si },
    &operand_data[3575],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_saddlvv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlp\t%0.1d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlvv2si },
    &operand_data[3577],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3450 */
  {
    "aarch64_uaddlvv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlp\t%0.1d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlvv2si },
    &operand_data[3577],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_saddlpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlp\t%0.4h, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlpv8qi },
    &operand_data[3579],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_uaddlpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlp\t%0.4h, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlpv8qi },
    &operand_data[3579],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_saddlpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlp\t%0.8h, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlpv16qi },
    &operand_data[2681],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_uaddlpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlp\t%0.8h, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlpv16qi },
    &operand_data[2681],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_saddlpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlp\t%0.2s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlpv4hi },
    &operand_data[3581],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_uaddlpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlp\t%0.2s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlpv4hi },
    &operand_data[3581],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_saddlpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlp\t%0.4s, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlpv8hi },
    &operand_data[2684],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_uaddlpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlp\t%0.4s, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlpv8hi },
    &operand_data[2684],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_saddlpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlp\t%0.2d, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlpv4si },
    &operand_data[2687],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_uaddlpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlp\t%0.2d, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlpv4si },
    &operand_data[2687],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_saddlpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlp\t%0.1d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlpv2si },
    &operand_data[3577],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3459 */
  {
    "aarch64_uaddlpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlp\t%0.1d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlpv2si },
    &operand_data[3577],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3468 */
  {
    "clrsbv8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbv8qi2 },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3468 */
  {
    "clrsbv16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbv16qi2 },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3468 */
  {
    "clrsbv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbv4hi2 },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3468 */
  {
    "clrsbv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbv8hi2 },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3468 */
  {
    "clrsbv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbv2si2 },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3468 */
  {
    "clrsbv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cls\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbv4si2 },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3476 */
  {
    "clzv8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzv8qi2 },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3476 */
  {
    "clzv16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzv16qi2 },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3476 */
  {
    "clzv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzv4hi2 },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3476 */
  {
    "clzv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzv8hi2 },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3476 */
  {
    "clzv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzv2si2 },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3476 */
  {
    "clzv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "clz\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzv4si2 },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3484 */
  {
    "popcountv8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cnt\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountv8qi2 },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3484 */
  {
    "popcountv16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cnt\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountv16qi2 },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umax_internalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%b0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umax_internalv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umin_internalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%b0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umin_internalv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smax_internalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%b0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smin_internalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%b0, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umax_internalv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%b0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umax_internalv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umin_internalv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%b0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umin_internalv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smax_internalv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%b0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smin_internalv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%b0, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umax_internalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umax_internalv4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umin_internalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umin_internalv4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smax_internalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smin_internalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umax_internalv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umax_internalv8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umin_internalv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umin_internalv8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smax_internalv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smin_internalv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umax_internalv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umax_internalv4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_umin_internalv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umin_internalv4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smax_internalv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3538 */
  {
    "aarch64_reduc_smin_internalv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3547 */
  {
    "aarch64_reduc_umax_internalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxp\t%0.2s, %1.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umax_internalv2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3547 */
  {
    "aarch64_reduc_umin_internalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminp\t%0.2s, %1.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_umin_internalv2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3547 */
  {
    "aarch64_reduc_smax_internalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxp\t%0.2s, %1.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3547 */
  {
    "aarch64_reduc_smin_internalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminp\t%0.2s, %1.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_nan_internalv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_nan_internalv4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_nan_internalv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_nan_internalv4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_internalv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_internalv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmv\t%h0, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_nan_internalv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_nan_internalv8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_nan_internalv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_nan_internalv8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_internalv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_internalv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmv\t%h0, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_nan_internalv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxp\t%s0, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_nan_internalv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_nan_internalv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminp\t%s0, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_nan_internalv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_internalv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmp\t%s0, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_internalv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmp\t%s0, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_nan_internalv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_nan_internalv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_nan_internalv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_nan_internalv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_internalv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_internalv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmv\t%s0, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_nan_internalv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxp\t%d0, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_nan_internalv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_nan_internalv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminp\t%d0, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_nan_internalv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smax_internalv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmp\t%d0, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smax_internalv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3556 */
  {
    "aarch64_reduc_smin_internalv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmp\t%d0, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reduc_smin_internalv2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3585 */
  {
    "aarch64_simd_bslv8qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2468 },
#else
    { 0, output_2468, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv8qi_internal },
    &operand_data[3583],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3585 */
  {
    "aarch64_simd_bslv16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2469 },
#else
    { 0, output_2469, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv16qi_internal },
    &operand_data[3587],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3585 */
  {
    "aarch64_simd_bslv4hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2470 },
#else
    { 0, output_2470, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv4hi_internal },
    &operand_data[3591],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3585 */
  {
    "aarch64_simd_bslv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2471 },
#else
    { 0, output_2471, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv8hi_internal },
    &operand_data[3595],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3585 */
  {
    "aarch64_simd_bslv2si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2472 },
#else
    { 0, output_2472, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv2si_internal },
    &operand_data[3599],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3585 */
  {
    "aarch64_simd_bslv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2473 },
#else
    { 0, output_2473, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv4si_internal },
    &operand_data[3603],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3585 */
  {
    "aarch64_simd_bslv2di_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2474 },
#else
    { 0, output_2474, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv2di_internal },
    &operand_data[3607],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3609 */
  {
    "*aarch64_simd_bslv8qi_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2475 },
#else
    { 0, output_2475, 0 },
#endif
    { 0 },
    &operand_data[3611],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3609 */
  {
    "*aarch64_simd_bslv16qi_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2476 },
#else
    { 0, output_2476, 0 },
#endif
    { 0 },
    &operand_data[3615],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3609 */
  {
    "*aarch64_simd_bslv4hi_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2477 },
#else
    { 0, output_2477, 0 },
#endif
    { 0 },
    &operand_data[3619],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3609 */
  {
    "*aarch64_simd_bslv8hi_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2478 },
#else
    { 0, output_2478, 0 },
#endif
    { 0 },
    &operand_data[3623],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3609 */
  {
    "*aarch64_simd_bslv2si_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2479 },
#else
    { 0, output_2479, 0 },
#endif
    { 0 },
    &operand_data[3627],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3609 */
  {
    "*aarch64_simd_bslv4si_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2480 },
#else
    { 0, output_2480, 0 },
#endif
    { 0 },
    &operand_data[3631],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3609 */
  {
    "*aarch64_simd_bslv2di_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2481 },
#else
    { 0, output_2481, 0 },
#endif
    { 0 },
    &operand_data[3635],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3636 */
  {
    "aarch64_simd_bsldi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2482 },
#else
    { 0, output_2482, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bsldi_internal },
    &operand_data[3639],
    4,
    4,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3678 */
  {
    "aarch64_simd_bsldi_alt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2483 },
#else
    { 0, output_2483, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bsldi_alt },
    &operand_data[3643],
    4,
    4,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extendsiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2484 },
#else
    { 0, 0, output_2484 },
#endif
    { 0 },
    &operand_data[3647],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extenddiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2485 },
#else
    { 0, 0, output_2485 },
#endif
    { 0 },
    &operand_data[3650],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extendsiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2486 },
#else
    { 0, 0, output_2486 },
#endif
    { 0 },
    &operand_data[3653],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extenddiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2487 },
#else
    { 0, 0, output_2487 },
#endif
    { 0 },
    &operand_data[3656],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extendsiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2488 },
#else
    { 0, 0, output_2488 },
#endif
    { 0 },
    &operand_data[3659],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extenddiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2489 },
#else
    { 0, 0, output_2489 },
#endif
    { 0 },
    &operand_data[3662],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extendsiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2490 },
#else
    { 0, 0, output_2490 },
#endif
    { 0 },
    &operand_data[3665],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4165 */
  {
    "*aarch64_get_lane_extenddiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2491 },
#else
    { 0, 0, output_2491 },
#endif
    { 0 },
    &operand_data[3668],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extendsiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2492 },
#else
    { 0, 0, output_2492 },
#endif
    { 0 },
    &operand_data[3647],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extenddiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2493 },
#else
    { 0, 0, output_2493 },
#endif
    { 0 },
    &operand_data[3650],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extendsiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2494 },
#else
    { 0, 0, output_2494 },
#endif
    { 0 },
    &operand_data[3653],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extenddiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2495 },
#else
    { 0, 0, output_2495 },
#endif
    { 0 },
    &operand_data[3656],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extendsiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2496 },
#else
    { 0, 0, output_2496 },
#endif
    { 0 },
    &operand_data[3659],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extenddiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2497 },
#else
    { 0, 0, output_2497 },
#endif
    { 0 },
    &operand_data[3662],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extendsiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2498 },
#else
    { 0, 0, output_2498 },
#endif
    { 0 },
    &operand_data[3665],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4180 */
  {
    "*aarch64_get_lane_zero_extenddiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2499 },
#else
    { 0, 0, output_2499 },
#endif
    { 0 },
    &operand_data[3668],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2500 },
#else
    { 0, 0, output_2500 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev8qi },
    &operand_data[3671],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2501 },
#else
    { 0, 0, output_2501 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev16qi },
    &operand_data[3674],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2502 },
#else
    { 0, 0, output_2502 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev4hi },
    &operand_data[3677],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2503 },
#else
    { 0, 0, output_2503 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev8hi },
    &operand_data[3680],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2504 },
#else
    { 0, 0, output_2504 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev2si },
    &operand_data[3683],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2505 },
#else
    { 0, 0, output_2505 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev4si },
    &operand_data[3686],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2506 },
#else
    { 0, 0, output_2506 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev2di },
    &operand_data[3689],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2507 },
#else
    { 0, 0, output_2507 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev4hf },
    &operand_data[3692],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2508 },
#else
    { 0, 0, output_2508 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev8hf },
    &operand_data[3695],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2509 },
#else
    { 0, 0, output_2509 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev4bf },
    &operand_data[3698],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2510 },
#else
    { 0, 0, output_2510 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev8bf },
    &operand_data[3701],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2511 },
#else
    { 0, 0, output_2511 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev2sf },
    &operand_data[3704],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2512 },
#else
    { 0, 0, output_2512 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev4sf },
    &operand_data[3707],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4200 */
  {
    "aarch64_get_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2513 },
#else
    { 0, 0, output_2513 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lanev2df },
    &operand_data[3710],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesv8qi },
    &operand_data[3713],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesv4hi },
    &operand_data[3716],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesv4bf },
    &operand_data[3719],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesv4hf },
    &operand_data[3722],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesv2si },
    &operand_data[3725],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesv2sf },
    &operand_data[3728],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanessi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%d0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanessi },
    &operand_data[3731],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanessf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%d0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanessf },
    &operand_data[3734],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesdi },
    &operand_data[3737],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4229 */
  {
    "load_pair_lanesdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldr\t%q0, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_load_pair_lanesdf },
    &operand_data[3740],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2524 },
#else
    { 0, output_2524, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesv8qi },
    &operand_data[3743],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2525 },
#else
    { 0, output_2525, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesv4hi },
    &operand_data[3746],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2526 },
#else
    { 0, output_2526, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesv4bf },
    &operand_data[3749],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2527 },
#else
    { 0, output_2527, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesv4hf },
    &operand_data[3752],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2528 },
#else
    { 0, output_2528, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesv2si },
    &operand_data[3755],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2529 },
#else
    { 0, output_2529, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesv2sf },
    &operand_data[3758],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanessi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2530 },
#else
    { 0, output_2530, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanessi },
    &operand_data[3761],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanessf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2531 },
#else
    { 0, output_2531, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanessf },
    &operand_data[3764],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2532 },
#else
    { 0, output_2532, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesdi },
    &operand_data[3767],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4259 */
  {
    "store_pair_lanesdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2533 },
#else
    { 0, output_2533, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_store_pair_lanesdf },
    &operand_data[3770],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2534 },
#else
    { 0, output_2534, 0 },
#endif
    { 0 },
    &operand_data[3773],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2535 },
#else
    { 0, output_2535, 0 },
#endif
    { 0 },
    &operand_data[3776],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2536 },
#else
    { 0, output_2536, 0 },
#endif
    { 0 },
    &operand_data[3779],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2537 },
#else
    { 0, output_2537, 0 },
#endif
    { 0 },
    &operand_data[3782],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2538 },
#else
    { 0, output_2538, 0 },
#endif
    { 0 },
    &operand_data[3785],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2539 },
#else
    { 0, output_2539, 0 },
#endif
    { 0 },
    &operand_data[3788],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2540 },
#else
    { 0, output_2540, 0 },
#endif
    { 0 },
    &operand_data[3791],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internalsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2541 },
#else
    { 0, output_2541, 0 },
#endif
    { 0 },
    &operand_data[3794],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internaldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2542 },
#else
    { 0, output_2542, 0 },
#endif
    { 0 },
    &operand_data[3797],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4278 */
  {
    "*aarch64_combine_internaldf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2543 },
#else
    { 0, output_2543, 0 },
#endif
    { 0 },
    &operand_data[3800],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2544 },
#else
    { 0, output_2544, 0 },
#endif
    { 0 },
    &operand_data[3803],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2545 },
#else
    { 0, output_2545, 0 },
#endif
    { 0 },
    &operand_data[3806],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2546 },
#else
    { 0, output_2546, 0 },
#endif
    { 0 },
    &operand_data[3809],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2547 },
#else
    { 0, output_2547, 0 },
#endif
    { 0 },
    &operand_data[3812],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2548 },
#else
    { 0, output_2548, 0 },
#endif
    { 0 },
    &operand_data[3815],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2549 },
#else
    { 0, output_2549, 0 },
#endif
    { 0 },
    &operand_data[3818],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_besi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2550 },
#else
    { 0, output_2550, 0 },
#endif
    { 0 },
    &operand_data[3821],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_besf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2551 },
#else
    { 0, output_2551, 0 },
#endif
    { 0 },
    &operand_data[3824],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2552 },
#else
    { 0, output_2552, 0 },
#endif
    { 0 },
    &operand_data[3827],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4296 */
  {
    "*aarch64_combine_internal_bedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2553 },
#else
    { 0, output_2553, 0 },
#endif
    { 0 },
    &operand_data[3830],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2554 },
#else
    { 0, output_2554, 0 },
#endif
    { 0 },
    &operand_data[3833],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2555 },
#else
    { 0, output_2555, 0 },
#endif
    { 0 },
    &operand_data[3836],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2556 },
#else
    { 0, output_2556, 0 },
#endif
    { 0 },
    &operand_data[3839],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2557 },
#else
    { 0, output_2557, 0 },
#endif
    { 0 },
    &operand_data[3842],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2558 },
#else
    { 0, output_2558, 0 },
#endif
    { 0 },
    &operand_data[3845],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2559 },
#else
    { 0, output_2559, 0 },
#endif
    { 0 },
    &operand_data[3848],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2560 },
#else
    { 0, output_2560, 0 },
#endif
    { 0 },
    &operand_data[3851],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2561 },
#else
    { 0, output_2561, 0 },
#endif
    { 0 },
    &operand_data[3854],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2562 },
#else
    { 0, output_2562, 0 },
#endif
    { 0 },
    &operand_data[3857],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4317 */
  {
    "*aarch64_combinezdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2563 },
#else
    { 0, output_2563, 0 },
#endif
    { 0 },
    &operand_data[3860],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2564 },
#else
    { 0, output_2564, 0 },
#endif
    { 0 },
    &operand_data[3833],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2565 },
#else
    { 0, output_2565, 0 },
#endif
    { 0 },
    &operand_data[3836],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2566 },
#else
    { 0, output_2566, 0 },
#endif
    { 0 },
    &operand_data[3839],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2567 },
#else
    { 0, output_2567, 0 },
#endif
    { 0 },
    &operand_data[3842],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2568 },
#else
    { 0, output_2568, 0 },
#endif
    { 0 },
    &operand_data[3845],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2569 },
#else
    { 0, output_2569, 0 },
#endif
    { 0 },
    &operand_data[3848],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_besi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2570 },
#else
    { 0, output_2570, 0 },
#endif
    { 0 },
    &operand_data[3851],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_besf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2571 },
#else
    { 0, output_2571, 0 },
#endif
    { 0 },
    &operand_data[3854],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2572 },
#else
    { 0, output_2572, 0 },
#endif
    { 0 },
    &operand_data[3857],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4331 */
  {
    "*aarch64_combinez_bedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_2573 },
#else
    { 0, output_2573, 0 },
#endif
    { 0 },
    &operand_data[3860],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_saddlv16qi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv16qi_hi_internal },
    &operand_data[3262],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_ssublv16qi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv16qi_hi_internal },
    &operand_data[3262],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_uaddlv16qi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv16qi_hi_internal },
    &operand_data[3262],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_usublv16qi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv16qi_hi_internal },
    &operand_data[3262],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_saddlv8hi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv8hi_hi_internal },
    &operand_data[3266],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_ssublv8hi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv8hi_hi_internal },
    &operand_data[3266],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_uaddlv8hi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv8hi_hi_internal },
    &operand_data[3266],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_usublv8hi_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv8hi_hi_internal },
    &operand_data[3266],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_saddlv4si_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv4si_hi_internal },
    &operand_data[3270],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_ssublv4si_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv4si_hi_internal },
    &operand_data[3270],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_uaddlv4si_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv4si_hi_internal },
    &operand_data[3270],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4405 */
  {
    "aarch64_usublv4si_hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv4si_hi_internal },
    &operand_data[3270],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_saddlv16qi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv16qi_lo_internal },
    &operand_data[3250],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_ssublv16qi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv16qi_lo_internal },
    &operand_data[3250],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_uaddlv16qi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv16qi_lo_internal },
    &operand_data[3250],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_usublv16qi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv16qi_lo_internal },
    &operand_data[3250],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_saddlv8hi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv8hi_lo_internal },
    &operand_data[3254],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_ssublv8hi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv8hi_lo_internal },
    &operand_data[3254],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_uaddlv8hi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv8hi_lo_internal },
    &operand_data[3254],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_usublv8hi_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv8hi_lo_internal },
    &operand_data[3254],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_saddlv4si_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv4si_lo_internal },
    &operand_data[3258],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_ssublv4si_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv4si_lo_internal },
    &operand_data[3258],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_uaddlv4si_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv4si_lo_internal },
    &operand_data[3258],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4418 */
  {
    "aarch64_usublv4si_lo_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv4si_lo_internal },
    &operand_data[3258],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_saddlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_ssublv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_uaddlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_usublv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_saddlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_ssublv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_uaddlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_usublv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_saddlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddlv2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_ssublv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssublv2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_uaddlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddlv2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4527 */
  {
    "aarch64_usublv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubl\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usublv2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4596 */
  {
    "aarch64_ssubwv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubwv8qi },
    &operand_data[3863],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4596 */
  {
    "aarch64_usubwv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubwv8qi },
    &operand_data[3863],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4596 */
  {
    "aarch64_ssubwv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubwv4hi },
    &operand_data[3866],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4596 */
  {
    "aarch64_usubwv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubwv4hi },
    &operand_data[3866],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4596 */
  {
    "aarch64_ssubwv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubwv2si },
    &operand_data[3869],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4596 */
  {
    "aarch64_usubwv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubwv2si },
    &operand_data[3869],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4606 */
  {
    "aarch64_ssubwv16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubwv16qi_internal },
    &operand_data[3872],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4606 */
  {
    "aarch64_usubwv16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubwv16qi_internal },
    &operand_data[3872],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4606 */
  {
    "aarch64_ssubwv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubwv8hi_internal },
    &operand_data[3876],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4606 */
  {
    "aarch64_usubwv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubwv8hi_internal },
    &operand_data[3876],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4606 */
  {
    "aarch64_ssubwv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubwv4si_internal },
    &operand_data[3880],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4606 */
  {
    "aarch64_usubwv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubwv4si_internal },
    &operand_data[3880],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4618 */
  {
    "aarch64_ssubw2v16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw2\t%0.8h, %1.8h, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubw2v16qi_internal },
    &operand_data[3884],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4618 */
  {
    "aarch64_usubw2v16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw2\t%0.8h, %1.8h, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubw2v16qi_internal },
    &operand_data[3884],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4618 */
  {
    "aarch64_ssubw2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw2\t%0.4s, %1.4s, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubw2v8hi_internal },
    &operand_data[3888],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4618 */
  {
    "aarch64_usubw2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw2\t%0.4s, %1.4s, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubw2v8hi_internal },
    &operand_data[3888],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4618 */
  {
    "aarch64_ssubw2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubw2\t%0.2d, %1.2d, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubw2v4si_internal },
    &operand_data[3892],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4618 */
  {
    "aarch64_usubw2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubw2\t%0.2d, %1.2d, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubw2v4si_internal },
    &operand_data[3892],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4630 */
  {
    "aarch64_saddwv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddwv8qi },
    &operand_data[3863],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4630 */
  {
    "aarch64_uaddwv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddwv8qi },
    &operand_data[3863],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4630 */
  {
    "aarch64_saddwv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddwv4hi },
    &operand_data[3866],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4630 */
  {
    "aarch64_uaddwv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddwv4hi },
    &operand_data[3866],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4630 */
  {
    "aarch64_saddwv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddwv2si },
    &operand_data[3869],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4630 */
  {
    "aarch64_uaddwv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddwv2si },
    &operand_data[3869],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4640 */
  {
    "aarch64_saddwv16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddwv16qi_internal },
    &operand_data[3872],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4640 */
  {
    "aarch64_uaddwv16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw\t%0.8h, %1.8h, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddwv16qi_internal },
    &operand_data[3872],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4640 */
  {
    "aarch64_saddwv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddwv8hi_internal },
    &operand_data[3876],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4640 */
  {
    "aarch64_uaddwv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw\t%0.4s, %1.4s, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddwv8hi_internal },
    &operand_data[3876],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4640 */
  {
    "aarch64_saddwv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddwv4si_internal },
    &operand_data[3880],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4640 */
  {
    "aarch64_uaddwv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw\t%0.2d, %1.2d, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddwv4si_internal },
    &operand_data[3880],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4653 */
  {
    "aarch64_saddw2v16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw2\t%0.8h, %1.8h, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddw2v16qi_internal },
    &operand_data[3884],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4653 */
  {
    "aarch64_uaddw2v16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw2\t%0.8h, %1.8h, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddw2v16qi_internal },
    &operand_data[3884],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4653 */
  {
    "aarch64_saddw2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw2\t%0.4s, %1.4s, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddw2v8hi_internal },
    &operand_data[3888],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4653 */
  {
    "aarch64_uaddw2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw2\t%0.4s, %1.4s, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddw2v8hi_internal },
    &operand_data[3888],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4653 */
  {
    "aarch64_saddw2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddw2\t%0.2d, %1.2d, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddw2v4si_internal },
    &operand_data[3892],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4653 */
  {
    "aarch64_uaddw2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddw2\t%0.2d, %1.2d, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddw2v4si_internal },
    &operand_data[3892],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shadd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shaddv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhadd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhaddv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_srhaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srhadd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srhaddv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_urhaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urhadd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urhaddv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shsubv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shsub\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shsubv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhsubv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhsub\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhsubv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shadd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shaddv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhadd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhaddv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_srhaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srhadd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srhaddv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_urhaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urhadd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urhaddv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shsubv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shsub\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shsubv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhsubv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhsub\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhsubv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shadd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shaddv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhadd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhaddv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_srhaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srhadd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srhaddv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_urhaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urhadd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urhaddv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shsubv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shsub\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shsubv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhsubv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhsub\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhsubv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shadd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shaddv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhadd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhaddv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_srhaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srhadd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srhaddv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_urhaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urhadd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urhaddv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shsubv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shsub\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shsubv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhsubv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhsub\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhsubv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shadd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shaddv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhadd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhaddv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_srhaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srhadd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srhaddv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_urhaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urhadd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urhaddv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shsubv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shsub\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shsubv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhsubv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhsub\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhsubv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shadd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shaddv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhadd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhaddv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_srhaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srhadd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srhaddv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_urhaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urhadd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urhaddv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_shsubv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shsub\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shsubv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4733 */
  {
    "aarch64_uhsubv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uhsub\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uhsubv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_addhnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv8hi_insn_le },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_raddhnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv8hi_insn_le },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_subhnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv8hi_insn_le },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_rsubhnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv8hi_insn_le },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_addhnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv4si_insn_le },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_raddhnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv4si_insn_le },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_subhnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv4si_insn_le },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_rsubhnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv4si_insn_le },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_addhnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv2di_insn_le },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_raddhnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv2di_insn_le },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_subhnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv2di_insn_le },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4745 */
  {
    "aarch64_rsubhnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv2di_insn_le },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_addhnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv8hi_insn_be },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_raddhnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv8hi_insn_be },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_subhnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv8hi_insn_be },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_rsubhnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn\t%0.8b, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv8hi_insn_be },
    &operand_data[3896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_addhnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv4si_insn_be },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_raddhnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv4si_insn_be },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_subhnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv4si_insn_be },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_rsubhnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn\t%0.4h, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv4si_insn_be },
    &operand_data[3900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_addhnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv2di_insn_be },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_raddhnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv2di_insn_be },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_subhnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv2di_insn_be },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4757 */
  {
    "aarch64_rsubhnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn\t%0.2s, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv2di_insn_be },
    &operand_data[3904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_addhn2v8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v8hi_insn_le },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_raddhn2v8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v8hi_insn_le },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_subhn2v8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v8hi_insn_le },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_rsubhn2v8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v8hi_insn_le },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_addhn2v4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v4si_insn_le },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_raddhn2v4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v4si_insn_le },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_subhn2v4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v4si_insn_le },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_rsubhn2v4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v4si_insn_le },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_addhn2v2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v2di_insn_le },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_raddhn2v2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v2di_insn_le },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_subhn2v2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v2di_insn_le },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4792 */
  {
    "aarch64_rsubhn2v2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v2di_insn_le },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_addhn2v8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v8hi_insn_be },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_raddhn2v8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v8hi_insn_be },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_subhn2v8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v8hi_insn_be },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_rsubhn2v8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn2\t%0.16b, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v8hi_insn_be },
    &operand_data[3908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_addhn2v4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v4si_insn_be },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_raddhn2v4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v4si_insn_be },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_subhn2v4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v4si_insn_be },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_rsubhn2v4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn2\t%0.8h, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v4si_insn_be },
    &operand_data[3912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_addhn2v2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v2di_insn_be },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_raddhn2v2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v2di_insn_be },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_subhn2v2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v2di_insn_be },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4804 */
  {
    "aarch64_rsubhn2v2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhn2\t%0.4s, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v2di_insn_be },
    &operand_data[3916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4836 */
  {
    "aarch64_pmulv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmul\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pmulv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4836 */
  {
    "aarch64_pmulv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmul\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pmulv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4846 */
  {
    "aarch64_pmullv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmull\t%0.8h, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pmullv8qi },
    &operand_data[2672],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4856 */
  {
    "aarch64_pmull_hiv16qi_insn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmull2\t%0.8h, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pmull_hiv16qi_insn },
    &operand_data[3262],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxhf },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxsf },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4886 */
  {
    "aarch64_fmulxdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmulxdf },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4899 */
  {
    "*aarch64_mulx_elt_to_128v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2742 },
#else
    { 0, 0, output_2742 },
#endif
    { 0 },
    &operand_data[3920],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4899 */
  {
    "*aarch64_mulx_elt_to_64v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2743 },
#else
    { 0, 0, output_2743 },
#endif
    { 0 },
    &operand_data[2601],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4918 */
  {
    "*aarch64_mulx_eltv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2744 },
#else
    { 0, 0, output_2744 },
#endif
    { 0 },
    &operand_data[2597],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4918 */
  {
    "*aarch64_mulx_eltv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2745 },
#else
    { 0, 0, output_2745 },
#endif
    { 0 },
    &operand_data[3924],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4918 */
  {
    "*aarch64_mulx_eltv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2746 },
#else
    { 0, 0, output_2746 },
#endif
    { 0 },
    &operand_data[3928],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4937 */
  {
    "*aarch64_mulx_elt_from_dupv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.4h, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2653],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4937 */
  {
    "*aarch64_mulx_elt_from_dupv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.8h, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2656],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4937 */
  {
    "*aarch64_mulx_elt_from_dupv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.2s, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2659],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4937 */
  {
    "*aarch64_mulx_elt_from_dupv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.4s, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2662],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4937 */
  {
    "*aarch64_mulx_elt_from_dupv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmulx\t%0.2d, %1.2d, %2.d[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[2665],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4953 */
  {
    "*aarch64_vgetfmulxv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2752 },
#else
    { 0, 0, output_2752 },
#endif
    { 0 },
    &operand_data[3932],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4953 */
  {
    "*aarch64_vgetfmulxv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2753 },
#else
    { 0, 0, output_2753 },
#endif
    { 0 },
    &operand_data[3936],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4953 */
  {
    "*aarch64_vgetfmulxv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2754 },
#else
    { 0, 0, output_2754 },
#endif
    { 0 },
    &operand_data[3940],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqaddsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqaddsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqaddsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqaddsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqadddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqadd\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqadddi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqadddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqadd\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqadddi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_sqsubdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqsub\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqsubdi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4970 */
  {
    "aarch64_uqsubdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqsub\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqsubdi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%0.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddv8qi },
    &operand_data[2723],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%0.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddv8qi },
    &operand_data[2723],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%0.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddv16qi },
    &operand_data[2727],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%0.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddv16qi },
    &operand_data[2727],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%0.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddv4hi },
    &operand_data[2731],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%0.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddv4hi },
    &operand_data[2731],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%0.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddv8hi },
    &operand_data[2735],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%0.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddv8hi },
    &operand_data[2735],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%0.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddv2si },
    &operand_data[2739],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%0.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddv2si },
    &operand_data[2739],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%0.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddv4si },
    &operand_data[2743],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%0.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddv4si },
    &operand_data[2743],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%0.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddv2di },
    &operand_data[3956],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%0.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddv2di },
    &operand_data[3956],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%b0, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddqi },
    &operand_data[3959],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%b0, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddqi },
    &operand_data[3959],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%h0, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddhi },
    &operand_data[3962],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%h0, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddhi },
    &operand_data[3962],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqaddsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%s0, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqaddsi },
    &operand_data[3965],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqaddsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%s0, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqaddsi },
    &operand_data[3965],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_suqadddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "suqadd\t%d0, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_suqadddi },
    &operand_data[3968],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4981 */
  {
    "aarch64_usqadddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usqadd\t%d0, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usqadddi },
    &operand_data[3968],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4993 */
  {
    "aarch64_sqmovnhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%b0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnhi },
    &operand_data[3971],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4993 */
  {
    "aarch64_uqmovnhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%b0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnhi },
    &operand_data[3971],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4993 */
  {
    "aarch64_sqmovnsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%h0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnsi },
    &operand_data[3973],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4993 */
  {
    "aarch64_uqmovnsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%h0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnsi },
    &operand_data[3973],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4993 */
  {
    "aarch64_sqmovndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%s0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovndi },
    &operand_data[3975],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4993 */
  {
    "aarch64_uqmovndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%s0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovndi },
    &operand_data[3975],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5002 */
  {
    "aarch64_sqmovnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv8hi_insn_le },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5002 */
  {
    "aarch64_uqmovnv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv8hi_insn_le },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5002 */
  {
    "aarch64_sqmovnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv4si_insn_le },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5002 */
  {
    "aarch64_uqmovnv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv4si_insn_le },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5002 */
  {
    "aarch64_sqmovnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv2di_insn_le },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5002 */
  {
    "aarch64_uqmovnv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv2di_insn_le },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5013 */
  {
    "aarch64_sqmovnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv8hi_insn_be },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5013 */
  {
    "aarch64_uqmovnv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv8hi_insn_be },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5013 */
  {
    "aarch64_sqmovnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv4si_insn_be },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5013 */
  {
    "aarch64_uqmovnv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv4si_insn_be },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5013 */
  {
    "aarch64_sqmovnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv2di_insn_be },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5013 */
  {
    "aarch64_uqmovnv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv2di_insn_be },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5046 */
  {
    "aarch64_sqxtn2v8hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v8hi_le },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5046 */
  {
    "aarch64_uqxtn2v8hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v8hi_le },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5046 */
  {
    "aarch64_sqxtn2v4si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v4si_le },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5046 */
  {
    "aarch64_uqxtn2v4si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v4si_le },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5046 */
  {
    "aarch64_sqxtn2v2di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v2di_le },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5046 */
  {
    "aarch64_uqxtn2v2di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v2di_le },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5057 */
  {
    "aarch64_sqxtn2v8hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v8hi_be },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5057 */
  {
    "aarch64_uqxtn2v8hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v8hi_be },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5057 */
  {
    "aarch64_sqxtn2v4si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v4si_be },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5057 */
  {
    "aarch64_uqxtn2v4si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v4si_be },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5057 */
  {
    "aarch64_sqxtn2v2di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v2di_be },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5057 */
  {
    "aarch64_uqxtn2v2di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtn2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v2di_be },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5087 */
  {
    "aarch64_sqmovunhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%b0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunhi },
    &operand_data[3971],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5087 */
  {
    "aarch64_sqmovunsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%h0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunsi },
    &operand_data[3973],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5087 */
  {
    "aarch64_sqmovundi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%s0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovundi },
    &operand_data[3975],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5096 */
  {
    "aarch64_sqmovunv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv8hi_insn_le },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5096 */
  {
    "aarch64_sqmovunv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv4si_insn_le },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5096 */
  {
    "aarch64_sqmovunv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv2di_insn_le },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5107 */
  {
    "aarch64_sqmovunv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv8hi_insn_be },
    &operand_data[3112],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5107 */
  {
    "aarch64_sqmovunv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv4si_insn_be },
    &operand_data[3115],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5107 */
  {
    "aarch64_sqmovunv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv2di_insn_be },
    &operand_data[3118],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5140 */
  {
    "aarch64_sqxtun2v8hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v8hi_le },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5140 */
  {
    "aarch64_sqxtun2v4si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v4si_le },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5140 */
  {
    "aarch64_sqxtun2v2di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v2di_le },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5151 */
  {
    "aarch64_sqxtun2v8hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun2\t%0.16b, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v8hi_be },
    &operand_data[3121],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5151 */
  {
    "aarch64_sqxtun2v4si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v4si_be },
    &operand_data[3124],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5151 */
  {
    "aarch64_sqxtun2v2di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtun2\t%0.4s, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v2di_be },
    &operand_data[3127],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsv8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegv4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsv4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegv8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsv8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegv2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsv2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegv4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsv4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegv2di },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsv2di },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%b0, %b1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegqi },
    &operand_data[976],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%b0, %b1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsqi },
    &operand_data[976],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqneghi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqneghi },
    &operand_data[3947],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabshi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabshi },
    &operand_data[3947],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegsi },
    &operand_data[973],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabssi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabssi },
    &operand_data[973],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqnegdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqneg\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqnegdi },
    &operand_data[970],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5181 */
  {
    "aarch64_sqabsdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqabs\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqabsdi },
    &operand_data[970],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqdmulhv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulhv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqrdmulhv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulhv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqdmulhv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulhv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqrdmulhv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulhv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqdmulhv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulhv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqrdmulhv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulhv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqdmulhv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulhv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqrdmulhv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulhv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqdmulhhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulhhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqrdmulhhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulhhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqdmulhsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulhsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5192 */
  {
    "aarch64_sqrdmulhsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulhsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqdmulh_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.4h, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_nv4hi },
    &operand_data[2641],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqrdmulh_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.4h, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_nv4hi },
    &operand_data[2641],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqdmulh_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.8h, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_nv8hi },
    &operand_data[2644],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqrdmulh_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.8h, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_nv8hi },
    &operand_data[2644],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqdmulh_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.2s, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_nv2si },
    &operand_data[2647],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqrdmulh_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.2s, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_nv2si },
    &operand_data[2647],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqdmulh_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.4s, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_nv4si },
    &operand_data[2650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5203 */
  {
    "aarch64_sqrdmulh_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.4s, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_nv4si },
    &operand_data[2650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqdmulh_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2908 },
#else
    { 0, 0, output_2908 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_lanev4hi },
    &operand_data[2573],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqrdmulh_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2909 },
#else
    { 0, 0, output_2909 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_lanev4hi },
    &operand_data[2573],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqdmulh_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2910 },
#else
    { 0, 0, output_2910 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_lanev8hi },
    &operand_data[2577],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqrdmulh_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2911 },
#else
    { 0, 0, output_2911 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_lanev8hi },
    &operand_data[2577],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqdmulh_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2912 },
#else
    { 0, 0, output_2912 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_lanev2si },
    &operand_data[2581],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqrdmulh_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2913 },
#else
    { 0, 0, output_2913 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_lanev2si },
    &operand_data[2581],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqdmulh_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2914 },
#else
    { 0, 0, output_2914 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_lanev4si },
    &operand_data[2585],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5217 */
  {
    "aarch64_sqrdmulh_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2915 },
#else
    { 0, 0, output_2915 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_lanev4si },
    &operand_data[2585],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqdmulh_laneqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2916 },
#else
    { 0, 0, output_2916 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_laneqv4hi },
    &operand_data[3977],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqrdmulh_laneqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2917 },
#else
    { 0, 0, output_2917 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_laneqv4hi },
    &operand_data[3977],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqdmulh_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2918 },
#else
    { 0, 0, output_2918 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_laneqv8hi },
    &operand_data[3981],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqrdmulh_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2919 },
#else
    { 0, 0, output_2919 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_laneqv8hi },
    &operand_data[3981],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqdmulh_laneqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2920 },
#else
    { 0, 0, output_2920 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_laneqv2si },
    &operand_data[3985],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqrdmulh_laneqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2921 },
#else
    { 0, 0, output_2921 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_laneqv2si },
    &operand_data[3985],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqdmulh_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2922 },
#else
    { 0, 0, output_2922 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_laneqv4si },
    &operand_data[3989],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5232 */
  {
    "aarch64_sqrdmulh_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2923 },
#else
    { 0, 0, output_2923 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_laneqv4si },
    &operand_data[3989],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5247 */
  {
    "aarch64_sqdmulh_lanehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2924 },
#else
    { 0, 0, output_2924 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_lanehi },
    &operand_data[3993],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5247 */
  {
    "aarch64_sqrdmulh_lanehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2925 },
#else
    { 0, 0, output_2925 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_lanehi },
    &operand_data[3993],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5247 */
  {
    "aarch64_sqdmulh_lanesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2926 },
#else
    { 0, 0, output_2926 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_lanesi },
    &operand_data[3997],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5247 */
  {
    "aarch64_sqrdmulh_lanesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2927 },
#else
    { 0, 0, output_2927 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_lanesi },
    &operand_data[3997],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5262 */
  {
    "aarch64_sqdmulh_laneqhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2928 },
#else
    { 0, 0, output_2928 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_laneqhi },
    &operand_data[4001],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5262 */
  {
    "aarch64_sqrdmulh_laneqhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2929 },
#else
    { 0, 0, output_2929 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_laneqhi },
    &operand_data[4001],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5262 */
  {
    "aarch64_sqdmulh_laneqsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2930 },
#else
    { 0, 0, output_2930 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmulh_laneqsi },
    &operand_data[4005],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5262 */
  {
    "aarch64_sqrdmulh_laneqsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2931 },
#else
    { 0, 0, output_2931 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmulh_laneqsi },
    &operand_data[4005],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlahv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlah\t%0.4h, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlahv4hi },
    &operand_data[2731],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlshv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlsh\t%0.4h, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlshv4hi },
    &operand_data[2731],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlahv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlah\t%0.8h, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlahv8hi },
    &operand_data[2735],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlshv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlsh\t%0.8h, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlshv8hi },
    &operand_data[2735],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlahv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlah\t%0.2s, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlahv2si },
    &operand_data[2739],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlshv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlsh\t%0.2s, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlshv2si },
    &operand_data[2739],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlahv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlah\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlahv4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlshv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlsh\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlshv4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlahhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlah\t%h0, %h2, %h3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlahhi },
    &operand_data[4009],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlshhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlsh\t%h0, %h2, %h3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlshhi },
    &operand_data[4009],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlahsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlah\t%s0, %s2, %s3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlahsi },
    &operand_data[4013],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5279 */
  {
    "aarch64_sqrdmlshsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmlsh\t%s0, %s2, %s3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlshsi },
    &operand_data[4013],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlah_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2944 },
#else
    { 0, 0, output_2944 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_lanev4hi },
    &operand_data[4017],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlsh_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2945 },
#else
    { 0, 0, output_2945 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_lanev4hi },
    &operand_data[4017],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlah_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2946 },
#else
    { 0, 0, output_2946 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_lanev8hi },
    &operand_data[4022],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlsh_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2947 },
#else
    { 0, 0, output_2947 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_lanev8hi },
    &operand_data[4022],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlah_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2948 },
#else
    { 0, 0, output_2948 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_lanev2si },
    &operand_data[4027],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlsh_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2949 },
#else
    { 0, 0, output_2949 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_lanev2si },
    &operand_data[4027],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlah_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2950 },
#else
    { 0, 0, output_2950 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_lanev4si },
    &operand_data[4032],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5293 */
  {
    "aarch64_sqrdmlsh_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2951 },
#else
    { 0, 0, output_2951 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_lanev4si },
    &operand_data[4032],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5311 */
  {
    "aarch64_sqrdmlah_lanehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2952 },
#else
    { 0, 0, output_2952 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_lanehi },
    &operand_data[4037],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5311 */
  {
    "aarch64_sqrdmlsh_lanehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2953 },
#else
    { 0, 0, output_2953 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_lanehi },
    &operand_data[4037],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5311 */
  {
    "aarch64_sqrdmlah_lanesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2954 },
#else
    { 0, 0, output_2954 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_lanesi },
    &operand_data[4042],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5311 */
  {
    "aarch64_sqrdmlsh_lanesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2955 },
#else
    { 0, 0, output_2955 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_lanesi },
    &operand_data[4042],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlah_laneqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2956 },
#else
    { 0, 0, output_2956 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_laneqv4hi },
    &operand_data[4047],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlsh_laneqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2957 },
#else
    { 0, 0, output_2957 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_laneqv4hi },
    &operand_data[4047],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlah_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2958 },
#else
    { 0, 0, output_2958 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_laneqv8hi },
    &operand_data[4052],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlsh_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2959 },
#else
    { 0, 0, output_2959 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_laneqv8hi },
    &operand_data[4052],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlah_laneqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2960 },
#else
    { 0, 0, output_2960 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_laneqv2si },
    &operand_data[4057],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlsh_laneqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2961 },
#else
    { 0, 0, output_2961 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_laneqv2si },
    &operand_data[4057],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlah_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2962 },
#else
    { 0, 0, output_2962 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_laneqv4si },
    &operand_data[4062],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5331 */
  {
    "aarch64_sqrdmlsh_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2963 },
#else
    { 0, 0, output_2963 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_laneqv4si },
    &operand_data[4062],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5349 */
  {
    "aarch64_sqrdmlah_laneqhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2964 },
#else
    { 0, 0, output_2964 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_laneqhi },
    &operand_data[4067],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5349 */
  {
    "aarch64_sqrdmlsh_laneqhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2965 },
#else
    { 0, 0, output_2965 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_laneqhi },
    &operand_data[4067],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5349 */
  {
    "aarch64_sqrdmlah_laneqsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2966 },
#else
    { 0, 0, output_2966 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlah_laneqsi },
    &operand_data[4072],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5349 */
  {
    "aarch64_sqrdmlsh_laneqsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2967 },
#else
    { 0, 0, output_2967 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdmlsh_laneqsi },
    &operand_data[4072],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5369 */
  {
    "aarch64_sqdmlalv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlalv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5369 */
  {
    "aarch64_sqdmlalv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlalv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5369 */
  {
    "aarch64_sqdmlalhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal\t%s0, %h2, %h3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlalhi },
    &operand_data[4077],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5369 */
  {
    "aarch64_sqdmlalsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal\t%d0, %s2, %s3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlalsi },
    &operand_data[4081],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5385 */
  {
    "aarch64_sqdmlslv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlslv4hi },
    &operand_data[2694],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5385 */
  {
    "aarch64_sqdmlslv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl\t%0.2d, %2.2s, %3.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlslv2si },
    &operand_data[2698],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5385 */
  {
    "aarch64_sqdmlslhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl\t%s0, %h2, %h3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlslhi },
    &operand_data[4077],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5385 */
  {
    "aarch64_sqdmlslsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl\t%d0, %s2, %s3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlslsi },
    &operand_data[4081],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5403 */
  {
    "aarch64_sqdmlal_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2976 },
#else
    { 0, 0, output_2976 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_lanev4hi },
    &operand_data[3324],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5403 */
  {
    "aarch64_sqdmlal_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2977 },
#else
    { 0, 0, output_2977 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_lanev2si },
    &operand_data[3334],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5427 */
  {
    "aarch64_sqdmlsl_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2978 },
#else
    { 0, 0, output_2978 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_lanev4hi },
    &operand_data[3324],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5427 */
  {
    "aarch64_sqdmlsl_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2979 },
#else
    { 0, 0, output_2979 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_lanev2si },
    &operand_data[3334],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5452 */
  {
    "aarch64_sqdmlsl_laneqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2980 },
#else
    { 0, 0, output_2980 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_laneqv4hi },
    &operand_data[3329],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5452 */
  {
    "aarch64_sqdmlsl_laneqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2981 },
#else
    { 0, 0, output_2981 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_laneqv2si },
    &operand_data[3339],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5476 */
  {
    "aarch64_sqdmlal_laneqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2982 },
#else
    { 0, 0, output_2982 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_laneqv4hi },
    &operand_data[3329],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5476 */
  {
    "aarch64_sqdmlal_laneqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2983 },
#else
    { 0, 0, output_2983 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_laneqv2si },
    &operand_data[3339],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5501 */
  {
    "aarch64_sqdmlal_lanehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2984 },
#else
    { 0, 0, output_2984 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_lanehi },
    &operand_data[4085],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5501 */
  {
    "aarch64_sqdmlal_lanesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2985 },
#else
    { 0, 0, output_2985 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_lanesi },
    &operand_data[4090],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5524 */
  {
    "aarch64_sqdmlsl_lanehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2986 },
#else
    { 0, 0, output_2986 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_lanehi },
    &operand_data[4085],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5524 */
  {
    "aarch64_sqdmlsl_lanesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2987 },
#else
    { 0, 0, output_2987 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_lanesi },
    &operand_data[4090],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5548 */
  {
    "aarch64_sqdmlal_laneqhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2988 },
#else
    { 0, 0, output_2988 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_laneqhi },
    &operand_data[4095],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5548 */
  {
    "aarch64_sqdmlal_laneqsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2989 },
#else
    { 0, 0, output_2989 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_laneqsi },
    &operand_data[4100],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5571 */
  {
    "aarch64_sqdmlsl_laneqhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2990 },
#else
    { 0, 0, output_2990 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_laneqhi },
    &operand_data[4095],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5571 */
  {
    "aarch64_sqdmlsl_laneqsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_2991 },
#else
    { 0, 0, output_2991 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_laneqsi },
    &operand_data[4100],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5596 */
  {
    "aarch64_sqdmlsl_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl\t%0.4s, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_nv4hi },
    &operand_data[3242],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5596 */
  {
    "aarch64_sqdmlsl_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl\t%0.2d, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl_nv2si },
    &operand_data[3246],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5613 */
  {
    "aarch64_sqdmlal_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal\t%0.4s, %2.4h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_nv4hi },
    &operand_data[3242],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5613 */
  {
    "aarch64_sqdmlal_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal\t%0.2d, %2.2s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal_nv2si },
    &operand_data[3246],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5633 */
  {
    "aarch64_sqdmlal2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal2\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2v8hi_internal },
    &operand_data[4105],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5633 */
  {
    "aarch64_sqdmlal2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal2\t%0.2d, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2v4si_internal },
    &operand_data[4110],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5653 */
  {
    "aarch64_sqdmlsl2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl2\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2v8hi_internal },
    &operand_data[4105],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5653 */
  {
    "aarch64_sqdmlsl2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl2\t%0.2d, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2v4si_internal },
    &operand_data[4110],
    5,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5691 */
  {
    "aarch64_sqdmlsl2_lanev8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3000 },
#else
    { 0, 0, output_3000 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_lanev8hi_internal },
    &operand_data[4115],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5691 */
  {
    "aarch64_sqdmlsl2_lanev4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3001 },
#else
    { 0, 0, output_3001 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_lanev4si_internal },
    &operand_data[4121],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5717 */
  {
    "aarch64_sqdmlal2_lanev8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3002 },
#else
    { 0, 0, output_3002 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_lanev8hi_internal },
    &operand_data[4115],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5717 */
  {
    "aarch64_sqdmlal2_lanev4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3003 },
#else
    { 0, 0, output_3003 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_lanev4si_internal },
    &operand_data[4121],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5743 */
  {
    "aarch64_sqdmlsl2_laneqv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3004 },
#else
    { 0, 0, output_3004 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_laneqv8hi_internal },
    &operand_data[4127],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5743 */
  {
    "aarch64_sqdmlsl2_laneqv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3005 },
#else
    { 0, 0, output_3005 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_laneqv4si_internal },
    &operand_data[4133],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5769 */
  {
    "aarch64_sqdmlal2_laneqv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3006 },
#else
    { 0, 0, output_3006 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_laneqv8hi_internal },
    &operand_data[4127],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5769 */
  {
    "aarch64_sqdmlal2_laneqv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3007 },
#else
    { 0, 0, output_3007 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_laneqv4si_internal },
    &operand_data[4133],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5829 */
  {
    "aarch64_sqdmlsl2_nv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl2\t%0.4s, %2.8h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_nv8hi_internal },
    &operand_data[4139],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5829 */
  {
    "aarch64_sqdmlsl2_nv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlsl2\t%0.2d, %2.4s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_nv4si_internal },
    &operand_data[4144],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5848 */
  {
    "aarch64_sqdmlal2_nv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal2\t%0.4s, %2.8h, %3.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_nv8hi_internal },
    &operand_data[4139],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5848 */
  {
    "aarch64_sqdmlal2_nv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmlal2\t%0.2d, %2.4s, %3.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_nv4si_internal },
    &operand_data[4144],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5885 */
  {
    "aarch64_sqdmullv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull\t%0.4s, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmullv4hi },
    &operand_data[2675],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5885 */
  {
    "aarch64_sqdmullv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull\t%0.2d, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmullv2si },
    &operand_data[2678],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5885 */
  {
    "aarch64_sqdmullhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull\t%s0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmullhi },
    &operand_data[4149],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5885 */
  {
    "aarch64_sqdmullsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull\t%d0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmullsi },
    &operand_data[4152],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5901 */
  {
    "aarch64_sqdmull_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3016 },
#else
    { 0, 0, output_3016 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_lanev4hi },
    &operand_data[3274],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5901 */
  {
    "aarch64_sqdmull_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3017 },
#else
    { 0, 0, output_3017 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_lanev2si },
    &operand_data[3282],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5922 */
  {
    "aarch64_sqdmull_laneqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3018 },
#else
    { 0, 0, output_3018 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_laneqv4hi },
    &operand_data[3278],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5922 */
  {
    "aarch64_sqdmull_laneqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3019 },
#else
    { 0, 0, output_3019 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_laneqv2si },
    &operand_data[3286],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5943 */
  {
    "aarch64_sqdmull_lanehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3020 },
#else
    { 0, 0, output_3020 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_lanehi },
    &operand_data[4155],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5943 */
  {
    "aarch64_sqdmull_lanesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3021 },
#else
    { 0, 0, output_3021 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_lanesi },
    &operand_data[4159],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5963 */
  {
    "aarch64_sqdmull_laneqhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3022 },
#else
    { 0, 0, output_3022 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_laneqhi },
    &operand_data[4163],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5963 */
  {
    "aarch64_sqdmull_laneqsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3023 },
#else
    { 0, 0, output_3023 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_laneqsi },
    &operand_data[4167],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5985 */
  {
    "aarch64_sqdmull_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull\t%0.4s, %1.4h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_nv4hi },
    &operand_data[3310],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5985 */
  {
    "aarch64_sqdmull_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull\t%0.2d, %1.2s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull_nv2si },
    &operand_data[3313],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6003 */
  {
    "aarch64_sqdmull2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull2\t%0.4s, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2v8hi_internal },
    &operand_data[3266],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6003 */
  {
    "aarch64_sqdmull2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull2\t%0.2d, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2v4si_internal },
    &operand_data[3270],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6036 */
  {
    "aarch64_sqdmull2_lanev8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3028 },
#else
    { 0, 0, output_3028 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_lanev8hi_internal },
    &operand_data[4171],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6036 */
  {
    "aarch64_sqdmull2_lanev4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3029 },
#else
    { 0, 0, output_3029 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_lanev4si_internal },
    &operand_data[4176],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6059 */
  {
    "aarch64_sqdmull2_laneqv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3030 },
#else
    { 0, 0, output_3030 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_laneqv8hi_internal },
    &operand_data[4181],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6059 */
  {
    "aarch64_sqdmull2_laneqv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3031 },
#else
    { 0, 0, output_3031 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_laneqv4si_internal },
    &operand_data[4186],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6112 */
  {
    "aarch64_sqdmull2_nv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull2\t%0.4s, %1.8h, %2.h[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_nv8hi_internal },
    &operand_data[3316],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6112 */
  {
    "aarch64_sqdmull2_nv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmull2\t%0.2d, %1.4s, %2.s[0]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_nv4si_internal },
    &operand_data[3320],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_sshldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_ushldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_srshldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6144 */
  {
    "aarch64_urshldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%b0, %b1, %b2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlqi },
    &operand_data[3944],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlhi },
    &operand_data[3947],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshlsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshlsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshlsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshlsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshlsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshlsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshlsi },
    &operand_data[3950],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqshldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqshldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_sqrshldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6158 */
  {
    "aarch64_uqrshldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshl\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshldi },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6201 */
  {
    "aarch64_sshllv16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3110 },
#else
    { 0, 0, output_3110 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshllv16qi_internal },
    &operand_data[4191],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6201 */
  {
    "aarch64_ushllv16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3111 },
#else
    { 0, 0, output_3111 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushllv16qi_internal },
    &operand_data[4191],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6201 */
  {
    "aarch64_sshllv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3112 },
#else
    { 0, 0, output_3112 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshllv8hi_internal },
    &operand_data[4195],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6201 */
  {
    "aarch64_ushllv8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3113 },
#else
    { 0, 0, output_3113 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushllv8hi_internal },
    &operand_data[4195],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6201 */
  {
    "aarch64_sshllv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3114 },
#else
    { 0, 0, output_3114 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshllv4si_internal },
    &operand_data[4199],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6201 */
  {
    "aarch64_ushllv4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3115 },
#else
    { 0, 0, output_3115 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushllv4si_internal },
    &operand_data[4199],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6219 */
  {
    "aarch64_sshll2v16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3116 },
#else
    { 0, 0, output_3116 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll2v16qi_internal },
    &operand_data[4203],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6219 */
  {
    "aarch64_ushll2v16qi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3117 },
#else
    { 0, 0, output_3117 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll2v16qi_internal },
    &operand_data[4203],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6219 */
  {
    "aarch64_sshll2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3118 },
#else
    { 0, 0, output_3118 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll2v8hi_internal },
    &operand_data[4207],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6219 */
  {
    "aarch64_ushll2v8hi_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3119 },
#else
    { 0, 0, output_3119 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll2v8hi_internal },
    &operand_data[4207],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6219 */
  {
    "aarch64_sshll2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3120 },
#else
    { 0, 0, output_3120 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll2v4si_internal },
    &operand_data[4211],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6219 */
  {
    "aarch64_ushll2v4si_internal",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3121 },
#else
    { 0, 0, output_3121 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll2v4si_internal },
    &operand_data[4211],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6237 */
  {
    "aarch64_sshll_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3122 },
#else
    { 0, 0, output_3122 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll_nv8qi },
    &operand_data[4215],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6237 */
  {
    "aarch64_ushll_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3123 },
#else
    { 0, 0, output_3123 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll_nv8qi },
    &operand_data[4215],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6237 */
  {
    "aarch64_sshll_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3124 },
#else
    { 0, 0, output_3124 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll_nv4hi },
    &operand_data[4218],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6237 */
  {
    "aarch64_ushll_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3125 },
#else
    { 0, 0, output_3125 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll_nv4hi },
    &operand_data[4218],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6237 */
  {
    "aarch64_sshll_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3126 },
#else
    { 0, 0, output_3126 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll_nv2si },
    &operand_data[4221],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6237 */
  {
    "aarch64_ushll_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3127 },
#else
    { 0, 0, output_3127 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll_nv2si },
    &operand_data[4221],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6255 */
  {
    "aarch64_sshll2_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3128 },
#else
    { 0, 0, output_3128 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll2_nv16qi },
    &operand_data[4224],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6255 */
  {
    "aarch64_ushll2_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3129 },
#else
    { 0, 0, output_3129 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll2_nv16qi },
    &operand_data[4224],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6255 */
  {
    "aarch64_sshll2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3130 },
#else
    { 0, 0, output_3130 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll2_nv8hi },
    &operand_data[4227],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6255 */
  {
    "aarch64_ushll2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3131 },
#else
    { 0, 0, output_3131 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll2_nv8hi },
    &operand_data[4227],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6255 */
  {
    "aarch64_sshll2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3132 },
#else
    { 0, 0, output_3132 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sshll2_nv4si },
    &operand_data[4230],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6255 */
  {
    "aarch64_ushll2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3133 },
#else
    { 0, 0, output_3133 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ushll2_nv4si },
    &operand_data[4230],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_nv8qi },
    &operand_data[4233],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_nv8qi },
    &operand_data[4233],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_nv16qi },
    &operand_data[4236],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_nv16qi },
    &operand_data[4236],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_nv4hi },
    &operand_data[4239],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_nv4hi },
    &operand_data[4239],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_nv8hi },
    &operand_data[4242],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_nv8hi },
    &operand_data[4242],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_nv2si },
    &operand_data[4245],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_nv2si },
    &operand_data[4245],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_nv4si },
    &operand_data[4248],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_nv4si },
    &operand_data[4248],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_nv2di },
    &operand_data[4251],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_nv2di },
    &operand_data[4251],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_srshr_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srshr\t%d0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srshr_ndi },
    &operand_data[4254],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6272 */
  {
    "aarch64_urshr_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urshr\t%d0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urshr_ndi },
    &operand_data[4254],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_nv8qi },
    &operand_data[4257],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_nv8qi },
    &operand_data[4257],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_nv8qi },
    &operand_data[4257],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_nv8qi },
    &operand_data[4257],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_nv16qi },
    &operand_data[4261],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_nv16qi },
    &operand_data[4261],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_nv16qi },
    &operand_data[4261],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_nv16qi },
    &operand_data[4261],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_nv4hi },
    &operand_data[4265],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_nv4hi },
    &operand_data[4265],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_nv4hi },
    &operand_data[4265],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_nv4hi },
    &operand_data[4265],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_nv8hi },
    &operand_data[4269],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_nv8hi },
    &operand_data[4269],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_nv8hi },
    &operand_data[4269],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_nv8hi },
    &operand_data[4269],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_nv2si },
    &operand_data[4273],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_nv2si },
    &operand_data[4273],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_nv2si },
    &operand_data[4273],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_nv2si },
    &operand_data[4273],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_nv4si },
    &operand_data[4277],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_nv4si },
    &operand_data[4277],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_nv4si },
    &operand_data[4277],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_nv4si },
    &operand_data[4277],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_nv2di },
    &operand_data[4281],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_nv2di },
    &operand_data[4281],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_nv2di },
    &operand_data[4281],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_nv2di },
    &operand_data[4281],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ssra_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssra\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssra_ndi },
    &operand_data[4285],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_usra_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usra\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usra_ndi },
    &operand_data[4285],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_srsra_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "srsra\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_srsra_ndi },
    &operand_data[4285],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6285 */
  {
    "aarch64_ursra_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ursra\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ursra_ndi },
    &operand_data[4285],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_nv8qi },
    &operand_data[4289],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_nv8qi },
    &operand_data[4289],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_nv8qi },
    &operand_data[4257],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.8b, %2.8b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_nv8qi },
    &operand_data[4257],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_nv16qi },
    &operand_data[4293],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_nv16qi },
    &operand_data[4293],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_nv16qi },
    &operand_data[4261],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.16b, %2.16b, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_nv16qi },
    &operand_data[4261],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_nv4hi },
    &operand_data[4297],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_nv4hi },
    &operand_data[4297],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_nv4hi },
    &operand_data[4265],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.4h, %2.4h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_nv4hi },
    &operand_data[4265],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_nv8hi },
    &operand_data[4301],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_nv8hi },
    &operand_data[4301],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_nv8hi },
    &operand_data[4269],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.8h, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_nv8hi },
    &operand_data[4269],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_nv2si },
    &operand_data[4305],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_nv2si },
    &operand_data[4305],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_nv2si },
    &operand_data[4273],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.2s, %2.2s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_nv2si },
    &operand_data[4273],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_nv4si },
    &operand_data[4309],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_nv4si },
    &operand_data[4309],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_nv4si },
    &operand_data[4277],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.4s, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_nv4si },
    &operand_data[4277],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_nv2di },
    &operand_data[4313],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_nv2di },
    &operand_data[4313],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_nv2di },
    &operand_data[4281],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_nv2di },
    &operand_data[4281],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssli_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssli_ndi },
    &operand_data[4317],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usli_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usli_ndi },
    &operand_data[4317],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_ssri_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssri_ndi },
    &operand_data[4285],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6299 */
  {
    "aarch64_usri_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%d0, %d2, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usri_ndi },
    &operand_data[4285],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nv8qi },
    &operand_data[4321],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nv8qi },
    &operand_data[4321],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.8b, %1.8b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nv8qi },
    &operand_data[4321],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nv16qi },
    &operand_data[4324],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nv16qi },
    &operand_data[4324],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.16b, %1.16b, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nv16qi },
    &operand_data[4324],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nv4hi },
    &operand_data[4327],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nv4hi },
    &operand_data[4327],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.4h, %1.4h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nv4hi },
    &operand_data[4327],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nv8hi },
    &operand_data[4330],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nv8hi },
    &operand_data[4330],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.8h, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nv8hi },
    &operand_data[4330],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nv2si },
    &operand_data[4333],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nv2si },
    &operand_data[4333],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.2s, %1.2s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nv2si },
    &operand_data[4333],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nv4si },
    &operand_data[4336],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nv4si },
    &operand_data[4336],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.4s, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nv4si },
    &operand_data[4336],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nv2di },
    &operand_data[4339],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nv2di },
    &operand_data[4339],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%0.2d, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nv2di },
    &operand_data[4339],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%b0, %b1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nqi },
    &operand_data[4342],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%b0, %b1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nqi },
    &operand_data[4342],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%b0, %b1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nqi },
    &operand_data[4342],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%h0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nhi },
    &operand_data[4345],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%h0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nhi },
    &operand_data[4345],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%h0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nhi },
    &operand_data[4345],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%s0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_nsi },
    &operand_data[4348],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%s0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_nsi },
    &operand_data[4348],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%s0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_nsi },
    &operand_data[4348],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshlu_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshlu\t%d0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshlu_ndi },
    &operand_data[4351],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_sqshl_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshl\t%d0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshl_ndi },
    &operand_data[4351],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6313 */
  {
    "aarch64_uqshl_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshl\t%d0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshl_ndi },
    &operand_data[4351],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqshrun_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%b0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nhi },
    &operand_data[4354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqrshrun_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%b0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nhi },
    &operand_data[4354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqshrn_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%b0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nhi },
    &operand_data[4354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_uqshrn_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%b0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nhi },
    &operand_data[4354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqrshrn_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%b0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nhi },
    &operand_data[4354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_uqrshrn_nhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%b0, %h1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nhi },
    &operand_data[4354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqshrun_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%h0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nsi },
    &operand_data[4357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqrshrun_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%h0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nsi },
    &operand_data[4357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqshrn_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%h0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nsi },
    &operand_data[4357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_uqshrn_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%h0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nsi },
    &operand_data[4357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqrshrn_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%h0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nsi },
    &operand_data[4357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_uqrshrn_nsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%h0, %s1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nsi },
    &operand_data[4357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqshrun_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%s0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_ndi },
    &operand_data[4360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqrshrun_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%s0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_ndi },
    &operand_data[4360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqshrn_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%s0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_ndi },
    &operand_data[4360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_uqshrn_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%s0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_ndi },
    &operand_data[4360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_sqrshrn_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%s0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_ndi },
    &operand_data[4360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6327 */
  {
    "aarch64_uqrshrn_ndi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%s0, %d1, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_ndi },
    &operand_data[4360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqshrun_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqrshrun_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqshrn_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_uqshrn_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqrshrn_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_uqrshrn_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv8hi_insn_le },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqshrun_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqrshrun_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqshrn_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_uqshrn_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqrshrn_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_uqrshrn_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv4si_insn_le },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqshrun_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqrshrun_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqshrn_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_uqshrn_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_sqrshrn_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6338 */
  {
    "aarch64_uqrshrn_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv2di_insn_le },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqshrun_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqrshrun_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqshrn_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_uqshrn_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqrshrn_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_uqrshrn_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%0.8b, %1.8h, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv8hi_insn_be },
    &operand_data[3139],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqshrun_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqrshrun_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqshrn_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_uqshrn_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqrshrn_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_uqrshrn_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%0.4h, %1.4s, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv4si_insn_be },
    &operand_data[3143],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqshrun_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqrshrun_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqshrn_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_uqshrn_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_sqrshrn_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6351 */
  {
    "aarch64_uqrshrn_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn\t%0.2s, %1.2d, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv2di_insn_be },
    &operand_data[3147],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqshrun2_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqrshrun2_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqshrn2_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_uqshrn2_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqrshrn2_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_uqrshrn2_nv8hi_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv8hi_insn_le },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqshrun2_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqrshrun2_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqshrn2_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_uqshrn2_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqrshrn2_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_uqrshrn2_nv4si_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv4si_insn_le },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqshrun2_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqrshrun2_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqshrn2_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_uqshrn2_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_sqrshrn2_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6390 */
  {
    "aarch64_uqrshrn2_nv2di_insn_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv2di_insn_le },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqshrun2_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqrshrun2_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqshrn2_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_uqshrn2_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqrshrn2_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_uqrshrn2_nv8hi_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn2\t%0.16b, %2.8h, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv8hi_insn_be },
    &operand_data[3160],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqshrun2_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqrshrun2_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqshrn2_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_uqshrn2_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqrshrn2_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_uqrshrn2_nv4si_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn2\t%0.8h, %2.4s, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv4si_insn_be },
    &operand_data[3164],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqshrun2_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrun2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqrshrun2_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrun2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqshrn2_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_uqshrn2_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_sqrshrn2_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6403 */
  {
    "aarch64_uqrshrn2_nv2di_insn_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrn2\t%0.4s, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv2di_insn_be },
    &operand_data[3168],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmltv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3337 },
#else
    { 0, output_3337, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv8qi },
    &operand_data[4363],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmlev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3338 },
#else
    { 0, output_3338, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev8qi },
    &operand_data[4363],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmeqv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3339 },
#else
    { 0, output_3339, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv8qi },
    &operand_data[4363],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3340 },
#else
    { 0, output_3340, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev8qi },
    &operand_data[4363],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgtv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3341 },
#else
    { 0, output_3341, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv8qi },
    &operand_data[4363],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmltv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3342 },
#else
    { 0, output_3342, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv16qi },
    &operand_data[4366],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmlev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3343 },
#else
    { 0, output_3343, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev16qi },
    &operand_data[4366],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmeqv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3344 },
#else
    { 0, output_3344, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv16qi },
    &operand_data[4366],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3345 },
#else
    { 0, output_3345, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev16qi },
    &operand_data[4366],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgtv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3346 },
#else
    { 0, output_3346, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv16qi },
    &operand_data[4366],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmltv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3347 },
#else
    { 0, output_3347, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv4hi },
    &operand_data[4369],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmlev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3348 },
#else
    { 0, output_3348, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev4hi },
    &operand_data[4369],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmeqv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3349 },
#else
    { 0, output_3349, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv4hi },
    &operand_data[4369],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3350 },
#else
    { 0, output_3350, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev4hi },
    &operand_data[4369],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgtv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3351 },
#else
    { 0, output_3351, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv4hi },
    &operand_data[4369],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmltv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3352 },
#else
    { 0, output_3352, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv8hi },
    &operand_data[4372],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmlev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3353 },
#else
    { 0, output_3353, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev8hi },
    &operand_data[4372],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmeqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3354 },
#else
    { 0, output_3354, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv8hi },
    &operand_data[4372],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3355 },
#else
    { 0, output_3355, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev8hi },
    &operand_data[4372],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgtv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3356 },
#else
    { 0, output_3356, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv8hi },
    &operand_data[4372],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmltv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3357 },
#else
    { 0, output_3357, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv2si },
    &operand_data[4375],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmlev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3358 },
#else
    { 0, output_3358, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev2si },
    &operand_data[4375],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmeqv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3359 },
#else
    { 0, output_3359, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv2si },
    &operand_data[4375],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3360 },
#else
    { 0, output_3360, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev2si },
    &operand_data[4375],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgtv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3361 },
#else
    { 0, output_3361, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv2si },
    &operand_data[4375],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmltv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3362 },
#else
    { 0, output_3362, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv4si },
    &operand_data[4378],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmlev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3363 },
#else
    { 0, output_3363, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev4si },
    &operand_data[4378],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmeqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3364 },
#else
    { 0, output_3364, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv4si },
    &operand_data[4378],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3365 },
#else
    { 0, output_3365, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev4si },
    &operand_data[4378],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgtv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3366 },
#else
    { 0, output_3366, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv4si },
    &operand_data[4378],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmltv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3367 },
#else
    { 0, output_3367, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv2di },
    &operand_data[4381],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmlev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3368 },
#else
    { 0, output_3368, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev2di },
    &operand_data[4381],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmeqv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3369 },
#else
    { 0, output_3369, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv2di },
    &operand_data[4381],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3370 },
#else
    { 0, output_3370, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev2di },
    &operand_data[4381],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6443 */
  {
    "aarch64_cmgtv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3371 },
#else
    { 0, output_3371, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv2di },
    &operand_data[4381],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6457 */
  {
    "aarch64_cmltdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltdi },
    &operand_data[4384],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6457 */
  {
    "aarch64_cmledi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmledi },
    &operand_data[4384],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6457 */
  {
    "aarch64_cmeqdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqdi },
    &operand_data[4384],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6457 */
  {
    "aarch64_cmgedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgedi },
    &operand_data[4384],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6457 */
  {
    "aarch64_cmgtdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtdi },
    &operand_data[4384],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6492 */
  {
    "*aarch64_cmltdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3377 },
#else
    { 0, output_3377, 0 },
#endif
    { 0 },
    &operand_data[4387],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6492 */
  {
    "*aarch64_cmledi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3378 },
#else
    { 0, output_3378, 0 },
#endif
    { 0 },
    &operand_data[4387],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6492 */
  {
    "*aarch64_cmeqdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3379 },
#else
    { 0, output_3379, 0 },
#endif
    { 0 },
    &operand_data[4387],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6492 */
  {
    "*aarch64_cmgedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3380 },
#else
    { 0, output_3380, 0 },
#endif
    { 0 },
    &operand_data[4387],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6492 */
  {
    "*aarch64_cmgtdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3381 },
#else
    { 0, output_3381, 0 },
#endif
    { 0 },
    &operand_data[4387],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmltuv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltuv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmleuv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.8b, %2.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleuv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgeuv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeuv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgtuv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtuv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmltuv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltuv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmleuv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.16b, %2.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleuv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgeuv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeuv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgtuv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtuv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmltuv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.4h, %2.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltuv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmleuv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.4h, %2.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleuv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgeuv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeuv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgtuv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtuv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmltuv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.8h, %2.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltuv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmleuv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.8h, %2.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleuv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgeuv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeuv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgtuv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtuv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmltuv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.2s, %2.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltuv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmleuv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.2s, %2.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleuv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgeuv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeuv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgtuv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtuv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmltuv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.4s, %2.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltuv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmleuv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.4s, %2.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleuv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgeuv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeuv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgtuv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtuv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmltuv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.2d, %2.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltuv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmleuv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.2d, %2.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleuv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgeuv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeuv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6508 */
  {
    "aarch64_cmgtuv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtuv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6520 */
  {
    "aarch64_cmltudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltudi },
    &operand_data[4390],
    3,
    3,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6520 */
  {
    "aarch64_cmleudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmleudi },
    &operand_data[4390],
    3,
    3,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6520 */
  {
    "aarch64_cmgeudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgeudi },
    &operand_data[4390],
    3,
    3,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6520 */
  {
    "aarch64_cmgtudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtudi },
    &operand_data[4390],
    3,
    3,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6555 */
  {
    "*aarch64_cmltudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%d0, %d2, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4393],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6555 */
  {
    "*aarch64_cmleudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%d0, %d2, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4393],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6555 */
  {
    "*aarch64_cmgeudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhs\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4393],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6555 */
  {
    "*aarch64_cmgtudi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmhi\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4393],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6575 */
  {
    "aarch64_cmtstv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstv8qi },
    &operand_data[4396],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6575 */
  {
    "aarch64_cmtstv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstv16qi },
    &operand_data[4401],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6575 */
  {
    "aarch64_cmtstv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstv4hi },
    &operand_data[4406],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6575 */
  {
    "aarch64_cmtstv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstv8hi },
    &operand_data[4411],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6575 */
  {
    "aarch64_cmtstv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstv2si },
    &operand_data[4416],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6575 */
  {
    "aarch64_cmtstv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstv4si },
    &operand_data[4421],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6575 */
  {
    "aarch64_cmtstv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstv2di },
    &operand_data[4426],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6594 */
  {
    "*aarch64_cmtst_same_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.8b, %1.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4431],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6594 */
  {
    "*aarch64_cmtst_same_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.16b, %1.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4435],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6594 */
  {
    "*aarch64_cmtst_same_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.4h, %1.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4439],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6594 */
  {
    "*aarch64_cmtst_same_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.8h, %1.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4443],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6594 */
  {
    "*aarch64_cmtst_same_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.2s, %1.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4447],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6594 */
  {
    "*aarch64_cmtst_same_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.4s, %1.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4451],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6594 */
  {
    "*aarch64_cmtst_same_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%0.2d, %1.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[4455],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6607 */
  {
    "aarch64_cmtstdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmtstdi },
    &operand_data[4459],
    3,
    3,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6645 */
  {
    "*aarch64_cmtstdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmtst\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[3953],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmltv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3434 },
#else
    { 0, output_3434, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv4hf },
    &operand_data[4462],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3435 },
#else
    { 0, output_3435, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev4hf },
    &operand_data[4462],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3436 },
#else
    { 0, output_3436, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv4hf },
    &operand_data[4462],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3437 },
#else
    { 0, output_3437, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev4hf },
    &operand_data[4462],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgtv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3438 },
#else
    { 0, output_3438, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv4hf },
    &operand_data[4462],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmltv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3439 },
#else
    { 0, output_3439, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv8hf },
    &operand_data[4465],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3440 },
#else
    { 0, output_3440, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev8hf },
    &operand_data[4465],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3441 },
#else
    { 0, output_3441, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv8hf },
    &operand_data[4465],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3442 },
#else
    { 0, output_3442, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev8hf },
    &operand_data[4465],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgtv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3443 },
#else
    { 0, output_3443, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv8hf },
    &operand_data[4465],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmltv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3444 },
#else
    { 0, output_3444, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv2sf },
    &operand_data[4468],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3445 },
#else
    { 0, output_3445, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev2sf },
    &operand_data[4468],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3446 },
#else
    { 0, output_3446, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv2sf },
    &operand_data[4468],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3447 },
#else
    { 0, output_3447, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev2sf },
    &operand_data[4468],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgtv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3448 },
#else
    { 0, output_3448, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv2sf },
    &operand_data[4468],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmltv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3449 },
#else
    { 0, output_3449, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv4sf },
    &operand_data[4471],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3450 },
#else
    { 0, output_3450, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev4sf },
    &operand_data[4471],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3451 },
#else
    { 0, output_3451, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv4sf },
    &operand_data[4471],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3452 },
#else
    { 0, output_3452, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev4sf },
    &operand_data[4471],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgtv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3453 },
#else
    { 0, output_3453, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv4sf },
    &operand_data[4471],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmltv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3454 },
#else
    { 0, output_3454, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltv2df },
    &operand_data[4474],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3455 },
#else
    { 0, output_3455, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlev2df },
    &operand_data[4474],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3456 },
#else
    { 0, output_3456, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqv2df },
    &operand_data[4474],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3457 },
#else
    { 0, output_3457, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgev2df },
    &operand_data[4474],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgtv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3458 },
#else
    { 0, output_3458, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtv2df },
    &operand_data[4474],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlthf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3459 },
#else
    { 0, output_3459, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlthf },
    &operand_data[4477],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlehf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3460 },
#else
    { 0, output_3460, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlehf },
    &operand_data[4477],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3461 },
#else
    { 0, output_3461, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqhf },
    &operand_data[4477],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgehf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3462 },
#else
    { 0, output_3462, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgehf },
    &operand_data[4477],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgthf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3463 },
#else
    { 0, output_3463, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgthf },
    &operand_data[4477],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmltsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3464 },
#else
    { 0, output_3464, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltsf },
    &operand_data[4480],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmlesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3465 },
#else
    { 0, output_3465, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmlesf },
    &operand_data[4480],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3466 },
#else
    { 0, output_3466, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqsf },
    &operand_data[4480],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3467 },
#else
    { 0, output_3467, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgesf },
    &operand_data[4480],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgtsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3468 },
#else
    { 0, output_3468, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtsf },
    &operand_data[4480],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmltdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3469 },
#else
    { 0, output_3469, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmltdf },
    &operand_data[4483],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmledf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3470 },
#else
    { 0, output_3470, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmledf },
    &operand_data[4483],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmeqdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3471 },
#else
    { 0, output_3471, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmeqdf },
    &operand_data[4483],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3472 },
#else
    { 0, output_3472, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgedf },
    &operand_data[4483],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6660 */
  {
    "aarch64_cmgtdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3473 },
#else
    { 0, output_3473, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmgtdf },
    &operand_data[4483],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facltv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.4h, %2.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facltv4hf },
    &operand_data[4486],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.4h, %2.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclev4hf },
    &operand_data[4486],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgev4hf },
    &operand_data[4486],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgtv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgtv4hf },
    &operand_data[4486],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facltv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.8h, %2.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facltv8hf },
    &operand_data[4489],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.8h, %2.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclev8hf },
    &operand_data[4489],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgev8hf },
    &operand_data[4489],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgtv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgtv8hf },
    &operand_data[4489],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facltv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.2s, %2.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facltv2sf },
    &operand_data[4492],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.2s, %2.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclev2sf },
    &operand_data[4492],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgev2sf },
    &operand_data[4492],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgtv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgtv2sf },
    &operand_data[4492],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facltv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.4s, %2.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facltv4sf },
    &operand_data[4495],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.4s, %2.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclev4sf },
    &operand_data[4495],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgev4sf },
    &operand_data[4495],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgtv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgtv4sf },
    &operand_data[4495],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facltv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.2d, %2.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facltv2df },
    &operand_data[4498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.2d, %2.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclev2df },
    &operand_data[4498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgev2df },
    &operand_data[4498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgtv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgtv2df },
    &operand_data[4498],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclthf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%h0, %h2, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclthf },
    &operand_data[4501],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclehf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%h0, %h2, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclehf },
    &operand_data[4501],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgehf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgehf },
    &operand_data[4501],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgthf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgthf },
    &operand_data[4501],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facltsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%s0, %s2, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facltsf },
    &operand_data[4504],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_faclesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%s0, %s2, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_faclesf },
    &operand_data[4504],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgesf },
    &operand_data[4504],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgtsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgtsf },
    &operand_data[4504],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facltdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%d0, %d2, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facltdf },
    &operand_data[4507],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facledf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%d0, %d2, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facledf },
    &operand_data[4507],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgedf },
    &operand_data[4507],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6678 */
  {
    "aarch64_facgtdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_facgtdf },
    &operand_data[4507],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6694 */
  {
    "aarch64_addpv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpv8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6694 */
  {
    "aarch64_addpv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpv16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6694 */
  {
    "aarch64_addpv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpv4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6694 */
  {
    "aarch64_addpv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpv8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6694 */
  {
    "aarch64_addpv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpv2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6694 */
  {
    "aarch64_addpv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6694 */
  {
    "aarch64_addpv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6705 */
  {
    "aarch64_addpdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addp\t%d0, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addpdi },
    &operand_data[3549],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6726 */
  {
    "*sqrtv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6726 */
  {
    "*sqrtv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6726 */
  {
    "*sqrtv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6726 */
  {
    "*sqrtv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6726 */
  {
    "*sqrtv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsqrt\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.16b - %T0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v16qi },
    &operand_data[4510],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v8hi },
    &operand_data[4512],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.4s - %T0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v4si },
    &operand_data[4514],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.2d - %T0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v2di },
    &operand_data[4516],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v8hf },
    &operand_data[4518],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.4s - %T0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v4sf },
    &operand_data[4520],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.2d - %T0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v2df },
    &operand_data[4522],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6736 */
  {
    "aarch64_simd_ld2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2v8bf },
    &operand_data[4524],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.8b - %T0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv8qi },
    &operand_data[4526],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv4hi },
    &operand_data[4528],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.2s - %T0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv2si },
    &operand_data[4530],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.1d - %T0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rdi },
    &operand_data[4532],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv4hf },
    &operand_data[4534],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.2s - %T0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv2sf },
    &operand_data[4536],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.1d - %T0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rdf },
    &operand_data[4538],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv4bf },
    &operand_data[4540],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.16b - %T0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv16qi },
    &operand_data[4542],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv8hi },
    &operand_data[4544],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.4s - %T0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv4si },
    &operand_data[4546],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.2d - %T0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv2di },
    &operand_data[4548],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv8hf },
    &operand_data[4550],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.4s - %T0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv4sf },
    &operand_data[4552],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.2d - %T0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv2df },
    &operand_data[4554],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6746 */
  {
    "aarch64_simd_ld2rv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2r\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld2rv8bf },
    &operand_data[4556],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x8qi_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3543 },
#else
    { 0, 0, output_3543 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x8qi_lanev8qi },
    &operand_data[4558],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x4hi_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3544 },
#else
    { 0, 0, output_3544 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x4hi_lanev4hi },
    &operand_data[4562],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x2si_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3545 },
#else
    { 0, 0, output_3545 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x2si_lanev2si },
    &operand_data[4566],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x1di_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3546 },
#else
    { 0, 0, output_3546 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x1di_lanedi },
    &operand_data[4570],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x4hf_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3547 },
#else
    { 0, 0, output_3547 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x4hf_lanev4hf },
    &operand_data[4574],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x2sf_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3548 },
#else
    { 0, 0, output_3548 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x2sf_lanev2sf },
    &operand_data[4578],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x1df_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3549 },
#else
    { 0, 0, output_3549 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x1df_lanedf },
    &operand_data[4582],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x4bf_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3550 },
#else
    { 0, 0, output_3550 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x4bf_lanev4bf },
    &operand_data[4586],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x16qi_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3551 },
#else
    { 0, 0, output_3551 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x16qi_lanev16qi },
    &operand_data[4590],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x8hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3552 },
#else
    { 0, 0, output_3552 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x8hi_lanev8hi },
    &operand_data[4594],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x4si_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3553 },
#else
    { 0, 0, output_3553 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x4si_lanev4si },
    &operand_data[4598],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x2di_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3554 },
#else
    { 0, 0, output_3554 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x2di_lanev2di },
    &operand_data[4602],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x8hf_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3555 },
#else
    { 0, 0, output_3555 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x8hf_lanev8hf },
    &operand_data[4606],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x4sf_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3556 },
#else
    { 0, 0, output_3556 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x4sf_lanev4sf },
    &operand_data[4610],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x2df_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3557 },
#else
    { 0, 0, output_3557 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x2df_lanev2df },
    &operand_data[4614],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6756 */
  {
    "aarch64_vec_load_lanesv2x8bf_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3558 },
#else
    { 0, 0, output_3558 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv2x8bf_lanev8bf },
    &operand_data[4618],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.16b - %T1.16b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v16qi },
    &operand_data[4622],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.8h - %T1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v8hi },
    &operand_data[4624],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.4s - %T1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v4si },
    &operand_data[4626],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.2d - %T1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v2di },
    &operand_data[4628],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.8h - %T1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v8hf },
    &operand_data[4630],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.4s - %T1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v4sf },
    &operand_data[4632],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.2d - %T1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v2df },
    &operand_data[4634],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6792 */
  {
    "aarch64_simd_st2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.8h - %T1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st2v8bf },
    &operand_data[4636],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x8qi_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3567 },
#else
    { 0, 0, output_3567 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x8qi_lanev8qi },
    &operand_data[4638],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x4hi_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3568 },
#else
    { 0, 0, output_3568 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x4hi_lanev4hi },
    &operand_data[4641],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x2si_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3569 },
#else
    { 0, 0, output_3569 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x2si_lanev2si },
    &operand_data[4644],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x1di_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3570 },
#else
    { 0, 0, output_3570 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x1di_lanedi },
    &operand_data[4647],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x4hf_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3571 },
#else
    { 0, 0, output_3571 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x4hf_lanev4hf },
    &operand_data[4650],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x2sf_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3572 },
#else
    { 0, 0, output_3572 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x2sf_lanev2sf },
    &operand_data[4653],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x1df_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3573 },
#else
    { 0, 0, output_3573 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x1df_lanedf },
    &operand_data[4656],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x4bf_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3574 },
#else
    { 0, 0, output_3574 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x4bf_lanev4bf },
    &operand_data[4659],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x16qi_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3575 },
#else
    { 0, 0, output_3575 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x16qi_lanev16qi },
    &operand_data[4662],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x8hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3576 },
#else
    { 0, 0, output_3576 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x8hi_lanev8hi },
    &operand_data[4665],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x4si_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3577 },
#else
    { 0, 0, output_3577 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x4si_lanev4si },
    &operand_data[4668],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x2di_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3578 },
#else
    { 0, 0, output_3578 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x2di_lanev2di },
    &operand_data[4671],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x8hf_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3579 },
#else
    { 0, 0, output_3579 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x8hf_lanev8hf },
    &operand_data[4674],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x4sf_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3580 },
#else
    { 0, 0, output_3580 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x4sf_lanev4sf },
    &operand_data[4677],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x2df_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3581 },
#else
    { 0, 0, output_3581 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x2df_lanev2df },
    &operand_data[4680],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6803 */
  {
    "aarch64_vec_store_lanesv2x8bf_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3582 },
#else
    { 0, 0, output_3582 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv2x8bf_lanev8bf },
    &operand_data[4683],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.16b - %U0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v16qi },
    &operand_data[4686],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v8hi },
    &operand_data[4688],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.4s - %U0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v4si },
    &operand_data[4690],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.2d - %U0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v2di },
    &operand_data[4692],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v8hf },
    &operand_data[4694],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.4s - %U0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v4sf },
    &operand_data[4696],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.2d - %U0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v2df },
    &operand_data[4698],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6836 */
  {
    "aarch64_simd_ld3v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3v8bf },
    &operand_data[4700],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.8b - %U0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv8qi },
    &operand_data[4702],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv4hi },
    &operand_data[4704],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.2s - %U0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv2si },
    &operand_data[4706],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.1d - %U0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rdi },
    &operand_data[4708],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv4hf },
    &operand_data[4710],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.2s - %U0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv2sf },
    &operand_data[4712],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.1d - %U0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rdf },
    &operand_data[4714],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv4bf },
    &operand_data[4716],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.16b - %U0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv16qi },
    &operand_data[4718],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv8hi },
    &operand_data[4720],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.4s - %U0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv4si },
    &operand_data[4722],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.2d - %U0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv2di },
    &operand_data[4724],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv8hf },
    &operand_data[4726],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.4s - %U0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv4sf },
    &operand_data[4728],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.2d - %U0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv2df },
    &operand_data[4730],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6846 */
  {
    "aarch64_simd_ld3rv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3r\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld3rv8bf },
    &operand_data[4732],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x8qi_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3607 },
#else
    { 0, 0, output_3607 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x8qi_lanev8qi },
    &operand_data[4734],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x4hi_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3608 },
#else
    { 0, 0, output_3608 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x4hi_lanev4hi },
    &operand_data[4738],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x2si_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3609 },
#else
    { 0, 0, output_3609 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x2si_lanev2si },
    &operand_data[4742],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x1di_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3610 },
#else
    { 0, 0, output_3610 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x1di_lanedi },
    &operand_data[4746],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x4hf_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3611 },
#else
    { 0, 0, output_3611 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x4hf_lanev4hf },
    &operand_data[4750],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x2sf_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3612 },
#else
    { 0, 0, output_3612 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x2sf_lanev2sf },
    &operand_data[4754],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x1df_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3613 },
#else
    { 0, 0, output_3613 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x1df_lanedf },
    &operand_data[4758],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x4bf_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3614 },
#else
    { 0, 0, output_3614 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x4bf_lanev4bf },
    &operand_data[4762],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x16qi_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3615 },
#else
    { 0, 0, output_3615 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x16qi_lanev16qi },
    &operand_data[4766],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x8hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3616 },
#else
    { 0, 0, output_3616 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x8hi_lanev8hi },
    &operand_data[4770],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x4si_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3617 },
#else
    { 0, 0, output_3617 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x4si_lanev4si },
    &operand_data[4774],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x2di_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3618 },
#else
    { 0, 0, output_3618 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x2di_lanev2di },
    &operand_data[4778],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x8hf_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3619 },
#else
    { 0, 0, output_3619 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x8hf_lanev8hf },
    &operand_data[4782],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x4sf_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3620 },
#else
    { 0, 0, output_3620 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x4sf_lanev4sf },
    &operand_data[4786],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x2df_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3621 },
#else
    { 0, 0, output_3621 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x2df_lanev2df },
    &operand_data[4790],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6856 */
  {
    "aarch64_vec_load_lanesv3x8bf_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3622 },
#else
    { 0, 0, output_3622 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv3x8bf_lanev8bf },
    &operand_data[4794],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.16b - %U1.16b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v16qi },
    &operand_data[4798],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.8h - %U1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v8hi },
    &operand_data[4800],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.4s - %U1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v4si },
    &operand_data[4802],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.2d - %U1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v2di },
    &operand_data[4804],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.8h - %U1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v8hf },
    &operand_data[4806],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.4s - %U1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v4sf },
    &operand_data[4808],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.2d - %U1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v2df },
    &operand_data[4810],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6892 */
  {
    "aarch64_simd_st3v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.8h - %U1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st3v8bf },
    &operand_data[4812],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x8qi_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3631 },
#else
    { 0, 0, output_3631 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x8qi_lanev8qi },
    &operand_data[4814],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x4hi_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3632 },
#else
    { 0, 0, output_3632 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x4hi_lanev4hi },
    &operand_data[4817],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x2si_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3633 },
#else
    { 0, 0, output_3633 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x2si_lanev2si },
    &operand_data[4820],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x1di_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3634 },
#else
    { 0, 0, output_3634 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x1di_lanedi },
    &operand_data[4823],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x4hf_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3635 },
#else
    { 0, 0, output_3635 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x4hf_lanev4hf },
    &operand_data[4826],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x2sf_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3636 },
#else
    { 0, 0, output_3636 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x2sf_lanev2sf },
    &operand_data[4829],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x1df_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3637 },
#else
    { 0, 0, output_3637 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x1df_lanedf },
    &operand_data[4832],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x4bf_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3638 },
#else
    { 0, 0, output_3638 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x4bf_lanev4bf },
    &operand_data[4835],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x16qi_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3639 },
#else
    { 0, 0, output_3639 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x16qi_lanev16qi },
    &operand_data[4838],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x8hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3640 },
#else
    { 0, 0, output_3640 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x8hi_lanev8hi },
    &operand_data[4841],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x4si_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3641 },
#else
    { 0, 0, output_3641 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x4si_lanev4si },
    &operand_data[4844],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x2di_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3642 },
#else
    { 0, 0, output_3642 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x2di_lanev2di },
    &operand_data[4847],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x8hf_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3643 },
#else
    { 0, 0, output_3643 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x8hf_lanev8hf },
    &operand_data[4850],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x4sf_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3644 },
#else
    { 0, 0, output_3644 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x4sf_lanev4sf },
    &operand_data[4853],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x2df_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3645 },
#else
    { 0, 0, output_3645 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x2df_lanev2df },
    &operand_data[4856],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6902 */
  {
    "aarch64_vec_store_lanesv3x8bf_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3646 },
#else
    { 0, 0, output_3646 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv3x8bf_lanev8bf },
    &operand_data[4859],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.16b - %V0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v16qi },
    &operand_data[4862],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v8hi },
    &operand_data[4864],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.4s - %V0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v4si },
    &operand_data[4866],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.2d - %V0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v2di },
    &operand_data[4868],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v8hf },
    &operand_data[4870],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.4s - %V0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v4sf },
    &operand_data[4872],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.2d - %V0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v2df },
    &operand_data[4874],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6936 */
  {
    "aarch64_simd_ld4v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4v8bf },
    &operand_data[4876],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.8b - %V0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv8qi },
    &operand_data[4878],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv4hi },
    &operand_data[4880],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.2s - %V0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv2si },
    &operand_data[4882],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.1d - %V0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rdi },
    &operand_data[4884],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv4hf },
    &operand_data[4886],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.2s - %V0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv2sf },
    &operand_data[4888],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.1d - %V0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rdf },
    &operand_data[4890],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv4bf },
    &operand_data[4892],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.16b - %V0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv16qi },
    &operand_data[4894],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv8hi },
    &operand_data[4896],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.4s - %V0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv4si },
    &operand_data[4898],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.2d - %V0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv2di },
    &operand_data[4900],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv8hf },
    &operand_data[4902],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.4s - %V0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv4sf },
    &operand_data[4904],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.2d - %V0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv2df },
    &operand_data[4906],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6946 */
  {
    "aarch64_simd_ld4rv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4r\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld4rv8bf },
    &operand_data[4908],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x8qi_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3671 },
#else
    { 0, 0, output_3671 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x8qi_lanev8qi },
    &operand_data[4910],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x4hi_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3672 },
#else
    { 0, 0, output_3672 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x4hi_lanev4hi },
    &operand_data[4914],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x2si_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3673 },
#else
    { 0, 0, output_3673 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x2si_lanev2si },
    &operand_data[4918],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x1di_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3674 },
#else
    { 0, 0, output_3674 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x1di_lanedi },
    &operand_data[4922],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x4hf_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3675 },
#else
    { 0, 0, output_3675 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x4hf_lanev4hf },
    &operand_data[4926],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x2sf_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3676 },
#else
    { 0, 0, output_3676 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x2sf_lanev2sf },
    &operand_data[4930],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x1df_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3677 },
#else
    { 0, 0, output_3677 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x1df_lanedf },
    &operand_data[4934],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x4bf_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3678 },
#else
    { 0, 0, output_3678 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x4bf_lanev4bf },
    &operand_data[4938],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x16qi_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3679 },
#else
    { 0, 0, output_3679 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x16qi_lanev16qi },
    &operand_data[4942],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x8hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3680 },
#else
    { 0, 0, output_3680 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x8hi_lanev8hi },
    &operand_data[4946],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x4si_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3681 },
#else
    { 0, 0, output_3681 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x4si_lanev4si },
    &operand_data[4950],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x2di_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3682 },
#else
    { 0, 0, output_3682 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x2di_lanev2di },
    &operand_data[4954],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x8hf_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3683 },
#else
    { 0, 0, output_3683 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x8hf_lanev8hf },
    &operand_data[4958],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x4sf_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3684 },
#else
    { 0, 0, output_3684 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x4sf_lanev4sf },
    &operand_data[4962],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x2df_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3685 },
#else
    { 0, 0, output_3685 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x2df_lanev2df },
    &operand_data[4966],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6956 */
  {
    "aarch64_vec_load_lanesv4x8bf_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3686 },
#else
    { 0, 0, output_3686 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_load_lanesv4x8bf_lanev8bf },
    &operand_data[4970],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.16b - %V1.16b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v16qi },
    &operand_data[4974],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.8h - %V1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v8hi },
    &operand_data[4976],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.4s - %V1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v4si },
    &operand_data[4978],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.2d - %V1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v2di },
    &operand_data[4980],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.8h - %V1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v8hf },
    &operand_data[4982],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.4s - %V1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v4sf },
    &operand_data[4984],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.2d - %V1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v2df },
    &operand_data[4986],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6992 */
  {
    "aarch64_simd_st4v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.8h - %V1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_st4v8bf },
    &operand_data[4988],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x8qi_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3695 },
#else
    { 0, 0, output_3695 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x8qi_lanev8qi },
    &operand_data[4990],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x4hi_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3696 },
#else
    { 0, 0, output_3696 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x4hi_lanev4hi },
    &operand_data[4993],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x2si_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3697 },
#else
    { 0, 0, output_3697 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x2si_lanev2si },
    &operand_data[4996],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x1di_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3698 },
#else
    { 0, 0, output_3698 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x1di_lanedi },
    &operand_data[4999],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x4hf_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3699 },
#else
    { 0, 0, output_3699 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x4hf_lanev4hf },
    &operand_data[5002],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x2sf_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3700 },
#else
    { 0, 0, output_3700 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x2sf_lanev2sf },
    &operand_data[5005],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x1df_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3701 },
#else
    { 0, 0, output_3701 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x1df_lanedf },
    &operand_data[5008],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x4bf_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3702 },
#else
    { 0, 0, output_3702 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x4bf_lanev4bf },
    &operand_data[5011],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x16qi_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3703 },
#else
    { 0, 0, output_3703 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x16qi_lanev16qi },
    &operand_data[5014],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x8hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3704 },
#else
    { 0, 0, output_3704 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x8hi_lanev8hi },
    &operand_data[5017],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x4si_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3705 },
#else
    { 0, 0, output_3705 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x4si_lanev4si },
    &operand_data[5020],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x2di_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3706 },
#else
    { 0, 0, output_3706 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x2di_lanev2di },
    &operand_data[5023],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x8hf_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3707 },
#else
    { 0, 0, output_3707 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x8hf_lanev8hf },
    &operand_data[5026],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x4sf_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3708 },
#else
    { 0, 0, output_3708 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x4sf_lanev4sf },
    &operand_data[5029],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x2df_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3709 },
#else
    { 0, 0, output_3709 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x2df_lanev2df },
    &operand_data[5032],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7003 */
  {
    "aarch64_vec_store_lanesv4x8bf_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_3710 },
#else
    { 0, 0, output_3710 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_store_lanesv4x8bf_lanev8bf },
    &operand_data[5035],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x8qi },
    &operand_data[5038],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x4hi },
    &operand_data[5041],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x2si },
    &operand_data[5044],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x1di },
    &operand_data[5047],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x4hf },
    &operand_data[5050],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x2sf },
    &operand_data[5053],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x1df },
    &operand_data[5056],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x4bf },
    &operand_data[5059],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x8qi },
    &operand_data[5062],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x4hi },
    &operand_data[5065],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x2si },
    &operand_data[5068],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x1di },
    &operand_data[5071],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x4hf },
    &operand_data[5074],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x2sf },
    &operand_data[5077],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x1df },
    &operand_data[5080],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x4bf },
    &operand_data[5083],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x8qi },
    &operand_data[5086],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x4hi },
    &operand_data[5089],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x2si },
    &operand_data[5092],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x1di },
    &operand_data[5095],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x4hf },
    &operand_data[5098],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x2sf },
    &operand_data[5101],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x1df },
    &operand_data[5104],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x4bf },
    &operand_data[5107],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x16qi },
    &operand_data[5110],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x8hi },
    &operand_data[5113],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x4si },
    &operand_data[5116],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x2di },
    &operand_data[5119],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x8hf },
    &operand_data[5122],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x4sf },
    &operand_data[5125],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x2df },
    &operand_data[5128],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv2x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv2x8bf },
    &operand_data[5131],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x16qi },
    &operand_data[5134],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x8hi },
    &operand_data[5137],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x4si },
    &operand_data[5140],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x2di },
    &operand_data[5143],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x8hf },
    &operand_data[5146],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x4sf },
    &operand_data[5149],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x2df },
    &operand_data[5152],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv3x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv3x8bf },
    &operand_data[5155],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x16qi },
    &operand_data[5158],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x8hi },
    &operand_data[5161],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x4si },
    &operand_data[5164],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x2di },
    &operand_data[5167],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x8hf },
    &operand_data[5170],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x4sf },
    &operand_data[5173],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x2df },
    &operand_data[5176],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7036 */
  {
    "aarch64_rev_reglistv4x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev_reglistv4x8bf },
    &operand_data[5179],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8b - %U0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v8qi },
    &operand_data[5182],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v4hi },
    &operand_data[5184],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2s - %U0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v2si },
    &operand_data[5186],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %U0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_di },
    &operand_data[5188],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v4hf },
    &operand_data[5190],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2s - %U0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v2sf },
    &operand_data[5192],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %U0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_df },
    &operand_data[5194],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v4bf },
    &operand_data[5196],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.16b - %U0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v16qi },
    &operand_data[4686],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v8hi },
    &operand_data[4688],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4s - %U0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v4si },
    &operand_data[4690],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2d - %U0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v2di },
    &operand_data[4692],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v8hf },
    &operand_data[4694],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4s - %U0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v4sf },
    &operand_data[4696],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2d - %U0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v2df },
    &operand_data[4698],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7106 */
  {
    "aarch64_ld1_x3_v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %U0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x3_v8bf },
    &operand_data[4700],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8b - %V0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v8qi },
    &operand_data[5198],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v4hi },
    &operand_data[5200],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2s - %V0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v2si },
    &operand_data[5202],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %V0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_di },
    &operand_data[5204],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v4hf },
    &operand_data[5206],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2s - %V0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v2sf },
    &operand_data[5208],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %V0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_df },
    &operand_data[5210],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v4bf },
    &operand_data[5212],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.16b - %V0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v16qi },
    &operand_data[4862],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v8hi },
    &operand_data[4864],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4s - %V0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v4si },
    &operand_data[4866],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2d - %V0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v2di },
    &operand_data[4868],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v8hf },
    &operand_data[4870],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4s - %V0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v4sf },
    &operand_data[4872],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2d - %V0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v2df },
    &operand_data[4874],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7126 */
  {
    "aarch64_ld1_x4_v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %V0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1_x4_v8bf },
    &operand_data[4876],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8b - %T1.8b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v8qi },
    &operand_data[5214],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %T1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v4hi },
    &operand_data[5216],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2s - %T1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v2si },
    &operand_data[5218],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %T1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_di },
    &operand_data[5220],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %T1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v4hf },
    &operand_data[5222],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2s - %T1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v2sf },
    &operand_data[5224],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %T1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_df },
    &operand_data[5226],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %T1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v4bf },
    &operand_data[5228],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.16b - %T1.16b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v16qi },
    &operand_data[4622],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %T1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v8hi },
    &operand_data[4624],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4s - %T1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v4si },
    &operand_data[4626],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2d - %T1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v2di },
    &operand_data[4628],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %T1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v8hf },
    &operand_data[4630],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4s - %T1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v4sf },
    &operand_data[4632],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2d - %T1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v2df },
    &operand_data[4634],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7146 */
  {
    "aarch64_st1_x2_v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %T1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x2_v8bf },
    &operand_data[4636],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8b - %U1.8b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v8qi },
    &operand_data[5230],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %U1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v4hi },
    &operand_data[5232],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2s - %U1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v2si },
    &operand_data[5234],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %U1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_di },
    &operand_data[5236],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %U1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v4hf },
    &operand_data[5238],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2s - %U1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v2sf },
    &operand_data[5240],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %U1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_df },
    &operand_data[5242],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %U1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v4bf },
    &operand_data[5244],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.16b - %U1.16b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v16qi },
    &operand_data[4798],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %U1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v8hi },
    &operand_data[4800],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4s - %U1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v4si },
    &operand_data[4802],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2d - %U1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v2di },
    &operand_data[4804],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %U1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v8hf },
    &operand_data[4806],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4s - %U1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v4sf },
    &operand_data[4808],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2d - %U1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v2df },
    &operand_data[4810],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7166 */
  {
    "aarch64_st1_x3_v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %U1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x3_v8bf },
    &operand_data[4812],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8b - %V1.8b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v8qi },
    &operand_data[5246],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %V1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v4hi },
    &operand_data[5248],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2s - %V1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v2si },
    &operand_data[5250],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %V1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_di },
    &operand_data[5252],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %V1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v4hf },
    &operand_data[5254],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2s - %V1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v2sf },
    &operand_data[5256],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %V1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_df },
    &operand_data[5258],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4h - %V1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v4bf },
    &operand_data[5260],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.16b - %V1.16b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v16qi },
    &operand_data[4974],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %V1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v8hi },
    &operand_data[4976],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4s - %V1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v4si },
    &operand_data[4978],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2d - %V1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v2di },
    &operand_data[4980],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %V1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v8hf },
    &operand_data[4982],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.4s - %V1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v4sf },
    &operand_data[4984],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.2d - %V1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v2df },
    &operand_data[4986],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7186 */
  {
    "aarch64_st1_x4_v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.8h - %V1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1_x4_v8bf },
    &operand_data[4988],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3839 },
#else
    { 0, output_3839, 0 },
#endif
    { 0 },
    &operand_data[5262],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3840 },
#else
    { 0, output_3840, 0 },
#endif
    { 0 },
    &operand_data[5264],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3841 },
#else
    { 0, output_3841, 0 },
#endif
    { 0 },
    &operand_data[5266],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3842 },
#else
    { 0, output_3842, 0 },
#endif
    { 0 },
    &operand_data[5268],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3843 },
#else
    { 0, output_3843, 0 },
#endif
    { 0 },
    &operand_data[5270],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3844 },
#else
    { 0, output_3844, 0 },
#endif
    { 0 },
    &operand_data[5272],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3845 },
#else
    { 0, output_3845, 0 },
#endif
    { 0 },
    &operand_data[5274],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3846 },
#else
    { 0, output_3846, 0 },
#endif
    { 0 },
    &operand_data[5276],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3847 },
#else
    { 0, output_3847, 0 },
#endif
    { 0 },
    &operand_data[5278],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3848 },
#else
    { 0, output_3848, 0 },
#endif
    { 0 },
    &operand_data[5280],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3849 },
#else
    { 0, output_3849, 0 },
#endif
    { 0 },
    &operand_data[5282],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3850 },
#else
    { 0, output_3850, 0 },
#endif
    { 0 },
    &operand_data[5284],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3851 },
#else
    { 0, output_3851, 0 },
#endif
    { 0 },
    &operand_data[5286],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3852 },
#else
    { 0, output_3852, 0 },
#endif
    { 0 },
    &operand_data[5288],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3853 },
#else
    { 0, output_3853, 0 },
#endif
    { 0 },
    &operand_data[5290],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3854 },
#else
    { 0, output_3854, 0 },
#endif
    { 0 },
    &operand_data[5292],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3855 },
#else
    { 0, output_3855, 0 },
#endif
    { 0 },
    &operand_data[5294],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3856 },
#else
    { 0, output_3856, 0 },
#endif
    { 0 },
    &operand_data[5296],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3857 },
#else
    { 0, output_3857, 0 },
#endif
    { 0 },
    &operand_data[5298],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3858 },
#else
    { 0, output_3858, 0 },
#endif
    { 0 },
    &operand_data[5300],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3859 },
#else
    { 0, output_3859, 0 },
#endif
    { 0 },
    &operand_data[5302],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3860 },
#else
    { 0, output_3860, 0 },
#endif
    { 0 },
    &operand_data[5304],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3861 },
#else
    { 0, output_3861, 0 },
#endif
    { 0 },
    &operand_data[5306],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3862 },
#else
    { 0, output_3862, 0 },
#endif
    { 0 },
    &operand_data[5308],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3863 },
#else
    { 0, output_3863, 0 },
#endif
    { 0 },
    &operand_data[5310],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3864 },
#else
    { 0, output_3864, 0 },
#endif
    { 0 },
    &operand_data[5312],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3865 },
#else
    { 0, output_3865, 0 },
#endif
    { 0 },
    &operand_data[5314],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3866 },
#else
    { 0, output_3866, 0 },
#endif
    { 0 },
    &operand_data[5316],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3867 },
#else
    { 0, output_3867, 0 },
#endif
    { 0 },
    &operand_data[5318],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3868 },
#else
    { 0, output_3868, 0 },
#endif
    { 0 },
    &operand_data[5320],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3869 },
#else
    { 0, output_3869, 0 },
#endif
    { 0 },
    &operand_data[5322],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv2x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3870 },
#else
    { 0, output_3870, 0 },
#endif
    { 0 },
    &operand_data[5324],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3871 },
#else
    { 0, output_3871, 0 },
#endif
    { 0 },
    &operand_data[5326],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3872 },
#else
    { 0, output_3872, 0 },
#endif
    { 0 },
    &operand_data[5328],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3873 },
#else
    { 0, output_3873, 0 },
#endif
    { 0 },
    &operand_data[5330],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3874 },
#else
    { 0, output_3874, 0 },
#endif
    { 0 },
    &operand_data[5332],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3875 },
#else
    { 0, output_3875, 0 },
#endif
    { 0 },
    &operand_data[5334],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3876 },
#else
    { 0, output_3876, 0 },
#endif
    { 0 },
    &operand_data[5336],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3877 },
#else
    { 0, output_3877, 0 },
#endif
    { 0 },
    &operand_data[5338],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv3x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3878 },
#else
    { 0, output_3878, 0 },
#endif
    { 0 },
    &operand_data[5340],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3879 },
#else
    { 0, output_3879, 0 },
#endif
    { 0 },
    &operand_data[5342],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3880 },
#else
    { 0, output_3880, 0 },
#endif
    { 0 },
    &operand_data[5344],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3881 },
#else
    { 0, output_3881, 0 },
#endif
    { 0 },
    &operand_data[5346],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3882 },
#else
    { 0, output_3882, 0 },
#endif
    { 0 },
    &operand_data[5348],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3883 },
#else
    { 0, output_3883, 0 },
#endif
    { 0 },
    &operand_data[5350],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3884 },
#else
    { 0, output_3884, 0 },
#endif
    { 0 },
    &operand_data[5352],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3885 },
#else
    { 0, output_3885, 0 },
#endif
    { 0 },
    &operand_data[5354],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7196 */
  {
    "*aarch64_movv4x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3886 },
#else
    { 0, output_3886, 0 },
#endif
    { 0 },
    &operand_data[5356],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7211 */
  {
    "*aarch64_movoi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3887 },
#else
    { 0, output_3887, 0 },
#endif
    { 0 },
    &operand_data[5358],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7211 */
  {
    "*aarch64_movci",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3888 },
#else
    { 0, output_3888, 0 },
#endif
    { 0 },
    &operand_data[5360],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7211 */
  {
    "*aarch64_movxi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3889 },
#else
    { 0, output_3889, 0 },
#endif
    { 0 },
    &operand_data[5362],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7226 */
  {
    "*aarch64_movv8di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5364],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v8qi },
    &operand_data[5366],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v16qi },
    &operand_data[5368],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v4hi },
    &operand_data[5370],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v8hi },
    &operand_data[5372],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v2si },
    &operand_data[5374],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v4si },
    &operand_data[5376],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v2di },
    &operand_data[5378],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v4hf },
    &operand_data[5380],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v8hf },
    &operand_data[5382],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v4bf },
    &operand_data[5384],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v8bf },
    &operand_data[5386],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v2sf },
    &operand_data[5388],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v4sf },
    &operand_data[5390],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1v2df },
    &operand_data[5392],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7236 */
  {
    "aarch64_be_ld1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%0}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_ld1di },
    &operand_data[5394],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.8b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v8qi },
    &operand_data[5396],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.16b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v16qi },
    &operand_data[5398],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v4hi },
    &operand_data[5400],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v8hi },
    &operand_data[5402],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v2si },
    &operand_data[5404],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v4si },
    &operand_data[5406],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v2di },
    &operand_data[5408],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v4hf },
    &operand_data[5410],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v8hf },
    &operand_data[5412],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v4bf },
    &operand_data[5414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.8h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v8bf },
    &operand_data[5416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v2sf },
    &operand_data[5418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.4s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v4sf },
    &operand_data[5420],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1.2d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1v2df },
    &operand_data[5422],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7246 */
  {
    "aarch64_be_st1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%1}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_st1di },
    &operand_data[5424],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3921 },
#else
    { 0, output_3921, 0 },
#endif
    { 0 },
    &operand_data[5426],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3922 },
#else
    { 0, output_3922, 0 },
#endif
    { 0 },
    &operand_data[5428],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3923 },
#else
    { 0, output_3923, 0 },
#endif
    { 0 },
    &operand_data[5430],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3924 },
#else
    { 0, output_3924, 0 },
#endif
    { 0 },
    &operand_data[5432],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3925 },
#else
    { 0, output_3925, 0 },
#endif
    { 0 },
    &operand_data[5434],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3926 },
#else
    { 0, output_3926, 0 },
#endif
    { 0 },
    &operand_data[5436],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3927 },
#else
    { 0, output_3927, 0 },
#endif
    { 0 },
    &operand_data[5438],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7255 */
  {
    "*aarch64_be_movv2x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3928 },
#else
    { 0, output_3928, 0 },
#endif
    { 0 },
    &operand_data[5440],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3929 },
#else
    { 0, output_3929, 0 },
#endif
    { 0 },
    &operand_data[5442],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3930 },
#else
    { 0, output_3930, 0 },
#endif
    { 0 },
    &operand_data[5444],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3931 },
#else
    { 0, output_3931, 0 },
#endif
    { 0 },
    &operand_data[5446],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3932 },
#else
    { 0, output_3932, 0 },
#endif
    { 0 },
    &operand_data[5448],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3933 },
#else
    { 0, output_3933, 0 },
#endif
    { 0 },
    &operand_data[5450],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3934 },
#else
    { 0, output_3934, 0 },
#endif
    { 0 },
    &operand_data[5452],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3935 },
#else
    { 0, output_3935, 0 },
#endif
    { 0 },
    &operand_data[5454],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7269 */
  {
    "*aarch64_be_movv2x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3936 },
#else
    { 0, output_3936, 0 },
#endif
    { 0 },
    &operand_data[5456],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7283 */
  {
    "*aarch64_be_movoi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_3937 },
#else
    { 0, output_3937, 0 },
#endif
    { 0 },
    &operand_data[5458],
    2,
    2,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5460],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5462],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5464],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5466],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5468],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5470],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5472],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5474],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5476],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5478],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5480],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5482],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5484],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5486],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5488],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7297 */
  {
    "*aarch64_be_movv3x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5490],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7308 */
  {
    "*aarch64_be_movci",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5492],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5494],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5496],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5498],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5500],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5502],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5504],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5506],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5508],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5510],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5512],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5514],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5516],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5518],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5520],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5522],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7319 */
  {
    "*aarch64_be_movv4x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5524],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7330 */
  {
    "*aarch64_be_movxi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5526],
    2,
    2,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7519 */
  {
    "aarch64_ld2v8qi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.8b - %T0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v8qi_dreg },
    &operand_data[5528],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7519 */
  {
    "aarch64_ld2v4hi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4hi_dreg },
    &operand_data[5530],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7519 */
  {
    "aarch64_ld2v2si_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.2s - %T0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v2si_dreg },
    &operand_data[5532],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7519 */
  {
    "aarch64_ld2v4hf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4hf_dreg },
    &operand_data[5534],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7519 */
  {
    "aarch64_ld2v2sf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.2s - %T0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v2sf_dreg },
    &operand_data[5536],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7519 */
  {
    "aarch64_ld2v4bf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4bf_dreg },
    &operand_data[5538],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7529 */
  {
    "aarch64_ld2di_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %T0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2di_dreg },
    &operand_data[5540],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7529 */
  {
    "aarch64_ld2df_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %T0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2df_dreg },
    &operand_data[5542],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7539 */
  {
    "aarch64_ld3v8qi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.8b - %U0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v8qi_dreg },
    &operand_data[5182],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7539 */
  {
    "aarch64_ld3v4hi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4hi_dreg },
    &operand_data[5184],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7539 */
  {
    "aarch64_ld3v2si_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.2s - %U0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v2si_dreg },
    &operand_data[5186],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7539 */
  {
    "aarch64_ld3v4hf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4hf_dreg },
    &operand_data[5190],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7539 */
  {
    "aarch64_ld3v2sf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.2s - %U0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v2sf_dreg },
    &operand_data[5192],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7539 */
  {
    "aarch64_ld3v4bf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3\t{%S0.4h - %U0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4bf_dreg },
    &operand_data[5196],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7549 */
  {
    "aarch64_ld3di_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %U0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3di_dreg },
    &operand_data[5188],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7549 */
  {
    "aarch64_ld3df_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %U0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3df_dreg },
    &operand_data[5194],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7559 */
  {
    "aarch64_ld4v8qi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.8b - %V0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v8qi_dreg },
    &operand_data[5198],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7559 */
  {
    "aarch64_ld4v4hi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4hi_dreg },
    &operand_data[5200],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7559 */
  {
    "aarch64_ld4v2si_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.2s - %V0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v2si_dreg },
    &operand_data[5202],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7559 */
  {
    "aarch64_ld4v4hf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4hf_dreg },
    &operand_data[5206],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7559 */
  {
    "aarch64_ld4v2sf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.2s - %V0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v2sf_dreg },
    &operand_data[5208],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7559 */
  {
    "aarch64_ld4v4bf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4\t{%S0.4h - %V0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4bf_dreg },
    &operand_data[5212],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7569 */
  {
    "aarch64_ld4di_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %V0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4di_dreg },
    &operand_data[5204],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7569 */
  {
    "aarch64_ld4df_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %V0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4df_dreg },
    &operand_data[5210],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7661 */
  {
    "aarch64_qtbl1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.8b, {%1.16b}, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl1v8qi },
    &operand_data[5544],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7661 */
  {
    "aarch64_qtbl1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.16b, {%1.16b}, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl1v16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7671 */
  {
    "aarch64_qtbx1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.8b, {%2.16b}, %3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx1v8qi },
    &operand_data[5547],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7671 */
  {
    "aarch64_qtbx1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.16b, {%2.16b}, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx1v16qi },
    &operand_data[2727],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7684 */
  {
    "aarch64_qtbl2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%S0.8b, {%S1.16b - %T1.16b}, %S2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl2v8qi },
    &operand_data[5551],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7684 */
  {
    "aarch64_qtbl2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%S0.16b, {%S1.16b - %T1.16b}, %S2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl2v16qi },
    &operand_data[5554],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7694 */
  {
    "aarch64_qtbx2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%S0.8b, {%S2.16b - %T2.16b}, %S3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx2v8qi },
    &operand_data[5557],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7694 */
  {
    "aarch64_qtbx2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%S0.16b, {%S2.16b - %T2.16b}, %S3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx2v16qi },
    &operand_data[5561],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7707 */
  {
    "aarch64_qtbl3v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%S0.8b, {%S1.16b - %U1.16b}, %S2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl3v8qi },
    &operand_data[5565],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7707 */
  {
    "aarch64_qtbl3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%S0.16b, {%S1.16b - %U1.16b}, %S2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl3v16qi },
    &operand_data[5568],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7717 */
  {
    "aarch64_qtbx3v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%S0.8b, {%S2.16b - %U2.16b}, %S3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx3v8qi },
    &operand_data[5571],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7717 */
  {
    "aarch64_qtbx3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%S0.16b, {%S2.16b - %U2.16b}, %S3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx3v16qi },
    &operand_data[5575],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7730 */
  {
    "aarch64_qtbl4v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%S0.8b, {%S1.16b - %V1.16b}, %S2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl4v8qi },
    &operand_data[5579],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7730 */
  {
    "aarch64_qtbl4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%S0.16b, {%S1.16b - %V1.16b}, %S2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbl4v16qi },
    &operand_data[5582],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7740 */
  {
    "aarch64_qtbx4v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%S0.8b, {%S2.16b - %V2.16b}, %S3.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx4v8qi },
    &operand_data[5585],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7740 */
  {
    "aarch64_qtbx4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%S0.16b, {%S2.16b - %V2.16b}, %S3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_qtbx4v16qi },
    &operand_data[5589],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7751 */
  {
    "aarch64_combinev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinev16qi },
    &operand_data[5593],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8b, %1.8b, %2.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v8qi },
    &operand_data[2449],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.16b, %1.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v16qi },
    &operand_data[2452],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v4hi },
    &operand_data[2455],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v8hi },
    &operand_data[2458],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v2si },
    &operand_data[2461],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v4bf },
    &operand_data[5596],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v4bf },
    &operand_data[5596],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v4bf },
    &operand_data[5596],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v4bf },
    &operand_data[5596],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v4bf },
    &operand_data[5596],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v4bf },
    &operand_data[5596],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v8bf },
    &operand_data[5599],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v8bf },
    &operand_data[5599],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v8bf },
    &operand_data[5599],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v8bf },
    &operand_data[5599],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v8bf },
    &operand_data[5599],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v8bf },
    &operand_data[5599],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip1v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip1v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_zip2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_zip2v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn1v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn1v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_trn2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_trn2v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp1v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp1v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7770 */
  {
    "aarch64_uzp2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uzp2v2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4097 },
#else
    { 0, 0, output_4097 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv8qi },
    &operand_data[5602],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4098 },
#else
    { 0, 0, output_4098 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv16qi },
    &operand_data[5606],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4099 },
#else
    { 0, 0, output_4099 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv4hi },
    &operand_data[5610],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4100 },
#else
    { 0, 0, output_4100 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv8hi },
    &operand_data[5614],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4101 },
#else
    { 0, 0, output_4101 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv2si },
    &operand_data[2581],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4102 },
#else
    { 0, 0, output_4102 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv4si },
    &operand_data[3989],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4103 },
#else
    { 0, 0, output_4103 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv2di },
    &operand_data[5618],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4104 },
#else
    { 0, 0, output_4104 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv4hf },
    &operand_data[5622],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4105 },
#else
    { 0, 0, output_4105 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv8hf },
    &operand_data[5626],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4106 },
#else
    { 0, 0, output_4106 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv4bf },
    &operand_data[5630],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4107 },
#else
    { 0, 0, output_4107 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv8bf },
    &operand_data[5634],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4108 },
#else
    { 0, 0, output_4108 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv2sf },
    &operand_data[2597],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4109 },
#else
    { 0, 0, output_4109 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv4sf },
    &operand_data[3924],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7784 */
  {
    "aarch64_extv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4110 },
#else
    { 0, 0, output_4110 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_extv2df },
    &operand_data[3928],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.8b, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v8qi },
    &operand_data[1471],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v4hi },
    &operand_data[1477],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v8hi },
    &operand_data[1480],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v2di },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v2di },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v2di },
    &operand_data[1489],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v4bf },
    &operand_data[1498],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v4bf },
    &operand_data[1498],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v4bf },
    &operand_data[1498],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v8bf },
    &operand_data[1501],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v8bf },
    &operand_data[1501],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v8bf },
    &operand_data[1501],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev64v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev64\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev64v2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev32v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev32\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev32v2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7802 */
  {
    "aarch64_rev16v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev16\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rev16v2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7811 */
  {
    "aarch64_st2v8qi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.8b - %T1.8b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v8qi_dreg },
    &operand_data[5214],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7811 */
  {
    "aarch64_st2v4hi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.4h - %T1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4hi_dreg },
    &operand_data[5216],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7811 */
  {
    "aarch64_st2v2si_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.2s - %T1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v2si_dreg },
    &operand_data[5218],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7811 */
  {
    "aarch64_st2v4hf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.4h - %T1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4hf_dreg },
    &operand_data[5222],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7811 */
  {
    "aarch64_st2v2sf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.2s - %T1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v2sf_dreg },
    &operand_data[5224],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7811 */
  {
    "aarch64_st2v4bf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2\t{%S1.4h - %T1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4bf_dreg },
    &operand_data[5228],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7821 */
  {
    "aarch64_st2di_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %T1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2di_dreg },
    &operand_data[5220],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7821 */
  {
    "aarch64_st2df_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %T1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2df_dreg },
    &operand_data[5226],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7831 */
  {
    "aarch64_st3v8qi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.8b - %U1.8b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v8qi_dreg },
    &operand_data[5230],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7831 */
  {
    "aarch64_st3v4hi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.4h - %U1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4hi_dreg },
    &operand_data[5232],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7831 */
  {
    "aarch64_st3v2si_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.2s - %U1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v2si_dreg },
    &operand_data[5234],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7831 */
  {
    "aarch64_st3v4hf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.4h - %U1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4hf_dreg },
    &operand_data[5238],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7831 */
  {
    "aarch64_st3v2sf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.2s - %U1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v2sf_dreg },
    &operand_data[5240],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7831 */
  {
    "aarch64_st3v4bf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3\t{%S1.4h - %U1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4bf_dreg },
    &operand_data[5244],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7841 */
  {
    "aarch64_st3di_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %U1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3di_dreg },
    &operand_data[5236],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7841 */
  {
    "aarch64_st3df_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %U1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3df_dreg },
    &operand_data[5242],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7851 */
  {
    "aarch64_st4v8qi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.8b - %V1.8b}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v8qi_dreg },
    &operand_data[5246],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7851 */
  {
    "aarch64_st4v4hi_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.4h - %V1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4hi_dreg },
    &operand_data[5248],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7851 */
  {
    "aarch64_st4v2si_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.2s - %V1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v2si_dreg },
    &operand_data[5250],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7851 */
  {
    "aarch64_st4v4hf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.4h - %V1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4hf_dreg },
    &operand_data[5254],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7851 */
  {
    "aarch64_st4v2sf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.2s - %V1.2s}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v2sf_dreg },
    &operand_data[5256],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7851 */
  {
    "aarch64_st4v4bf_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4\t{%S1.4h - %V1.4h}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4bf_dreg },
    &operand_data[5260],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7861 */
  {
    "aarch64_st4di_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %V1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4di_dreg },
    &operand_data[5252],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7861 */
  {
    "aarch64_st4df_dreg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1\t{%S1.1d - %V1.1d}, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4df_dreg },
    &operand_data[5258],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5638],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5640],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5642],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5644],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5646],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5648],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5650],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5652],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5654],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5656],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5658],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5660],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5662],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7942 */
  {
    "*aarch64_simd_ld1rv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1r\t{%0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5664],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v8qi_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8b - %T0.8b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v8qi_x2 },
    &operand_data[5528],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v4hi_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v4hi_x2 },
    &operand_data[5530],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v2si_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2s - %T0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v2si_x2 },
    &operand_data[5532],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1di_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %T0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1di_x2 },
    &operand_data[5540],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v4hf_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v4hf_x2 },
    &operand_data[5534],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v2sf_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2s - %T0.2s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v2sf_x2 },
    &operand_data[5536],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1df_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.1d - %T0.1d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1df_x2 },
    &operand_data[5542],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v4bf_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4h - %T0.4h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v4bf_x2 },
    &operand_data[5538],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v16qi_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.16b - %T0.16b}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v16qi_x2 },
    &operand_data[4510],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v8hi_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v8hi_x2 },
    &operand_data[4512],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v4si_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4s - %T0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v4si_x2 },
    &operand_data[4514],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v2di_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2d - %T0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v2di_x2 },
    &operand_data[4516],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v8hf_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v8hf_x2 },
    &operand_data[4518],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v4sf_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.4s - %T0.4s}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v4sf_x2 },
    &operand_data[4520],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v2df_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.2d - %T0.2d}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v2df_x2 },
    &operand_data[4522],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7951 */
  {
    "aarch64_simd_ld1v8bf_x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1\t{%S0.8h - %T0.8h}, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ld1v8bf_x2 },
    &operand_data[4524],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.4h, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpev4hf },
    &operand_data[1492],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.8h, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpev8hf },
    &operand_data[1495],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpev2sf },
    &operand_data[1414],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpev4sf },
    &operand_data[1416],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.2d, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpev2df },
    &operand_data[1418],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpehf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpehf },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpesf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpesf },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7962 */
  {
    "aarch64_frecpedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpedf },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7972 */
  {
    "aarch64_frecpxhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpx\t%h0, %h1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpxhf },
    &operand_data[1179],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7972 */
  {
    "aarch64_frecpxsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpx\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpxsf },
    &operand_data[1181],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7972 */
  {
    "aarch64_frecpxdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpx\t%d0, %d1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpxdf },
    &operand_data[1183],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpsv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.4h, %1.4h, %2.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsv4hf },
    &operand_data[2470],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpsv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.8h, %1.8h, %2.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsv8hf },
    &operand_data[2473],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpsv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.2s, %1.2s, %2.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsv2sf },
    &operand_data[2476],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpsv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsv4sf },
    &operand_data[2479],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpsv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsv2df },
    &operand_data[2482],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpshf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%h0, %h1, %h2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpshf },
    &operand_data[1209],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpssf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%s0, %s1, %s2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpssf },
    &operand_data[1213],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7981 */
  {
    "aarch64_frecpsdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%d0, %d1, %d2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsdf },
    &operand_data[1217],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7992 */
  {
    "aarch64_urecpev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urecpe\t%0.2s, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urecpev2si },
    &operand_data[1483],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7992 */
  {
    "aarch64_urecpev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "urecpe\t%0.4s, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_urecpev4si },
    &operand_data[1486],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8044 */
  {
    "aarch64_crypto_aesev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aese\t%0.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_aesev16qi },
    &operand_data[5666],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8044 */
  {
    "aarch64_crypto_aesdv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesd\t%0.16b, %2.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_aesdv16qi },
    &operand_data[5666],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8056 */
  {
    "aarch64_crypto_aesmcv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesmc\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_aesmcv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8056 */
  {
    "aarch64_crypto_aesimcv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesimc\t%0.16b, %1.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_aesimcv16qi },
    &operand_data[1474],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8070 */
  {
    "*aarch64_crypto_aese_fused",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aese\t%0.16b, %2.16b\n\taesmc\t%0.16b, %0.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5666],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8091 */
  {
    "*aarch64_crypto_aesd_fused",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesd\t%0.16b, %2.16b\n\taesimc\t%0.16b, %0.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[5666],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8109 */
  {
    "aarch64_crypto_sha1hsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1h\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha1hsi },
    &operand_data[973],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8119 */
  {
    "aarch64_crypto_sha1hv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1h\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha1hv4si },
    &operand_data[3547],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8129 */
  {
    "aarch64_be_crypto_sha1hv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1h\t%s0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_be_crypto_sha1hv4si },
    &operand_data[3547],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8139 */
  {
    "aarch64_crypto_sha1su1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1su1\t%0.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha1su1v4si },
    &operand_data[2743],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8149 */
  {
    "aarch64_crypto_sha1cv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1c\t%q0, %s2, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha1cv4si },
    &operand_data[5669],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8149 */
  {
    "aarch64_crypto_sha1mv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1m\t%q0, %s2, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha1mv4si },
    &operand_data[5669],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8149 */
  {
    "aarch64_crypto_sha1pv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1p\t%q0, %s2, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha1pv4si },
    &operand_data[5669],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8160 */
  {
    "aarch64_crypto_sha1su0v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha1su0\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha1su0v4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8173 */
  {
    "aarch64_crypto_sha256hv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha256h\t%q0, %q2, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha256hv4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8173 */
  {
    "aarch64_crypto_sha256h2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha256h2\t%q0, %q2, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha256h2v4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8184 */
  {
    "aarch64_crypto_sha256su0v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha256su0\t%0.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha256su0v4si },
    &operand_data[2743],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8194 */
  {
    "aarch64_crypto_sha256su1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha256su1\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha256su1v4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8207 */
  {
    "aarch64_crypto_sha512hqv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha512h\t%q0, %q2, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha512hqv2di },
    &operand_data[5673],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8207 */
  {
    "aarch64_crypto_sha512h2qv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha512h2\t%q0, %q2, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha512h2qv2di },
    &operand_data[5673],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8218 */
  {
    "aarch64_crypto_sha512su0qv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha512su0\t%0.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha512su0qv2di },
    &operand_data[3956],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8228 */
  {
    "aarch64_crypto_sha512su1qv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sha512su1\t%0.2d, %2.2d, %3.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_sha512su1qv2di },
    &operand_data[5673],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8241 */
  {
    "eor3qv16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor3\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_eor3qv16qi4 },
    &operand_data[5677],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8241 */
  {
    "eor3qv8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor3\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_eor3qv8hi4 },
    &operand_data[5681],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8241 */
  {
    "eor3qv4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor3\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_eor3qv4si4 },
    &operand_data[5685],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8241 */
  {
    "eor3qv2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor3\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_eor3qv2di4 },
    &operand_data[5689],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8253 */
  {
    "aarch64_rax1qv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rax1\t%0.2d, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rax1qv2di },
    &operand_data[2467],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8265 */
  {
    "aarch64_xarqv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xar\t%0.2d, %1.2d, %2.2d, %3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xarqv2di },
    &operand_data[5693],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8277 */
  {
    "bcaxqv16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bcax\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bcaxqv16qi4 },
    &operand_data[5677],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8277 */
  {
    "bcaxqv8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bcax\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bcaxqv8hi4 },
    &operand_data[5681],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8277 */
  {
    "bcaxqv4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bcax\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bcaxqv4si4 },
    &operand_data[5685],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8277 */
  {
    "bcaxqv2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bcax\t%0.16b, %1.16b, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_bcaxqv2di4 },
    &operand_data[5689],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8291 */
  {
    "aarch64_sm3ss1qv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm3ss1\t%0.4s, %1.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm3ss1qv4si },
    &operand_data[5685],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8303 */
  {
    "aarch64_sm3tt1aqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm3tt1a\t%0.4s, %2.4s, %3.4s[%4]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm3tt1aqv4si },
    &operand_data[5697],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8303 */
  {
    "aarch64_sm3tt1bqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm3tt1b\t%0.4s, %2.4s, %3.4s[%4]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm3tt1bqv4si },
    &operand_data[5697],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8303 */
  {
    "aarch64_sm3tt2aqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm3tt2a\t%0.4s, %2.4s, %3.4s[%4]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm3tt2aqv4si },
    &operand_data[5697],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8303 */
  {
    "aarch64_sm3tt2bqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm3tt2b\t%0.4s, %2.4s, %3.4s[%4]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm3tt2bqv4si },
    &operand_data[5697],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8315 */
  {
    "aarch64_sm3partw1qv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm3partw1\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm3partw1qv4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8315 */
  {
    "aarch64_sm3partw2qv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm3partw2\t%0.4s, %2.4s, %3.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm3partw2qv4si },
    &operand_data[2743],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8328 */
  {
    "aarch64_sm4eqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm4e\t%0.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm4eqv4si },
    &operand_data[2743],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8338 */
  {
    "aarch64_sm4ekeyqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm4ekey\t%0.4s, %1.4s, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sm4ekeyqv4si },
    &operand_data[2464],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8393 */
  {
    "aarch64_simd_fmlal_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal\t%0.2s, %2.2h, %3.2h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlal_lowv2sf },
    &operand_data[5702],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8393 */
  {
    "aarch64_simd_fmlalq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlalq_lowv4sf },
    &operand_data[5708],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8410 */
  {
    "aarch64_simd_fmlsl_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl\t%0.2s, %2.2h, %3.2h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlsl_lowv2sf },
    &operand_data[5702],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8410 */
  {
    "aarch64_simd_fmlslq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlslq_lowv4sf },
    &operand_data[5708],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8428 */
  {
    "aarch64_simd_fmlal_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal2\t%0.2s, %2.2h, %3.2h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlal_highv2sf },
    &operand_data[5714],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8428 */
  {
    "aarch64_simd_fmlalq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal2\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlalq_highv4sf },
    &operand_data[5720],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8445 */
  {
    "aarch64_simd_fmlsl_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl2\t%0.2s, %2.2h, %3.2h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlsl_highv2sf },
    &operand_data[5714],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8445 */
  {
    "aarch64_simd_fmlslq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl2\t%0.4s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlslq_highv4sf },
    &operand_data[5720],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8504 */
  {
    "aarch64_simd_fmlal_lane_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlal_lane_lowv2sf },
    &operand_data[5726],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8522 */
  {
    "aarch64_simd_fmlsl_lane_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlsl_lane_lowv2sf },
    &operand_data[5726],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8541 */
  {
    "aarch64_simd_fmlal_lane_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal2\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlal_lane_highv2sf },
    &operand_data[5732],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8559 */
  {
    "aarch64_simd_fmlsl_lane_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl2\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlsl_lane_highv2sf },
    &operand_data[5732],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8618 */
  {
    "aarch64_simd_fmlalq_laneq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlalq_laneq_lowv4sf },
    &operand_data[5738],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8636 */
  {
    "aarch64_simd_fmlslq_laneq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlslq_laneq_lowv4sf },
    &operand_data[5738],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8655 */
  {
    "aarch64_simd_fmlalq_laneq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal2\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlalq_laneq_highv4sf },
    &operand_data[5744],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8673 */
  {
    "aarch64_simd_fmlslq_laneq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl2\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlslq_laneq_highv4sf },
    &operand_data[5744],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8734 */
  {
    "aarch64_simd_fmlal_laneq_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlal_laneq_lowv2sf },
    &operand_data[5750],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8752 */
  {
    "aarch64_simd_fmlsl_laneq_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlsl_laneq_lowv2sf },
    &operand_data[5750],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8771 */
  {
    "aarch64_simd_fmlal_laneq_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal2\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlal_laneq_highv2sf },
    &operand_data[5756],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8789 */
  {
    "aarch64_simd_fmlsl_laneq_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl2\t%0.2s, %2.2h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlsl_laneq_highv2sf },
    &operand_data[5756],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8848 */
  {
    "aarch64_simd_fmlalq_lane_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlalq_lane_lowv4sf },
    &operand_data[5762],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8866 */
  {
    "aarch64_simd_fmlslq_lane_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlslq_lane_lowv4sf },
    &operand_data[5762],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8885 */
  {
    "aarch64_simd_fmlalq_lane_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlal2\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlalq_lane_highv4sf },
    &operand_data[5768],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8903 */
  {
    "aarch64_simd_fmlslq_lane_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmlsl2\t%0.4s, %2.4h, %3.h[%5]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_fmlslq_lane_highv4sf },
    &operand_data[5768],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8924 */
  {
    "aarch64_crypto_pmulldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmull\t%0.1q, %1.1d, %2.1d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_pmulldi },
    &operand_data[5774],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8934 */
  {
    "aarch64_crypto_pmullv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmull2\t%0.1q, %1.2d, %2.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_crypto_pmullv2di },
    &operand_data[5777],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8945 */
  {
    "extendv8qiv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl\t%0.8h, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendv8qiv8hi2 },
    &operand_data[2672],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8945 */
  {
    "zero_extendv8qiv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl\t%0.8h, %1.8b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendv8qiv8hi2 },
    &operand_data[2672],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8945 */
  {
    "extendv4hiv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl\t%0.4s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendv4hiv4si2 },
    &operand_data[2675],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8945 */
  {
    "zero_extendv4hiv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl\t%0.4s, %1.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendv4hiv4si2 },
    &operand_data[2675],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8945 */
  {
    "extendv2siv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sxtl\t%0.2d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendv2siv2di2 },
    &operand_data[2678],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8945 */
  {
    "zero_extendv2siv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uxtl\t%0.2d, %1.2s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendv2siv2di2 },
    &operand_data[2678],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8961 */
  {
    "truncv8hiv8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.8b, %1.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncv8hiv8qi2 },
    &operand_data[3151],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8961 */
  {
    "truncv4siv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncv4siv4hi2 },
    &operand_data[3154],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8961 */
  {
    "truncv2div2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "xtn\t%0.2s, %1.2d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncv2div2si2 },
    &operand_data[3157],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8969 */
  {
    "aarch64_bfdotv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfdot\t%0.2s, %2.4h, %3.4h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfdotv2sf },
    &operand_data[5780],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8969 */
  {
    "aarch64_bfdotv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfdot\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfdotv4sf },
    &operand_data[5784],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8982 */
  {
    "aarch64_bfdot_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4306 },
#else
    { 0, 0, output_4306 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfdot_lanev2sf },
    &operand_data[5788],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8982 */
  {
    "aarch64_bfdot_laneqv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4307 },
#else
    { 0, 0, output_4307 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfdot_laneqv2sf },
    &operand_data[5793],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8982 */
  {
    "aarch64_bfdot_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4308 },
#else
    { 0, 0, output_4308 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfdot_lanev4sf },
    &operand_data[5798],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8982 */
  {
    "aarch64_bfdot_laneqv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4309 },
#else
    { 0, 0, output_4309 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfdot_laneqv4sf },
    &operand_data[5803],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9023 */
  {
    "aarch64_bfmmlaqv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfmmla\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfmmlaqv4sf },
    &operand_data[5784],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9035 */
  {
    "aarch64_bfmlalbv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfmlalb\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfmlalbv4sf },
    &operand_data[5784],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9035 */
  {
    "aarch64_bfmlaltv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfmlalt\t%0.4s, %2.8h, %3.8h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfmlaltv4sf },
    &operand_data[5784],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9046 */
  {
    "aarch64_bfmlalb_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4313 },
#else
    { 0, 0, output_4313 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfmlalb_lanev4sf },
    &operand_data[5798],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9046 */
  {
    "aarch64_bfmlalt_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4314 },
#else
    { 0, 0, output_4314 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfmlalt_lanev4sf },
    &operand_data[5798],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9046 */
  {
    "aarch64_bfmlalb_lane_qv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4315 },
#else
    { 0, 0, output_4315 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfmlalb_lane_qv4sf },
    &operand_data[5803],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9046 */
  {
    "aarch64_bfmlalt_lane_qv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4316 },
#else
    { 0, 0, output_4316 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfmlalt_lane_qv4sf },
    &operand_data[5803],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9062 */
  {
    "aarch64_simd_smmlav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smmla\t%0.4s, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_smmlav16qi },
    &operand_data[2568],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9062 */
  {
    "aarch64_simd_ummlav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ummla\t%0.4s, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_ummlav16qi },
    &operand_data[2568],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9062 */
  {
    "aarch64_simd_usmmlav16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usmmla\t%0.4s, %2.16b, %3.16b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_usmmlav16qi },
    &operand_data[2568],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9074 */
  {
    "aarch64_bfcvtnv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfcvtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfcvtnv4bf },
    &operand_data[5808],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9074 */
  {
    "aarch64_bfcvtn_qv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfcvtn\t%0.4h, %1.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfcvtn_qv8bf },
    &operand_data[5810],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9083 */
  {
    "aarch64_bfcvtn2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfcvtn2\t%0.8h, %2.4s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfcvtn2v8bf },
    &operand_data[5812],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9093 */
  {
    "aarch64_bfcvtbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfcvt\t%h0, %s1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfcvtbf },
    &operand_data[5815],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9103 */
  {
    "aarch64_vbfcvtv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shll\t%0.4s, %1.4h, #16",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vbfcvtv4bf },
    &operand_data[5817],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9103 */
  {
    "aarch64_vbfcvtv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shll\t%0.4s, %1.4h, #16",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vbfcvtv8bf },
    &operand_data[5819],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9112 */
  {
    "aarch64_vbfcvt_highv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shll2\t%0.4s, %1.8h, #16",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vbfcvt_highv8bf },
    &operand_data[5819],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9121 */
  {
    "aarch64_bfcvtsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shl\t%d0, %d1, #16",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bfcvtsf },
    &operand_data[5821],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:44 */
  {
    "aarch64_compare_and_swapqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapqi },
    &operand_data[5823],
    7,
    8,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:44 */
  {
    "aarch64_compare_and_swaphi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swaphi },
    &operand_data[5831],
    7,
    8,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:70 */
  {
    "aarch64_compare_and_swapsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapsi },
    &operand_data[5839],
    7,
    8,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:70 */
  {
    "aarch64_compare_and_swapdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapdi },
    &operand_data[5847],
    7,
    8,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:94 */
  {
    "aarch64_compare_and_swapti",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapti },
    &operand_data[5855],
    7,
    8,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:118 */
  {
    "aarch64_compare_and_swapqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4333 },
#else
    { 0, 0, output_4333 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapqi_lse },
    &operand_data[5863],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:118 */
  {
    "aarch64_compare_and_swaphi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4334 },
#else
    { 0, 0, output_4334 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swaphi_lse },
    &operand_data[5867],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:141 */
  {
    "aarch64_compare_and_swapsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4335 },
#else
    { 0, 0, output_4335 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapsi_lse },
    &operand_data[5871],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:141 */
  {
    "aarch64_compare_and_swapdi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4336 },
#else
    { 0, 0, output_4336 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapdi_lse },
    &operand_data[5875],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:163 */
  {
    "aarch64_compare_and_swapti_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4337 },
#else
    { 0, 0, output_4337 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_compare_and_swapti_lse },
    &operand_data[5879],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:217 */
  {
    "aarch64_atomic_exchangeqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangeqi },
    &operand_data[5883],
    4,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:217 */
  {
    "aarch64_atomic_exchangehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangehi },
    &operand_data[5888],
    4,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:217 */
  {
    "aarch64_atomic_exchangesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangesi },
    &operand_data[5893],
    4,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:217 */
  {
    "aarch64_atomic_exchangedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangedi },
    &operand_data[5898],
    4,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:238 */
  {
    "aarch64_atomic_exchangeqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4342 },
#else
    { 0, 0, output_4342 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangeqi_lse },
    &operand_data[5903],
    4,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:238 */
  {
    "aarch64_atomic_exchangehi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4343 },
#else
    { 0, 0, output_4343 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangehi_lse },
    &operand_data[5907],
    4,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:238 */
  {
    "aarch64_atomic_exchangesi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4344 },
#else
    { 0, 0, output_4344 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangesi_lse },
    &operand_data[5911],
    4,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:238 */
  {
    "aarch64_atomic_exchangedi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4345 },
#else
    { 0, 0, output_4345 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_exchangedi_lse },
    &operand_data[5915],
    4,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_addqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_addqi },
    &operand_data[5919],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_subqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_subqi },
    &operand_data[5919],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_orqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_orqi },
    &operand_data[5924],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_xorqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xorqi },
    &operand_data[5924],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_andqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_andqi },
    &operand_data[5924],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_addhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_addhi },
    &operand_data[5929],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_subhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_subhi },
    &operand_data[5929],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_orhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_orhi },
    &operand_data[5934],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_xorhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xorhi },
    &operand_data[5934],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_andhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_andhi },
    &operand_data[5934],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_addsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_addsi },
    &operand_data[5939],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_subsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_subsi },
    &operand_data[5939],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_orsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_orsi },
    &operand_data[5944],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_xorsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xorsi },
    &operand_data[5944],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_andsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_andsi },
    &operand_data[5944],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_adddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_adddi },
    &operand_data[5949],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_subdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_subdi },
    &operand_data[5949],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_ordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_ordi },
    &operand_data[5954],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_xordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xordi },
    &operand_data[5954],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:338 */
  {
    "aarch64_atomic_anddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_anddi },
    &operand_data[5954],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_iorqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4366 },
#else
    { 0, 0, output_4366 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_iorqi_lse },
    &operand_data[5959],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_bicqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4367 },
#else
    { 0, 0, output_4367 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_bicqi_lse },
    &operand_data[5959],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_xorqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4368 },
#else
    { 0, 0, output_4368 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xorqi_lse },
    &operand_data[5959],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_addqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4369 },
#else
    { 0, 0, output_4369 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_addqi_lse },
    &operand_data[5959],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_iorhi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4370 },
#else
    { 0, 0, output_4370 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_iorhi_lse },
    &operand_data[5963],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_bichi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4371 },
#else
    { 0, 0, output_4371 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_bichi_lse },
    &operand_data[5963],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_xorhi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4372 },
#else
    { 0, 0, output_4372 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xorhi_lse },
    &operand_data[5963],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_addhi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4373 },
#else
    { 0, 0, output_4373 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_addhi_lse },
    &operand_data[5963],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_iorsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4374 },
#else
    { 0, 0, output_4374 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_iorsi_lse },
    &operand_data[5967],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_bicsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4375 },
#else
    { 0, 0, output_4375 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_bicsi_lse },
    &operand_data[5967],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_xorsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4376 },
#else
    { 0, 0, output_4376 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xorsi_lse },
    &operand_data[5967],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_addsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4377 },
#else
    { 0, 0, output_4377 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_addsi_lse },
    &operand_data[5967],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_iordi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4378 },
#else
    { 0, 0, output_4378 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_iordi_lse },
    &operand_data[5971],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_bicdi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4379 },
#else
    { 0, 0, output_4379 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_bicdi_lse },
    &operand_data[5971],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_xordi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4380 },
#else
    { 0, 0, output_4380 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xordi_lse },
    &operand_data[5971],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:371 */
  {
    "aarch64_atomic_adddi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4381 },
#else
    { 0, 0, output_4381 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_adddi_lse },
    &operand_data[5971],
    3,
    4,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:393 */
  {
    "atomic_nandqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nandqi },
    &operand_data[5924],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:393 */
  {
    "atomic_nandhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nandhi },
    &operand_data[5934],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:393 */
  {
    "atomic_nandsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nandsi },
    &operand_data[5944],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:393 */
  {
    "atomic_nanddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nanddi },
    &operand_data[5954],
    3,
    5,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_addqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_addqi },
    &operand_data[5975],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_subqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_subqi },
    &operand_data[5975],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_orqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_orqi },
    &operand_data[5981],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_xorqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xorqi },
    &operand_data[5981],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_andqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_andqi },
    &operand_data[5981],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_addhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_addhi },
    &operand_data[5987],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_subhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_subhi },
    &operand_data[5987],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_orhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_orhi },
    &operand_data[5993],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_xorhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xorhi },
    &operand_data[5993],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_andhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_andhi },
    &operand_data[5993],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_addsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_addsi },
    &operand_data[5999],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_subsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_subsi },
    &operand_data[5999],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_orsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_orsi },
    &operand_data[6005],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_xorsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xorsi },
    &operand_data[6005],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_andsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_andsi },
    &operand_data[6005],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_adddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_adddi },
    &operand_data[6011],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_subdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_subdi },
    &operand_data[6011],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_ordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_ordi },
    &operand_data[6017],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_xordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xordi },
    &operand_data[6017],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:496 */
  {
    "aarch64_atomic_fetch_anddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_anddi },
    &operand_data[6017],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_iorqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4406 },
#else
    { 0, 0, output_4406 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_iorqi_lse },
    &operand_data[6023],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_bicqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4407 },
#else
    { 0, 0, output_4407 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_bicqi_lse },
    &operand_data[6023],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_xorqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4408 },
#else
    { 0, 0, output_4408 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xorqi_lse },
    &operand_data[6023],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_addqi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4409 },
#else
    { 0, 0, output_4409 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_addqi_lse },
    &operand_data[6023],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_iorhi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4410 },
#else
    { 0, 0, output_4410 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_iorhi_lse },
    &operand_data[6027],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_bichi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4411 },
#else
    { 0, 0, output_4411 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_bichi_lse },
    &operand_data[6027],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_xorhi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4412 },
#else
    { 0, 0, output_4412 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xorhi_lse },
    &operand_data[6027],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_addhi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4413 },
#else
    { 0, 0, output_4413 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_addhi_lse },
    &operand_data[6027],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_iorsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4414 },
#else
    { 0, 0, output_4414 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_iorsi_lse },
    &operand_data[6031],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_bicsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4415 },
#else
    { 0, 0, output_4415 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_bicsi_lse },
    &operand_data[6031],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_xorsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4416 },
#else
    { 0, 0, output_4416 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xorsi_lse },
    &operand_data[6031],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_addsi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4417 },
#else
    { 0, 0, output_4417 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_addsi_lse },
    &operand_data[6031],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_iordi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4418 },
#else
    { 0, 0, output_4418 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_iordi_lse },
    &operand_data[6035],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_bicdi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4419 },
#else
    { 0, 0, output_4419 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_bicdi_lse },
    &operand_data[6035],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_xordi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4420 },
#else
    { 0, 0, output_4420 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_xordi_lse },
    &operand_data[6035],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:519 */
  {
    "aarch64_atomic_fetch_adddi_lse",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4421 },
#else
    { 0, 0, output_4421 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_fetch_adddi_lse },
    &operand_data[6035],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:542 */
  {
    "atomic_fetch_nandqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_nandqi },
    &operand_data[5981],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:542 */
  {
    "atomic_fetch_nandhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_nandhi },
    &operand_data[5993],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:542 */
  {
    "atomic_fetch_nandsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_nandsi },
    &operand_data[6005],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:542 */
  {
    "atomic_fetch_nanddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_nanddi },
    &operand_data[6017],
    4,
    6,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_add_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_add_fetchqi },
    &operand_data[6039],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_sub_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_sub_fetchqi },
    &operand_data[6039],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_or_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_or_fetchqi },
    &operand_data[6044],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_xor_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xor_fetchqi },
    &operand_data[6044],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_and_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_and_fetchqi },
    &operand_data[6044],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_add_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_add_fetchhi },
    &operand_data[6049],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_sub_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_sub_fetchhi },
    &operand_data[6049],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_or_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_or_fetchhi },
    &operand_data[6054],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_xor_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xor_fetchhi },
    &operand_data[6054],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_and_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_and_fetchhi },
    &operand_data[6054],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_add_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_add_fetchsi },
    &operand_data[5999],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_sub_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_sub_fetchsi },
    &operand_data[5999],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_or_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_or_fetchsi },
    &operand_data[6005],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_xor_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xor_fetchsi },
    &operand_data[6005],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_and_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_and_fetchsi },
    &operand_data[6005],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_add_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_add_fetchdi },
    &operand_data[6059],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_sub_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_sub_fetchdi },
    &operand_data[6059],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_or_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_or_fetchdi },
    &operand_data[6064],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_xor_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_xor_fetchdi },
    &operand_data[6064],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:596 */
  {
    "aarch64_atomic_and_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_atomic_and_fetchdi },
    &operand_data[6064],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:619 */
  {
    "atomic_nand_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nand_fetchqi },
    &operand_data[6044],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:619 */
  {
    "atomic_nand_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nand_fetchhi },
    &operand_data[6054],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:619 */
  {
    "atomic_nand_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nand_fetchsi },
    &operand_data[6005],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:619 */
  {
    "atomic_nand_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_nand_fetchdi },
    &operand_data[6064],
    4,
    5,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:643 */
  {
    "atomic_loadqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4450 },
#else
    { 0, 0, output_4450 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_loadqi },
    &operand_data[6069],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:643 */
  {
    "atomic_loadhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4451 },
#else
    { 0, 0, output_4451 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_loadhi },
    &operand_data[6072],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:643 */
  {
    "atomic_loadsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4452 },
#else
    { 0, 0, output_4452 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_loadsi },
    &operand_data[6075],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:643 */
  {
    "atomic_loaddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4453 },
#else
    { 0, 0, output_4453 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_loaddi },
    &operand_data[6078],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:659 */
  {
    "atomic_storeqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4454 },
#else
    { 0, 0, output_4454 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_storeqi },
    &operand_data[6081],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:659 */
  {
    "atomic_storehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4455 },
#else
    { 0, 0, output_4455 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_storehi },
    &operand_data[6084],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:659 */
  {
    "atomic_storesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4456 },
#else
    { 0, 0, output_4456 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_storesi },
    &operand_data[6087],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:659 */
  {
    "atomic_storedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4457 },
#else
    { 0, 0, output_4457 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_storedi },
    &operand_data[6090],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:678 */
  {
    "aarch64_load_exclusiveqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4458 },
#else
    { 0, 0, output_4458 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_exclusiveqi },
    &operand_data[6093],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:678 */
  {
    "aarch64_load_exclusivehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4459 },
#else
    { 0, 0, output_4459 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_exclusivehi },
    &operand_data[6096],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:695 */
  {
    "aarch64_load_exclusivesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4460 },
#else
    { 0, 0, output_4460 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_exclusivesi },
    &operand_data[6075],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:695 */
  {
    "aarch64_load_exclusivedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4461 },
#else
    { 0, 0, output_4461 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_exclusivedi },
    &operand_data[6078],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:711 */
  {
    "aarch64_load_exclusive_pair",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4462 },
#else
    { 0, 0, output_4462 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_exclusive_pair },
    &operand_data[6099],
    4,
    4,
    2,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:729 */
  {
    "aarch64_store_exclusiveqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4463 },
#else
    { 0, 0, output_4463 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_exclusiveqi },
    &operand_data[6103],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:729 */
  {
    "aarch64_store_exclusivehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4464 },
#else
    { 0, 0, output_4464 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_exclusivehi },
    &operand_data[6107],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:729 */
  {
    "aarch64_store_exclusivesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4465 },
#else
    { 0, 0, output_4465 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_exclusivesi },
    &operand_data[6111],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:729 */
  {
    "aarch64_store_exclusivedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4466 },
#else
    { 0, 0, output_4466 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_exclusivedi },
    &operand_data[6115],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:747 */
  {
    "aarch64_store_exclusive_pair",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4467 },
#else
    { 0, 0, output_4467 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_exclusive_pair },
    &operand_data[6119],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:788 */
  {
    "*dmb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4468 },
#else
    { 0, 0, output_4468 },
#endif
    { 0 },
    &operand_data[6124],
    2,
    2,
    1,
    0,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx16qi_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4469 },
#else
    { 0, 0, output_4469 },
#endif
    { 0 },
    &operand_data[6126],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx8hi_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4470 },
#else
    { 0, 0, output_4470 },
#endif
    { 0 },
    &operand_data[6128],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx4si_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4471 },
#else
    { 0, 0, output_4471 },
#endif
    { 0 },
    &operand_data[6130],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx2di_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4472 },
#else
    { 0, 0, output_4472 },
#endif
    { 0 },
    &operand_data[6132],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx8bf_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4473 },
#else
    { 0, 0, output_4473 },
#endif
    { 0 },
    &operand_data[6134],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx8hf_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4474 },
#else
    { 0, 0, output_4474 },
#endif
    { 0 },
    &operand_data[6136],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx4sf_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4475 },
#else
    { 0, 0, output_4475 },
#endif
    { 0 },
    &operand_data[6138],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:689 */
  {
    "*aarch64_sve_movvnx2df_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4476 },
#else
    { 0, 0, output_4476 },
#endif
    { 0 },
    &operand_data[6140],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx8qi_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4477 },
#else
    { 0, 0, output_4477 },
#endif
    { 0 },
    &operand_data[6142],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx4qi_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4478 },
#else
    { 0, 0, output_4478 },
#endif
    { 0 },
    &operand_data[6144],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2qi_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4479 },
#else
    { 0, 0, output_4479 },
#endif
    { 0 },
    &operand_data[6146],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx8hi_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4480 },
#else
    { 0, 0, output_4480 },
#endif
    { 0 },
    &operand_data[6148],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx4hi_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4481 },
#else
    { 0, 0, output_4481 },
#endif
    { 0 },
    &operand_data[6150],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2hi_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4482 },
#else
    { 0, 0, output_4482 },
#endif
    { 0 },
    &operand_data[6152],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx8hf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4483 },
#else
    { 0, 0, output_4483 },
#endif
    { 0 },
    &operand_data[6154],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx4hf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4484 },
#else
    { 0, 0, output_4484 },
#endif
    { 0 },
    &operand_data[6156],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2hf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4485 },
#else
    { 0, 0, output_4485 },
#endif
    { 0 },
    &operand_data[6158],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx8bf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4486 },
#else
    { 0, 0, output_4486 },
#endif
    { 0 },
    &operand_data[6160],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx4bf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4487 },
#else
    { 0, 0, output_4487 },
#endif
    { 0 },
    &operand_data[6162],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2bf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4488 },
#else
    { 0, 0, output_4488 },
#endif
    { 0 },
    &operand_data[6164],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx4si_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4489 },
#else
    { 0, 0, output_4489 },
#endif
    { 0 },
    &operand_data[6166],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2si_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4490 },
#else
    { 0, 0, output_4490 },
#endif
    { 0 },
    &operand_data[6168],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx4sf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4491 },
#else
    { 0, 0, output_4491 },
#endif
    { 0 },
    &operand_data[6170],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2sf_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4492 },
#else
    { 0, 0, output_4492 },
#endif
    { 0 },
    &operand_data[6172],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2di_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4493 },
#else
    { 0, 0, output_4493 },
#endif
    { 0 },
    &operand_data[6174],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:707 */
  {
    "*aarch64_sve_movvnx2df_no_ldr_str",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4494 },
#else
    { 0, 0, output_4494 },
#endif
    { 0 },
    &operand_data[6176],
    2,
    2,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4495 },
#else
    { 0, output_4495, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx16qi },
    &operand_data[6178],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4496 },
#else
    { 0, output_4496, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8qi },
    &operand_data[6181],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4497 },
#else
    { 0, output_4497, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4qi },
    &operand_data[6184],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4498 },
#else
    { 0, output_4498, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2qi },
    &operand_data[6187],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4499 },
#else
    { 0, output_4499, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8hi },
    &operand_data[6190],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4500 },
#else
    { 0, output_4500, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4hi },
    &operand_data[6193],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4501 },
#else
    { 0, output_4501, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2hi },
    &operand_data[6196],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4502 },
#else
    { 0, output_4502, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8hf },
    &operand_data[6199],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4503 },
#else
    { 0, output_4503, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4hf },
    &operand_data[6202],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4504 },
#else
    { 0, output_4504, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2hf },
    &operand_data[6205],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4505 },
#else
    { 0, output_4505, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8bf },
    &operand_data[6208],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4506 },
#else
    { 0, output_4506, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4bf },
    &operand_data[6211],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4507 },
#else
    { 0, output_4507, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2bf },
    &operand_data[6214],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4508 },
#else
    { 0, output_4508, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4si },
    &operand_data[6217],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4509 },
#else
    { 0, output_4509, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2si },
    &operand_data[6220],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4510 },
#else
    { 0, output_4510, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4sf },
    &operand_data[6223],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4511 },
#else
    { 0, output_4511, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2sf },
    &operand_data[6226],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4512 },
#else
    { 0, output_4512, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2di },
    &operand_data[6229],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:745 */
  {
    "aarch64_pred_movvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4513 },
#else
    { 0, output_4513, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx2df },
    &operand_data[6232],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx16qi_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6235],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx8qi_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6238],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx4qi_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6241],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2qi_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6244],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx8hi_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6247],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx4hi_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6250],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2hi_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6253],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx8hf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6256],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx4hf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6259],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2hf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6262],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx8bf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx4bf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2bf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6271],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx4si_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6274],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2si_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6277],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx4sf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6280],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2sf_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6283],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2di_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6286],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:767 */
  {
    "*aarch64_sve_movvnx2df_subreg_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6289],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6292],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6294],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6296],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6298],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6300],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6302],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6304],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6306],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6308],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6310],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6312],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6314],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6316],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6318],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6320],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6322],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6324],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6326],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:804 */
  {
    "*aarch64_sve_reinterpretvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6328],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx32qi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6330],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx16hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6332],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx8si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6334],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx4di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6336],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx16bf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6338],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx16hf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6340],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx8sf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6342],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx4df_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6344],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx48qi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6346],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx24hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6348],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx12si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6350],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx6di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6352],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx24bf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6354],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx24hf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6356],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx12sf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6358],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx6df_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6360],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx64qi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6362],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx32hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6364],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx16si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6366],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx8di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6368],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx32bf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6370],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx32hf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6372],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx16sf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6374],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:849 */
  {
    "*aarch64_sve_movvnx8df_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6376],
    2,
    2,
    0,
    4,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx32qi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6378],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx16hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6380],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx8si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6382],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx4di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6384],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx16bf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6386],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx16hf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6388],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx8sf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6390],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx4df_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6392],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx48qi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6394],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx24hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6396],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx12si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6398],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx6di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6400],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx24bf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6402],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx24hf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6404],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx12sf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6406],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx6df_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6408],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx64qi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6410],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx32hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6412],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx16si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6414],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx8di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6416],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx32bf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6418],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx32hf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6420],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx16sf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6422],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:859 */
  {
    "*aarch64_sve_movvnx8df_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6424],
    2,
    2,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx32qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx32qi },
    &operand_data[6426],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx16hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx16hi },
    &operand_data[6429],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx8si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8si },
    &operand_data[6432],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx4di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4di },
    &operand_data[6435],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx16bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx16bf },
    &operand_data[6438],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx16hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx16hf },
    &operand_data[6441],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx8sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8sf },
    &operand_data[6444],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx4df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx4df },
    &operand_data[6447],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx48qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx48qi },
    &operand_data[6450],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx24hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx24hi },
    &operand_data[6453],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx12si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx12si },
    &operand_data[6456],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx6di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx6di },
    &operand_data[6459],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx24bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx24bf },
    &operand_data[6462],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx24hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx24hf },
    &operand_data[6465],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx12sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx12sf },
    &operand_data[6468],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx6df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx6df },
    &operand_data[6471],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx64qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx64qi },
    &operand_data[6474],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx32hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx32hi },
    &operand_data[6477],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx16si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx16si },
    &operand_data[6480],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx8di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8di },
    &operand_data[6483],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx32bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx32bf },
    &operand_data[6486],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx32hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx32hf },
    &operand_data[6489],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx16sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx16sf },
    &operand_data[6492],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:895 */
  {
    "aarch64_pred_movvnx8df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_movvnx8df },
    &operand_data[6495],
    3,
    3,
    0,
    3,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:951 */
  {
    "*aarch64_sve_movvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4624 },
#else
    { 0, 0, output_4624 },
#endif
    { 0 },
    &operand_data[6498],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:951 */
  {
    "*aarch64_sve_movvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4625 },
#else
    { 0, 0, output_4625 },
#endif
    { 0 },
    &operand_data[6500],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:951 */
  {
    "*aarch64_sve_movvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4626 },
#else
    { 0, 0, output_4626 },
#endif
    { 0 },
    &operand_data[6502],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:951 */
  {
    "*aarch64_sve_movvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4627 },
#else
    { 0, 0, output_4627 },
#endif
    { 0 },
    &operand_data[6504],
    2,
    2,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:965 */
  {
    "*aarch64_sve_ptruevnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4628 },
#else
    { 0, 0, output_4628 },
#endif
    { 0 },
    &operand_data[6506],
    6,
    6,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:990 */
  {
    "*aarch64_sve_ptruevnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4629 },
#else
    { 0, 0, output_4629 },
#endif
    { 0 },
    &operand_data[6512],
    6,
    6,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:990 */
  {
    "*aarch64_sve_ptruevnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4630 },
#else
    { 0, 0, output_4630 },
#endif
    { 0 },
    &operand_data[6518],
    6,
    6,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:990 */
  {
    "*aarch64_sve_ptruevnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4631 },
#else
    { 0, 0, output_4631 },
#endif
    { 0 },
    &operand_data[6524],
    6,
    6,
    1,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1018 */
  {
    "*aarch64_sve_ptruevnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4632 },
#else
    { 0, 0, output_4632 },
#endif
    { 0 },
    &operand_data[6530],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1043 */
  {
    "*aarch64_sve_ptruevnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4633 },
#else
    { 0, 0, output_4633 },
#endif
    { 0 },
    &operand_data[6536],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1043 */
  {
    "*aarch64_sve_ptruevnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4634 },
#else
    { 0, 0, output_4634 },
#endif
    { 0 },
    &operand_data[6542],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1043 */
  {
    "*aarch64_sve_ptruevnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4635 },
#else
    { 0, 0, output_4635 },
#endif
    { 0 },
    &operand_data[6548],
    6,
    6,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1080 */
  {
    "aarch64_wrffr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4636 },
#else
    { 0, output_4636, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_wrffr },
    &operand_data[6554],
    1,
    1,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1097 */
  {
    "aarch64_update_ffr_for_load",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_update_ffr_for_load },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1112 */
  {
    "aarch64_copy_ffr_to_ffrt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_copy_ffr_to_ffrt },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1123 */
  {
    "aarch64_rdffr",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rdffr\t%0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rdffr },
    &operand_data[6506],
    1,
    1,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1131 */
  {
    "aarch64_rdffr_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rdffr\t%0.b, %1/z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rdffr_z },
    &operand_data[6555],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1141 */
  {
    "*aarch64_rdffr_z_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rdffrs\t%0.b, %1/z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6557],
    3,
    3,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1157 */
  {
    "*aarch64_rdffr_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rdffrs\t%0.b, %1/z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6557],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1171 */
  {
    "*aarch64_rdffr_z_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rdffrs\t%0.b, %1/z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6560],
    3,
    3,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1190 */
  {
    "*aarch64_rdffr_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rdffrs\t%0.b, %1/z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[6555],
    2,
    2,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1208 */
  {
    "aarch64_update_ffrt",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_update_ffrt },
    &operand_data[0],
    0,
    0,
    0,
    0,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx16qivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.b, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx16qivnx16bi },
    &operand_data[6563],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx8qivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx8qivnx8bi },
    &operand_data[6566],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx4qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx4qivnx4bi },
    &operand_data[6569],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2qivnx2bi },
    &operand_data[6572],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx8hivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx8hivnx8bi },
    &operand_data[6575],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx4hivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx4hivnx4bi },
    &operand_data[6578],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2hivnx2bi },
    &operand_data[6581],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx8hfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx8hfvnx8bi },
    &operand_data[6584],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx4hfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx4hfvnx4bi },
    &operand_data[6587],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2hfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2hfvnx2bi },
    &operand_data[6590],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx8bfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx8bfvnx8bi },
    &operand_data[6593],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx4bfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx4bfvnx4bi },
    &operand_data[6596],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2bfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2bfvnx2bi },
    &operand_data[6599],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx4sivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx4sivnx4bi },
    &operand_data[6602],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2sivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1w\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2sivnx2bi },
    &operand_data[6605],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx4sfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx4sfvnx4bi },
    &operand_data[6608],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2sfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1w\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2sfvnx2bi },
    &operand_data[6611],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2divnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2divnx2bi },
    &operand_data[6614],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1243 */
  {
    "maskloadvnx2dfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskloadvnx2dfvnx2bi },
    &operand_data[6617],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx32qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2b\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx32qivnx16qi },
    &operand_data[6620],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx16hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx16hivnx8hi },
    &operand_data[6623],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx8sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2w\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx8sivnx4si },
    &operand_data[6626],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx4divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2d\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx4divnx2di },
    &operand_data[6629],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx16bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx16bfvnx8bf },
    &operand_data[6632],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx16hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx16hfvnx8hf },
    &operand_data[6635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx8sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2w\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx8sfvnx4sf },
    &operand_data[6638],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx4dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld2d\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx4dfvnx2df },
    &operand_data[6641],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx48qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3b\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx48qivnx16qi },
    &operand_data[6644],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx24hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx24hivnx8hi },
    &operand_data[6647],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx12sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3w\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx12sivnx4si },
    &operand_data[6650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx6divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3d\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx6divnx2di },
    &operand_data[6653],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx24bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx24bfvnx8bf },
    &operand_data[6656],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx24hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx24hfvnx8hf },
    &operand_data[6659],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx12sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3w\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx12sfvnx4sf },
    &operand_data[6662],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx6dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld3d\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx6dfvnx2df },
    &operand_data[6665],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx64qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4b\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx64qivnx16qi },
    &operand_data[6668],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx32hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx32hivnx8hi },
    &operand_data[6671],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx16sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4w\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx16sivnx4si },
    &operand_data[6674],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx8divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4d\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx8divnx2di },
    &operand_data[6677],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx32bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx32bfvnx8bf },
    &operand_data[6680],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx32hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4h\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx32hfvnx8hf },
    &operand_data[6683],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx16sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4w\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx16sfvnx4sf },
    &operand_data[6686],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1267 */
  {
    "vec_mask_load_lanesvnx8dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld4d\t%0, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_load_lanesvnx8dfvnx2df },
    &operand_data[6689],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx8hivnx8qi },
    &operand_data[6692],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx8hivnx8qi },
    &operand_data[6692],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx8hivnx8qi },
    &operand_data[6692],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx8hivnx8qi },
    &operand_data[6692],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx4hivnx4qi },
    &operand_data[6696],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx4hivnx4qi },
    &operand_data[6696],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx4hivnx4qi },
    &operand_data[6696],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx4hivnx4qi },
    &operand_data[6696],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx2hivnx2qi },
    &operand_data[6700],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx2hivnx2qi },
    &operand_data[6700],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx2hivnx2qi },
    &operand_data[6700],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx2hivnx2qi },
    &operand_data[6700],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx4sivnx4qi },
    &operand_data[6704],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx4sivnx4qi },
    &operand_data[6704],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx4sivnx4qi },
    &operand_data[6704],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx4sivnx4qi },
    &operand_data[6704],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sh\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx4sivnx4hi },
    &operand_data[6708],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sh\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx4sivnx4hi },
    &operand_data[6708],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx4sivnx4hi },
    &operand_data[6708],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx4sivnx4hi },
    &operand_data[6708],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx2sivnx2qi },
    &operand_data[6712],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx2sivnx2qi },
    &operand_data[6712],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx2sivnx2qi },
    &operand_data[6712],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx2sivnx2qi },
    &operand_data[6712],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx2sivnx2hi },
    &operand_data[6716],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx2sivnx2hi },
    &operand_data[6716],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx2sivnx2hi },
    &operand_data[6716],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx2sivnx2hi },
    &operand_data[6716],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx2divnx2qi },
    &operand_data[6720],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx2divnx2qi },
    &operand_data[6720],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx2divnx2qi },
    &operand_data[6720],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx2divnx2qi },
    &operand_data[6720],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx2divnx2hi },
    &operand_data[6724],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx2divnx2hi },
    &operand_data[6724],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx2divnx2hi },
    &operand_data[6724],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx2divnx2hi },
    &operand_data[6724],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sw\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_extendvnx2divnx2si },
    &operand_data[6728],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1sw\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_extendvnx2divnx2si },
    &operand_data[6728],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_x_zero_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1w\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_x_zero_extendvnx2divnx2si },
    &operand_data[6728],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1290 */
  {
    "aarch64_load_zero_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1w\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_load_zero_extendvnx2divnx2si },
    &operand_data[6728],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1b\t%0.b, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx16qi },
    &operand_data[6732],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1b\t%0.b, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx16qi },
    &operand_data[6735],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx8hi },
    &operand_data[6738],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx8hi },
    &operand_data[6741],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx4si },
    &operand_data[6744],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx4si },
    &operand_data[6747],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx2di },
    &operand_data[6750],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx2di },
    &operand_data[6753],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx8bf },
    &operand_data[6756],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx8bf },
    &operand_data[6759],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx8hf },
    &operand_data[6762],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx8hf },
    &operand_data[6765],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx4sf },
    &operand_data[6768],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx4sf },
    &operand_data[6771],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldff1vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1vnx2df },
    &operand_data[6774],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1323 */
  {
    "aarch64_ldnf1vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1vnx2df },
    &operand_data[6777],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sb\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx8hivnx8qi },
    &operand_data[6780],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sb\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx8hivnx8qi },
    &operand_data[6784],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1b\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx8hivnx8qi },
    &operand_data[6780],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1b\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx8hivnx8qi },
    &operand_data[6784],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx4hivnx4qi },
    &operand_data[6788],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx4hivnx4qi },
    &operand_data[6792],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx4hivnx4qi },
    &operand_data[6788],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx4hivnx4qi },
    &operand_data[6792],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx2hivnx2qi },
    &operand_data[6796],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx2hivnx2qi },
    &operand_data[6800],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx2hivnx2qi },
    &operand_data[6796],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx2hivnx2qi },
    &operand_data[6800],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx4sivnx4qi },
    &operand_data[6804],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sb\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx4sivnx4qi },
    &operand_data[6808],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx4sivnx4qi },
    &operand_data[6804],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1b\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx4sivnx4qi },
    &operand_data[6808],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sh\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx4sivnx4hi },
    &operand_data[6812],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sh\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx4sivnx4hi },
    &operand_data[6816],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1h\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx4sivnx4hi },
    &operand_data[6812],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1h\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx4sivnx4hi },
    &operand_data[6816],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx2sivnx2qi },
    &operand_data[6820],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx2sivnx2qi },
    &operand_data[6824],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx2sivnx2qi },
    &operand_data[6820],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx2sivnx2qi },
    &operand_data[6824],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx2sivnx2hi },
    &operand_data[6828],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx2sivnx2hi },
    &operand_data[6832],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx2sivnx2hi },
    &operand_data[6828],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx2sivnx2hi },
    &operand_data[6832],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx2divnx2qi },
    &operand_data[6836],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sb\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx2divnx2qi },
    &operand_data[6840],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx2divnx2qi },
    &operand_data[6836],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1b\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx2divnx2qi },
    &operand_data[6840],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx2divnx2hi },
    &operand_data[6844],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sh\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx2divnx2hi },
    &operand_data[6848],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx2divnx2hi },
    &operand_data[6844],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1h\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx2divnx2hi },
    &operand_data[6848],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1sw\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_extendvnx2divnx2si },
    &operand_data[6852],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1sw\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_extendvnx2divnx2si },
    &operand_data[6856],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldff1_zero_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldff1w\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_zero_extendvnx2divnx2si },
    &operand_data[6852],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1353 */
  {
    "aarch64_ldnf1_zero_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnf1w\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnf1_zero_extendvnx2divnx2si },
    &operand_data[6856],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1b\t%0.b, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx16qi },
    &operand_data[6563],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx8hi },
    &operand_data[6575],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx4si },
    &operand_data[6602],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx2di },
    &operand_data[6614],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx8bf },
    &operand_data[6593],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1h\t%0.h, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx8hf },
    &operand_data[6584],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1w\t%0.s, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx4sf },
    &operand_data[6608],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1383 */
  {
    "aarch64_ldnt1vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ldnt1d\t%0.d, %2/z, %1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldnt1vnx2df },
    &operand_data[6617],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1420 */
  {
    "mask_gather_loadvnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4793 },
#else
    { 0, output_4793, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx4qivnx4si },
    &operand_data[6860],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1420 */
  {
    "mask_gather_loadvnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4794 },
#else
    { 0, output_4794, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx4hivnx4si },
    &operand_data[6866],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1420 */
  {
    "mask_gather_loadvnx4hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4795 },
#else
    { 0, output_4795, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx4hfvnx4si },
    &operand_data[6872],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1420 */
  {
    "mask_gather_loadvnx4bfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4796 },
#else
    { 0, output_4796, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx4bfvnx4si },
    &operand_data[6878],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1420 */
  {
    "mask_gather_loadvnx4sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4797 },
#else
    { 0, output_4797, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx4sivnx4si },
    &operand_data[6884],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1420 */
  {
    "mask_gather_loadvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4798 },
#else
    { 0, output_4798, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx4sfvnx4si },
    &operand_data[6890],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4799 },
#else
    { 0, output_4799, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2qivnx2di },
    &operand_data[6896],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4800 },
#else
    { 0, output_4800, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2hivnx2di },
    &operand_data[6902],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4801 },
#else
    { 0, output_4801, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2hfvnx2di },
    &operand_data[6908],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2bfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4802 },
#else
    { 0, output_4802, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2bfvnx2di },
    &operand_data[6914],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4803 },
#else
    { 0, output_4803, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2sivnx2di },
    &operand_data[6920],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4804 },
#else
    { 0, output_4804, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2sfvnx2di },
    &operand_data[6926],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4805 },
#else
    { 0, output_4805, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2divnx2di },
    &operand_data[6932],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1442 */
  {
    "mask_gather_loadvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4806 },
#else
    { 0, output_4806, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_gather_loadvnx2dfvnx2di },
    &operand_data[6938],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2qivnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4807 },
#else
    { 0, output_4807, 0 },
#endif
    { 0 },
    &operand_data[6944],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2qivnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4808 },
#else
    { 0, output_4808, 0 },
#endif
    { 0 },
    &operand_data[6944],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2hivnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4809 },
#else
    { 0, output_4809, 0 },
#endif
    { 0 },
    &operand_data[6951],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2hivnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4810 },
#else
    { 0, output_4810, 0 },
#endif
    { 0 },
    &operand_data[6951],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2hfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4811 },
#else
    { 0, output_4811, 0 },
#endif
    { 0 },
    &operand_data[6958],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2hfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4812 },
#else
    { 0, output_4812, 0 },
#endif
    { 0 },
    &operand_data[6958],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2bfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4813 },
#else
    { 0, output_4813, 0 },
#endif
    { 0 },
    &operand_data[6965],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2bfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4814 },
#else
    { 0, output_4814, 0 },
#endif
    { 0 },
    &operand_data[6965],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2sivnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4815 },
#else
    { 0, output_4815, 0 },
#endif
    { 0 },
    &operand_data[6972],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2sivnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4816 },
#else
    { 0, output_4816, 0 },
#endif
    { 0 },
    &operand_data[6972],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2sfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4817 },
#else
    { 0, output_4817, 0 },
#endif
    { 0 },
    &operand_data[6979],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2sfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4818 },
#else
    { 0, output_4818, 0 },
#endif
    { 0 },
    &operand_data[6979],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2divnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4819 },
#else
    { 0, output_4819, 0 },
#endif
    { 0 },
    &operand_data[6986],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2divnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4820 },
#else
    { 0, output_4820, 0 },
#endif
    { 0 },
    &operand_data[6986],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2dfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4821 },
#else
    { 0, output_4821, 0 },
#endif
    { 0 },
    &operand_data[6993],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1461 */
  {
    "*mask_gather_loadvnx2dfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4822 },
#else
    { 0, output_4822, 0 },
#endif
    { 0 },
    &operand_data[6993],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2qivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4823 },
#else
    { 0, output_4823, 0 },
#endif
    { 0 },
    &operand_data[7000],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2hivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4824 },
#else
    { 0, output_4824, 0 },
#endif
    { 0 },
    &operand_data[7007],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2hfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4825 },
#else
    { 0, output_4825, 0 },
#endif
    { 0 },
    &operand_data[7014],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2bfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4826 },
#else
    { 0, output_4826, 0 },
#endif
    { 0 },
    &operand_data[7021],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2sivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4827 },
#else
    { 0, output_4827, 0 },
#endif
    { 0 },
    &operand_data[7028],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2sfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4828 },
#else
    { 0, output_4828, 0 },
#endif
    { 0 },
    &operand_data[7035],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2divnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4829 },
#else
    { 0, output_4829, 0 },
#endif
    { 0 },
    &operand_data[7042],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1487 */
  {
    "*mask_gather_loadvnx2dfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4830 },
#else
    { 0, output_4830, 0 },
#endif
    { 0 },
    &operand_data[7049],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2qivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4831 },
#else
    { 0, output_4831, 0 },
#endif
    { 0 },
    &operand_data[7056],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2hivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4832 },
#else
    { 0, output_4832, 0 },
#endif
    { 0 },
    &operand_data[7063],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2hfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4833 },
#else
    { 0, output_4833, 0 },
#endif
    { 0 },
    &operand_data[7070],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2bfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4834 },
#else
    { 0, output_4834, 0 },
#endif
    { 0 },
    &operand_data[7077],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2sivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4835 },
#else
    { 0, output_4835, 0 },
#endif
    { 0 },
    &operand_data[7084],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2sfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4836 },
#else
    { 0, output_4836, 0 },
#endif
    { 0 },
    &operand_data[7091],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2divnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4837 },
#else
    { 0, output_4837, 0 },
#endif
    { 0 },
    &operand_data[7098],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1514 */
  {
    "*mask_gather_loadvnx2dfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4838 },
#else
    { 0, output_4838, 0 },
#endif
    { 0 },
    &operand_data[7105],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1546 */
  {
    "aarch64_gather_load_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4839 },
#else
    { 0, output_4839, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx4hivnx4qi },
    &operand_data[7112],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1546 */
  {
    "aarch64_gather_load_zero_extendvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4840 },
#else
    { 0, output_4840, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx4hivnx4qi },
    &operand_data[7112],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1546 */
  {
    "aarch64_gather_load_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4841 },
#else
    { 0, output_4841, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx4sivnx4qi },
    &operand_data[7119],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1546 */
  {
    "aarch64_gather_load_zero_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4842 },
#else
    { 0, output_4842, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx4sivnx4qi },
    &operand_data[7119],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1546 */
  {
    "aarch64_gather_load_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4843 },
#else
    { 0, output_4843, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx4sivnx4hi },
    &operand_data[7126],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1546 */
  {
    "aarch64_gather_load_zero_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4844 },
#else
    { 0, output_4844, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx4sivnx4hi },
    &operand_data[7126],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4845 },
#else
    { 0, output_4845, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx2hivnx2qi },
    &operand_data[7133],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_zero_extendvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4846 },
#else
    { 0, output_4846, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx2hivnx2qi },
    &operand_data[7133],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4847 },
#else
    { 0, output_4847, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx2sivnx2qi },
    &operand_data[7140],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_zero_extendvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4848 },
#else
    { 0, output_4848, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx2sivnx2qi },
    &operand_data[7140],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4849 },
#else
    { 0, output_4849, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx2sivnx2hi },
    &operand_data[7147],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_zero_extendvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4850 },
#else
    { 0, output_4850, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx2sivnx2hi },
    &operand_data[7147],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4851 },
#else
    { 0, output_4851, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx2divnx2qi },
    &operand_data[7154],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_zero_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4852 },
#else
    { 0, output_4852, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx2divnx2qi },
    &operand_data[7154],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4853 },
#else
    { 0, output_4853, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx2divnx2hi },
    &operand_data[7161],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_zero_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4854 },
#else
    { 0, output_4854, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx2divnx2hi },
    &operand_data[7161],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4855 },
#else
    { 0, output_4855, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_extendvnx2divnx2si },
    &operand_data[7168],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1576 */
  {
    "aarch64_gather_load_zero_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4856 },
#else
    { 0, output_4856, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_load_zero_extendvnx2divnx2si },
    &operand_data[7168],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2hivnx2qi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4857 },
#else
    { 0, output_4857, 0 },
#endif
    { 0 },
    &operand_data[7175],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2hivnx2qi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4858 },
#else
    { 0, output_4858, 0 },
#endif
    { 0 },
    &operand_data[7175],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2hivnx2qi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4859 },
#else
    { 0, output_4859, 0 },
#endif
    { 0 },
    &operand_data[7175],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2hivnx2qi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4860 },
#else
    { 0, output_4860, 0 },
#endif
    { 0 },
    &operand_data[7175],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2qi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4861 },
#else
    { 0, output_4861, 0 },
#endif
    { 0 },
    &operand_data[7183],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2qi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4862 },
#else
    { 0, output_4862, 0 },
#endif
    { 0 },
    &operand_data[7183],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2qi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4863 },
#else
    { 0, output_4863, 0 },
#endif
    { 0 },
    &operand_data[7183],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2qi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4864 },
#else
    { 0, output_4864, 0 },
#endif
    { 0 },
    &operand_data[7183],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2hi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4865 },
#else
    { 0, output_4865, 0 },
#endif
    { 0 },
    &operand_data[7191],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2hi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4866 },
#else
    { 0, output_4866, 0 },
#endif
    { 0 },
    &operand_data[7191],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2hi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4867 },
#else
    { 0, output_4867, 0 },
#endif
    { 0 },
    &operand_data[7191],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2hi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4868 },
#else
    { 0, output_4868, 0 },
#endif
    { 0 },
    &operand_data[7191],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2divnx2qi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4869 },
#else
    { 0, output_4869, 0 },
#endif
    { 0 },
    &operand_data[7199],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2qi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4870 },
#else
    { 0, output_4870, 0 },
#endif
    { 0 },
    &operand_data[7199],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2divnx2qi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4871 },
#else
    { 0, output_4871, 0 },
#endif
    { 0 },
    &operand_data[7199],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2qi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4872 },
#else
    { 0, output_4872, 0 },
#endif
    { 0 },
    &operand_data[7199],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2divnx2hi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4873 },
#else
    { 0, output_4873, 0 },
#endif
    { 0 },
    &operand_data[7207],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2hi_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4874 },
#else
    { 0, output_4874, 0 },
#endif
    { 0 },
    &operand_data[7207],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2divnx2hi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4875 },
#else
    { 0, output_4875, 0 },
#endif
    { 0 },
    &operand_data[7207],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2hi_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4876 },
#else
    { 0, output_4876, 0 },
#endif
    { 0 },
    &operand_data[7207],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2divnx2si_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4877 },
#else
    { 0, output_4877, 0 },
#endif
    { 0 },
    &operand_data[7215],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2si_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4878 },
#else
    { 0, output_4878, 0 },
#endif
    { 0 },
    &operand_data[7215],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_extendvnx2divnx2si_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4879 },
#else
    { 0, output_4879, 0 },
#endif
    { 0 },
    &operand_data[7215],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1603 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2si_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4880 },
#else
    { 0, output_4880, 0 },
#endif
    { 0 },
    &operand_data[7215],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_extendvnx2hivnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4881 },
#else
    { 0, output_4881, 0 },
#endif
    { 0 },
    &operand_data[7223],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_zero_extendvnx2hivnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4882 },
#else
    { 0, output_4882, 0 },
#endif
    { 0 },
    &operand_data[7223],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4883 },
#else
    { 0, output_4883, 0 },
#endif
    { 0 },
    &operand_data[7231],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4884 },
#else
    { 0, output_4884, 0 },
#endif
    { 0 },
    &operand_data[7231],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2hi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4885 },
#else
    { 0, output_4885, 0 },
#endif
    { 0 },
    &operand_data[7239],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2hi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4886 },
#else
    { 0, output_4886, 0 },
#endif
    { 0 },
    &operand_data[7239],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_extendvnx2divnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4887 },
#else
    { 0, output_4887, 0 },
#endif
    { 0 },
    &operand_data[7247],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4888 },
#else
    { 0, output_4888, 0 },
#endif
    { 0 },
    &operand_data[7247],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_extendvnx2divnx2hi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4889 },
#else
    { 0, output_4889, 0 },
#endif
    { 0 },
    &operand_data[7255],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2hi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4890 },
#else
    { 0, output_4890, 0 },
#endif
    { 0 },
    &operand_data[7255],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_extendvnx2divnx2si_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4891 },
#else
    { 0, output_4891, 0 },
#endif
    { 0 },
    &operand_data[7263],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1634 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2si_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4892 },
#else
    { 0, output_4892, 0 },
#endif
    { 0 },
    &operand_data[7263],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_extendvnx2hivnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4893 },
#else
    { 0, output_4893, 0 },
#endif
    { 0 },
    &operand_data[7271],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_zero_extendvnx2hivnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4894 },
#else
    { 0, output_4894, 0 },
#endif
    { 0 },
    &operand_data[7271],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4895 },
#else
    { 0, output_4895, 0 },
#endif
    { 0 },
    &operand_data[7279],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4896 },
#else
    { 0, output_4896, 0 },
#endif
    { 0 },
    &operand_data[7279],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_extendvnx2sivnx2hi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4897 },
#else
    { 0, output_4897, 0 },
#endif
    { 0 },
    &operand_data[7287],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_zero_extendvnx2sivnx2hi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4898 },
#else
    { 0, output_4898, 0 },
#endif
    { 0 },
    &operand_data[7287],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_extendvnx2divnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4899 },
#else
    { 0, output_4899, 0 },
#endif
    { 0 },
    &operand_data[7295],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4900 },
#else
    { 0, output_4900, 0 },
#endif
    { 0 },
    &operand_data[7295],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_extendvnx2divnx2hi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4901 },
#else
    { 0, output_4901, 0 },
#endif
    { 0 },
    &operand_data[7303],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2hi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4902 },
#else
    { 0, output_4902, 0 },
#endif
    { 0 },
    &operand_data[7303],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_extendvnx2divnx2si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4903 },
#else
    { 0, output_4903, 0 },
#endif
    { 0 },
    &operand_data[7311],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1666 */
  {
    "*aarch64_gather_load_zero_extendvnx2divnx2si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4904 },
#else
    { 0, output_4904, 0 },
#endif
    { 0 },
    &operand_data[7311],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1702 */
  {
    "aarch64_ldff1_gathervnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4905 },
#else
    { 0, output_4905, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gathervnx4si },
    &operand_data[7319],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1702 */
  {
    "aarch64_ldff1_gathervnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4906 },
#else
    { 0, output_4906, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gathervnx4sf },
    &operand_data[7325],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1725 */
  {
    "aarch64_ldff1_gathervnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4907 },
#else
    { 0, output_4907, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gathervnx2di },
    &operand_data[6932],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1725 */
  {
    "aarch64_ldff1_gathervnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4908 },
#else
    { 0, output_4908, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gathervnx2df },
    &operand_data[6938],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1745 */
  {
    "*aarch64_ldff1_gathervnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4909 },
#else
    { 0, output_4909, 0 },
#endif
    { 0 },
    &operand_data[7042],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1745 */
  {
    "*aarch64_ldff1_gathervnx2df_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4910 },
#else
    { 0, output_4910, 0 },
#endif
    { 0 },
    &operand_data[7049],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1772 */
  {
    "*aarch64_ldff1_gathervnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4911 },
#else
    { 0, output_4911, 0 },
#endif
    { 0 },
    &operand_data[7098],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1772 */
  {
    "*aarch64_ldff1_gathervnx2df_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4912 },
#else
    { 0, output_4912, 0 },
#endif
    { 0 },
    &operand_data[7105],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1805 */
  {
    "aarch64_ldff1_gather_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4913 },
#else
    { 0, output_4913, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_extendvnx4sivnx4qi },
    &operand_data[7331],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1805 */
  {
    "aarch64_ldff1_gather_zero_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4914 },
#else
    { 0, output_4914, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_zero_extendvnx4sivnx4qi },
    &operand_data[7331],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1805 */
  {
    "aarch64_ldff1_gather_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4915 },
#else
    { 0, output_4915, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_extendvnx4sivnx4hi },
    &operand_data[7338],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1805 */
  {
    "aarch64_ldff1_gather_zero_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4916 },
#else
    { 0, output_4916, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_zero_extendvnx4sivnx4hi },
    &operand_data[7338],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1836 */
  {
    "aarch64_ldff1_gather_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4917 },
#else
    { 0, output_4917, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_extendvnx2divnx2qi },
    &operand_data[7154],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1836 */
  {
    "aarch64_ldff1_gather_zero_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4918 },
#else
    { 0, output_4918, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_zero_extendvnx2divnx2qi },
    &operand_data[7154],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1836 */
  {
    "aarch64_ldff1_gather_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4919 },
#else
    { 0, output_4919, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_extendvnx2divnx2hi },
    &operand_data[7161],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1836 */
  {
    "aarch64_ldff1_gather_zero_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4920 },
#else
    { 0, output_4920, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_zero_extendvnx2divnx2hi },
    &operand_data[7161],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1836 */
  {
    "aarch64_ldff1_gather_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4921 },
#else
    { 0, output_4921, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_extendvnx2divnx2si },
    &operand_data[7168],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1836 */
  {
    "aarch64_ldff1_gather_zero_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4922 },
#else
    { 0, output_4922, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ldff1_gather_zero_extendvnx2divnx2si },
    &operand_data[7168],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1864 */
  {
    "*aarch64_ldff1_gather_extendvnx2divnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4923 },
#else
    { 0, output_4923, 0 },
#endif
    { 0 },
    &operand_data[7247],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1864 */
  {
    "*aarch64_ldff1_gather_zero_extendvnx2divnx2qi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4924 },
#else
    { 0, output_4924, 0 },
#endif
    { 0 },
    &operand_data[7247],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1864 */
  {
    "*aarch64_ldff1_gather_extendvnx2divnx2hi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4925 },
#else
    { 0, output_4925, 0 },
#endif
    { 0 },
    &operand_data[7255],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1864 */
  {
    "*aarch64_ldff1_gather_zero_extendvnx2divnx2hi_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4926 },
#else
    { 0, output_4926, 0 },
#endif
    { 0 },
    &operand_data[7255],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1864 */
  {
    "*aarch64_ldff1_gather_extendvnx2divnx2si_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4927 },
#else
    { 0, output_4927, 0 },
#endif
    { 0 },
    &operand_data[7263],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1864 */
  {
    "*aarch64_ldff1_gather_zero_extendvnx2divnx2si_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4928 },
#else
    { 0, output_4928, 0 },
#endif
    { 0 },
    &operand_data[7263],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1896 */
  {
    "*aarch64_ldff1_gather_extendvnx2divnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4929 },
#else
    { 0, output_4929, 0 },
#endif
    { 0 },
    &operand_data[7295],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1896 */
  {
    "*aarch64_ldff1_gather_zero_extendvnx2divnx2qi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4930 },
#else
    { 0, output_4930, 0 },
#endif
    { 0 },
    &operand_data[7295],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1896 */
  {
    "*aarch64_ldff1_gather_extendvnx2divnx2hi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4931 },
#else
    { 0, output_4931, 0 },
#endif
    { 0 },
    &operand_data[7303],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1896 */
  {
    "*aarch64_ldff1_gather_zero_extendvnx2divnx2hi_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4932 },
#else
    { 0, output_4932, 0 },
#endif
    { 0 },
    &operand_data[7303],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1896 */
  {
    "*aarch64_ldff1_gather_extendvnx2divnx2si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4933 },
#else
    { 0, output_4933, 0 },
#endif
    { 0 },
    &operand_data[7311],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1896 */
  {
    "*aarch64_ldff1_gather_zero_extendvnx2divnx2si_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_4934 },
#else
    { 0, output_4934, 0 },
#endif
    { 0 },
    &operand_data[7311],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1940 */
  {
    "aarch64_sve_prefetchvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4935 },
#else
    { 0, 0, output_4935 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_prefetchvnx16qi },
    &operand_data[7345],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1940 */
  {
    "aarch64_sve_prefetchvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4936 },
#else
    { 0, 0, output_4936 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_prefetchvnx8hi },
    &operand_data[7350],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1940 */
  {
    "aarch64_sve_prefetchvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4937 },
#else
    { 0, 0, output_4937 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_prefetchvnx4si },
    &operand_data[7355],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1940 */
  {
    "aarch64_sve_prefetchvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4938 },
#else
    { 0, 0, output_4938 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_prefetchvnx2di },
    &operand_data[7360],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1976 */
  {
    "aarch64_sve_gather_prefetchvnx16qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4939 },
#else
    { 0, 0, output_4939 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx16qivnx4si },
    &operand_data[7365],
    9,
    9,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1976 */
  {
    "aarch64_sve_gather_prefetchvnx8hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4940 },
#else
    { 0, 0, output_4940 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx8hivnx4si },
    &operand_data[7374],
    9,
    9,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1976 */
  {
    "aarch64_sve_gather_prefetchvnx4sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4941 },
#else
    { 0, 0, output_4941 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx4sivnx4si },
    &operand_data[7383],
    9,
    9,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1976 */
  {
    "aarch64_sve_gather_prefetchvnx2divnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4942 },
#else
    { 0, 0, output_4942 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx2divnx4si },
    &operand_data[7392],
    9,
    9,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2005 */
  {
    "aarch64_sve_gather_prefetchvnx16qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4943 },
#else
    { 0, 0, output_4943 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx16qivnx2di },
    &operand_data[7401],
    9,
    9,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2005 */
  {
    "aarch64_sve_gather_prefetchvnx8hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4944 },
#else
    { 0, 0, output_4944 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx8hivnx2di },
    &operand_data[7410],
    9,
    9,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2005 */
  {
    "aarch64_sve_gather_prefetchvnx4sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4945 },
#else
    { 0, 0, output_4945 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx4sivnx2di },
    &operand_data[7419],
    9,
    9,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2005 */
  {
    "aarch64_sve_gather_prefetchvnx2divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4946 },
#else
    { 0, 0, output_4946 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_gather_prefetchvnx2divnx2di },
    &operand_data[7428],
    9,
    9,
    0,
    4,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2031 */
  {
    "*aarch64_sve_gather_prefetchvnx16qivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4947 },
#else
    { 0, 0, output_4947 },
#endif
    { 0 },
    &operand_data[7437],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2031 */
  {
    "*aarch64_sve_gather_prefetchvnx8hivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4948 },
#else
    { 0, 0, output_4948 },
#endif
    { 0 },
    &operand_data[7447],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2031 */
  {
    "*aarch64_sve_gather_prefetchvnx4sivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4949 },
#else
    { 0, 0, output_4949 },
#endif
    { 0 },
    &operand_data[7457],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2031 */
  {
    "*aarch64_sve_gather_prefetchvnx2divnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4950 },
#else
    { 0, 0, output_4950 },
#endif
    { 0 },
    &operand_data[7467],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2064 */
  {
    "*aarch64_sve_gather_prefetchvnx16qivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4951 },
#else
    { 0, 0, output_4951 },
#endif
    { 0 },
    &operand_data[7477],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2064 */
  {
    "*aarch64_sve_gather_prefetchvnx8hivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4952 },
#else
    { 0, 0, output_4952 },
#endif
    { 0 },
    &operand_data[7487],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2064 */
  {
    "*aarch64_sve_gather_prefetchvnx4sivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4953 },
#else
    { 0, 0, output_4953 },
#endif
    { 0 },
    &operand_data[7497],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2064 */
  {
    "*aarch64_sve_gather_prefetchvnx2divnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_4954 },
#else
    { 0, 0, output_4954 },
#endif
    { 0 },
    &operand_data[7507],
    10,
    10,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx16qivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1b\t%1.b, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx16qivnx16bi },
    &operand_data[7517],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx8qivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1b\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx8qivnx8bi },
    &operand_data[7520],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx4qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1b\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx4qivnx4bi },
    &operand_data[7523],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1b\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2qivnx2bi },
    &operand_data[7526],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx8hivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx8hivnx8bi },
    &operand_data[7529],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx4hivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx4hivnx4bi },
    &operand_data[7532],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2hivnx2bi },
    &operand_data[7535],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx8hfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx8hfvnx8bi },
    &operand_data[7538],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx4hfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx4hfvnx4bi },
    &operand_data[7541],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2hfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2hfvnx2bi },
    &operand_data[7544],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx8bfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx8bfvnx8bi },
    &operand_data[7547],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx4bfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx4bfvnx4bi },
    &operand_data[7550],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2bfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2bfvnx2bi },
    &operand_data[7553],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx4sivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1w\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx4sivnx4bi },
    &operand_data[7556],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2sivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1w\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2sivnx2bi },
    &operand_data[7559],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx4sfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1w\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx4sfvnx4bi },
    &operand_data[7562],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2sfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1w\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2sfvnx2bi },
    &operand_data[7565],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2divnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1d\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2divnx2bi },
    &operand_data[7568],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2116 */
  {
    "maskstorevnx2dfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1d\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_maskstorevnx2dfvnx2bi },
    &operand_data[7571],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx32qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2b\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx32qivnx16qi },
    &operand_data[7574],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx16hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx16hivnx8hi },
    &operand_data[7577],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx8sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2w\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx8sivnx4si },
    &operand_data[7580],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx4divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2d\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx4divnx2di },
    &operand_data[7583],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx16bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx16bfvnx8bf },
    &operand_data[7586],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx16hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx16hfvnx8hf },
    &operand_data[7589],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx8sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2w\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx8sfvnx4sf },
    &operand_data[7592],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx4dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st2d\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx4dfvnx2df },
    &operand_data[7595],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx48qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3b\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx48qivnx16qi },
    &operand_data[7598],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx24hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx24hivnx8hi },
    &operand_data[7601],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx12sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3w\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx12sivnx4si },
    &operand_data[7604],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx6divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3d\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx6divnx2di },
    &operand_data[7607],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx24bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx24bfvnx8bf },
    &operand_data[7610],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx24hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx24hfvnx8hf },
    &operand_data[7613],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx12sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3w\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx12sfvnx4sf },
    &operand_data[7616],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx6dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st3d\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx6dfvnx2df },
    &operand_data[7619],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx64qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4b\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx64qivnx16qi },
    &operand_data[7622],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx32hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx32hivnx8hi },
    &operand_data[7625],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx16sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4w\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx16sivnx4si },
    &operand_data[7628],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx8divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4d\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx8divnx2di },
    &operand_data[7631],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx32bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx32bfvnx8bf },
    &operand_data[7634],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx32hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4h\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx32hfvnx8hf },
    &operand_data[7637],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx16sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4w\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx16sfvnx4sf },
    &operand_data[7640],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2146 */
  {
    "vec_mask_store_lanesvnx8dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st4d\t%1, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_mask_store_lanesvnx8dfvnx2df },
    &operand_data[7643],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2167 */
  {
    "aarch64_store_truncvnx8qivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1b\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_truncvnx8qivnx8hi },
    &operand_data[7646],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2180 */
  {
    "aarch64_store_truncvnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1b\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_truncvnx4qivnx4si },
    &operand_data[7649],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2180 */
  {
    "aarch64_store_truncvnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_truncvnx4hivnx4si },
    &operand_data[7652],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2193 */
  {
    "aarch64_store_truncvnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1b\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_truncvnx2qivnx2di },
    &operand_data[7655],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2193 */
  {
    "aarch64_store_truncvnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1h\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_truncvnx2hivnx2di },
    &operand_data[7658],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2193 */
  {
    "aarch64_store_truncvnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "st1w\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_store_truncvnx2sivnx2di },
    &operand_data[7661],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1b\t%1.b, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx16qi },
    &operand_data[7517],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1h\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx8hi },
    &operand_data[7529],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1w\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx4si },
    &operand_data[7556],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1d\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx2di },
    &operand_data[7568],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1h\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx8bf },
    &operand_data[7547],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1h\t%1.h, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx8hf },
    &operand_data[7538],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1w\t%1.s, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx4sf },
    &operand_data[7562],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2215 */
  {
    "aarch64_stnt1vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "stnt1d\t%1.d, %2, %0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_stnt1vnx2df },
    &operand_data[7571],
    3,
    3,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2253 */
  {
    "mask_scatter_storevnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5012 },
#else
    { 0, output_5012, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx4qivnx4si },
    &operand_data[7664],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2253 */
  {
    "mask_scatter_storevnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5013 },
#else
    { 0, output_5013, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx4hivnx4si },
    &operand_data[7670],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2253 */
  {
    "mask_scatter_storevnx4hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5014 },
#else
    { 0, output_5014, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx4hfvnx4si },
    &operand_data[7676],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2253 */
  {
    "mask_scatter_storevnx4bfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5015 },
#else
    { 0, output_5015, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx4bfvnx4si },
    &operand_data[7682],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2253 */
  {
    "mask_scatter_storevnx4sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5016 },
#else
    { 0, output_5016, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx4sivnx4si },
    &operand_data[7688],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2253 */
  {
    "mask_scatter_storevnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5017 },
#else
    { 0, output_5017, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx4sfvnx4si },
    &operand_data[7694],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5018 },
#else
    { 0, output_5018, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2qivnx2di },
    &operand_data[7700],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5019 },
#else
    { 0, output_5019, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2hivnx2di },
    &operand_data[7706],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5020 },
#else
    { 0, output_5020, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2hfvnx2di },
    &operand_data[7712],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2bfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5021 },
#else
    { 0, output_5021, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2bfvnx2di },
    &operand_data[7718],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5022 },
#else
    { 0, output_5022, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2sivnx2di },
    &operand_data[7724],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5023 },
#else
    { 0, output_5023, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2sfvnx2di },
    &operand_data[7730],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5024 },
#else
    { 0, output_5024, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2divnx2di },
    &operand_data[7736],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2275 */
  {
    "mask_scatter_storevnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5025 },
#else
    { 0, output_5025, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_scatter_storevnx2dfvnx2di },
    &operand_data[7742],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2qivnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5026 },
#else
    { 0, output_5026, 0 },
#endif
    { 0 },
    &operand_data[7748],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2qivnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5027 },
#else
    { 0, output_5027, 0 },
#endif
    { 0 },
    &operand_data[7748],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2hivnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5028 },
#else
    { 0, output_5028, 0 },
#endif
    { 0 },
    &operand_data[7755],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2hivnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5029 },
#else
    { 0, output_5029, 0 },
#endif
    { 0 },
    &operand_data[7755],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2hfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5030 },
#else
    { 0, output_5030, 0 },
#endif
    { 0 },
    &operand_data[7762],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2hfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5031 },
#else
    { 0, output_5031, 0 },
#endif
    { 0 },
    &operand_data[7762],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2bfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5032 },
#else
    { 0, output_5032, 0 },
#endif
    { 0 },
    &operand_data[7769],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2bfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5033 },
#else
    { 0, output_5033, 0 },
#endif
    { 0 },
    &operand_data[7769],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2sivnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5034 },
#else
    { 0, output_5034, 0 },
#endif
    { 0 },
    &operand_data[7776],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2sivnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5035 },
#else
    { 0, output_5035, 0 },
#endif
    { 0 },
    &operand_data[7776],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2sfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5036 },
#else
    { 0, output_5036, 0 },
#endif
    { 0 },
    &operand_data[7783],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2sfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5037 },
#else
    { 0, output_5037, 0 },
#endif
    { 0 },
    &operand_data[7783],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2divnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5038 },
#else
    { 0, output_5038, 0 },
#endif
    { 0 },
    &operand_data[7790],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2divnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5039 },
#else
    { 0, output_5039, 0 },
#endif
    { 0 },
    &operand_data[7790],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2dfvnx2di_sxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5040 },
#else
    { 0, output_5040, 0 },
#endif
    { 0 },
    &operand_data[7797],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2294 */
  {
    "*mask_scatter_storevnx2dfvnx2di_uxtw_unpacked",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5041 },
#else
    { 0, output_5041, 0 },
#endif
    { 0 },
    &operand_data[7797],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2qivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5042 },
#else
    { 0, output_5042, 0 },
#endif
    { 0 },
    &operand_data[7804],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2hivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5043 },
#else
    { 0, output_5043, 0 },
#endif
    { 0 },
    &operand_data[7811],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2hfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5044 },
#else
    { 0, output_5044, 0 },
#endif
    { 0 },
    &operand_data[7818],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2bfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5045 },
#else
    { 0, output_5045, 0 },
#endif
    { 0 },
    &operand_data[7825],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2sivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5046 },
#else
    { 0, output_5046, 0 },
#endif
    { 0 },
    &operand_data[7832],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2sfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5047 },
#else
    { 0, output_5047, 0 },
#endif
    { 0 },
    &operand_data[7839],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2divnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5048 },
#else
    { 0, output_5048, 0 },
#endif
    { 0 },
    &operand_data[7846],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2320 */
  {
    "*mask_scatter_storevnx2dfvnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5049 },
#else
    { 0, output_5049, 0 },
#endif
    { 0 },
    &operand_data[7853],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2qivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5050 },
#else
    { 0, output_5050, 0 },
#endif
    { 0 },
    &operand_data[7860],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2hivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5051 },
#else
    { 0, output_5051, 0 },
#endif
    { 0 },
    &operand_data[7867],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2hfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5052 },
#else
    { 0, output_5052, 0 },
#endif
    { 0 },
    &operand_data[7874],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2bfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5053 },
#else
    { 0, output_5053, 0 },
#endif
    { 0 },
    &operand_data[7881],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2sivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5054 },
#else
    { 0, output_5054, 0 },
#endif
    { 0 },
    &operand_data[7888],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2sfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5055 },
#else
    { 0, output_5055, 0 },
#endif
    { 0 },
    &operand_data[7895],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2divnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5056 },
#else
    { 0, output_5056, 0 },
#endif
    { 0 },
    &operand_data[7902],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2347 */
  {
    "*mask_scatter_storevnx2dfvnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5057 },
#else
    { 0, output_5057, 0 },
#endif
    { 0 },
    &operand_data[7909],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2376 */
  {
    "aarch64_scatter_store_truncvnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5058 },
#else
    { 0, output_5058, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_store_truncvnx4qivnx4si },
    &operand_data[7916],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2376 */
  {
    "aarch64_scatter_store_truncvnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5059 },
#else
    { 0, output_5059, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_store_truncvnx4hivnx4si },
    &operand_data[7922],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2399 */
  {
    "aarch64_scatter_store_truncvnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5060 },
#else
    { 0, output_5060, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_store_truncvnx2qivnx2di },
    &operand_data[7928],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2399 */
  {
    "aarch64_scatter_store_truncvnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5061 },
#else
    { 0, output_5061, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_store_truncvnx2hivnx2di },
    &operand_data[7934],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2399 */
  {
    "aarch64_scatter_store_truncvnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5062 },
#else
    { 0, output_5062, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_store_truncvnx2sivnx2di },
    &operand_data[7940],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2419 */
  {
    "*aarch64_scatter_store_truncvnx2qivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5063 },
#else
    { 0, output_5063, 0 },
#endif
    { 0 },
    &operand_data[7946],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2419 */
  {
    "*aarch64_scatter_store_truncvnx2hivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5064 },
#else
    { 0, output_5064, 0 },
#endif
    { 0 },
    &operand_data[7953],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2419 */
  {
    "*aarch64_scatter_store_truncvnx2sivnx2di_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5065 },
#else
    { 0, output_5065, 0 },
#endif
    { 0 },
    &operand_data[7960],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2446 */
  {
    "*aarch64_scatter_store_truncvnx2qivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5066 },
#else
    { 0, output_5066, 0 },
#endif
    { 0 },
    &operand_data[7967],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2446 */
  {
    "*aarch64_scatter_store_truncvnx2hivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5067 },
#else
    { 0, output_5067, 0 },
#endif
    { 0 },
    &operand_data[7974],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2446 */
  {
    "*aarch64_scatter_store_truncvnx2sivnx2di_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5068 },
#else
    { 0, output_5068, 0 },
#endif
    { 0 },
    &operand_data[7981],
    7,
    7,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx16qi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5069 },
#else
    { 0, output_5069, 0 },
#endif
    { 0 },
    &operand_data[7988],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx8qi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5070 },
#else
    { 0, output_5070, 0 },
#endif
    { 0 },
    &operand_data[7991],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx4qi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5071 },
#else
    { 0, output_5071, 0 },
#endif
    { 0 },
    &operand_data[7994],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2qi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5072 },
#else
    { 0, output_5072, 0 },
#endif
    { 0 },
    &operand_data[7997],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx8hi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5073 },
#else
    { 0, output_5073, 0 },
#endif
    { 0 },
    &operand_data[8000],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx4hi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5074 },
#else
    { 0, output_5074, 0 },
#endif
    { 0 },
    &operand_data[8003],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2hi_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5075 },
#else
    { 0, output_5075, 0 },
#endif
    { 0 },
    &operand_data[8006],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx8hf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5076 },
#else
    { 0, output_5076, 0 },
#endif
    { 0 },
    &operand_data[8009],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx4hf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5077 },
#else
    { 0, output_5077, 0 },
#endif
    { 0 },
    &operand_data[8012],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2hf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5078 },
#else
    { 0, output_5078, 0 },
#endif
    { 0 },
    &operand_data[8015],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx8bf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5079 },
#else
    { 0, output_5079, 0 },
#endif
    { 0 },
    &operand_data[8018],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx4bf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5080 },
#else
    { 0, output_5080, 0 },
#endif
    { 0 },
    &operand_data[8021],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2bf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5081 },
#else
    { 0, output_5081, 0 },
#endif
    { 0 },
    &operand_data[8024],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx4si_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5082 },
#else
    { 0, output_5082, 0 },
#endif
    { 0 },
    &operand_data[8027],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2si_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5083 },
#else
    { 0, output_5083, 0 },
#endif
    { 0 },
    &operand_data[8030],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx4sf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5084 },
#else
    { 0, output_5084, 0 },
#endif
    { 0 },
    &operand_data[8033],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2sf_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5085 },
#else
    { 0, output_5085, 0 },
#endif
    { 0 },
    &operand_data[8036],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2di_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5086 },
#else
    { 0, output_5086, 0 },
#endif
    { 0 },
    &operand_data[8039],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2511 */
  {
    "*vec_duplicatevnx2df_reg",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5087 },
#else
    { 0, output_5087, 0 },
#endif
    { 0 },
    &operand_data[8042],
    2,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx16qi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5088 },
#else
    { 0, 0, output_5088 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx16qi_le },
    &operand_data[8045],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx8hi_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5089 },
#else
    { 0, 0, output_5089 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx8hi_le },
    &operand_data[8047],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx4si_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5090 },
#else
    { 0, 0, output_5090 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx4si_le },
    &operand_data[8049],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx2di_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5091 },
#else
    { 0, 0, output_5091 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx2di_le },
    &operand_data[8051],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx8bf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5092 },
#else
    { 0, 0, output_5092 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx8bf_le },
    &operand_data[8053],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx8hf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5093 },
#else
    { 0, 0, output_5093 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx8hf_le },
    &operand_data[8055],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx4sf_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5094 },
#else
    { 0, 0, output_5094 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx4sf_le },
    &operand_data[8057],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2536 */
  {
    "aarch64_vec_duplicate_vqvnx2df_le",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5095 },
#else
    { 0, 0, output_5095 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx2df_le },
    &operand_data[8059],
    2,
    2,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx16qi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5096 },
#else
    { 0, 0, output_5096 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx16qi_be },
    &operand_data[8061],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx8hi_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5097 },
#else
    { 0, 0, output_5097 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx8hi_be },
    &operand_data[8064],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx4si_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5098 },
#else
    { 0, 0, output_5098 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx4si_be },
    &operand_data[8067],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx2di_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5099 },
#else
    { 0, 0, output_5099 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx2di_be },
    &operand_data[8070],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx8bf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5100 },
#else
    { 0, 0, output_5100 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx8bf_be },
    &operand_data[8073],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx8hf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5101 },
#else
    { 0, 0, output_5101 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx8hf_be },
    &operand_data[8076],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx4sf_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5102 },
#else
    { 0, 0, output_5102 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx4sf_be },
    &operand_data[8079],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2552 */
  {
    "aarch64_vec_duplicate_vqvnx2df_be",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5103 },
#else
    { 0, 0, output_5103 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_duplicate_vqvnx2df_be },
    &operand_data[8082],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rb\t%0.b, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx16qi },
    &operand_data[8085],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rb\t%0.b, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx8qi },
    &operand_data[8089],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rb\t%0.b, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx4qi },
    &operand_data[8093],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rb\t%0.b, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2qi },
    &operand_data[8097],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx8hi },
    &operand_data[8101],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx4hi },
    &operand_data[8105],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2hi },
    &operand_data[8109],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx8hf },
    &operand_data[8113],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx4hf },
    &operand_data[8117],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2hf },
    &operand_data[8121],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx8bf },
    &operand_data[8125],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx4bf },
    &operand_data[8129],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rh\t%0.h, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2bf },
    &operand_data[8133],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rw\t%0.s, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx4si },
    &operand_data[8137],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rw\t%0.s, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2si },
    &operand_data[8141],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rw\t%0.s, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx4sf },
    &operand_data[8145],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rw\t%0.s, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2sf },
    &operand_data[8149],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rd\t%0.d, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2di },
    &operand_data[8153],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2571 */
  {
    "sve_ld1rvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ld1rd\t%0.d, %1/z, %2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sve_ld1rvnx2df },
    &operand_data[8157],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5123 },
#else
    { 0, 0, output_5123 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx16qi },
    &operand_data[8161],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5124 },
#else
    { 0, 0, output_5124 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx8hi },
    &operand_data[8164],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5125 },
#else
    { 0, 0, output_5125 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx4si },
    &operand_data[8167],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5126 },
#else
    { 0, 0, output_5126 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx2di },
    &operand_data[8170],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5127 },
#else
    { 0, 0, output_5127 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx8bf },
    &operand_data[8173],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5128 },
#else
    { 0, 0, output_5128 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx8hf },
    &operand_data[8176],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5129 },
#else
    { 0, 0, output_5129 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx4sf },
    &operand_data[8179],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2585 */
  {
    "aarch64_sve_ld1rqvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5130 },
#else
    { 0, 0, output_5130 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rqvnx2df },
    &operand_data[8182],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5131 },
#else
    { 0, 0, output_5131 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx16qi },
    &operand_data[8185],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5132 },
#else
    { 0, 0, output_5132 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx8hi },
    &operand_data[8188],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5133 },
#else
    { 0, 0, output_5133 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx4si },
    &operand_data[8191],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5134 },
#else
    { 0, 0, output_5134 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx2di },
    &operand_data[8194],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5135 },
#else
    { 0, 0, output_5135 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx8bf },
    &operand_data[8197],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5136 },
#else
    { 0, 0, output_5136 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx8hf },
    &operand_data[8200],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5137 },
#else
    { 0, 0, output_5137 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx4sf },
    &operand_data[8203],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2598 */
  {
    "aarch64_sve_ld1rovnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5138 },
#else
    { 0, 0, output_5138 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ld1rovnx2df },
    &operand_data[8206],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5139 },
#else
    { 0, output_5139, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx16qi },
    &operand_data[8209],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5140 },
#else
    { 0, output_5140, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx8hi },
    &operand_data[8212],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5141 },
#else
    { 0, output_5141, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx4si },
    &operand_data[8215],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5142 },
#else
    { 0, output_5142, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx2di },
    &operand_data[8218],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5143 },
#else
    { 0, output_5143, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx8bf },
    &operand_data[8221],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5144 },
#else
    { 0, output_5144, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx8hf },
    &operand_data[8224],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5145 },
#else
    { 0, output_5145, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx4sf },
    &operand_data[8227],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2630 */
  {
    "vec_shl_insert_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5146 },
#else
    { 0, output_5146, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_shl_insert_vnx2df },
    &operand_data[8230],
    3,
    3,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5147 },
#else
    { 0, output_5147, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx16qi },
    &operand_data[8233],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5148 },
#else
    { 0, output_5148, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx8qi },
    &operand_data[8236],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5149 },
#else
    { 0, output_5149, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx4qi },
    &operand_data[8239],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5150 },
#else
    { 0, output_5150, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx2qi },
    &operand_data[8242],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5151 },
#else
    { 0, output_5151, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx8hi },
    &operand_data[8245],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5152 },
#else
    { 0, output_5152, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx4hi },
    &operand_data[8248],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5153 },
#else
    { 0, output_5153, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx2hi },
    &operand_data[8251],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5154 },
#else
    { 0, output_5154, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx4si },
    &operand_data[8254],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5155 },
#else
    { 0, output_5155, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx2si },
    &operand_data[8257],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2652 */
  {
    "vec_seriesvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5156 },
#else
    { 0, output_5156, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_seriesvnx2di },
    &operand_data[8260],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx16qi_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5157 },
#else
    { 0, 0, output_5157 },
#endif
    { 0 },
    &operand_data[8263],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx8qi_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5158 },
#else
    { 0, 0, output_5158 },
#endif
    { 0 },
    &operand_data[8266],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx4qi_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5159 },
#else
    { 0, 0, output_5159 },
#endif
    { 0 },
    &operand_data[8269],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx2qi_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5160 },
#else
    { 0, 0, output_5160 },
#endif
    { 0 },
    &operand_data[8272],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx8hi_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5161 },
#else
    { 0, 0, output_5161 },
#endif
    { 0 },
    &operand_data[8275],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx4hi_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5162 },
#else
    { 0, 0, output_5162 },
#endif
    { 0 },
    &operand_data[8278],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx2hi_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5163 },
#else
    { 0, 0, output_5163 },
#endif
    { 0 },
    &operand_data[8281],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx4si_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5164 },
#else
    { 0, 0, output_5164 },
#endif
    { 0 },
    &operand_data[8284],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx2si_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5165 },
#else
    { 0, 0, output_5165 },
#endif
    { 0 },
    &operand_data[8287],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2666 */
  {
    "*vec_seriesvnx2di_plus",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5166 },
#else
    { 0, 0, output_5166 },
#endif
    { 0 },
    &operand_data[8290],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx16qiqi_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5167 },
#else
    { 0, 0, output_5167 },
#endif
    { 0 },
    &operand_data[8293],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx8hihi_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5168 },
#else
    { 0, 0, output_5168 },
#endif
    { 0 },
    &operand_data[8295],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx4sisi_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5169 },
#else
    { 0, 0, output_5169 },
#endif
    { 0 },
    &operand_data[8297],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx2didi_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5170 },
#else
    { 0, 0, output_5170 },
#endif
    { 0 },
    &operand_data[8299],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx8bfbf_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5171 },
#else
    { 0, 0, output_5171 },
#endif
    { 0 },
    &operand_data[8301],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx8hfhf_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5172 },
#else
    { 0, 0, output_5172 },
#endif
    { 0 },
    &operand_data[8303],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx4sfsf_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5173 },
#else
    { 0, 0, output_5173 },
#endif
    { 0 },
    &operand_data[8305],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2758 */
  {
    "*vec_extractvnx2dfdf_0",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5174 },
#else
    { 0, 0, output_5174 },
#endif
    { 0 },
    &operand_data[8307],
    2,
    2,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx16qiqi_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5175 },
#else
    { 0, 0, output_5175 },
#endif
    { 0 },
    &operand_data[8309],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx8hihi_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5176 },
#else
    { 0, 0, output_5176 },
#endif
    { 0 },
    &operand_data[8312],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx4sisi_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5177 },
#else
    { 0, 0, output_5177 },
#endif
    { 0 },
    &operand_data[8315],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx2didi_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5178 },
#else
    { 0, 0, output_5178 },
#endif
    { 0 },
    &operand_data[8318],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx8bfbf_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5179 },
#else
    { 0, 0, output_5179 },
#endif
    { 0 },
    &operand_data[8321],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx8hfhf_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5180 },
#else
    { 0, 0, output_5180 },
#endif
    { 0 },
    &operand_data[8324],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx4sfsf_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5181 },
#else
    { 0, 0, output_5181 },
#endif
    { 0 },
    &operand_data[8327],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2792 */
  {
    "*vec_extractvnx2dfdf_v128",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5182 },
#else
    { 0, 0, output_5182 },
#endif
    { 0 },
    &operand_data[8330],
    3,
    3,
    0,
    3,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx16qiqi_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5183 },
#else
    { 0, 0, output_5183 },
#endif
    { 0 },
    &operand_data[8333],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx8hihi_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5184 },
#else
    { 0, 0, output_5184 },
#endif
    { 0 },
    &operand_data[8336],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx4sisi_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5185 },
#else
    { 0, 0, output_5185 },
#endif
    { 0 },
    &operand_data[8339],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx2didi_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5186 },
#else
    { 0, 0, output_5186 },
#endif
    { 0 },
    &operand_data[8342],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx8bfbf_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5187 },
#else
    { 0, 0, output_5187 },
#endif
    { 0 },
    &operand_data[8345],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx8hfhf_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5188 },
#else
    { 0, 0, output_5188 },
#endif
    { 0 },
    &operand_data[8348],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx4sfsf_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5189 },
#else
    { 0, 0, output_5189 },
#endif
    { 0 },
    &operand_data[8351],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2818 */
  {
    "*vec_extractvnx2dfdf_dup",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5190 },
#else
    { 0, 0, output_5190 },
#endif
    { 0 },
    &operand_data[8354],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx16qiqi_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5191 },
#else
    { 0, 0, output_5191 },
#endif
    { 0 },
    &operand_data[8357],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx8hihi_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5192 },
#else
    { 0, 0, output_5192 },
#endif
    { 0 },
    &operand_data[8360],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx4sisi_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5193 },
#else
    { 0, 0, output_5193 },
#endif
    { 0 },
    &operand_data[8363],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx2didi_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5194 },
#else
    { 0, 0, output_5194 },
#endif
    { 0 },
    &operand_data[8366],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx8bfbf_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5195 },
#else
    { 0, 0, output_5195 },
#endif
    { 0 },
    &operand_data[8369],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx8hfhf_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5196 },
#else
    { 0, 0, output_5196 },
#endif
    { 0 },
    &operand_data[8372],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx4sfsf_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5197 },
#else
    { 0, 0, output_5197 },
#endif
    { 0 },
    &operand_data[8375],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2833 */
  {
    "*vec_extractvnx2dfdf_ext",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_5198 },
#else
    { 0, 0, output_5198 },
#endif
    { 0 },
    &operand_data[8378],
    3,
    3,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5199 },
#else
    { 0, output_5199, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx16qi },
    &operand_data[8381],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5200 },
#else
    { 0, output_5200, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx16qi },
    &operand_data[8381],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5201 },
#else
    { 0, output_5201, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx8hi },
    &operand_data[8384],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5202 },
#else
    { 0, output_5202, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx8hi },
    &operand_data[8384],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5203 },
#else
    { 0, output_5203, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx4si },
    &operand_data[8387],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5204 },
#else
    { 0, output_5204, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx4si },
    &operand_data[8387],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5205 },
#else
    { 0, output_5205, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx2di },
    &operand_data[8390],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5206 },
#else
    { 0, output_5206, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx2di },
    &operand_data[8390],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5207 },
#else
    { 0, output_5207, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx8bf },
    &operand_data[8393],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5208 },
#else
    { 0, output_5208, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx8bf },
    &operand_data[8393],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5209 },
#else
    { 0, output_5209, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx8hf },
    &operand_data[8396],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5210 },
#else
    { 0, output_5210, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx8hf },
    &operand_data[8396],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5211 },
#else
    { 0, output_5211, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx4sf },
    &operand_data[8399],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5212 },
#else
    { 0, output_5212, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx4sf },
    &operand_data[8399],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_after_last_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5213 },
#else
    { 0, output_5213, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_after_last_vnx2df },
    &operand_data[8402],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2859 */
  {
    "extract_last_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5214 },
#else
    { 0, output_5214, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extract_last_vnx2df },
    &operand_data[8402],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5215 },
#else
    { 0, output_5215, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5216 },
#else
    { 0, output_5216, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5217 },
#else
    { 0, output_5217, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5218 },
#else
    { 0, output_5218, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5219 },
#else
    { 0, output_5219, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5220 },
#else
    { 0, output_5220, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5221 },
#else
    { 0, output_5221, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5222 },
#else
    { 0, output_5222, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5223 },
#else
    { 0, output_5223, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5224 },
#else
    { 0, output_5224, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5225 },
#else
    { 0, output_5225, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5226 },
#else
    { 0, output_5226, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5227 },
#else
    { 0, output_5227, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5228 },
#else
    { 0, output_5228, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5229 },
#else
    { 0, output_5229, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5230 },
#else
    { 0, output_5230, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx8qi },
    &operand_data[8408],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5231 },
#else
    { 0, output_5231, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5232 },
#else
    { 0, output_5232, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5233 },
#else
    { 0, output_5233, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5234 },
#else
    { 0, output_5234, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5235 },
#else
    { 0, output_5235, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5236 },
#else
    { 0, output_5236, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5237 },
#else
    { 0, output_5237, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5238 },
#else
    { 0, output_5238, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx4qi },
    &operand_data[8411],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5239 },
#else
    { 0, output_5239, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5240 },
#else
    { 0, output_5240, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5241 },
#else
    { 0, output_5241, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5242 },
#else
    { 0, output_5242, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5243 },
#else
    { 0, output_5243, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5244 },
#else
    { 0, output_5244, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5245 },
#else
    { 0, output_5245, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5246 },
#else
    { 0, output_5246, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx2qi },
    &operand_data[8414],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5247 },
#else
    { 0, output_5247, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5248 },
#else
    { 0, output_5248, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5249 },
#else
    { 0, output_5249, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5250 },
#else
    { 0, output_5250, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5251 },
#else
    { 0, output_5251, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5252 },
#else
    { 0, output_5252, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5253 },
#else
    { 0, output_5253, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5254 },
#else
    { 0, output_5254, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5255 },
#else
    { 0, output_5255, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5256 },
#else
    { 0, output_5256, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5257 },
#else
    { 0, output_5257, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5258 },
#else
    { 0, output_5258, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5259 },
#else
    { 0, output_5259, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5260 },
#else
    { 0, output_5260, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5261 },
#else
    { 0, output_5261, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5262 },
#else
    { 0, output_5262, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx4hi },
    &operand_data[8420],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5263 },
#else
    { 0, output_5263, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5264 },
#else
    { 0, output_5264, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5265 },
#else
    { 0, output_5265, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5266 },
#else
    { 0, output_5266, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5267 },
#else
    { 0, output_5267, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5268 },
#else
    { 0, output_5268, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5269 },
#else
    { 0, output_5269, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5270 },
#else
    { 0, output_5270, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx2hi },
    &operand_data[8423],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5271 },
#else
    { 0, output_5271, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5272 },
#else
    { 0, output_5272, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5273 },
#else
    { 0, output_5273, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5274 },
#else
    { 0, output_5274, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5275 },
#else
    { 0, output_5275, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5276 },
#else
    { 0, output_5276, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5277 },
#else
    { 0, output_5277, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5278 },
#else
    { 0, output_5278, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5279 },
#else
    { 0, output_5279, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5280 },
#else
    { 0, output_5280, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5281 },
#else
    { 0, output_5281, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5282 },
#else
    { 0, output_5282, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5283 },
#else
    { 0, output_5283, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5284 },
#else
    { 0, output_5284, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5285 },
#else
    { 0, output_5285, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5286 },
#else
    { 0, output_5286, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx2si },
    &operand_data[8429],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_absvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5287 },
#else
    { 0, output_5287, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_negvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5288 },
#else
    { 0, output_5288, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_one_cmplvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5289 },
#else
    { 0, output_5289, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_one_cmplvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clrsbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5290 },
#else
    { 0, output_5290, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clrsbvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_clzvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5291 },
#else
    { 0, output_5291, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_clzvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_popcountvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5292 },
#else
    { 0, output_5292, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_popcountvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qabsvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5293 },
#else
    { 0, output_5293, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qabsvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2927 */
  {
    "aarch64_pred_qnegvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5294 },
#else
    { 0, output_5294, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_qnegvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5295 },
#else
    { 0, output_5295, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5296 },
#else
    { 0, output_5296, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5297 },
#else
    { 0, output_5297, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5298 },
#else
    { 0, output_5298, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5299 },
#else
    { 0, output_5299, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5300 },
#else
    { 0, output_5300, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5301 },
#else
    { 0, output_5301, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5302 },
#else
    { 0, output_5302, 0 },
#endif
    { 0 },
    &operand_data[8405],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5303 },
#else
    { 0, output_5303, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5304 },
#else
    { 0, output_5304, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5305 },
#else
    { 0, output_5305, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5306 },
#else
    { 0, output_5306, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5307 },
#else
    { 0, output_5307, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5308 },
#else
    { 0, output_5308, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5309 },
#else
    { 0, output_5309, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5310 },
#else
    { 0, output_5310, 0 },
#endif
    { 0 },
    &operand_data[8408],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5311 },
#else
    { 0, output_5311, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5312 },
#else
    { 0, output_5312, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5313 },
#else
    { 0, output_5313, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5314 },
#else
    { 0, output_5314, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5315 },
#else
    { 0, output_5315, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5316 },
#else
    { 0, output_5316, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5317 },
#else
    { 0, output_5317, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5318 },
#else
    { 0, output_5318, 0 },
#endif
    { 0 },
    &operand_data[8411],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5319 },
#else
    { 0, output_5319, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5320 },
#else
    { 0, output_5320, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5321 },
#else
    { 0, output_5321, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5322 },
#else
    { 0, output_5322, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5323 },
#else
    { 0, output_5323, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5324 },
#else
    { 0, output_5324, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5325 },
#else
    { 0, output_5325, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5326 },
#else
    { 0, output_5326, 0 },
#endif
    { 0 },
    &operand_data[8414],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5327 },
#else
    { 0, output_5327, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5328 },
#else
    { 0, output_5328, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5329 },
#else
    { 0, output_5329, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5330 },
#else
    { 0, output_5330, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5331 },
#else
    { 0, output_5331, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5332 },
#else
    { 0, output_5332, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5333 },
#else
    { 0, output_5333, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5334 },
#else
    { 0, output_5334, 0 },
#endif
    { 0 },
    &operand_data[8417],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5335 },
#else
    { 0, output_5335, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5336 },
#else
    { 0, output_5336, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5337 },
#else
    { 0, output_5337, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5338 },
#else
    { 0, output_5338, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5339 },
#else
    { 0, output_5339, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5340 },
#else
    { 0, output_5340, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5341 },
#else
    { 0, output_5341, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5342 },
#else
    { 0, output_5342, 0 },
#endif
    { 0 },
    &operand_data[8420],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5343 },
#else
    { 0, output_5343, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5344 },
#else
    { 0, output_5344, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5345 },
#else
    { 0, output_5345, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5346 },
#else
    { 0, output_5346, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5347 },
#else
    { 0, output_5347, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5348 },
#else
    { 0, output_5348, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5349 },
#else
    { 0, output_5349, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5350 },
#else
    { 0, output_5350, 0 },
#endif
    { 0 },
    &operand_data[8423],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5351 },
#else
    { 0, output_5351, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5352 },
#else
    { 0, output_5352, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5353 },
#else
    { 0, output_5353, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5354 },
#else
    { 0, output_5354, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5355 },
#else
    { 0, output_5355, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5356 },
#else
    { 0, output_5356, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5357 },
#else
    { 0, output_5357, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5358 },
#else
    { 0, output_5358, 0 },
#endif
    { 0 },
    &operand_data[8426],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5359 },
#else
    { 0, output_5359, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5360 },
#else
    { 0, output_5360, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5361 },
#else
    { 0, output_5361, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5362 },
#else
    { 0, output_5362, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5363 },
#else
    { 0, output_5363, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5364 },
#else
    { 0, output_5364, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5365 },
#else
    { 0, output_5365, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5366 },
#else
    { 0, output_5366, 0 },
#endif
    { 0 },
    &operand_data[8429],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_absvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5367 },
#else
    { 0, output_5367, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_negvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5368 },
#else
    { 0, output_5368, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_one_cmplvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5369 },
#else
    { 0, output_5369, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clrsbvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5370 },
#else
    { 0, output_5370, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_clzvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5371 },
#else
    { 0, output_5371, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_popcountvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5372 },
#else
    { 0, output_5372, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qabsvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5373 },
#else
    { 0, output_5373, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2954 */
  {
    "*cond_qnegvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5374 },
#else
    { 0, output_5374, 0 },
#endif
    { 0 },
    &operand_data[8432],
    3,
    3,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5375 },
#else
    { 0, output_5375, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5376 },
#else
    { 0, output_5376, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5377 },
#else
    { 0, output_5377, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5378 },
#else
    { 0, output_5378, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5379 },
#else
    { 0, output_5379, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5380 },
#else
    { 0, output_5380, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5381 },
#else
    { 0, output_5381, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5382 },
#else
    { 0, output_5382, 0 },
#endif
    { 0 },
    &operand_data[8435],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5383 },
#else
    { 0, output_5383, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5384 },
#else
    { 0, output_5384, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5385 },
#else
    { 0, output_5385, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5386 },
#else
    { 0, output_5386, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5387 },
#else
    { 0, output_5387, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5388 },
#else
    { 0, output_5388, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5389 },
#else
    { 0, output_5389, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5390 },
#else
    { 0, output_5390, 0 },
#endif
    { 0 },
    &operand_data[8439],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5391 },
#else
    { 0, output_5391, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5392 },
#else
    { 0, output_5392, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5393 },
#else
    { 0, output_5393, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5394 },
#else
    { 0, output_5394, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5395 },
#else
    { 0, output_5395, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5396 },
#else
    { 0, output_5396, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5397 },
#else
    { 0, output_5397, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5398 },
#else
    { 0, output_5398, 0 },
#endif
    { 0 },
    &operand_data[8443],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5399 },
#else
    { 0, output_5399, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5400 },
#else
    { 0, output_5400, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5401 },
#else
    { 0, output_5401, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5402 },
#else
    { 0, output_5402, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5403 },
#else
    { 0, output_5403, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5404 },
#else
    { 0, output_5404, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5405 },
#else
    { 0, output_5405, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5406 },
#else
    { 0, output_5406, 0 },
#endif
    { 0 },
    &operand_data[8447],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5407 },
#else
    { 0, output_5407, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5408 },
#else
    { 0, output_5408, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5409 },
#else
    { 0, output_5409, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5410 },
#else
    { 0, output_5410, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5411 },
#else
    { 0, output_5411, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5412 },
#else
    { 0, output_5412, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5413 },
#else
    { 0, output_5413, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5414 },
#else
    { 0, output_5414, 0 },
#endif
    { 0 },
    &operand_data[8451],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5415 },
#else
    { 0, output_5415, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5416 },
#else
    { 0, output_5416, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5417 },
#else
    { 0, output_5417, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5418 },
#else
    { 0, output_5418, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5419 },
#else
    { 0, output_5419, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5420 },
#else
    { 0, output_5420, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5421 },
#else
    { 0, output_5421, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5422 },
#else
    { 0, output_5422, 0 },
#endif
    { 0 },
    &operand_data[8455],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5423 },
#else
    { 0, output_5423, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5424 },
#else
    { 0, output_5424, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5425 },
#else
    { 0, output_5425, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5426 },
#else
    { 0, output_5426, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5427 },
#else
    { 0, output_5427, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5428 },
#else
    { 0, output_5428, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5429 },
#else
    { 0, output_5429, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5430 },
#else
    { 0, output_5430, 0 },
#endif
    { 0 },
    &operand_data[8459],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5431 },
#else
    { 0, output_5431, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5432 },
#else
    { 0, output_5432, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5433 },
#else
    { 0, output_5433, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5434 },
#else
    { 0, output_5434, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5435 },
#else
    { 0, output_5435, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5436 },
#else
    { 0, output_5436, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5437 },
#else
    { 0, output_5437, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5438 },
#else
    { 0, output_5438, 0 },
#endif
    { 0 },
    &operand_data[8463],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5439 },
#else
    { 0, output_5439, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5440 },
#else
    { 0, output_5440, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5441 },
#else
    { 0, output_5441, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5442 },
#else
    { 0, output_5442, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5443 },
#else
    { 0, output_5443, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5444 },
#else
    { 0, output_5444, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5445 },
#else
    { 0, output_5445, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5446 },
#else
    { 0, output_5446, 0 },
#endif
    { 0 },
    &operand_data[8467],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_absvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5447 },
#else
    { 0, output_5447, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_negvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5448 },
#else
    { 0, output_5448, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_one_cmplvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5449 },
#else
    { 0, output_5449, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clrsbvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5450 },
#else
    { 0, output_5450, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_clzvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5451 },
#else
    { 0, output_5451, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_popcountvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5452 },
#else
    { 0, output_5452, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qabsvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5453 },
#else
    { 0, output_5453, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2976 */
  {
    "*cond_qnegvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5454 },
#else
    { 0, output_5454, 0 },
#endif
    { 0 },
    &operand_data[8471],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_rbitvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5455 },
#else
    { 0, output_5455, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_rbitvnx16qi },
    &operand_data[8405],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_rbitvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5456 },
#else
    { 0, output_5456, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_rbitvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_revbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5457 },
#else
    { 0, output_5457, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_revbvnx8hi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_rbitvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5458 },
#else
    { 0, output_5458, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_rbitvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_revbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5459 },
#else
    { 0, output_5459, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_revbvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_revhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5460 },
#else
    { 0, output_5460, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_revhvnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_rbitvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5461 },
#else
    { 0, output_5461, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_rbitvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_revbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5462 },
#else
    { 0, output_5462, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_revbvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_revhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5463 },
#else
    { 0, output_5463, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_revhvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3003 */
  {
    "aarch64_pred_revwvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5464 },
#else
    { 0, output_5464, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_revwvnx2di },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx16qivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5465 },
#else
    { 0, output_5465, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx16qivnx8bi },
    &operand_data[8475],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx16qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5466 },
#else
    { 0, output_5466, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx16qivnx4bi },
    &operand_data[8478],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5467 },
#else
    { 0, output_5467, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8qivnx4bi },
    &operand_data[8481],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8hivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5468 },
#else
    { 0, output_5468, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8hivnx4bi },
    &operand_data[8484],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8hfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5469 },
#else
    { 0, output_5469, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8hfvnx4bi },
    &operand_data[8487],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8bfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5470 },
#else
    { 0, output_5470, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8bfvnx4bi },
    &operand_data[8490],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx16qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5471 },
#else
    { 0, output_5471, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx16qivnx2bi },
    &operand_data[8493],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5472 },
#else
    { 0, output_5472, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8qivnx2bi },
    &operand_data[8496],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx4qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5473 },
#else
    { 0, output_5473, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx4qivnx2bi },
    &operand_data[8499],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5474 },
#else
    { 0, output_5474, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8hivnx2bi },
    &operand_data[8502],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx4hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5475 },
#else
    { 0, output_5475, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx4hivnx2bi },
    &operand_data[8505],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8hfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5476 },
#else
    { 0, output_5476, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8hfvnx2bi },
    &operand_data[8508],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx4hfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5477 },
#else
    { 0, output_5477, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx4hfvnx2bi },
    &operand_data[8511],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx8bfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5478 },
#else
    { 0, output_5478, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx8bfvnx2bi },
    &operand_data[8514],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx4bfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5479 },
#else
    { 0, output_5479, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx4bfvnx2bi },
    &operand_data[8517],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx4sivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5480 },
#else
    { 0, output_5480, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx4sivnx2bi },
    &operand_data[8520],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3022 */
  {
    "aarch64_sve_revbhw_vnx4sfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5481 },
#else
    { 0, output_5481, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revbhw_vnx4sfvnx2bi },
    &operand_data[8523],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_rbitvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5482 },
#else
    { 0, output_5482, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_rbitvnx16qi },
    &operand_data[8526],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_rbitvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5483 },
#else
    { 0, output_5483, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_rbitvnx8hi },
    &operand_data[8530],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_revbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5484 },
#else
    { 0, output_5484, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_revbvnx8hi },
    &operand_data[8530],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_rbitvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5485 },
#else
    { 0, output_5485, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_rbitvnx4si },
    &operand_data[8534],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_revbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5486 },
#else
    { 0, output_5486, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_revbvnx4si },
    &operand_data[8534],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_revhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5487 },
#else
    { 0, output_5487, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_revhvnx4si },
    &operand_data[8534],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_rbitvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5488 },
#else
    { 0, output_5488, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_rbitvnx2di },
    &operand_data[8538],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_revbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5489 },
#else
    { 0, output_5489, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_revbvnx2di },
    &operand_data[8538],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_revhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5490 },
#else
    { 0, output_5490, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_revhvnx2di },
    &operand_data[8538],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3038 */
  {
    "cond_revwvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5491 },
#else
    { 0, output_5491, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_revwvnx2di },
    &operand_data[8538],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx8qivnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5492 },
#else
    { 0, output_5492, 0 },
#endif
    { 0 },
    &operand_data[8542],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx8qivnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5493 },
#else
    { 0, output_5493, 0 },
#endif
    { 0 },
    &operand_data[8542],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx4qivnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5494 },
#else
    { 0, output_5494, 0 },
#endif
    { 0 },
    &operand_data[8545],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx4qivnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5495 },
#else
    { 0, output_5495, 0 },
#endif
    { 0 },
    &operand_data[8545],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx2qivnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5496 },
#else
    { 0, output_5496, 0 },
#endif
    { 0 },
    &operand_data[8548],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx2qivnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5497 },
#else
    { 0, output_5497, 0 },
#endif
    { 0 },
    &operand_data[8548],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx4qivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5498 },
#else
    { 0, output_5498, 0 },
#endif
    { 0 },
    &operand_data[8551],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx4qivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5499 },
#else
    { 0, output_5499, 0 },
#endif
    { 0 },
    &operand_data[8551],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx4hivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5500 },
#else
    { 0, output_5500, 0 },
#endif
    { 0 },
    &operand_data[8554],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx4hivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5501 },
#else
    { 0, output_5501, 0 },
#endif
    { 0 },
    &operand_data[8554],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx2qivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5502 },
#else
    { 0, output_5502, 0 },
#endif
    { 0 },
    &operand_data[8557],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx2qivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5503 },
#else
    { 0, output_5503, 0 },
#endif
    { 0 },
    &operand_data[8557],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx2hivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5504 },
#else
    { 0, output_5504, 0 },
#endif
    { 0 },
    &operand_data[8560],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx2hivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5505 },
#else
    { 0, output_5505, 0 },
#endif
    { 0 },
    &operand_data[8560],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx2qivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5506 },
#else
    { 0, output_5506, 0 },
#endif
    { 0 },
    &operand_data[8563],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx2qivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5507 },
#else
    { 0, output_5507, 0 },
#endif
    { 0 },
    &operand_data[8563],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx2hivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5508 },
#else
    { 0, output_5508, 0 },
#endif
    { 0 },
    &operand_data[8566],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx2hivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5509 },
#else
    { 0, output_5509, 0 },
#endif
    { 0 },
    &operand_data[8566],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*extendvnx2sivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5510 },
#else
    { 0, output_5510, 0 },
#endif
    { 0 },
    &operand_data[8569],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3082 */
  {
    "*zero_extendvnx2sivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5511 },
#else
    { 0, output_5511, 0 },
#endif
    { 0 },
    &operand_data[8569],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3097 */
  {
    "aarch64_pred_sxtvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5512 },
#else
    { 0, output_5512, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sxtvnx8hivnx8qi },
    &operand_data[8417],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3097 */
  {
    "aarch64_pred_sxtvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5513 },
#else
    { 0, output_5513, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sxtvnx4sivnx4qi },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3097 */
  {
    "aarch64_pred_sxtvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5514 },
#else
    { 0, output_5514, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sxtvnx4sivnx4hi },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3097 */
  {
    "aarch64_pred_sxtvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5515 },
#else
    { 0, output_5515, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sxtvnx2divnx2qi },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3097 */
  {
    "aarch64_pred_sxtvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5516 },
#else
    { 0, output_5516, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sxtvnx2divnx2hi },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3097 */
  {
    "aarch64_pred_sxtvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5517 },
#else
    { 0, output_5517, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sxtvnx2divnx2si },
    &operand_data[8432],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3114 */
  {
    "aarch64_cond_sxtvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5518 },
#else
    { 0, output_5518, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sxtvnx8hivnx8qi },
    &operand_data[8530],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3114 */
  {
    "aarch64_cond_sxtvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5519 },
#else
    { 0, output_5519, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sxtvnx4sivnx4qi },
    &operand_data[8534],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3114 */
  {
    "aarch64_cond_sxtvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5520 },
#else
    { 0, output_5520, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sxtvnx4sivnx4hi },
    &operand_data[8534],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3114 */
  {
    "aarch64_cond_sxtvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5521 },
#else
    { 0, output_5521, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sxtvnx2divnx2qi },
    &operand_data[8538],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3114 */
  {
    "aarch64_cond_sxtvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5522 },
#else
    { 0, output_5522, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sxtvnx2divnx2hi },
    &operand_data[8538],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3114 */
  {
    "aarch64_cond_sxtvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5523 },
#else
    { 0, output_5523, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sxtvnx2divnx2si },
    &operand_data[8538],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5524 },
#else
    { 0, output_5524, 0 },
#endif
    { 0 },
    &operand_data[8572],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5525 },
#else
    { 0, output_5525, 0 },
#endif
    { 0 },
    &operand_data[8576],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5526 },
#else
    { 0, output_5526, 0 },
#endif
    { 0 },
    &operand_data[8580],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5527 },
#else
    { 0, output_5527, 0 },
#endif
    { 0 },
    &operand_data[8584],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5528 },
#else
    { 0, output_5528, 0 },
#endif
    { 0 },
    &operand_data[8588],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5529 },
#else
    { 0, output_5529, 0 },
#endif
    { 0 },
    &operand_data[8592],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5530 },
#else
    { 0, output_5530, 0 },
#endif
    { 0 },
    &operand_data[8596],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5531 },
#else
    { 0, output_5531, 0 },
#endif
    { 0 },
    &operand_data[8600],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5532 },
#else
    { 0, output_5532, 0 },
#endif
    { 0 },
    &operand_data[8604],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3137 */
  {
    "*cond_uxtvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5533 },
#else
    { 0, output_5533, 0 },
#endif
    { 0 },
    &operand_data[8608],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5534 },
#else
    { 0, output_5534, 0 },
#endif
    { 0 },
    &operand_data[8612],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5535 },
#else
    { 0, output_5535, 0 },
#endif
    { 0 },
    &operand_data[8617],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5536 },
#else
    { 0, output_5536, 0 },
#endif
    { 0 },
    &operand_data[8622],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5537 },
#else
    { 0, output_5537, 0 },
#endif
    { 0 },
    &operand_data[8627],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5538 },
#else
    { 0, output_5538, 0 },
#endif
    { 0 },
    &operand_data[8632],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5539 },
#else
    { 0, output_5539, 0 },
#endif
    { 0 },
    &operand_data[8637],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5540 },
#else
    { 0, output_5540, 0 },
#endif
    { 0 },
    &operand_data[8642],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5541 },
#else
    { 0, output_5541, 0 },
#endif
    { 0 },
    &operand_data[8647],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5542 },
#else
    { 0, output_5542, 0 },
#endif
    { 0 },
    &operand_data[8652],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3161 */
  {
    "*cond_uxtvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5543 },
#else
    { 0, output_5543, 0 },
#endif
    { 0 },
    &operand_data[8657],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx8hivnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx8hivnx8qi2 },
    &operand_data[8662],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx4hivnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx4hivnx4qi2 },
    &operand_data[8664],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx2hivnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx2hivnx2qi2 },
    &operand_data[8666],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx4sivnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx4sivnx4qi2 },
    &operand_data[8668],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx4sivnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx4sivnx4hi2 },
    &operand_data[8670],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx2sivnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx2sivnx2qi2 },
    &operand_data[8672],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx2sivnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx2sivnx2hi2 },
    &operand_data[8674],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx2divnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx2divnx2qi2 },
    &operand_data[8676],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx2divnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx2divnx2hi2 },
    &operand_data[8678],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3187 */
  {
    "truncvnx2divnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_truncvnx2divnx2si2 },
    &operand_data[8680],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5554 },
#else
    { 0, output_5554, 0 },
#endif
    { 0 },
    &operand_data[8682],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5555 },
#else
    { 0, output_5555, 0 },
#endif
    { 0 },
    &operand_data[8688],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5556 },
#else
    { 0, output_5556, 0 },
#endif
    { 0 },
    &operand_data[8694],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5557 },
#else
    { 0, output_5557, 0 },
#endif
    { 0 },
    &operand_data[8700],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5558 },
#else
    { 0, output_5558, 0 },
#endif
    { 0 },
    &operand_data[8706],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5559 },
#else
    { 0, output_5559, 0 },
#endif
    { 0 },
    &operand_data[8712],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5560 },
#else
    { 0, output_5560, 0 },
#endif
    { 0 },
    &operand_data[8718],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5561 },
#else
    { 0, output_5561, 0 },
#endif
    { 0 },
    &operand_data[8724],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5562 },
#else
    { 0, output_5562, 0 },
#endif
    { 0 },
    &operand_data[8730],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3229 */
  {
    "*cnotvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5563 },
#else
    { 0, output_5563, 0 },
#endif
    { 0 },
    &operand_data[8736],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5564 },
#else
    { 0, output_5564, 0 },
#endif
    { 0 },
    &operand_data[8742],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5565 },
#else
    { 0, output_5565, 0 },
#endif
    { 0 },
    &operand_data[8748],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5566 },
#else
    { 0, output_5566, 0 },
#endif
    { 0 },
    &operand_data[8754],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5567 },
#else
    { 0, output_5567, 0 },
#endif
    { 0 },
    &operand_data[8760],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5568 },
#else
    { 0, output_5568, 0 },
#endif
    { 0 },
    &operand_data[8766],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5569 },
#else
    { 0, output_5569, 0 },
#endif
    { 0 },
    &operand_data[8772],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5570 },
#else
    { 0, output_5570, 0 },
#endif
    { 0 },
    &operand_data[8778],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5571 },
#else
    { 0, output_5571, 0 },
#endif
    { 0 },
    &operand_data[8784],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5572 },
#else
    { 0, output_5572, 0 },
#endif
    { 0 },
    &operand_data[8790],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3276 */
  {
    "*cond_cnotvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5573 },
#else
    { 0, output_5573, 0 },
#endif
    { 0 },
    &operand_data[8796],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5574 },
#else
    { 0, output_5574, 0 },
#endif
    { 0 },
    &operand_data[8802],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5575 },
#else
    { 0, output_5575, 0 },
#endif
    { 0 },
    &operand_data[8809],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5576 },
#else
    { 0, output_5576, 0 },
#endif
    { 0 },
    &operand_data[8816],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5577 },
#else
    { 0, output_5577, 0 },
#endif
    { 0 },
    &operand_data[8823],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5578 },
#else
    { 0, output_5578, 0 },
#endif
    { 0 },
    &operand_data[8830],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5579 },
#else
    { 0, output_5579, 0 },
#endif
    { 0 },
    &operand_data[8837],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5580 },
#else
    { 0, output_5580, 0 },
#endif
    { 0 },
    &operand_data[8844],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5581 },
#else
    { 0, output_5581, 0 },
#endif
    { 0 },
    &operand_data[8851],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5582 },
#else
    { 0, output_5582, 0 },
#endif
    { 0 },
    &operand_data[8858],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3312 */
  {
    "*cond_cnotvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5583 },
#else
    { 0, output_5583, 0 },
#endif
    { 0 },
    &operand_data[8865],
    7,
    7,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3350 */
  {
    "aarch64_sve_fexpavnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fexpa\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fexpavnx8hf },
    &operand_data[8872],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3350 */
  {
    "aarch64_sve_fexpavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fexpa\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fexpavnx4sf },
    &operand_data[8874],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3350 */
  {
    "aarch64_sve_fexpavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fexpa\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fexpavnx2df },
    &operand_data[8876],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3379 */
  {
    "aarch64_sve_frecpevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frecpevnx8hf },
    &operand_data[8878],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3379 */
  {
    "aarch64_sve_frsqrtevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frsqrtevnx8hf },
    &operand_data[8878],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3379 */
  {
    "aarch64_sve_frecpevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frecpevnx4sf },
    &operand_data[8880],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3379 */
  {
    "aarch64_sve_frsqrtevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frsqrtevnx4sf },
    &operand_data[8880],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3379 */
  {
    "aarch64_sve_frecpevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecpe\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frecpevnx2df },
    &operand_data[8882],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3379 */
  {
    "aarch64_sve_frsqrtevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrte\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frsqrtevnx2df },
    &operand_data[8882],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_absvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5593 },
#else
    { 0, output_5593, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_negvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5594 },
#else
    { 0, output_5594, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_frecpxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5595 },
#else
    { 0, output_5595, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_frecpxvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_roundvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5596 },
#else
    { 0, output_5596, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_roundvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_nearbyintvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5597 },
#else
    { 0, output_5597, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nearbyintvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_floorvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5598 },
#else
    { 0, output_5598, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_floorvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_frintnvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5599 },
#else
    { 0, output_5599, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_frintnvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_ceilvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5600 },
#else
    { 0, output_5600, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ceilvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_rintvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5601 },
#else
    { 0, output_5601, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_rintvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_btruncvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5602 },
#else
    { 0, output_5602, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_btruncvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_sqrtvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5603 },
#else
    { 0, output_5603, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqrtvnx8hf },
    &operand_data[8884],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_absvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5604 },
#else
    { 0, output_5604, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_negvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5605 },
#else
    { 0, output_5605, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_frecpxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5606 },
#else
    { 0, output_5606, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_frecpxvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_roundvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5607 },
#else
    { 0, output_5607, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_roundvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_nearbyintvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5608 },
#else
    { 0, output_5608, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nearbyintvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_floorvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5609 },
#else
    { 0, output_5609, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_floorvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_frintnvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5610 },
#else
    { 0, output_5610, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_frintnvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_ceilvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5611 },
#else
    { 0, output_5611, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ceilvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_rintvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5612 },
#else
    { 0, output_5612, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_rintvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_btruncvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5613 },
#else
    { 0, output_5613, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_btruncvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_sqrtvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5614 },
#else
    { 0, output_5614, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqrtvnx4sf },
    &operand_data[8888],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_absvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5615 },
#else
    { 0, output_5615, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_absvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_negvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5616 },
#else
    { 0, output_5616, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_negvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_frecpxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5617 },
#else
    { 0, output_5617, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_frecpxvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_roundvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5618 },
#else
    { 0, output_5618, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_roundvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_nearbyintvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5619 },
#else
    { 0, output_5619, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nearbyintvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_floorvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5620 },
#else
    { 0, output_5620, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_floorvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_frintnvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5621 },
#else
    { 0, output_5621, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_frintnvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_ceilvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5622 },
#else
    { 0, output_5622, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ceilvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_rintvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5623 },
#else
    { 0, output_5623, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_rintvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_btruncvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5624 },
#else
    { 0, output_5624, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_btruncvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3403 */
  {
    "aarch64_pred_sqrtvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5625 },
#else
    { 0, output_5625, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqrtvnx2df },
    &operand_data[8892],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_absvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5626 },
#else
    { 0, output_5626, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_negvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5627 },
#else
    { 0, output_5627, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_frecpxvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5628 },
#else
    { 0, output_5628, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_roundvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5629 },
#else
    { 0, output_5629, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_nearbyintvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5630 },
#else
    { 0, output_5630, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_floorvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5631 },
#else
    { 0, output_5631, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_frintnvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5632 },
#else
    { 0, output_5632, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_ceilvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5633 },
#else
    { 0, output_5633, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_rintvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5634 },
#else
    { 0, output_5634, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_btruncvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5635 },
#else
    { 0, output_5635, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_sqrtvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5636 },
#else
    { 0, output_5636, 0 },
#endif
    { 0 },
    &operand_data[8896],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_absvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5637 },
#else
    { 0, output_5637, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_negvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5638 },
#else
    { 0, output_5638, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_frecpxvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5639 },
#else
    { 0, output_5639, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_roundvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5640 },
#else
    { 0, output_5640, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_nearbyintvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5641 },
#else
    { 0, output_5641, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_floorvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5642 },
#else
    { 0, output_5642, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_frintnvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5643 },
#else
    { 0, output_5643, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_ceilvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5644 },
#else
    { 0, output_5644, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_rintvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5645 },
#else
    { 0, output_5645, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_btruncvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5646 },
#else
    { 0, output_5646, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_sqrtvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5647 },
#else
    { 0, output_5647, 0 },
#endif
    { 0 },
    &operand_data[8900],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_absvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5648 },
#else
    { 0, output_5648, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_negvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5649 },
#else
    { 0, output_5649, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_frecpxvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5650 },
#else
    { 0, output_5650, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_roundvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5651 },
#else
    { 0, output_5651, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_nearbyintvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5652 },
#else
    { 0, output_5652, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_floorvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5653 },
#else
    { 0, output_5653, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_frintnvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5654 },
#else
    { 0, output_5654, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_ceilvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5655 },
#else
    { 0, output_5655, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_rintvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5656 },
#else
    { 0, output_5656, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_btruncvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5657 },
#else
    { 0, output_5657, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3433 */
  {
    "*cond_sqrtvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5658 },
#else
    { 0, output_5658, 0 },
#endif
    { 0 },
    &operand_data[8904],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_absvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5659 },
#else
    { 0, output_5659, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_negvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5660 },
#else
    { 0, output_5660, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_frecpxvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5661 },
#else
    { 0, output_5661, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_roundvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5662 },
#else
    { 0, output_5662, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_nearbyintvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5663 },
#else
    { 0, output_5663, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_floorvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5664 },
#else
    { 0, output_5664, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_frintnvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5665 },
#else
    { 0, output_5665, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_ceilvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5666 },
#else
    { 0, output_5666, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_rintvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5667 },
#else
    { 0, output_5667, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_btruncvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5668 },
#else
    { 0, output_5668, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_sqrtvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5669 },
#else
    { 0, output_5669, 0 },
#endif
    { 0 },
    &operand_data[8884],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_absvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5670 },
#else
    { 0, output_5670, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_negvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5671 },
#else
    { 0, output_5671, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_frecpxvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5672 },
#else
    { 0, output_5672, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_roundvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5673 },
#else
    { 0, output_5673, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_nearbyintvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5674 },
#else
    { 0, output_5674, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_floorvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5675 },
#else
    { 0, output_5675, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_frintnvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5676 },
#else
    { 0, output_5676, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_ceilvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5677 },
#else
    { 0, output_5677, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_rintvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5678 },
#else
    { 0, output_5678, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_btruncvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5679 },
#else
    { 0, output_5679, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_sqrtvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5680 },
#else
    { 0, output_5680, 0 },
#endif
    { 0 },
    &operand_data[8888],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_absvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5681 },
#else
    { 0, output_5681, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_negvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5682 },
#else
    { 0, output_5682, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_frecpxvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5683 },
#else
    { 0, output_5683, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_roundvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5684 },
#else
    { 0, output_5684, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_nearbyintvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5685 },
#else
    { 0, output_5685, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_floorvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5686 },
#else
    { 0, output_5686, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_frintnvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5687 },
#else
    { 0, output_5687, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_ceilvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5688 },
#else
    { 0, output_5688, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_rintvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5689 },
#else
    { 0, output_5689, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_btruncvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5690 },
#else
    { 0, output_5690, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3455 */
  {
    "*cond_sqrtvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5691 },
#else
    { 0, output_5691, 0 },
#endif
    { 0 },
    &operand_data[8892],
    3,
    3,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_absvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5692 },
#else
    { 0, output_5692, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_negvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5693 },
#else
    { 0, output_5693, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_frecpxvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5694 },
#else
    { 0, output_5694, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_roundvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5695 },
#else
    { 0, output_5695, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_nearbyintvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5696 },
#else
    { 0, output_5696, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_floorvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5697 },
#else
    { 0, output_5697, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_frintnvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5698 },
#else
    { 0, output_5698, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_ceilvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5699 },
#else
    { 0, output_5699, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_rintvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5700 },
#else
    { 0, output_5700, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_btruncvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5701 },
#else
    { 0, output_5701, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_sqrtvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5702 },
#else
    { 0, output_5702, 0 },
#endif
    { 0 },
    &operand_data[8908],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_absvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5703 },
#else
    { 0, output_5703, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_negvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5704 },
#else
    { 0, output_5704, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_frecpxvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5705 },
#else
    { 0, output_5705, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_roundvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5706 },
#else
    { 0, output_5706, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_nearbyintvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5707 },
#else
    { 0, output_5707, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_floorvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5708 },
#else
    { 0, output_5708, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_frintnvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5709 },
#else
    { 0, output_5709, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_ceilvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5710 },
#else
    { 0, output_5710, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_rintvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5711 },
#else
    { 0, output_5711, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_btruncvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5712 },
#else
    { 0, output_5712, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_sqrtvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5713 },
#else
    { 0, output_5713, 0 },
#endif
    { 0 },
    &operand_data[8913],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_absvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5714 },
#else
    { 0, output_5714, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_negvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5715 },
#else
    { 0, output_5715, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_frecpxvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5716 },
#else
    { 0, output_5716, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_roundvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5717 },
#else
    { 0, output_5717, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_nearbyintvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5718 },
#else
    { 0, output_5718, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_floorvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5719 },
#else
    { 0, output_5719, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_frintnvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5720 },
#else
    { 0, output_5720, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_ceilvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5721 },
#else
    { 0, output_5721, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_rintvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5722 },
#else
    { 0, output_5722, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_btruncvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5723 },
#else
    { 0, output_5723, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3481 */
  {
    "*cond_sqrtvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5724 },
#else
    { 0, output_5724, 0 },
#endif
    { 0 },
    &operand_data[8918],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_absvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5725 },
#else
    { 0, output_5725, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_negvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5726 },
#else
    { 0, output_5726, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_frecpxvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5727 },
#else
    { 0, output_5727, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_roundvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5728 },
#else
    { 0, output_5728, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_nearbyintvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5729 },
#else
    { 0, output_5729, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_floorvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5730 },
#else
    { 0, output_5730, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_frintnvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5731 },
#else
    { 0, output_5731, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_ceilvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5732 },
#else
    { 0, output_5732, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_rintvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5733 },
#else
    { 0, output_5733, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_btruncvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5734 },
#else
    { 0, output_5734, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_sqrtvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5735 },
#else
    { 0, output_5735, 0 },
#endif
    { 0 },
    &operand_data[8908],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_absvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5736 },
#else
    { 0, output_5736, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_negvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5737 },
#else
    { 0, output_5737, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_frecpxvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5738 },
#else
    { 0, output_5738, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_roundvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5739 },
#else
    { 0, output_5739, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_nearbyintvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5740 },
#else
    { 0, output_5740, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_floorvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5741 },
#else
    { 0, output_5741, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_frintnvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5742 },
#else
    { 0, output_5742, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_ceilvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5743 },
#else
    { 0, output_5743, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_rintvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5744 },
#else
    { 0, output_5744, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_btruncvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5745 },
#else
    { 0, output_5745, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_sqrtvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5746 },
#else
    { 0, output_5746, 0 },
#endif
    { 0 },
    &operand_data[8913],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_absvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5747 },
#else
    { 0, output_5747, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_negvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5748 },
#else
    { 0, output_5748, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_frecpxvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5749 },
#else
    { 0, output_5749, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_roundvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5750 },
#else
    { 0, output_5750, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_nearbyintvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5751 },
#else
    { 0, output_5751, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_floorvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5752 },
#else
    { 0, output_5752, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_frintnvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5753 },
#else
    { 0, output_5753, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_ceilvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5754 },
#else
    { 0, output_5754, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_rintvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5755 },
#else
    { 0, output_5755, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_btruncvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5756 },
#else
    { 0, output_5756, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3504 */
  {
    "*cond_sqrtvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5757 },
#else
    { 0, output_5757, 0 },
#endif
    { 0 },
    &operand_data[8918],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3593 */
  {
    "*one_cmplvnx16bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.b, %1/z, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3593 */
  {
    "*one_cmplvnx8bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.b, %1/z, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3593 */
  {
    "*one_cmplvnx4bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.b, %1/z, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3593 */
  {
    "*one_cmplvnx2bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "not\t%0.b, %1/z, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5762 },
#else
    { 0, output_5762, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx16qi },
    &operand_data[8935],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5763 },
#else
    { 0, output_5763, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx16qi },
    &operand_data[8935],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5764 },
#else
    { 0, output_5764, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx16qi },
    &operand_data[8935],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5765 },
#else
    { 0, output_5765, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx16qi },
    &operand_data[8939],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5766 },
#else
    { 0, output_5766, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx16qi },
    &operand_data[8939],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5767 },
#else
    { 0, output_5767, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx8qi },
    &operand_data[8943],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5768 },
#else
    { 0, output_5768, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx8qi },
    &operand_data[8943],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5769 },
#else
    { 0, output_5769, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx8qi },
    &operand_data[8943],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5770 },
#else
    { 0, output_5770, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx8qi },
    &operand_data[8947],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5771 },
#else
    { 0, output_5771, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx8qi },
    &operand_data[8947],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5772 },
#else
    { 0, output_5772, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx4qi },
    &operand_data[8951],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5773 },
#else
    { 0, output_5773, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx4qi },
    &operand_data[8951],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5774 },
#else
    { 0, output_5774, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx4qi },
    &operand_data[8951],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5775 },
#else
    { 0, output_5775, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx4qi },
    &operand_data[8955],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5776 },
#else
    { 0, output_5776, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx4qi },
    &operand_data[8955],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5777 },
#else
    { 0, output_5777, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx2qi },
    &operand_data[8959],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5778 },
#else
    { 0, output_5778, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx2qi },
    &operand_data[8959],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5779 },
#else
    { 0, output_5779, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx2qi },
    &operand_data[8959],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5780 },
#else
    { 0, output_5780, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx2qi },
    &operand_data[8963],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5781 },
#else
    { 0, output_5781, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx2qi },
    &operand_data[8963],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5782 },
#else
    { 0, output_5782, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx8hi },
    &operand_data[8967],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5783 },
#else
    { 0, output_5783, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx8hi },
    &operand_data[8967],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5784 },
#else
    { 0, output_5784, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx8hi },
    &operand_data[8967],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5785 },
#else
    { 0, output_5785, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx8hi },
    &operand_data[8971],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5786 },
#else
    { 0, output_5786, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx8hi },
    &operand_data[8971],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5787 },
#else
    { 0, output_5787, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx4hi },
    &operand_data[8975],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5788 },
#else
    { 0, output_5788, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx4hi },
    &operand_data[8975],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5789 },
#else
    { 0, output_5789, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx4hi },
    &operand_data[8975],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5790 },
#else
    { 0, output_5790, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx4hi },
    &operand_data[8979],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5791 },
#else
    { 0, output_5791, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx4hi },
    &operand_data[8979],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5792 },
#else
    { 0, output_5792, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx2hi },
    &operand_data[8983],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5793 },
#else
    { 0, output_5793, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx2hi },
    &operand_data[8983],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5794 },
#else
    { 0, output_5794, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx2hi },
    &operand_data[8983],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5795 },
#else
    { 0, output_5795, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx2hi },
    &operand_data[8987],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5796 },
#else
    { 0, output_5796, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx2hi },
    &operand_data[8987],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5797 },
#else
    { 0, output_5797, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx4si },
    &operand_data[8991],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5798 },
#else
    { 0, output_5798, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx4si },
    &operand_data[8991],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5799 },
#else
    { 0, output_5799, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx4si },
    &operand_data[8991],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5800 },
#else
    { 0, output_5800, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx4si },
    &operand_data[8995],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5801 },
#else
    { 0, output_5801, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx4si },
    &operand_data[8995],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5802 },
#else
    { 0, output_5802, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx2si },
    &operand_data[8999],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5803 },
#else
    { 0, output_5803, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx2si },
    &operand_data[8999],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5804 },
#else
    { 0, output_5804, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx2si },
    &operand_data[8999],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5805 },
#else
    { 0, output_5805, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx2si },
    &operand_data[9003],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5806 },
#else
    { 0, output_5806, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx2si },
    &operand_data[9003],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_mulvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5807 },
#else
    { 0, output_5807, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx2di },
    &operand_data[9007],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_smaxvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5808 },
#else
    { 0, output_5808, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx2di },
    &operand_data[9007],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_sminvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5809 },
#else
    { 0, output_5809, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx2di },
    &operand_data[9007],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_umaxvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5810 },
#else
    { 0, output_5810, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxvnx2di },
    &operand_data[9011],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3649 */
  {
    "aarch64_pred_uminvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5811 },
#else
    { 0, output_5811, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminvnx2di },
    &operand_data[9011],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5812 },
#else
    { 0, output_5812, 0 },
#endif
    { 0 },
    &operand_data[9015],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5813 },
#else
    { 0, output_5813, 0 },
#endif
    { 0 },
    &operand_data[9015],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5814 },
#else
    { 0, output_5814, 0 },
#endif
    { 0 },
    &operand_data[9015],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5815 },
#else
    { 0, output_5815, 0 },
#endif
    { 0 },
    &operand_data[9018],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5816 },
#else
    { 0, output_5816, 0 },
#endif
    { 0 },
    &operand_data[9018],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5817 },
#else
    { 0, output_5817, 0 },
#endif
    { 0 },
    &operand_data[9021],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5818 },
#else
    { 0, output_5818, 0 },
#endif
    { 0 },
    &operand_data[9021],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5819 },
#else
    { 0, output_5819, 0 },
#endif
    { 0 },
    &operand_data[9021],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5820 },
#else
    { 0, output_5820, 0 },
#endif
    { 0 },
    &operand_data[9024],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5821 },
#else
    { 0, output_5821, 0 },
#endif
    { 0 },
    &operand_data[9024],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5822 },
#else
    { 0, output_5822, 0 },
#endif
    { 0 },
    &operand_data[9027],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5823 },
#else
    { 0, output_5823, 0 },
#endif
    { 0 },
    &operand_data[9027],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5824 },
#else
    { 0, output_5824, 0 },
#endif
    { 0 },
    &operand_data[9027],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5825 },
#else
    { 0, output_5825, 0 },
#endif
    { 0 },
    &operand_data[9030],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5826 },
#else
    { 0, output_5826, 0 },
#endif
    { 0 },
    &operand_data[9030],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5827 },
#else
    { 0, output_5827, 0 },
#endif
    { 0 },
    &operand_data[9033],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5828 },
#else
    { 0, output_5828, 0 },
#endif
    { 0 },
    &operand_data[9033],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5829 },
#else
    { 0, output_5829, 0 },
#endif
    { 0 },
    &operand_data[9033],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5830 },
#else
    { 0, output_5830, 0 },
#endif
    { 0 },
    &operand_data[9036],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5831 },
#else
    { 0, output_5831, 0 },
#endif
    { 0 },
    &operand_data[9036],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5832 },
#else
    { 0, output_5832, 0 },
#endif
    { 0 },
    &operand_data[9039],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5833 },
#else
    { 0, output_5833, 0 },
#endif
    { 0 },
    &operand_data[9039],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5834 },
#else
    { 0, output_5834, 0 },
#endif
    { 0 },
    &operand_data[9039],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5835 },
#else
    { 0, output_5835, 0 },
#endif
    { 0 },
    &operand_data[9042],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5836 },
#else
    { 0, output_5836, 0 },
#endif
    { 0 },
    &operand_data[9042],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5837 },
#else
    { 0, output_5837, 0 },
#endif
    { 0 },
    &operand_data[9045],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5838 },
#else
    { 0, output_5838, 0 },
#endif
    { 0 },
    &operand_data[9045],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5839 },
#else
    { 0, output_5839, 0 },
#endif
    { 0 },
    &operand_data[9045],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5840 },
#else
    { 0, output_5840, 0 },
#endif
    { 0 },
    &operand_data[9048],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5841 },
#else
    { 0, output_5841, 0 },
#endif
    { 0 },
    &operand_data[9048],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5842 },
#else
    { 0, output_5842, 0 },
#endif
    { 0 },
    &operand_data[9051],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5843 },
#else
    { 0, output_5843, 0 },
#endif
    { 0 },
    &operand_data[9051],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5844 },
#else
    { 0, output_5844, 0 },
#endif
    { 0 },
    &operand_data[9051],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5845 },
#else
    { 0, output_5845, 0 },
#endif
    { 0 },
    &operand_data[9054],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5846 },
#else
    { 0, output_5846, 0 },
#endif
    { 0 },
    &operand_data[9054],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5847 },
#else
    { 0, output_5847, 0 },
#endif
    { 0 },
    &operand_data[9057],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5848 },
#else
    { 0, output_5848, 0 },
#endif
    { 0 },
    &operand_data[9057],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5849 },
#else
    { 0, output_5849, 0 },
#endif
    { 0 },
    &operand_data[9057],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5850 },
#else
    { 0, output_5850, 0 },
#endif
    { 0 },
    &operand_data[9060],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5851 },
#else
    { 0, output_5851, 0 },
#endif
    { 0 },
    &operand_data[9060],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5852 },
#else
    { 0, output_5852, 0 },
#endif
    { 0 },
    &operand_data[9063],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5853 },
#else
    { 0, output_5853, 0 },
#endif
    { 0 },
    &operand_data[9063],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5854 },
#else
    { 0, output_5854, 0 },
#endif
    { 0 },
    &operand_data[9063],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5855 },
#else
    { 0, output_5855, 0 },
#endif
    { 0 },
    &operand_data[9066],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5856 },
#else
    { 0, output_5856, 0 },
#endif
    { 0 },
    &operand_data[9066],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_mulvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5857 },
#else
    { 0, output_5857, 0 },
#endif
    { 0 },
    &operand_data[9069],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_smaxvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5858 },
#else
    { 0, output_5858, 0 },
#endif
    { 0 },
    &operand_data[9069],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_sminvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5859 },
#else
    { 0, output_5859, 0 },
#endif
    { 0 },
    &operand_data[9069],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_umaxvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5860 },
#else
    { 0, output_5860, 0 },
#endif
    { 0 },
    &operand_data[9072],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3676 */
  {
    "*post_ra_uminvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5861 },
#else
    { 0, output_5861, 0 },
#endif
    { 0 },
    &operand_data[9072],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5862 },
#else
    { 0, output_5862, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5863 },
#else
    { 0, output_5863, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5864 },
#else
    { 0, output_5864, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5865 },
#else
    { 0, output_5865, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5866 },
#else
    { 0, output_5866, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5867 },
#else
    { 0, output_5867, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5868 },
#else
    { 0, output_5868, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5869 },
#else
    { 0, output_5869, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5870 },
#else
    { 0, output_5870, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5871 },
#else
    { 0, output_5871, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5872 },
#else
    { 0, output_5872, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5873 },
#else
    { 0, output_5873, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5874 },
#else
    { 0, output_5874, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5875 },
#else
    { 0, output_5875, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5876 },
#else
    { 0, output_5876, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5877 },
#else
    { 0, output_5877, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5878 },
#else
    { 0, output_5878, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5879 },
#else
    { 0, output_5879, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5880 },
#else
    { 0, output_5880, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5881 },
#else
    { 0, output_5881, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5882 },
#else
    { 0, output_5882, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5883 },
#else
    { 0, output_5883, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5884 },
#else
    { 0, output_5884, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5885 },
#else
    { 0, output_5885, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5886 },
#else
    { 0, output_5886, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5887 },
#else
    { 0, output_5887, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5888 },
#else
    { 0, output_5888, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5889 },
#else
    { 0, output_5889, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5890 },
#else
    { 0, output_5890, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5891 },
#else
    { 0, output_5891, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5892 },
#else
    { 0, output_5892, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5893 },
#else
    { 0, output_5893, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5894 },
#else
    { 0, output_5894, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5895 },
#else
    { 0, output_5895, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5896 },
#else
    { 0, output_5896, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5897 },
#else
    { 0, output_5897, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5898 },
#else
    { 0, output_5898, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5899 },
#else
    { 0, output_5899, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5900 },
#else
    { 0, output_5900, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5901 },
#else
    { 0, output_5901, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5902 },
#else
    { 0, output_5902, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5903 },
#else
    { 0, output_5903, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5904 },
#else
    { 0, output_5904, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5905 },
#else
    { 0, output_5905, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5906 },
#else
    { 0, output_5906, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5907 },
#else
    { 0, output_5907, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5908 },
#else
    { 0, output_5908, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5909 },
#else
    { 0, output_5909, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5910 },
#else
    { 0, output_5910, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5911 },
#else
    { 0, output_5911, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5912 },
#else
    { 0, output_5912, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5913 },
#else
    { 0, output_5913, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5914 },
#else
    { 0, output_5914, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5915 },
#else
    { 0, output_5915, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5916 },
#else
    { 0, output_5916, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5917 },
#else
    { 0, output_5917, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5918 },
#else
    { 0, output_5918, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5919 },
#else
    { 0, output_5919, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5920 },
#else
    { 0, output_5920, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5921 },
#else
    { 0, output_5921, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5922 },
#else
    { 0, output_5922, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5923 },
#else
    { 0, output_5923, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5924 },
#else
    { 0, output_5924, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5925 },
#else
    { 0, output_5925, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5926 },
#else
    { 0, output_5926, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5927 },
#else
    { 0, output_5927, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5928 },
#else
    { 0, output_5928, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5929 },
#else
    { 0, output_5929, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5930 },
#else
    { 0, output_5930, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5931 },
#else
    { 0, output_5931, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5932 },
#else
    { 0, output_5932, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5933 },
#else
    { 0, output_5933, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5934 },
#else
    { 0, output_5934, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5935 },
#else
    { 0, output_5935, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5936 },
#else
    { 0, output_5936, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5937 },
#else
    { 0, output_5937, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5938 },
#else
    { 0, output_5938, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5939 },
#else
    { 0, output_5939, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5940 },
#else
    { 0, output_5940, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5941 },
#else
    { 0, output_5941, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5942 },
#else
    { 0, output_5942, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5943 },
#else
    { 0, output_5943, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5944 },
#else
    { 0, output_5944, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5945 },
#else
    { 0, output_5945, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5946 },
#else
    { 0, output_5946, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5947 },
#else
    { 0, output_5947, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5948 },
#else
    { 0, output_5948, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5949 },
#else
    { 0, output_5949, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5950 },
#else
    { 0, output_5950, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5951 },
#else
    { 0, output_5951, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5952 },
#else
    { 0, output_5952, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5953 },
#else
    { 0, output_5953, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5954 },
#else
    { 0, output_5954, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5955 },
#else
    { 0, output_5955, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5956 },
#else
    { 0, output_5956, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5957 },
#else
    { 0, output_5957, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5958 },
#else
    { 0, output_5958, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5959 },
#else
    { 0, output_5959, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5960 },
#else
    { 0, output_5960, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5961 },
#else
    { 0, output_5961, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5962 },
#else
    { 0, output_5962, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5963 },
#else
    { 0, output_5963, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5964 },
#else
    { 0, output_5964, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5965 },
#else
    { 0, output_5965, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5966 },
#else
    { 0, output_5966, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5967 },
#else
    { 0, output_5967, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5968 },
#else
    { 0, output_5968, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5969 },
#else
    { 0, output_5969, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5970 },
#else
    { 0, output_5970, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5971 },
#else
    { 0, output_5971, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5972 },
#else
    { 0, output_5972, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5973 },
#else
    { 0, output_5973, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5974 },
#else
    { 0, output_5974, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5975 },
#else
    { 0, output_5975, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5976 },
#else
    { 0, output_5976, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5977 },
#else
    { 0, output_5977, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5978 },
#else
    { 0, output_5978, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5979 },
#else
    { 0, output_5979, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5980 },
#else
    { 0, output_5980, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5981 },
#else
    { 0, output_5981, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5982 },
#else
    { 0, output_5982, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5983 },
#else
    { 0, output_5983, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5984 },
#else
    { 0, output_5984, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5985 },
#else
    { 0, output_5985, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5986 },
#else
    { 0, output_5986, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5987 },
#else
    { 0, output_5987, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5988 },
#else
    { 0, output_5988, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5989 },
#else
    { 0, output_5989, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5990 },
#else
    { 0, output_5990, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5991 },
#else
    { 0, output_5991, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5992 },
#else
    { 0, output_5992, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5993 },
#else
    { 0, output_5993, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5994 },
#else
    { 0, output_5994, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5995 },
#else
    { 0, output_5995, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5996 },
#else
    { 0, output_5996, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5997 },
#else
    { 0, output_5997, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5998 },
#else
    { 0, output_5998, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_5999 },
#else
    { 0, output_5999, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6000 },
#else
    { 0, output_6000, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6001 },
#else
    { 0, output_6001, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6002 },
#else
    { 0, output_6002, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6003 },
#else
    { 0, output_6003, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6004 },
#else
    { 0, output_6004, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6005 },
#else
    { 0, output_6005, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6006 },
#else
    { 0, output_6006, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6007 },
#else
    { 0, output_6007, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6008 },
#else
    { 0, output_6008, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6009 },
#else
    { 0, output_6009, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6010 },
#else
    { 0, output_6010, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6011 },
#else
    { 0, output_6011, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6012 },
#else
    { 0, output_6012, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6013 },
#else
    { 0, output_6013, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6014 },
#else
    { 0, output_6014, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_addvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6015 },
#else
    { 0, output_6015, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_subvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6016 },
#else
    { 0, output_6016, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_mulvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6017 },
#else
    { 0, output_6017, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_smaxvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6018 },
#else
    { 0, output_6018, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_umaxvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6019 },
#else
    { 0, output_6019, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sminvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6020 },
#else
    { 0, output_6020, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_uminvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6021 },
#else
    { 0, output_6021, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashlvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6022 },
#else
    { 0, output_6022, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ashrvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6023 },
#else
    { 0, output_6023, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_lshrvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6024 },
#else
    { 0, output_6024, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_andvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6025 },
#else
    { 0, output_6025, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_iorvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6026 },
#else
    { 0, output_6026, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_xorvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6027 },
#else
    { 0, output_6027, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ssaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6028 },
#else
    { 0, output_6028, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_usaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6029 },
#else
    { 0, output_6029, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_sssubvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6030 },
#else
    { 0, output_6030, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3702 */
  {
    "*cond_ussubvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6031 },
#else
    { 0, output_6031, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6032 },
#else
    { 0, output_6032, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6033 },
#else
    { 0, output_6033, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6034 },
#else
    { 0, output_6034, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6035 },
#else
    { 0, output_6035, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6036 },
#else
    { 0, output_6036, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6037 },
#else
    { 0, output_6037, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6038 },
#else
    { 0, output_6038, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6039 },
#else
    { 0, output_6039, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6040 },
#else
    { 0, output_6040, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6041 },
#else
    { 0, output_6041, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6042 },
#else
    { 0, output_6042, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6043 },
#else
    { 0, output_6043, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6044 },
#else
    { 0, output_6044, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6045 },
#else
    { 0, output_6045, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6046 },
#else
    { 0, output_6046, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6047 },
#else
    { 0, output_6047, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6048 },
#else
    { 0, output_6048, 0 },
#endif
    { 0 },
    &operand_data[9115],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6049 },
#else
    { 0, output_6049, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6050 },
#else
    { 0, output_6050, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6051 },
#else
    { 0, output_6051, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6052 },
#else
    { 0, output_6052, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6053 },
#else
    { 0, output_6053, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6054 },
#else
    { 0, output_6054, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6055 },
#else
    { 0, output_6055, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6056 },
#else
    { 0, output_6056, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6057 },
#else
    { 0, output_6057, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6058 },
#else
    { 0, output_6058, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6059 },
#else
    { 0, output_6059, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6060 },
#else
    { 0, output_6060, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6061 },
#else
    { 0, output_6061, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6062 },
#else
    { 0, output_6062, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6063 },
#else
    { 0, output_6063, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6064 },
#else
    { 0, output_6064, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6065 },
#else
    { 0, output_6065, 0 },
#endif
    { 0 },
    &operand_data[9119],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6066 },
#else
    { 0, output_6066, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6067 },
#else
    { 0, output_6067, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6068 },
#else
    { 0, output_6068, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6069 },
#else
    { 0, output_6069, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6070 },
#else
    { 0, output_6070, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6071 },
#else
    { 0, output_6071, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6072 },
#else
    { 0, output_6072, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6073 },
#else
    { 0, output_6073, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6074 },
#else
    { 0, output_6074, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6075 },
#else
    { 0, output_6075, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6076 },
#else
    { 0, output_6076, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6077 },
#else
    { 0, output_6077, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6078 },
#else
    { 0, output_6078, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6079 },
#else
    { 0, output_6079, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6080 },
#else
    { 0, output_6080, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6081 },
#else
    { 0, output_6081, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6082 },
#else
    { 0, output_6082, 0 },
#endif
    { 0 },
    &operand_data[9123],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6083 },
#else
    { 0, output_6083, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6084 },
#else
    { 0, output_6084, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6085 },
#else
    { 0, output_6085, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6086 },
#else
    { 0, output_6086, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6087 },
#else
    { 0, output_6087, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6088 },
#else
    { 0, output_6088, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6089 },
#else
    { 0, output_6089, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6090 },
#else
    { 0, output_6090, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6091 },
#else
    { 0, output_6091, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6092 },
#else
    { 0, output_6092, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6093 },
#else
    { 0, output_6093, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6094 },
#else
    { 0, output_6094, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6095 },
#else
    { 0, output_6095, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6096 },
#else
    { 0, output_6096, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6097 },
#else
    { 0, output_6097, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6098 },
#else
    { 0, output_6098, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6099 },
#else
    { 0, output_6099, 0 },
#endif
    { 0 },
    &operand_data[9127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6100 },
#else
    { 0, output_6100, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6101 },
#else
    { 0, output_6101, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6102 },
#else
    { 0, output_6102, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6103 },
#else
    { 0, output_6103, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6104 },
#else
    { 0, output_6104, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6105 },
#else
    { 0, output_6105, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6106 },
#else
    { 0, output_6106, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6107 },
#else
    { 0, output_6107, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6108 },
#else
    { 0, output_6108, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6109 },
#else
    { 0, output_6109, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6110 },
#else
    { 0, output_6110, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6111 },
#else
    { 0, output_6111, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6112 },
#else
    { 0, output_6112, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6113 },
#else
    { 0, output_6113, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6114 },
#else
    { 0, output_6114, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6115 },
#else
    { 0, output_6115, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6116 },
#else
    { 0, output_6116, 0 },
#endif
    { 0 },
    &operand_data[9131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6117 },
#else
    { 0, output_6117, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6118 },
#else
    { 0, output_6118, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6119 },
#else
    { 0, output_6119, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6120 },
#else
    { 0, output_6120, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6121 },
#else
    { 0, output_6121, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6122 },
#else
    { 0, output_6122, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6123 },
#else
    { 0, output_6123, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6124 },
#else
    { 0, output_6124, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6125 },
#else
    { 0, output_6125, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6126 },
#else
    { 0, output_6126, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6127 },
#else
    { 0, output_6127, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6128 },
#else
    { 0, output_6128, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6129 },
#else
    { 0, output_6129, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6130 },
#else
    { 0, output_6130, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6131 },
#else
    { 0, output_6131, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6132 },
#else
    { 0, output_6132, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6133 },
#else
    { 0, output_6133, 0 },
#endif
    { 0 },
    &operand_data[9135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6134 },
#else
    { 0, output_6134, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6135 },
#else
    { 0, output_6135, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6136 },
#else
    { 0, output_6136, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6137 },
#else
    { 0, output_6137, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6138 },
#else
    { 0, output_6138, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6139 },
#else
    { 0, output_6139, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6140 },
#else
    { 0, output_6140, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6141 },
#else
    { 0, output_6141, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6142 },
#else
    { 0, output_6142, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6143 },
#else
    { 0, output_6143, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6144 },
#else
    { 0, output_6144, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6145 },
#else
    { 0, output_6145, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6146 },
#else
    { 0, output_6146, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6147 },
#else
    { 0, output_6147, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6148 },
#else
    { 0, output_6148, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6149 },
#else
    { 0, output_6149, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6150 },
#else
    { 0, output_6150, 0 },
#endif
    { 0 },
    &operand_data[9139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6151 },
#else
    { 0, output_6151, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6152 },
#else
    { 0, output_6152, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6153 },
#else
    { 0, output_6153, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6154 },
#else
    { 0, output_6154, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6155 },
#else
    { 0, output_6155, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6156 },
#else
    { 0, output_6156, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6157 },
#else
    { 0, output_6157, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6158 },
#else
    { 0, output_6158, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6159 },
#else
    { 0, output_6159, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6160 },
#else
    { 0, output_6160, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6161 },
#else
    { 0, output_6161, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6162 },
#else
    { 0, output_6162, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6163 },
#else
    { 0, output_6163, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6164 },
#else
    { 0, output_6164, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6165 },
#else
    { 0, output_6165, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6166 },
#else
    { 0, output_6166, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6167 },
#else
    { 0, output_6167, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6168 },
#else
    { 0, output_6168, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6169 },
#else
    { 0, output_6169, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6170 },
#else
    { 0, output_6170, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6171 },
#else
    { 0, output_6171, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6172 },
#else
    { 0, output_6172, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6173 },
#else
    { 0, output_6173, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6174 },
#else
    { 0, output_6174, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6175 },
#else
    { 0, output_6175, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6176 },
#else
    { 0, output_6176, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6177 },
#else
    { 0, output_6177, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6178 },
#else
    { 0, output_6178, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6179 },
#else
    { 0, output_6179, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6180 },
#else
    { 0, output_6180, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6181 },
#else
    { 0, output_6181, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6182 },
#else
    { 0, output_6182, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6183 },
#else
    { 0, output_6183, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6184 },
#else
    { 0, output_6184, 0 },
#endif
    { 0 },
    &operand_data[9147],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_addvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6185 },
#else
    { 0, output_6185, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_subvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6186 },
#else
    { 0, output_6186, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_mulvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6187 },
#else
    { 0, output_6187, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_smaxvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6188 },
#else
    { 0, output_6188, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_umaxvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6189 },
#else
    { 0, output_6189, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sminvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6190 },
#else
    { 0, output_6190, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_uminvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6191 },
#else
    { 0, output_6191, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashlvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6192 },
#else
    { 0, output_6192, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ashrvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6193 },
#else
    { 0, output_6193, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_lshrvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6194 },
#else
    { 0, output_6194, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_andvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6195 },
#else
    { 0, output_6195, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_iorvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6196 },
#else
    { 0, output_6196, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_xorvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6197 },
#else
    { 0, output_6197, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ssaddvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6198 },
#else
    { 0, output_6198, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_usaddvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6199 },
#else
    { 0, output_6199, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_sssubvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6200 },
#else
    { 0, output_6200, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3719 */
  {
    "*cond_ussubvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6201 },
#else
    { 0, output_6201, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6202 },
#else
    { 0, output_6202, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6203 },
#else
    { 0, output_6203, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6204 },
#else
    { 0, output_6204, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6205 },
#else
    { 0, output_6205, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6206 },
#else
    { 0, output_6206, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6207 },
#else
    { 0, output_6207, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6208 },
#else
    { 0, output_6208, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6209 },
#else
    { 0, output_6209, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6210 },
#else
    { 0, output_6210, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6211 },
#else
    { 0, output_6211, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6212 },
#else
    { 0, output_6212, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6213 },
#else
    { 0, output_6213, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6214 },
#else
    { 0, output_6214, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6215 },
#else
    { 0, output_6215, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6216 },
#else
    { 0, output_6216, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6217 },
#else
    { 0, output_6217, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6218 },
#else
    { 0, output_6218, 0 },
#endif
    { 0 },
    &operand_data[9155],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6219 },
#else
    { 0, output_6219, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6220 },
#else
    { 0, output_6220, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6221 },
#else
    { 0, output_6221, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6222 },
#else
    { 0, output_6222, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6223 },
#else
    { 0, output_6223, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6224 },
#else
    { 0, output_6224, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6225 },
#else
    { 0, output_6225, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6226 },
#else
    { 0, output_6226, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6227 },
#else
    { 0, output_6227, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6228 },
#else
    { 0, output_6228, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6229 },
#else
    { 0, output_6229, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6230 },
#else
    { 0, output_6230, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6231 },
#else
    { 0, output_6231, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6232 },
#else
    { 0, output_6232, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6233 },
#else
    { 0, output_6233, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6234 },
#else
    { 0, output_6234, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6235 },
#else
    { 0, output_6235, 0 },
#endif
    { 0 },
    &operand_data[9160],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6236 },
#else
    { 0, output_6236, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6237 },
#else
    { 0, output_6237, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6238 },
#else
    { 0, output_6238, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6239 },
#else
    { 0, output_6239, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6240 },
#else
    { 0, output_6240, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6241 },
#else
    { 0, output_6241, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6242 },
#else
    { 0, output_6242, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6243 },
#else
    { 0, output_6243, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6244 },
#else
    { 0, output_6244, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6245 },
#else
    { 0, output_6245, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6246 },
#else
    { 0, output_6246, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6247 },
#else
    { 0, output_6247, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6248 },
#else
    { 0, output_6248, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6249 },
#else
    { 0, output_6249, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6250 },
#else
    { 0, output_6250, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6251 },
#else
    { 0, output_6251, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6252 },
#else
    { 0, output_6252, 0 },
#endif
    { 0 },
    &operand_data[9165],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6253 },
#else
    { 0, output_6253, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6254 },
#else
    { 0, output_6254, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6255 },
#else
    { 0, output_6255, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6256 },
#else
    { 0, output_6256, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6257 },
#else
    { 0, output_6257, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6258 },
#else
    { 0, output_6258, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6259 },
#else
    { 0, output_6259, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6260 },
#else
    { 0, output_6260, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6261 },
#else
    { 0, output_6261, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6262 },
#else
    { 0, output_6262, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6263 },
#else
    { 0, output_6263, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6264 },
#else
    { 0, output_6264, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6265 },
#else
    { 0, output_6265, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6266 },
#else
    { 0, output_6266, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6267 },
#else
    { 0, output_6267, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6268 },
#else
    { 0, output_6268, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6269 },
#else
    { 0, output_6269, 0 },
#endif
    { 0 },
    &operand_data[9170],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6270 },
#else
    { 0, output_6270, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6271 },
#else
    { 0, output_6271, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6272 },
#else
    { 0, output_6272, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6273 },
#else
    { 0, output_6273, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6274 },
#else
    { 0, output_6274, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6275 },
#else
    { 0, output_6275, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6276 },
#else
    { 0, output_6276, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6277 },
#else
    { 0, output_6277, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6278 },
#else
    { 0, output_6278, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6279 },
#else
    { 0, output_6279, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6280 },
#else
    { 0, output_6280, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6281 },
#else
    { 0, output_6281, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6282 },
#else
    { 0, output_6282, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6283 },
#else
    { 0, output_6283, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6284 },
#else
    { 0, output_6284, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6285 },
#else
    { 0, output_6285, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6286 },
#else
    { 0, output_6286, 0 },
#endif
    { 0 },
    &operand_data[9175],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6287 },
#else
    { 0, output_6287, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6288 },
#else
    { 0, output_6288, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6289 },
#else
    { 0, output_6289, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6290 },
#else
    { 0, output_6290, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6291 },
#else
    { 0, output_6291, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6292 },
#else
    { 0, output_6292, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6293 },
#else
    { 0, output_6293, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6294 },
#else
    { 0, output_6294, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6295 },
#else
    { 0, output_6295, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6296 },
#else
    { 0, output_6296, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6297 },
#else
    { 0, output_6297, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6298 },
#else
    { 0, output_6298, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6299 },
#else
    { 0, output_6299, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6300 },
#else
    { 0, output_6300, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6301 },
#else
    { 0, output_6301, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6302 },
#else
    { 0, output_6302, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6303 },
#else
    { 0, output_6303, 0 },
#endif
    { 0 },
    &operand_data[9180],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6304 },
#else
    { 0, output_6304, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6305 },
#else
    { 0, output_6305, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6306 },
#else
    { 0, output_6306, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6307 },
#else
    { 0, output_6307, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6308 },
#else
    { 0, output_6308, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6309 },
#else
    { 0, output_6309, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6310 },
#else
    { 0, output_6310, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6311 },
#else
    { 0, output_6311, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6312 },
#else
    { 0, output_6312, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6313 },
#else
    { 0, output_6313, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6314 },
#else
    { 0, output_6314, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6315 },
#else
    { 0, output_6315, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6316 },
#else
    { 0, output_6316, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6317 },
#else
    { 0, output_6317, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6318 },
#else
    { 0, output_6318, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6319 },
#else
    { 0, output_6319, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6320 },
#else
    { 0, output_6320, 0 },
#endif
    { 0 },
    &operand_data[9185],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6321 },
#else
    { 0, output_6321, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6322 },
#else
    { 0, output_6322, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6323 },
#else
    { 0, output_6323, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6324 },
#else
    { 0, output_6324, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6325 },
#else
    { 0, output_6325, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6326 },
#else
    { 0, output_6326, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6327 },
#else
    { 0, output_6327, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6328 },
#else
    { 0, output_6328, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6329 },
#else
    { 0, output_6329, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6330 },
#else
    { 0, output_6330, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6331 },
#else
    { 0, output_6331, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6332 },
#else
    { 0, output_6332, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6333 },
#else
    { 0, output_6333, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6334 },
#else
    { 0, output_6334, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6335 },
#else
    { 0, output_6335, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6336 },
#else
    { 0, output_6336, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6337 },
#else
    { 0, output_6337, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6338 },
#else
    { 0, output_6338, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6339 },
#else
    { 0, output_6339, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6340 },
#else
    { 0, output_6340, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6341 },
#else
    { 0, output_6341, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6342 },
#else
    { 0, output_6342, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6343 },
#else
    { 0, output_6343, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6344 },
#else
    { 0, output_6344, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6345 },
#else
    { 0, output_6345, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6346 },
#else
    { 0, output_6346, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6347 },
#else
    { 0, output_6347, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6348 },
#else
    { 0, output_6348, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6349 },
#else
    { 0, output_6349, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6350 },
#else
    { 0, output_6350, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6351 },
#else
    { 0, output_6351, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6352 },
#else
    { 0, output_6352, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6353 },
#else
    { 0, output_6353, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6354 },
#else
    { 0, output_6354, 0 },
#endif
    { 0 },
    &operand_data[9195],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_addvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6355 },
#else
    { 0, output_6355, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_subvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6356 },
#else
    { 0, output_6356, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_mulvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6357 },
#else
    { 0, output_6357, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_smaxvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6358 },
#else
    { 0, output_6358, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_umaxvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6359 },
#else
    { 0, output_6359, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sminvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6360 },
#else
    { 0, output_6360, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_uminvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6361 },
#else
    { 0, output_6361, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashlvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6362 },
#else
    { 0, output_6362, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ashrvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6363 },
#else
    { 0, output_6363, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_lshrvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6364 },
#else
    { 0, output_6364, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_andvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6365 },
#else
    { 0, output_6365, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_iorvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6366 },
#else
    { 0, output_6366, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_xorvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6367 },
#else
    { 0, output_6367, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ssaddvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6368 },
#else
    { 0, output_6368, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_usaddvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6369 },
#else
    { 0, output_6369, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_sssubvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6370 },
#else
    { 0, output_6370, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3736 */
  {
    "*cond_ussubvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6371 },
#else
    { 0, output_6371, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6372 },
#else
    { 0, 0, output_6372 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx16qi3 },
    &operand_data[9205],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6373 },
#else
    { 0, 0, output_6373 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx8qi3 },
    &operand_data[9208],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6374 },
#else
    { 0, 0, output_6374 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx4qi3 },
    &operand_data[9211],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6375 },
#else
    { 0, 0, output_6375 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx2qi3 },
    &operand_data[9214],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6376 },
#else
    { 0, 0, output_6376 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx8hi3 },
    &operand_data[9217],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6377 },
#else
    { 0, 0, output_6377 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx4hi3 },
    &operand_data[9220],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6378 },
#else
    { 0, 0, output_6378 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx2hi3 },
    &operand_data[9223],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6379 },
#else
    { 0, 0, output_6379 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx4si3 },
    &operand_data[9226],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6380 },
#else
    { 0, 0, output_6380 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx2si3 },
    &operand_data[9229],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3781 */
  {
    "addvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_6381 },
#else
    { 0, 0, output_6381 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx2di3 },
    &operand_data[9232],
    3,
    3,
    0,
    6,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6382 },
#else
    { 0, output_6382, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx16qi3 },
    &operand_data[9235],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6383 },
#else
    { 0, output_6383, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx8qi3 },
    &operand_data[9238],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6384 },
#else
    { 0, output_6384, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx4qi3 },
    &operand_data[9241],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6385 },
#else
    { 0, output_6385, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx2qi3 },
    &operand_data[9244],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6386 },
#else
    { 0, output_6386, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx8hi3 },
    &operand_data[9247],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6387 },
#else
    { 0, output_6387, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx4hi3 },
    &operand_data[9250],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6388 },
#else
    { 0, output_6388, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx2hi3 },
    &operand_data[9253],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6389 },
#else
    { 0, output_6389, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx4si3 },
    &operand_data[9256],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6390 },
#else
    { 0, output_6390, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx2si3 },
    &operand_data[9259],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3807 */
  {
    "subvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6391 },
#else
    { 0, output_6391, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx2di3 },
    &operand_data[9262],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3831 */
  {
    "aarch64_adrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.s, [%1.s, %2.s]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_adrvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3831 */
  {
    "aarch64_adrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_adrvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3842 */
  {
    "*aarch64_adr_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, sxtw]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9268],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3862 */
  {
    "*aarch64_adr_uxtw_unspec",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, uxtw]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9272],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3875 */
  {
    "*aarch64_adr_uxtw_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, uxtw]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9272],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3903 */
  {
    "*aarch64_adrvnx2qi_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, lsl %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9276],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3903 */
  {
    "*aarch64_adrvnx2hi_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, lsl %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9281],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3903 */
  {
    "*aarch64_adrvnx2si_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, lsl %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9286],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3903 */
  {
    "*aarch64_adrvnx2di_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, lsl %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9291],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3903 */
  {
    "*aarch64_adrvnx4qi_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.s, [%1.s, %2.s, lsl %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9296],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3903 */
  {
    "*aarch64_adrvnx4hi_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.s, [%1.s, %2.s, lsl %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9301],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3903 */
  {
    "*aarch64_adrvnx4si_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.s, [%1.s, %2.s, lsl %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9306],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3922 */
  {
    "*aarch64_adr_shift_sxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, sxtw %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9311],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3946 */
  {
    "*aarch64_adr_shift_uxtw",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "adr\t%0.d, [%1.d, %2.d, uxtw %3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9317],
    6,
    6,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6406 },
#else
    { 0, output_6406, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx16qi },
    &operand_data[9323],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6407 },
#else
    { 0, output_6407, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx16qi },
    &operand_data[9323],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6408 },
#else
    { 0, output_6408, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx8qi },
    &operand_data[9327],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6409 },
#else
    { 0, output_6409, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx8qi },
    &operand_data[9327],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6410 },
#else
    { 0, output_6410, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx4qi },
    &operand_data[9331],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6411 },
#else
    { 0, output_6411, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx4qi },
    &operand_data[9331],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6412 },
#else
    { 0, output_6412, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx2qi },
    &operand_data[9335],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6413 },
#else
    { 0, output_6413, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx2qi },
    &operand_data[9335],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6414 },
#else
    { 0, output_6414, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx8hi },
    &operand_data[9339],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6415 },
#else
    { 0, output_6415, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx8hi },
    &operand_data[9339],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6416 },
#else
    { 0, output_6416, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx4hi },
    &operand_data[9343],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6417 },
#else
    { 0, output_6417, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx4hi },
    &operand_data[9343],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6418 },
#else
    { 0, output_6418, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx2hi },
    &operand_data[9347],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6419 },
#else
    { 0, output_6419, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx2hi },
    &operand_data[9347],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6420 },
#else
    { 0, output_6420, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx4si },
    &operand_data[9351],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6421 },
#else
    { 0, output_6421, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx4si },
    &operand_data[9351],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6422 },
#else
    { 0, output_6422, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx2si },
    &operand_data[9355],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6423 },
#else
    { 0, output_6423, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx2si },
    &operand_data[9355],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_sabdvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6424 },
#else
    { 0, output_6424, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sabdvnx2di },
    &operand_data[9359],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3990 */
  {
    "aarch64_pred_uabdvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6425 },
#else
    { 0, output_6425, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uabdvnx2di },
    &operand_data[9359],
    4,
    4,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6426 },
#else
    { 0, output_6426, 0 },
#endif
    { 0 },
    &operand_data[9363],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6427 },
#else
    { 0, output_6427, 0 },
#endif
    { 0 },
    &operand_data[9363],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6428 },
#else
    { 0, output_6428, 0 },
#endif
    { 0 },
    &operand_data[9369],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6429 },
#else
    { 0, output_6429, 0 },
#endif
    { 0 },
    &operand_data[9369],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6430 },
#else
    { 0, output_6430, 0 },
#endif
    { 0 },
    &operand_data[9375],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6431 },
#else
    { 0, output_6431, 0 },
#endif
    { 0 },
    &operand_data[9375],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6432 },
#else
    { 0, output_6432, 0 },
#endif
    { 0 },
    &operand_data[9381],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6433 },
#else
    { 0, output_6433, 0 },
#endif
    { 0 },
    &operand_data[9381],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6434 },
#else
    { 0, output_6434, 0 },
#endif
    { 0 },
    &operand_data[9387],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6435 },
#else
    { 0, output_6435, 0 },
#endif
    { 0 },
    &operand_data[9387],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6436 },
#else
    { 0, output_6436, 0 },
#endif
    { 0 },
    &operand_data[9393],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6437 },
#else
    { 0, output_6437, 0 },
#endif
    { 0 },
    &operand_data[9393],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6438 },
#else
    { 0, output_6438, 0 },
#endif
    { 0 },
    &operand_data[9399],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6439 },
#else
    { 0, output_6439, 0 },
#endif
    { 0 },
    &operand_data[9399],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6440 },
#else
    { 0, output_6440, 0 },
#endif
    { 0 },
    &operand_data[9405],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6441 },
#else
    { 0, output_6441, 0 },
#endif
    { 0 },
    &operand_data[9405],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6442 },
#else
    { 0, output_6442, 0 },
#endif
    { 0 },
    &operand_data[9411],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6443 },
#else
    { 0, output_6443, 0 },
#endif
    { 0 },
    &operand_data[9411],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_sabdvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6444 },
#else
    { 0, output_6444, 0 },
#endif
    { 0 },
    &operand_data[9417],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4038 */
  {
    "*aarch64_cond_uabdvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6445 },
#else
    { 0, output_6445, 0 },
#endif
    { 0 },
    &operand_data[9417],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6446 },
#else
    { 0, output_6446, 0 },
#endif
    { 0 },
    &operand_data[9423],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6447 },
#else
    { 0, output_6447, 0 },
#endif
    { 0 },
    &operand_data[9423],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6448 },
#else
    { 0, output_6448, 0 },
#endif
    { 0 },
    &operand_data[9429],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6449 },
#else
    { 0, output_6449, 0 },
#endif
    { 0 },
    &operand_data[9429],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6450 },
#else
    { 0, output_6450, 0 },
#endif
    { 0 },
    &operand_data[9435],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6451 },
#else
    { 0, output_6451, 0 },
#endif
    { 0 },
    &operand_data[9435],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6452 },
#else
    { 0, output_6452, 0 },
#endif
    { 0 },
    &operand_data[9441],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6453 },
#else
    { 0, output_6453, 0 },
#endif
    { 0 },
    &operand_data[9441],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6454 },
#else
    { 0, output_6454, 0 },
#endif
    { 0 },
    &operand_data[9447],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6455 },
#else
    { 0, output_6455, 0 },
#endif
    { 0 },
    &operand_data[9447],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6456 },
#else
    { 0, output_6456, 0 },
#endif
    { 0 },
    &operand_data[9453],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6457 },
#else
    { 0, output_6457, 0 },
#endif
    { 0 },
    &operand_data[9453],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6458 },
#else
    { 0, output_6458, 0 },
#endif
    { 0 },
    &operand_data[9459],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6459 },
#else
    { 0, output_6459, 0 },
#endif
    { 0 },
    &operand_data[9459],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6460 },
#else
    { 0, output_6460, 0 },
#endif
    { 0 },
    &operand_data[9465],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6461 },
#else
    { 0, output_6461, 0 },
#endif
    { 0 },
    &operand_data[9465],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6462 },
#else
    { 0, output_6462, 0 },
#endif
    { 0 },
    &operand_data[9471],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6463 },
#else
    { 0, output_6463, 0 },
#endif
    { 0 },
    &operand_data[9471],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_sabdvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6464 },
#else
    { 0, output_6464, 0 },
#endif
    { 0 },
    &operand_data[9477],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4069 */
  {
    "*aarch64_cond_uabdvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6465 },
#else
    { 0, output_6465, 0 },
#endif
    { 0 },
    &operand_data[9477],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6466 },
#else
    { 0, output_6466, 0 },
#endif
    { 0 },
    &operand_data[9483],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6467 },
#else
    { 0, output_6467, 0 },
#endif
    { 0 },
    &operand_data[9483],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6468 },
#else
    { 0, output_6468, 0 },
#endif
    { 0 },
    &operand_data[9490],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6469 },
#else
    { 0, output_6469, 0 },
#endif
    { 0 },
    &operand_data[9490],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6470 },
#else
    { 0, output_6470, 0 },
#endif
    { 0 },
    &operand_data[9497],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6471 },
#else
    { 0, output_6471, 0 },
#endif
    { 0 },
    &operand_data[9497],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6472 },
#else
    { 0, output_6472, 0 },
#endif
    { 0 },
    &operand_data[9504],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6473 },
#else
    { 0, output_6473, 0 },
#endif
    { 0 },
    &operand_data[9504],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6474 },
#else
    { 0, output_6474, 0 },
#endif
    { 0 },
    &operand_data[9511],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6475 },
#else
    { 0, output_6475, 0 },
#endif
    { 0 },
    &operand_data[9511],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6476 },
#else
    { 0, output_6476, 0 },
#endif
    { 0 },
    &operand_data[9518],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6477 },
#else
    { 0, output_6477, 0 },
#endif
    { 0 },
    &operand_data[9518],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6478 },
#else
    { 0, output_6478, 0 },
#endif
    { 0 },
    &operand_data[9525],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6479 },
#else
    { 0, output_6479, 0 },
#endif
    { 0 },
    &operand_data[9525],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6480 },
#else
    { 0, output_6480, 0 },
#endif
    { 0 },
    &operand_data[9532],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6481 },
#else
    { 0, output_6481, 0 },
#endif
    { 0 },
    &operand_data[9532],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6482 },
#else
    { 0, output_6482, 0 },
#endif
    { 0 },
    &operand_data[9539],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6483 },
#else
    { 0, output_6483, 0 },
#endif
    { 0 },
    &operand_data[9539],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_sabdvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6484 },
#else
    { 0, output_6484, 0 },
#endif
    { 0 },
    &operand_data[9546],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4100 */
  {
    "*aarch64_cond_uabdvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6485 },
#else
    { 0, output_6485, 0 },
#endif
    { 0 },
    &operand_data[9546],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_ssaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6486 },
#else
    { 0, output_6486, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssaddvnx16qi },
    &operand_data[9553],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_sssubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6487 },
#else
    { 0, output_6487, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sssubvnx16qi },
    &operand_data[9553],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_ssaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6488 },
#else
    { 0, output_6488, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssaddvnx8hi },
    &operand_data[9556],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_sssubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6489 },
#else
    { 0, output_6489, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sssubvnx8hi },
    &operand_data[9556],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_ssaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6490 },
#else
    { 0, output_6490, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssaddvnx4si },
    &operand_data[9559],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_sssubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6491 },
#else
    { 0, output_6491, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sssubvnx4si },
    &operand_data[9559],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_ssaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6492 },
#else
    { 0, output_6492, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssaddvnx2di },
    &operand_data[9562],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4156 */
  {
    "aarch64_sve_sssubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6493 },
#else
    { 0, output_6493, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sssubvnx2di },
    &operand_data[9562],
    3,
    3,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_usaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6494 },
#else
    { 0, output_6494, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usaddvnx16qi },
    &operand_data[9565],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_ussubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6495 },
#else
    { 0, output_6495, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ussubvnx16qi },
    &operand_data[9565],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_usaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6496 },
#else
    { 0, output_6496, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usaddvnx8hi },
    &operand_data[9568],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_ussubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6497 },
#else
    { 0, output_6497, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ussubvnx8hi },
    &operand_data[9568],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_usaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6498 },
#else
    { 0, output_6498, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usaddvnx4si },
    &operand_data[9571],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_ussubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6499 },
#else
    { 0, output_6499, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ussubvnx4si },
    &operand_data[9571],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_usaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6500 },
#else
    { 0, output_6500, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usaddvnx2di },
    &operand_data[9574],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4172 */
  {
    "aarch64_sve_ussubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6501 },
#else
    { 0, output_6501, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ussubvnx2di },
    &operand_data[9574],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6502 },
#else
    { 0, output_6502, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx16qi },
    &operand_data[9323],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6503 },
#else
    { 0, output_6503, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx16qi },
    &operand_data[9323],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6504 },
#else
    { 0, output_6504, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx8qi },
    &operand_data[9327],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6505 },
#else
    { 0, output_6505, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx8qi },
    &operand_data[9327],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6506 },
#else
    { 0, output_6506, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx4qi },
    &operand_data[9331],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6507 },
#else
    { 0, output_6507, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx4qi },
    &operand_data[9331],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6508 },
#else
    { 0, output_6508, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx2qi },
    &operand_data[9335],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6509 },
#else
    { 0, output_6509, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx2qi },
    &operand_data[9335],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6510 },
#else
    { 0, output_6510, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx8hi },
    &operand_data[9339],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6511 },
#else
    { 0, output_6511, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx8hi },
    &operand_data[9339],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6512 },
#else
    { 0, output_6512, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx4hi },
    &operand_data[9343],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6513 },
#else
    { 0, output_6513, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx4hi },
    &operand_data[9343],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6514 },
#else
    { 0, output_6514, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx2hi },
    &operand_data[9347],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6515 },
#else
    { 0, output_6515, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx2hi },
    &operand_data[9347],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6516 },
#else
    { 0, output_6516, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx4si },
    &operand_data[9351],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6517 },
#else
    { 0, output_6517, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx4si },
    &operand_data[9351],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6518 },
#else
    { 0, output_6518, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx2si },
    &operand_data[9355],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6519 },
#else
    { 0, output_6519, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx2si },
    &operand_data[9355],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_smulhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6520 },
#else
    { 0, output_6520, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smulhvnx2di },
    &operand_data[9359],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4210 */
  {
    "aarch64_pred_umulhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6521 },
#else
    { 0, output_6521, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umulhvnx2di },
    &operand_data[9359],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_smulhvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6522 },
#else
    { 0, output_6522, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_umulhvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6523 },
#else
    { 0, output_6523, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_smulhvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6524 },
#else
    { 0, output_6524, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_umulhvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6525 },
#else
    { 0, output_6525, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_smulhvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6526 },
#else
    { 0, output_6526, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_umulhvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6527 },
#else
    { 0, output_6527, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_smulhvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6528 },
#else
    { 0, output_6528, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4246 */
  {
    "*cond_umulhvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6529 },
#else
    { 0, output_6529, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_smulhvnx16qi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6530 },
#else
    { 0, output_6530, 0 },
#endif
    { 0 },
    &operand_data[9577],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_umulhvnx16qi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6531 },
#else
    { 0, output_6531, 0 },
#endif
    { 0 },
    &operand_data[9577],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_smulhvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6532 },
#else
    { 0, output_6532, 0 },
#endif
    { 0 },
    &operand_data[9582],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_umulhvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6533 },
#else
    { 0, output_6533, 0 },
#endif
    { 0 },
    &operand_data[9582],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_smulhvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6534 },
#else
    { 0, output_6534, 0 },
#endif
    { 0 },
    &operand_data[9587],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_umulhvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6535 },
#else
    { 0, output_6535, 0 },
#endif
    { 0 },
    &operand_data[9587],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_smulhvnx2di_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6536 },
#else
    { 0, output_6536, 0 },
#endif
    { 0 },
    &operand_data[9592],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4263 */
  {
    "*cond_umulhvnx2di_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6537 },
#else
    { 0, output_6537, 0 },
#endif
    { 0 },
    &operand_data[9592],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4305 */
  {
    "aarch64_pred_divvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6538 },
#else
    { 0, output_6538, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_divvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4305 */
  {
    "aarch64_pred_udivvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6539 },
#else
    { 0, output_6539, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_udivvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4305 */
  {
    "aarch64_pred_divvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6540 },
#else
    { 0, output_6540, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_divvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4305 */
  {
    "aarch64_pred_udivvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6541 },
#else
    { 0, output_6541, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_udivvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4335 */
  {
    "*cond_divvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6542 },
#else
    { 0, output_6542, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4335 */
  {
    "*cond_udivvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6543 },
#else
    { 0, output_6543, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4335 */
  {
    "*cond_divvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6544 },
#else
    { 0, output_6544, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4335 */
  {
    "*cond_udivvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6545 },
#else
    { 0, output_6545, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4352 */
  {
    "*cond_divvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6546 },
#else
    { 0, output_6546, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4352 */
  {
    "*cond_udivvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6547 },
#else
    { 0, output_6547, 0 },
#endif
    { 0 },
    &operand_data[9143],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4352 */
  {
    "*cond_divvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6548 },
#else
    { 0, output_6548, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4352 */
  {
    "*cond_udivvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6549 },
#else
    { 0, output_6549, 0 },
#endif
    { 0 },
    &operand_data[9151],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4369 */
  {
    "*cond_divvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6550 },
#else
    { 0, output_6550, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4369 */
  {
    "*cond_udivvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6551 },
#else
    { 0, output_6551, 0 },
#endif
    { 0 },
    &operand_data[9190],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4369 */
  {
    "*cond_divvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6552 },
#else
    { 0, output_6552, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4369 */
  {
    "*cond_udivvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6553 },
#else
    { 0, output_6553, 0 },
#endif
    { 0 },
    &operand_data[9200],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6554 },
#else
    { 0, output_6554, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx16qi3 },
    &operand_data[9605],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6555 },
#else
    { 0, output_6555, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx16qi3 },
    &operand_data[9605],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6556 },
#else
    { 0, output_6556, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx16qi3 },
    &operand_data[9605],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6557 },
#else
    { 0, output_6557, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx8qi3 },
    &operand_data[9608],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6558 },
#else
    { 0, output_6558, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx8qi3 },
    &operand_data[9608],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6559 },
#else
    { 0, output_6559, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx8qi3 },
    &operand_data[9608],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6560 },
#else
    { 0, output_6560, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx4qi3 },
    &operand_data[9611],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6561 },
#else
    { 0, output_6561, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx4qi3 },
    &operand_data[9611],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6562 },
#else
    { 0, output_6562, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx4qi3 },
    &operand_data[9611],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6563 },
#else
    { 0, output_6563, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx2qi3 },
    &operand_data[9614],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6564 },
#else
    { 0, output_6564, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx2qi3 },
    &operand_data[9614],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6565 },
#else
    { 0, output_6565, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx2qi3 },
    &operand_data[9614],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6566 },
#else
    { 0, output_6566, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx8hi3 },
    &operand_data[9617],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6567 },
#else
    { 0, output_6567, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx8hi3 },
    &operand_data[9617],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6568 },
#else
    { 0, output_6568, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx8hi3 },
    &operand_data[9617],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6569 },
#else
    { 0, output_6569, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx4hi3 },
    &operand_data[9620],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6570 },
#else
    { 0, output_6570, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx4hi3 },
    &operand_data[9620],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6571 },
#else
    { 0, output_6571, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx4hi3 },
    &operand_data[9620],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6572 },
#else
    { 0, output_6572, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx2hi3 },
    &operand_data[9623],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6573 },
#else
    { 0, output_6573, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx2hi3 },
    &operand_data[9623],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6574 },
#else
    { 0, output_6574, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx2hi3 },
    &operand_data[9623],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6575 },
#else
    { 0, output_6575, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx4si3 },
    &operand_data[9626],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6576 },
#else
    { 0, output_6576, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx4si3 },
    &operand_data[9626],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6577 },
#else
    { 0, output_6577, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx4si3 },
    &operand_data[9626],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6578 },
#else
    { 0, output_6578, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx2si3 },
    &operand_data[9629],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6579 },
#else
    { 0, output_6579, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx2si3 },
    &operand_data[9629],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6580 },
#else
    { 0, output_6580, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx2si3 },
    &operand_data[9629],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "andvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6581 },
#else
    { 0, output_6581, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx2di3 },
    &operand_data[9632],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "iorvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6582 },
#else
    { 0, output_6582, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx2di3 },
    &operand_data[9632],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4408 */
  {
    "xorvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6583 },
#else
    { 0, output_6583, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx2di3 },
    &operand_data[9632],
    3,
    3,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9635],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9639],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9643],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9647],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9651],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9655],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9659],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9663],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9667],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4446 */
  {
    "*bicvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9268],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6594 },
#else
    { 0, output_6594, 0 },
#endif
    { 0 },
    &operand_data[9075],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6595 },
#else
    { 0, output_6595, 0 },
#endif
    { 0 },
    &operand_data[9079],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6596 },
#else
    { 0, output_6596, 0 },
#endif
    { 0 },
    &operand_data[9083],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6597 },
#else
    { 0, output_6597, 0 },
#endif
    { 0 },
    &operand_data[9087],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6598 },
#else
    { 0, output_6598, 0 },
#endif
    { 0 },
    &operand_data[9091],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6599 },
#else
    { 0, output_6599, 0 },
#endif
    { 0 },
    &operand_data[9095],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6600 },
#else
    { 0, output_6600, 0 },
#endif
    { 0 },
    &operand_data[9099],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6601 },
#else
    { 0, output_6601, 0 },
#endif
    { 0 },
    &operand_data[9103],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6602 },
#else
    { 0, output_6602, 0 },
#endif
    { 0 },
    &operand_data[9107],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4477 */
  {
    "*cond_bicvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6603 },
#else
    { 0, output_6603, 0 },
#endif
    { 0 },
    &operand_data[9111],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6604 },
#else
    { 0, output_6604, 0 },
#endif
    { 0 },
    &operand_data[9671],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6605 },
#else
    { 0, output_6605, 0 },
#endif
    { 0 },
    &operand_data[9676],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6606 },
#else
    { 0, output_6606, 0 },
#endif
    { 0 },
    &operand_data[9681],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6607 },
#else
    { 0, output_6607, 0 },
#endif
    { 0 },
    &operand_data[9686],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6608 },
#else
    { 0, output_6608, 0 },
#endif
    { 0 },
    &operand_data[9691],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6609 },
#else
    { 0, output_6609, 0 },
#endif
    { 0 },
    &operand_data[9696],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6610 },
#else
    { 0, output_6610, 0 },
#endif
    { 0 },
    &operand_data[9701],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6611 },
#else
    { 0, output_6611, 0 },
#endif
    { 0 },
    &operand_data[9706],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6612 },
#else
    { 0, output_6612, 0 },
#endif
    { 0 },
    &operand_data[9711],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4495 */
  {
    "*cond_bicvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6613 },
#else
    { 0, output_6613, 0 },
#endif
    { 0 },
    &operand_data[9716],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6614 },
#else
    { 0, output_6614, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx16qi },
    &operand_data[9721],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6615 },
#else
    { 0, output_6615, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx16qi },
    &operand_data[9725],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6616 },
#else
    { 0, output_6616, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx16qi },
    &operand_data[9725],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6617 },
#else
    { 0, output_6617, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx8qi },
    &operand_data[9729],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6618 },
#else
    { 0, output_6618, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx8qi },
    &operand_data[9733],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6619 },
#else
    { 0, output_6619, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx8qi },
    &operand_data[9733],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6620 },
#else
    { 0, output_6620, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx4qi },
    &operand_data[9737],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6621 },
#else
    { 0, output_6621, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx4qi },
    &operand_data[9741],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6622 },
#else
    { 0, output_6622, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx4qi },
    &operand_data[9741],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6623 },
#else
    { 0, output_6623, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx2qi },
    &operand_data[9745],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6624 },
#else
    { 0, output_6624, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx2qi },
    &operand_data[9749],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6625 },
#else
    { 0, output_6625, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx2qi },
    &operand_data[9749],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6626 },
#else
    { 0, output_6626, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx8hi },
    &operand_data[9753],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6627 },
#else
    { 0, output_6627, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx8hi },
    &operand_data[9757],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6628 },
#else
    { 0, output_6628, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx8hi },
    &operand_data[9757],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6629 },
#else
    { 0, output_6629, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx4hi },
    &operand_data[9761],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6630 },
#else
    { 0, output_6630, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx4hi },
    &operand_data[9765],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6631 },
#else
    { 0, output_6631, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx4hi },
    &operand_data[9765],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6632 },
#else
    { 0, output_6632, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx2hi },
    &operand_data[9769],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6633 },
#else
    { 0, output_6633, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx2hi },
    &operand_data[9773],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6634 },
#else
    { 0, output_6634, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx2hi },
    &operand_data[9773],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6635 },
#else
    { 0, output_6635, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx4si },
    &operand_data[9777],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6636 },
#else
    { 0, output_6636, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx4si },
    &operand_data[9781],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6637 },
#else
    { 0, output_6637, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx4si },
    &operand_data[9781],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6638 },
#else
    { 0, output_6638, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx2si },
    &operand_data[9785],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6639 },
#else
    { 0, output_6639, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx2si },
    &operand_data[9789],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6640 },
#else
    { 0, output_6640, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx2si },
    &operand_data[9789],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6641 },
#else
    { 0, output_6641, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashlvnx2di },
    &operand_data[9793],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_ashrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6642 },
#else
    { 0, output_6642, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ashrvnx2di },
    &operand_data[9797],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4579 */
  {
    "aarch64_pred_lshrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6643 },
#else
    { 0, output_6643, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_lshrvnx2di },
    &operand_data[9797],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9801],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9804],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9804],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9807],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9810],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9810],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9813],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9816],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9816],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9819],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9822],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.b, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9822],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9825],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9828],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9828],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9831],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9834],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9834],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9837],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9840],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.h, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9840],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.s, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9843],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.s, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9846],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.s, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9846],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.s, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9849],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.s, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9852],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.s, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9852],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashlvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.d, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9855],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vashrvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.d, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9858],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4603 */
  {
    "*post_ra_vlshrvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.d, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[9858],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx16qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6674 },
#else
    { 0, output_6674, 0 },
#endif
    { 0 },
    &operand_data[9861],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx16qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6675 },
#else
    { 0, output_6675, 0 },
#endif
    { 0 },
    &operand_data[9865],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx16qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6676 },
#else
    { 0, output_6676, 0 },
#endif
    { 0 },
    &operand_data[9865],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx8qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6677 },
#else
    { 0, output_6677, 0 },
#endif
    { 0 },
    &operand_data[9869],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx8qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6678 },
#else
    { 0, output_6678, 0 },
#endif
    { 0 },
    &operand_data[9873],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx8qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6679 },
#else
    { 0, output_6679, 0 },
#endif
    { 0 },
    &operand_data[9873],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx4qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6680 },
#else
    { 0, output_6680, 0 },
#endif
    { 0 },
    &operand_data[9877],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx4qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6681 },
#else
    { 0, output_6681, 0 },
#endif
    { 0 },
    &operand_data[9881],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx4qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6682 },
#else
    { 0, output_6682, 0 },
#endif
    { 0 },
    &operand_data[9881],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx2qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6683 },
#else
    { 0, output_6683, 0 },
#endif
    { 0 },
    &operand_data[9885],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx2qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6684 },
#else
    { 0, output_6684, 0 },
#endif
    { 0 },
    &operand_data[9889],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx2qi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6685 },
#else
    { 0, output_6685, 0 },
#endif
    { 0 },
    &operand_data[9889],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx8hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6686 },
#else
    { 0, output_6686, 0 },
#endif
    { 0 },
    &operand_data[9893],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx8hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6687 },
#else
    { 0, output_6687, 0 },
#endif
    { 0 },
    &operand_data[9897],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx8hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6688 },
#else
    { 0, output_6688, 0 },
#endif
    { 0 },
    &operand_data[9897],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx4hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6689 },
#else
    { 0, output_6689, 0 },
#endif
    { 0 },
    &operand_data[9901],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx4hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6690 },
#else
    { 0, output_6690, 0 },
#endif
    { 0 },
    &operand_data[9905],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx4hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6691 },
#else
    { 0, output_6691, 0 },
#endif
    { 0 },
    &operand_data[9905],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx2hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6692 },
#else
    { 0, output_6692, 0 },
#endif
    { 0 },
    &operand_data[9909],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx2hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6693 },
#else
    { 0, output_6693, 0 },
#endif
    { 0 },
    &operand_data[9913],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx2hi_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6694 },
#else
    { 0, output_6694, 0 },
#endif
    { 0 },
    &operand_data[9913],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx4si_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6695 },
#else
    { 0, output_6695, 0 },
#endif
    { 0 },
    &operand_data[9917],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx4si_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6696 },
#else
    { 0, output_6696, 0 },
#endif
    { 0 },
    &operand_data[9921],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx4si_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6697 },
#else
    { 0, output_6697, 0 },
#endif
    { 0 },
    &operand_data[9921],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx2si_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6698 },
#else
    { 0, output_6698, 0 },
#endif
    { 0 },
    &operand_data[9925],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx2si_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6699 },
#else
    { 0, output_6699, 0 },
#endif
    { 0 },
    &operand_data[9929],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx2si_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6700 },
#else
    { 0, output_6700, 0 },
#endif
    { 0 },
    &operand_data[9929],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashlvnx2di_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6701 },
#else
    { 0, output_6701, 0 },
#endif
    { 0 },
    &operand_data[9933],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_ashrvnx2di_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6702 },
#else
    { 0, output_6702, 0 },
#endif
    { 0 },
    &operand_data[9937],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4613 */
  {
    "*cond_lshrvnx2di_2_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6703 },
#else
    { 0, output_6703, 0 },
#endif
    { 0 },
    &operand_data[9937],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx16qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6704 },
#else
    { 0, output_6704, 0 },
#endif
    { 0 },
    &operand_data[9941],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx16qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6705 },
#else
    { 0, output_6705, 0 },
#endif
    { 0 },
    &operand_data[9946],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx16qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6706 },
#else
    { 0, output_6706, 0 },
#endif
    { 0 },
    &operand_data[9946],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx8qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6707 },
#else
    { 0, output_6707, 0 },
#endif
    { 0 },
    &operand_data[9951],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx8qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6708 },
#else
    { 0, output_6708, 0 },
#endif
    { 0 },
    &operand_data[9956],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx8qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6709 },
#else
    { 0, output_6709, 0 },
#endif
    { 0 },
    &operand_data[9956],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx4qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6710 },
#else
    { 0, output_6710, 0 },
#endif
    { 0 },
    &operand_data[9961],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx4qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6711 },
#else
    { 0, output_6711, 0 },
#endif
    { 0 },
    &operand_data[9966],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx4qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6712 },
#else
    { 0, output_6712, 0 },
#endif
    { 0 },
    &operand_data[9966],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx2qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6713 },
#else
    { 0, output_6713, 0 },
#endif
    { 0 },
    &operand_data[9971],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx2qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6714 },
#else
    { 0, output_6714, 0 },
#endif
    { 0 },
    &operand_data[9976],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx2qi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6715 },
#else
    { 0, output_6715, 0 },
#endif
    { 0 },
    &operand_data[9976],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx8hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6716 },
#else
    { 0, output_6716, 0 },
#endif
    { 0 },
    &operand_data[9981],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx8hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6717 },
#else
    { 0, output_6717, 0 },
#endif
    { 0 },
    &operand_data[9986],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx8hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6718 },
#else
    { 0, output_6718, 0 },
#endif
    { 0 },
    &operand_data[9986],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx4hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6719 },
#else
    { 0, output_6719, 0 },
#endif
    { 0 },
    &operand_data[9991],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx4hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6720 },
#else
    { 0, output_6720, 0 },
#endif
    { 0 },
    &operand_data[9996],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx4hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6721 },
#else
    { 0, output_6721, 0 },
#endif
    { 0 },
    &operand_data[9996],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx2hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6722 },
#else
    { 0, output_6722, 0 },
#endif
    { 0 },
    &operand_data[10001],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx2hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6723 },
#else
    { 0, output_6723, 0 },
#endif
    { 0 },
    &operand_data[10006],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx2hi_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6724 },
#else
    { 0, output_6724, 0 },
#endif
    { 0 },
    &operand_data[10006],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx4si_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6725 },
#else
    { 0, output_6725, 0 },
#endif
    { 0 },
    &operand_data[10011],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx4si_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6726 },
#else
    { 0, output_6726, 0 },
#endif
    { 0 },
    &operand_data[10016],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx4si_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6727 },
#else
    { 0, output_6727, 0 },
#endif
    { 0 },
    &operand_data[10016],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx2si_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6728 },
#else
    { 0, output_6728, 0 },
#endif
    { 0 },
    &operand_data[10021],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx2si_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6729 },
#else
    { 0, output_6729, 0 },
#endif
    { 0 },
    &operand_data[10026],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx2si_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6730 },
#else
    { 0, output_6730, 0 },
#endif
    { 0 },
    &operand_data[10026],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashlvnx2di_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6731 },
#else
    { 0, output_6731, 0 },
#endif
    { 0 },
    &operand_data[10031],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_ashrvnx2di_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6732 },
#else
    { 0, output_6732, 0 },
#endif
    { 0 },
    &operand_data[10036],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4630 */
  {
    "*cond_lshrvnx2di_any_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6733 },
#else
    { 0, output_6733, 0 },
#endif
    { 0 },
    &operand_data[10036],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_lslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.b, %1.b, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_lslvnx16qi },
    &operand_data[10041],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_asrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.b, %1.b, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_asrvnx16qi },
    &operand_data[10041],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_lsrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.b, %1.b, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_lsrvnx16qi },
    &operand_data[10041],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_lslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.h, %1.h, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_lslvnx8hi },
    &operand_data[10044],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_asrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.h, %1.h, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_asrvnx8hi },
    &operand_data[10044],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_lsrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.h, %1.h, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_lsrvnx8hi },
    &operand_data[10044],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_lslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsl\t%0.s, %1.s, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_lslvnx4si },
    &operand_data[10047],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_asrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "asr\t%0.s, %1.s, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_asrvnx4si },
    &operand_data[10047],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4656 */
  {
    "aarch64_sve_lsrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "lsr\t%0.s, %1.s, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_lsrvnx4si },
    &operand_data[10047],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_lslvnx16qi_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6743 },
#else
    { 0, output_6743, 0 },
#endif
    { 0 },
    &operand_data[10050],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_asrvnx16qi_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6744 },
#else
    { 0, output_6744, 0 },
#endif
    { 0 },
    &operand_data[10050],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_lsrvnx16qi_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6745 },
#else
    { 0, output_6745, 0 },
#endif
    { 0 },
    &operand_data[10050],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_lslvnx8hi_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6746 },
#else
    { 0, output_6746, 0 },
#endif
    { 0 },
    &operand_data[10054],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_asrvnx8hi_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6747 },
#else
    { 0, output_6747, 0 },
#endif
    { 0 },
    &operand_data[10054],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_lsrvnx8hi_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6748 },
#else
    { 0, output_6748, 0 },
#endif
    { 0 },
    &operand_data[10054],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_lslvnx4si_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6749 },
#else
    { 0, output_6749, 0 },
#endif
    { 0 },
    &operand_data[10058],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_asrvnx4si_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6750 },
#else
    { 0, output_6750, 0 },
#endif
    { 0 },
    &operand_data[10058],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4682 */
  {
    "*cond_lsrvnx4si_m",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6751 },
#else
    { 0, output_6751, 0 },
#endif
    { 0 },
    &operand_data[10058],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_lslvnx16qi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6752 },
#else
    { 0, output_6752, 0 },
#endif
    { 0 },
    &operand_data[10062],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_asrvnx16qi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6753 },
#else
    { 0, output_6753, 0 },
#endif
    { 0 },
    &operand_data[10062],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_lsrvnx16qi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6754 },
#else
    { 0, output_6754, 0 },
#endif
    { 0 },
    &operand_data[10062],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_lslvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6755 },
#else
    { 0, output_6755, 0 },
#endif
    { 0 },
    &operand_data[10067],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_asrvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6756 },
#else
    { 0, output_6756, 0 },
#endif
    { 0 },
    &operand_data[10067],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_lsrvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6757 },
#else
    { 0, output_6757, 0 },
#endif
    { 0 },
    &operand_data[10067],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_lslvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6758 },
#else
    { 0, output_6758, 0 },
#endif
    { 0 },
    &operand_data[10072],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_asrvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6759 },
#else
    { 0, output_6759, 0 },
#endif
    { 0 },
    &operand_data[10072],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4699 */
  {
    "*cond_lsrvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6760 },
#else
    { 0, output_6760, 0 },
#endif
    { 0 },
    &operand_data[10072],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6761 },
#else
    { 0, output_6761, 0 },
#endif
    { 0 },
    &operand_data[9865],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6762 },
#else
    { 0, output_6762, 0 },
#endif
    { 0 },
    &operand_data[9873],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6763 },
#else
    { 0, output_6763, 0 },
#endif
    { 0 },
    &operand_data[9881],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6764 },
#else
    { 0, output_6764, 0 },
#endif
    { 0 },
    &operand_data[9889],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6765 },
#else
    { 0, output_6765, 0 },
#endif
    { 0 },
    &operand_data[9897],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6766 },
#else
    { 0, output_6766, 0 },
#endif
    { 0 },
    &operand_data[9905],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6767 },
#else
    { 0, output_6767, 0 },
#endif
    { 0 },
    &operand_data[9913],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6768 },
#else
    { 0, output_6768, 0 },
#endif
    { 0 },
    &operand_data[9921],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6769 },
#else
    { 0, output_6769, 0 },
#endif
    { 0 },
    &operand_data[9929],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4742 */
  {
    "*sdiv_pow2vnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6770 },
#else
    { 0, output_6770, 0 },
#endif
    { 0 },
    &operand_data[9937],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6771 },
#else
    { 0, output_6771, 0 },
#endif
    { 0 },
    &operand_data[10077],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6772 },
#else
    { 0, output_6772, 0 },
#endif
    { 0 },
    &operand_data[10082],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6773 },
#else
    { 0, output_6773, 0 },
#endif
    { 0 },
    &operand_data[10077],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6774 },
#else
    { 0, output_6774, 0 },
#endif
    { 0 },
    &operand_data[10077],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6775 },
#else
    { 0, output_6775, 0 },
#endif
    { 0 },
    &operand_data[10087],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6776 },
#else
    { 0, output_6776, 0 },
#endif
    { 0 },
    &operand_data[10092],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6777 },
#else
    { 0, output_6777, 0 },
#endif
    { 0 },
    &operand_data[10087],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6778 },
#else
    { 0, output_6778, 0 },
#endif
    { 0 },
    &operand_data[10087],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6779 },
#else
    { 0, output_6779, 0 },
#endif
    { 0 },
    &operand_data[10097],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6780 },
#else
    { 0, output_6780, 0 },
#endif
    { 0 },
    &operand_data[10102],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6781 },
#else
    { 0, output_6781, 0 },
#endif
    { 0 },
    &operand_data[10097],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6782 },
#else
    { 0, output_6782, 0 },
#endif
    { 0 },
    &operand_data[10097],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6783 },
#else
    { 0, output_6783, 0 },
#endif
    { 0 },
    &operand_data[10107],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6784 },
#else
    { 0, output_6784, 0 },
#endif
    { 0 },
    &operand_data[10112],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6785 },
#else
    { 0, output_6785, 0 },
#endif
    { 0 },
    &operand_data[10107],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6786 },
#else
    { 0, output_6786, 0 },
#endif
    { 0 },
    &operand_data[10107],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6787 },
#else
    { 0, output_6787, 0 },
#endif
    { 0 },
    &operand_data[10117],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6788 },
#else
    { 0, output_6788, 0 },
#endif
    { 0 },
    &operand_data[10122],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6789 },
#else
    { 0, output_6789, 0 },
#endif
    { 0 },
    &operand_data[10117],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6790 },
#else
    { 0, output_6790, 0 },
#endif
    { 0 },
    &operand_data[10117],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6791 },
#else
    { 0, output_6791, 0 },
#endif
    { 0 },
    &operand_data[10127],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6792 },
#else
    { 0, output_6792, 0 },
#endif
    { 0 },
    &operand_data[10132],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6793 },
#else
    { 0, output_6793, 0 },
#endif
    { 0 },
    &operand_data[10127],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6794 },
#else
    { 0, output_6794, 0 },
#endif
    { 0 },
    &operand_data[10127],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6795 },
#else
    { 0, output_6795, 0 },
#endif
    { 0 },
    &operand_data[10137],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6796 },
#else
    { 0, output_6796, 0 },
#endif
    { 0 },
    &operand_data[10142],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6797 },
#else
    { 0, output_6797, 0 },
#endif
    { 0 },
    &operand_data[10137],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6798 },
#else
    { 0, output_6798, 0 },
#endif
    { 0 },
    &operand_data[10137],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6799 },
#else
    { 0, output_6799, 0 },
#endif
    { 0 },
    &operand_data[10147],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6800 },
#else
    { 0, output_6800, 0 },
#endif
    { 0 },
    &operand_data[10152],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6801 },
#else
    { 0, output_6801, 0 },
#endif
    { 0 },
    &operand_data[10147],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6802 },
#else
    { 0, output_6802, 0 },
#endif
    { 0 },
    &operand_data[10147],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6803 },
#else
    { 0, output_6803, 0 },
#endif
    { 0 },
    &operand_data[10157],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6804 },
#else
    { 0, output_6804, 0 },
#endif
    { 0 },
    &operand_data[10162],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6805 },
#else
    { 0, output_6805, 0 },
#endif
    { 0 },
    &operand_data[10157],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6806 },
#else
    { 0, output_6806, 0 },
#endif
    { 0 },
    &operand_data[10157],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_asrdvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6807 },
#else
    { 0, output_6807, 0 },
#endif
    { 0 },
    &operand_data[10167],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_sqshluvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6808 },
#else
    { 0, output_6808, 0 },
#endif
    { 0 },
    &operand_data[10172],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_srshrvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6809 },
#else
    { 0, output_6809, 0 },
#endif
    { 0 },
    &operand_data[10167],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4778 */
  {
    "*cond_urshrvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6810 },
#else
    { 0, output_6810, 0 },
#endif
    { 0 },
    &operand_data[10167],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6811 },
#else
    { 0, output_6811, 0 },
#endif
    { 0 },
    &operand_data[10177],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6812 },
#else
    { 0, output_6812, 0 },
#endif
    { 0 },
    &operand_data[10183],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6813 },
#else
    { 0, output_6813, 0 },
#endif
    { 0 },
    &operand_data[10177],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6814 },
#else
    { 0, output_6814, 0 },
#endif
    { 0 },
    &operand_data[10177],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6815 },
#else
    { 0, output_6815, 0 },
#endif
    { 0 },
    &operand_data[10189],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6816 },
#else
    { 0, output_6816, 0 },
#endif
    { 0 },
    &operand_data[10195],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6817 },
#else
    { 0, output_6817, 0 },
#endif
    { 0 },
    &operand_data[10189],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6818 },
#else
    { 0, output_6818, 0 },
#endif
    { 0 },
    &operand_data[10189],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6819 },
#else
    { 0, output_6819, 0 },
#endif
    { 0 },
    &operand_data[10201],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6820 },
#else
    { 0, output_6820, 0 },
#endif
    { 0 },
    &operand_data[10207],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6821 },
#else
    { 0, output_6821, 0 },
#endif
    { 0 },
    &operand_data[10201],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6822 },
#else
    { 0, output_6822, 0 },
#endif
    { 0 },
    &operand_data[10201],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6823 },
#else
    { 0, output_6823, 0 },
#endif
    { 0 },
    &operand_data[10213],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6824 },
#else
    { 0, output_6824, 0 },
#endif
    { 0 },
    &operand_data[10219],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6825 },
#else
    { 0, output_6825, 0 },
#endif
    { 0 },
    &operand_data[10213],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6826 },
#else
    { 0, output_6826, 0 },
#endif
    { 0 },
    &operand_data[10213],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6827 },
#else
    { 0, output_6827, 0 },
#endif
    { 0 },
    &operand_data[10225],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6828 },
#else
    { 0, output_6828, 0 },
#endif
    { 0 },
    &operand_data[10231],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6829 },
#else
    { 0, output_6829, 0 },
#endif
    { 0 },
    &operand_data[10225],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6830 },
#else
    { 0, output_6830, 0 },
#endif
    { 0 },
    &operand_data[10225],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6831 },
#else
    { 0, output_6831, 0 },
#endif
    { 0 },
    &operand_data[10237],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6832 },
#else
    { 0, output_6832, 0 },
#endif
    { 0 },
    &operand_data[10243],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6833 },
#else
    { 0, output_6833, 0 },
#endif
    { 0 },
    &operand_data[10237],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6834 },
#else
    { 0, output_6834, 0 },
#endif
    { 0 },
    &operand_data[10237],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6835 },
#else
    { 0, output_6835, 0 },
#endif
    { 0 },
    &operand_data[10249],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6836 },
#else
    { 0, output_6836, 0 },
#endif
    { 0 },
    &operand_data[10255],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6837 },
#else
    { 0, output_6837, 0 },
#endif
    { 0 },
    &operand_data[10249],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6838 },
#else
    { 0, output_6838, 0 },
#endif
    { 0 },
    &operand_data[10249],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6839 },
#else
    { 0, output_6839, 0 },
#endif
    { 0 },
    &operand_data[10261],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6840 },
#else
    { 0, output_6840, 0 },
#endif
    { 0 },
    &operand_data[10267],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6841 },
#else
    { 0, output_6841, 0 },
#endif
    { 0 },
    &operand_data[10261],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6842 },
#else
    { 0, output_6842, 0 },
#endif
    { 0 },
    &operand_data[10261],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6843 },
#else
    { 0, output_6843, 0 },
#endif
    { 0 },
    &operand_data[10273],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6844 },
#else
    { 0, output_6844, 0 },
#endif
    { 0 },
    &operand_data[10279],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6845 },
#else
    { 0, output_6845, 0 },
#endif
    { 0 },
    &operand_data[10273],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6846 },
#else
    { 0, output_6846, 0 },
#endif
    { 0 },
    &operand_data[10273],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_asrdvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6847 },
#else
    { 0, output_6847, 0 },
#endif
    { 0 },
    &operand_data[10285],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_sqshluvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6848 },
#else
    { 0, output_6848, 0 },
#endif
    { 0 },
    &operand_data[10291],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_srshrvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6849 },
#else
    { 0, output_6849, 0 },
#endif
    { 0 },
    &operand_data[10285],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4802 */
  {
    "*cond_urshrvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6850 },
#else
    { 0, output_6850, 0 },
#endif
    { 0 },
    &operand_data[10285],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4842 */
  {
    "aarch64_sve_ftsmulvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ftsmul\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ftsmulvnx8hf },
    &operand_data[10297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4842 */
  {
    "aarch64_sve_ftsselvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ftssel\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ftsselvnx8hf },
    &operand_data[10297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4842 */
  {
    "aarch64_sve_ftsmulvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ftsmul\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ftsmulvnx4sf },
    &operand_data[10300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4842 */
  {
    "aarch64_sve_ftsselvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ftssel\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ftsselvnx4sf },
    &operand_data[10300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4842 */
  {
    "aarch64_sve_ftsmulvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ftsmul\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ftsmulvnx2df },
    &operand_data[10303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4842 */
  {
    "aarch64_sve_ftsselvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ftssel\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ftsselvnx2df },
    &operand_data[10303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4854 */
  {
    "aarch64_pred_fscalevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6857 },
#else
    { 0, output_6857, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fscalevnx8hf },
    &operand_data[10306],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4854 */
  {
    "aarch64_pred_fscalevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6858 },
#else
    { 0, output_6858, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fscalevnx4sf },
    &operand_data[10311],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4854 */
  {
    "aarch64_pred_fscalevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6859 },
#else
    { 0, output_6859, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fscalevnx2df },
    &operand_data[10316],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4888 */
  {
    "*cond_fscalevnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6860 },
#else
    { 0, output_6860, 0 },
#endif
    { 0 },
    &operand_data[10321],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4888 */
  {
    "*cond_fscalevnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6861 },
#else
    { 0, output_6861, 0 },
#endif
    { 0 },
    &operand_data[10326],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4888 */
  {
    "*cond_fscalevnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6862 },
#else
    { 0, output_6862, 0 },
#endif
    { 0 },
    &operand_data[10331],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4911 */
  {
    "*cond_fscalevnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6863 },
#else
    { 0, output_6863, 0 },
#endif
    { 0 },
    &operand_data[10306],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4911 */
  {
    "*cond_fscalevnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6864 },
#else
    { 0, output_6864, 0 },
#endif
    { 0 },
    &operand_data[10311],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4911 */
  {
    "*cond_fscalevnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6865 },
#else
    { 0, output_6865, 0 },
#endif
    { 0 },
    &operand_data[10316],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4933 */
  {
    "*cond_fscalevnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6866 },
#else
    { 0, output_6866, 0 },
#endif
    { 0 },
    &operand_data[10336],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4933 */
  {
    "*cond_fscalevnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6867 },
#else
    { 0, output_6867, 0 },
#endif
    { 0 },
    &operand_data[10342],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4933 */
  {
    "*cond_fscalevnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6868 },
#else
    { 0, output_6868, 0 },
#endif
    { 0 },
    &operand_data[10348],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4969 */
  {
    "*cond_fscalevnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6869 },
#else
    { 0, output_6869, 0 },
#endif
    { 0 },
    &operand_data[10336],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4969 */
  {
    "*cond_fscalevnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6870 },
#else
    { 0, output_6870, 0 },
#endif
    { 0 },
    &operand_data[10342],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4969 */
  {
    "*cond_fscalevnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6871 },
#else
    { 0, output_6871, 0 },
#endif
    { 0 },
    &operand_data[10348],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_faddvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_fsubvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_fmulvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_faddvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_fsubvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_fmulvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_faddvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadd\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_fsubvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fsub\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5010 */
  {
    "*post_ra_fmulvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5038 */
  {
    "aarch64_sve_frecpsvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frecpsvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5038 */
  {
    "aarch64_sve_frsqrtsvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frsqrtsvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5038 */
  {
    "aarch64_sve_frecpsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frecpsvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5038 */
  {
    "aarch64_sve_frsqrtsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frsqrtsvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5038 */
  {
    "aarch64_sve_frecpsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frecps\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frecpsvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5038 */
  {
    "aarch64_sve_frsqrtsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "frsqrts\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_frsqrtsvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5065 */
  {
    "aarch64_pred_divvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6887 },
#else
    { 0, output_6887, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_divvnx8hf },
    &operand_data[10363],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5065 */
  {
    "aarch64_pred_mulxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6888 },
#else
    { 0, output_6888, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulxvnx8hf },
    &operand_data[10363],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5065 */
  {
    "aarch64_pred_divvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6889 },
#else
    { 0, output_6889, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_divvnx4sf },
    &operand_data[10368],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5065 */
  {
    "aarch64_pred_mulxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6890 },
#else
    { 0, output_6890, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulxvnx4sf },
    &operand_data[10368],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5065 */
  {
    "aarch64_pred_divvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6891 },
#else
    { 0, output_6891, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_divvnx2df },
    &operand_data[10373],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5065 */
  {
    "aarch64_pred_mulxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6892 },
#else
    { 0, output_6892, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulxvnx2df },
    &operand_data[10373],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_addvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6893 },
#else
    { 0, output_6893, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_divvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6894 },
#else
    { 0, output_6894, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_fmax_nanvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6895 },
#else
    { 0, output_6895, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_smaxvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6896 },
#else
    { 0, output_6896, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_fmin_nanvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6897 },
#else
    { 0, output_6897, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_sminvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6898 },
#else
    { 0, output_6898, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_mulvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6899 },
#else
    { 0, output_6899, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_mulxvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6900 },
#else
    { 0, output_6900, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_subvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6901 },
#else
    { 0, output_6901, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_addvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6902 },
#else
    { 0, output_6902, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_divvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6903 },
#else
    { 0, output_6903, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_fmax_nanvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6904 },
#else
    { 0, output_6904, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_smaxvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6905 },
#else
    { 0, output_6905, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_fmin_nanvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6906 },
#else
    { 0, output_6906, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_sminvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6907 },
#else
    { 0, output_6907, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_mulvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6908 },
#else
    { 0, output_6908, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_mulxvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6909 },
#else
    { 0, output_6909, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_subvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6910 },
#else
    { 0, output_6910, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_addvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6911 },
#else
    { 0, output_6911, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_divvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6912 },
#else
    { 0, output_6912, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_fmax_nanvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6913 },
#else
    { 0, output_6913, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_smaxvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6914 },
#else
    { 0, output_6914, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_fmin_nanvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6915 },
#else
    { 0, output_6915, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_sminvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6916 },
#else
    { 0, output_6916, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_mulvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6917 },
#else
    { 0, output_6917, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_mulxvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6918 },
#else
    { 0, output_6918, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5098 */
  {
    "*cond_subvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6919 },
#else
    { 0, output_6919, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_addvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6920 },
#else
    { 0, output_6920, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_divvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6921 },
#else
    { 0, output_6921, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_fmax_nanvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6922 },
#else
    { 0, output_6922, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_smaxvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6923 },
#else
    { 0, output_6923, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_fmin_nanvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6924 },
#else
    { 0, output_6924, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_sminvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6925 },
#else
    { 0, output_6925, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_mulvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6926 },
#else
    { 0, output_6926, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_mulxvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6927 },
#else
    { 0, output_6927, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_subvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6928 },
#else
    { 0, output_6928, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_addvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6929 },
#else
    { 0, output_6929, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_divvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6930 },
#else
    { 0, output_6930, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_fmax_nanvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6931 },
#else
    { 0, output_6931, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_smaxvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6932 },
#else
    { 0, output_6932, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_fmin_nanvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6933 },
#else
    { 0, output_6933, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_sminvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6934 },
#else
    { 0, output_6934, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_mulvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6935 },
#else
    { 0, output_6935, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_mulxvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6936 },
#else
    { 0, output_6936, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_subvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6937 },
#else
    { 0, output_6937, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_addvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6938 },
#else
    { 0, output_6938, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_divvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6939 },
#else
    { 0, output_6939, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_fmax_nanvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6940 },
#else
    { 0, output_6940, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_smaxvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6941 },
#else
    { 0, output_6941, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_fmin_nanvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6942 },
#else
    { 0, output_6942, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_sminvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6943 },
#else
    { 0, output_6943, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_mulvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6944 },
#else
    { 0, output_6944, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_mulxvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6945 },
#else
    { 0, output_6945, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5121 */
  {
    "*cond_subvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6946 },
#else
    { 0, output_6946, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_fmax_nanvnx8hf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6947 },
#else
    { 0, output_6947, 0 },
#endif
    { 0 },
    &operand_data[10393],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_smaxvnx8hf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6948 },
#else
    { 0, output_6948, 0 },
#endif
    { 0 },
    &operand_data[10393],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_fmin_nanvnx8hf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6949 },
#else
    { 0, output_6949, 0 },
#endif
    { 0 },
    &operand_data[10393],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_sminvnx8hf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6950 },
#else
    { 0, output_6950, 0 },
#endif
    { 0 },
    &operand_data[10393],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_mulvnx8hf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6951 },
#else
    { 0, output_6951, 0 },
#endif
    { 0 },
    &operand_data[10398],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_fmax_nanvnx4sf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6952 },
#else
    { 0, output_6952, 0 },
#endif
    { 0 },
    &operand_data[10403],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_smaxvnx4sf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6953 },
#else
    { 0, output_6953, 0 },
#endif
    { 0 },
    &operand_data[10403],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_fmin_nanvnx4sf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6954 },
#else
    { 0, output_6954, 0 },
#endif
    { 0 },
    &operand_data[10403],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_sminvnx4sf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6955 },
#else
    { 0, output_6955, 0 },
#endif
    { 0 },
    &operand_data[10403],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_mulvnx4sf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6956 },
#else
    { 0, output_6956, 0 },
#endif
    { 0 },
    &operand_data[10408],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_fmax_nanvnx2df_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6957 },
#else
    { 0, output_6957, 0 },
#endif
    { 0 },
    &operand_data[10413],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_smaxvnx2df_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6958 },
#else
    { 0, output_6958, 0 },
#endif
    { 0 },
    &operand_data[10413],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_fmin_nanvnx2df_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6959 },
#else
    { 0, output_6959, 0 },
#endif
    { 0 },
    &operand_data[10413],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_sminvnx2df_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6960 },
#else
    { 0, output_6960, 0 },
#endif
    { 0 },
    &operand_data[10413],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5141 */
  {
    "*cond_mulvnx2df_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6961 },
#else
    { 0, output_6961, 0 },
#endif
    { 0 },
    &operand_data[10418],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_fmax_nanvnx8hf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6962 },
#else
    { 0, output_6962, 0 },
#endif
    { 0 },
    &operand_data[10393],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_smaxvnx8hf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6963 },
#else
    { 0, output_6963, 0 },
#endif
    { 0 },
    &operand_data[10393],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_fmin_nanvnx8hf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6964 },
#else
    { 0, output_6964, 0 },
#endif
    { 0 },
    &operand_data[10393],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_sminvnx8hf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6965 },
#else
    { 0, output_6965, 0 },
#endif
    { 0 },
    &operand_data[10393],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_mulvnx8hf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6966 },
#else
    { 0, output_6966, 0 },
#endif
    { 0 },
    &operand_data[10398],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_fmax_nanvnx4sf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6967 },
#else
    { 0, output_6967, 0 },
#endif
    { 0 },
    &operand_data[10403],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_smaxvnx4sf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6968 },
#else
    { 0, output_6968, 0 },
#endif
    { 0 },
    &operand_data[10403],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_fmin_nanvnx4sf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6969 },
#else
    { 0, output_6969, 0 },
#endif
    { 0 },
    &operand_data[10403],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_sminvnx4sf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6970 },
#else
    { 0, output_6970, 0 },
#endif
    { 0 },
    &operand_data[10403],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_mulvnx4sf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6971 },
#else
    { 0, output_6971, 0 },
#endif
    { 0 },
    &operand_data[10408],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_fmax_nanvnx2df_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6972 },
#else
    { 0, output_6972, 0 },
#endif
    { 0 },
    &operand_data[10413],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_smaxvnx2df_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6973 },
#else
    { 0, output_6973, 0 },
#endif
    { 0 },
    &operand_data[10413],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_fmin_nanvnx2df_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6974 },
#else
    { 0, output_6974, 0 },
#endif
    { 0 },
    &operand_data[10413],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_sminvnx2df_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6975 },
#else
    { 0, output_6975, 0 },
#endif
    { 0 },
    &operand_data[10413],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5164 */
  {
    "*cond_mulvnx2df_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6976 },
#else
    { 0, output_6976, 0 },
#endif
    { 0 },
    &operand_data[10418],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_addvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6977 },
#else
    { 0, output_6977, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_divvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6978 },
#else
    { 0, output_6978, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_fmax_nanvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6979 },
#else
    { 0, output_6979, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_smaxvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6980 },
#else
    { 0, output_6980, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_fmin_nanvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6981 },
#else
    { 0, output_6981, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_sminvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6982 },
#else
    { 0, output_6982, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_mulvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6983 },
#else
    { 0, output_6983, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_mulxvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6984 },
#else
    { 0, output_6984, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_subvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6985 },
#else
    { 0, output_6985, 0 },
#endif
    { 0 },
    &operand_data[10423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_addvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6986 },
#else
    { 0, output_6986, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_divvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6987 },
#else
    { 0, output_6987, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_fmax_nanvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6988 },
#else
    { 0, output_6988, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_smaxvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6989 },
#else
    { 0, output_6989, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_fmin_nanvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6990 },
#else
    { 0, output_6990, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_sminvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6991 },
#else
    { 0, output_6991, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_mulvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6992 },
#else
    { 0, output_6992, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_mulxvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6993 },
#else
    { 0, output_6993, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_subvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6994 },
#else
    { 0, output_6994, 0 },
#endif
    { 0 },
    &operand_data[10428],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_addvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6995 },
#else
    { 0, output_6995, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_divvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6996 },
#else
    { 0, output_6996, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_fmax_nanvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6997 },
#else
    { 0, output_6997, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_smaxvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6998 },
#else
    { 0, output_6998, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_fmin_nanvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_6999 },
#else
    { 0, output_6999, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_sminvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7000 },
#else
    { 0, output_7000, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_mulvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7001 },
#else
    { 0, output_7001, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_mulxvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7002 },
#else
    { 0, output_7002, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5184 */
  {
    "*cond_subvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7003 },
#else
    { 0, output_7003, 0 },
#endif
    { 0 },
    &operand_data[10433],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_addvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7004 },
#else
    { 0, output_7004, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_divvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7005 },
#else
    { 0, output_7005, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_fmax_nanvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7006 },
#else
    { 0, output_7006, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_smaxvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7007 },
#else
    { 0, output_7007, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_fmin_nanvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7008 },
#else
    { 0, output_7008, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_sminvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7009 },
#else
    { 0, output_7009, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_mulvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7010 },
#else
    { 0, output_7010, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_mulxvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7011 },
#else
    { 0, output_7011, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_subvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7012 },
#else
    { 0, output_7012, 0 },
#endif
    { 0 },
    &operand_data[10423],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_addvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7013 },
#else
    { 0, output_7013, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_divvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7014 },
#else
    { 0, output_7014, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_fmax_nanvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7015 },
#else
    { 0, output_7015, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_smaxvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7016 },
#else
    { 0, output_7016, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_fmin_nanvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7017 },
#else
    { 0, output_7017, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_sminvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7018 },
#else
    { 0, output_7018, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_mulvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7019 },
#else
    { 0, output_7019, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_mulxvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7020 },
#else
    { 0, output_7020, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_subvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7021 },
#else
    { 0, output_7021, 0 },
#endif
    { 0 },
    &operand_data[10428],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_addvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7022 },
#else
    { 0, output_7022, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_divvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7023 },
#else
    { 0, output_7023, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_fmax_nanvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7024 },
#else
    { 0, output_7024, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_smaxvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7025 },
#else
    { 0, output_7025, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_fmin_nanvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7026 },
#else
    { 0, output_7026, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_sminvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7027 },
#else
    { 0, output_7027, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_mulvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7028 },
#else
    { 0, output_7028, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_mulxvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7029 },
#else
    { 0, output_7029, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5207 */
  {
    "*cond_subvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7030 },
#else
    { 0, output_7030, 0 },
#endif
    { 0 },
    &operand_data[10433],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_addvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7031 },
#else
    { 0, output_7031, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_divvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7032 },
#else
    { 0, output_7032, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_fmax_nanvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7033 },
#else
    { 0, output_7033, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_smaxvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7034 },
#else
    { 0, output_7034, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_fmin_nanvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7035 },
#else
    { 0, output_7035, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_sminvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7036 },
#else
    { 0, output_7036, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_mulvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7037 },
#else
    { 0, output_7037, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_mulxvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7038 },
#else
    { 0, output_7038, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_subvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7039 },
#else
    { 0, output_7039, 0 },
#endif
    { 0 },
    &operand_data[10438],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_addvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7040 },
#else
    { 0, output_7040, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_divvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7041 },
#else
    { 0, output_7041, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_fmax_nanvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7042 },
#else
    { 0, output_7042, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_smaxvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7043 },
#else
    { 0, output_7043, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_fmin_nanvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7044 },
#else
    { 0, output_7044, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_sminvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7045 },
#else
    { 0, output_7045, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_mulvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7046 },
#else
    { 0, output_7046, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_mulxvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7047 },
#else
    { 0, output_7047, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_subvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7048 },
#else
    { 0, output_7048, 0 },
#endif
    { 0 },
    &operand_data[10444],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_addvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7049 },
#else
    { 0, output_7049, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_divvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7050 },
#else
    { 0, output_7050, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_fmax_nanvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7051 },
#else
    { 0, output_7051, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_smaxvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7052 },
#else
    { 0, output_7052, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_fmin_nanvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7053 },
#else
    { 0, output_7053, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_sminvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7054 },
#else
    { 0, output_7054, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_mulvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7055 },
#else
    { 0, output_7055, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_mulxvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7056 },
#else
    { 0, output_7056, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5227 */
  {
    "*cond_subvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7057 },
#else
    { 0, output_7057, 0 },
#endif
    { 0 },
    &operand_data[10450],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_addvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7058 },
#else
    { 0, output_7058, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_divvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7059 },
#else
    { 0, output_7059, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_fmax_nanvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7060 },
#else
    { 0, output_7060, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_smaxvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7061 },
#else
    { 0, output_7061, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_fmin_nanvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7062 },
#else
    { 0, output_7062, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_sminvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7063 },
#else
    { 0, output_7063, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_mulvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7064 },
#else
    { 0, output_7064, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_mulxvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7065 },
#else
    { 0, output_7065, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_subvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7066 },
#else
    { 0, output_7066, 0 },
#endif
    { 0 },
    &operand_data[10438],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_addvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7067 },
#else
    { 0, output_7067, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_divvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7068 },
#else
    { 0, output_7068, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_fmax_nanvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7069 },
#else
    { 0, output_7069, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_smaxvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7070 },
#else
    { 0, output_7070, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_fmin_nanvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7071 },
#else
    { 0, output_7071, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_sminvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7072 },
#else
    { 0, output_7072, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_mulvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7073 },
#else
    { 0, output_7073, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_mulxvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7074 },
#else
    { 0, output_7074, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_subvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7075 },
#else
    { 0, output_7075, 0 },
#endif
    { 0 },
    &operand_data[10444],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_addvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7076 },
#else
    { 0, output_7076, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_divvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7077 },
#else
    { 0, output_7077, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_fmax_nanvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7078 },
#else
    { 0, output_7078, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_smaxvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7079 },
#else
    { 0, output_7079, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_fmin_nanvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7080 },
#else
    { 0, output_7080, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_sminvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7081 },
#else
    { 0, output_7081, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_mulvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7082 },
#else
    { 0, output_7082, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_mulxvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7083 },
#else
    { 0, output_7083, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5266 */
  {
    "*cond_subvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7084 },
#else
    { 0, output_7084, 0 },
#endif
    { 0 },
    &operand_data[10450],
    5,
    5,
    1,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_fmax_nanvnx8hf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7085 },
#else
    { 0, output_7085, 0 },
#endif
    { 0 },
    &operand_data[10456],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_smaxvnx8hf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7086 },
#else
    { 0, output_7086, 0 },
#endif
    { 0 },
    &operand_data[10456],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_fmin_nanvnx8hf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7087 },
#else
    { 0, output_7087, 0 },
#endif
    { 0 },
    &operand_data[10456],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_sminvnx8hf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7088 },
#else
    { 0, output_7088, 0 },
#endif
    { 0 },
    &operand_data[10456],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_mulvnx8hf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7089 },
#else
    { 0, output_7089, 0 },
#endif
    { 0 },
    &operand_data[10462],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_fmax_nanvnx4sf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7090 },
#else
    { 0, output_7090, 0 },
#endif
    { 0 },
    &operand_data[10468],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_smaxvnx4sf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7091 },
#else
    { 0, output_7091, 0 },
#endif
    { 0 },
    &operand_data[10468],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_fmin_nanvnx4sf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7092 },
#else
    { 0, output_7092, 0 },
#endif
    { 0 },
    &operand_data[10468],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_sminvnx4sf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7093 },
#else
    { 0, output_7093, 0 },
#endif
    { 0 },
    &operand_data[10468],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_mulvnx4sf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7094 },
#else
    { 0, output_7094, 0 },
#endif
    { 0 },
    &operand_data[10474],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_fmax_nanvnx2df_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7095 },
#else
    { 0, output_7095, 0 },
#endif
    { 0 },
    &operand_data[10480],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_smaxvnx2df_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7096 },
#else
    { 0, output_7096, 0 },
#endif
    { 0 },
    &operand_data[10480],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_fmin_nanvnx2df_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7097 },
#else
    { 0, output_7097, 0 },
#endif
    { 0 },
    &operand_data[10480],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_sminvnx2df_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7098 },
#else
    { 0, output_7098, 0 },
#endif
    { 0 },
    &operand_data[10480],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5299 */
  {
    "*cond_mulvnx2df_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7099 },
#else
    { 0, output_7099, 0 },
#endif
    { 0 },
    &operand_data[10486],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_fmax_nanvnx8hf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7100 },
#else
    { 0, output_7100, 0 },
#endif
    { 0 },
    &operand_data[10456],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_smaxvnx8hf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7101 },
#else
    { 0, output_7101, 0 },
#endif
    { 0 },
    &operand_data[10456],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_fmin_nanvnx8hf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7102 },
#else
    { 0, output_7102, 0 },
#endif
    { 0 },
    &operand_data[10456],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_sminvnx8hf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7103 },
#else
    { 0, output_7103, 0 },
#endif
    { 0 },
    &operand_data[10456],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_mulvnx8hf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7104 },
#else
    { 0, output_7104, 0 },
#endif
    { 0 },
    &operand_data[10462],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_fmax_nanvnx4sf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7105 },
#else
    { 0, output_7105, 0 },
#endif
    { 0 },
    &operand_data[10468],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_smaxvnx4sf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7106 },
#else
    { 0, output_7106, 0 },
#endif
    { 0 },
    &operand_data[10468],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_fmin_nanvnx4sf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7107 },
#else
    { 0, output_7107, 0 },
#endif
    { 0 },
    &operand_data[10468],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_sminvnx4sf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7108 },
#else
    { 0, output_7108, 0 },
#endif
    { 0 },
    &operand_data[10468],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_mulvnx4sf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7109 },
#else
    { 0, output_7109, 0 },
#endif
    { 0 },
    &operand_data[10474],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_fmax_nanvnx2df_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7110 },
#else
    { 0, output_7110, 0 },
#endif
    { 0 },
    &operand_data[10480],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_smaxvnx2df_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7111 },
#else
    { 0, output_7111, 0 },
#endif
    { 0 },
    &operand_data[10480],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_fmin_nanvnx2df_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7112 },
#else
    { 0, output_7112, 0 },
#endif
    { 0 },
    &operand_data[10480],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_sminvnx2df_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7113 },
#else
    { 0, output_7113, 0 },
#endif
    { 0 },
    &operand_data[10480],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5334 */
  {
    "*cond_mulvnx2df_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7114 },
#else
    { 0, output_7114, 0 },
#endif
    { 0 },
    &operand_data[10486],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5371 */
  {
    "aarch64_pred_addvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7115 },
#else
    { 0, output_7115, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_addvnx8hf },
    &operand_data[10492],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5371 */
  {
    "aarch64_pred_addvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7116 },
#else
    { 0, output_7116, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_addvnx4sf },
    &operand_data[10497],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5371 */
  {
    "aarch64_pred_addvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7117 },
#else
    { 0, output_7117, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_addvnx2df },
    &operand_data[10502],
    5,
    5,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5400 */
  {
    "*cond_addvnx8hf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7118 },
#else
    { 0, output_7118, 0 },
#endif
    { 0 },
    &operand_data[10507],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5400 */
  {
    "*cond_addvnx4sf_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7119 },
#else
    { 0, output_7119, 0 },
#endif
    { 0 },
    &operand_data[10512],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5400 */
  {
    "*cond_addvnx2df_2_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7120 },
#else
    { 0, output_7120, 0 },
#endif
    { 0 },
    &operand_data[10517],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5425 */
  {
    "*cond_addvnx8hf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7121 },
#else
    { 0, output_7121, 0 },
#endif
    { 0 },
    &operand_data[10507],
    4,
    4,
    2,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5425 */
  {
    "*cond_addvnx4sf_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7122 },
#else
    { 0, output_7122, 0 },
#endif
    { 0 },
    &operand_data[10512],
    4,
    4,
    2,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5425 */
  {
    "*cond_addvnx2df_2_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7123 },
#else
    { 0, output_7123, 0 },
#endif
    { 0 },
    &operand_data[10517],
    4,
    4,
    2,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5448 */
  {
    "*cond_addvnx8hf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7124 },
#else
    { 0, output_7124, 0 },
#endif
    { 0 },
    &operand_data[10522],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5448 */
  {
    "*cond_addvnx4sf_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7125 },
#else
    { 0, output_7125, 0 },
#endif
    { 0 },
    &operand_data[10528],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5448 */
  {
    "*cond_addvnx2df_any_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7126 },
#else
    { 0, output_7126, 0 },
#endif
    { 0 },
    &operand_data[10534],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5486 */
  {
    "*cond_addvnx8hf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7127 },
#else
    { 0, output_7127, 0 },
#endif
    { 0 },
    &operand_data[10522],
    5,
    5,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5486 */
  {
    "*cond_addvnx4sf_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7128 },
#else
    { 0, output_7128, 0 },
#endif
    { 0 },
    &operand_data[10528],
    5,
    5,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5486 */
  {
    "*cond_addvnx2df_any_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7129 },
#else
    { 0, output_7129, 0 },
#endif
    { 0 },
    &operand_data[10534],
    5,
    5,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5527 */
  {
    "aarch64_pred_cadd90vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7130 },
#else
    { 0, output_7130, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cadd90vnx8hf },
    &operand_data[10540],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5527 */
  {
    "aarch64_pred_cadd270vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7131 },
#else
    { 0, output_7131, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cadd270vnx8hf },
    &operand_data[10540],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5527 */
  {
    "aarch64_pred_cadd90vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7132 },
#else
    { 0, output_7132, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cadd90vnx4sf },
    &operand_data[10545],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5527 */
  {
    "aarch64_pred_cadd270vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7133 },
#else
    { 0, output_7133, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cadd270vnx4sf },
    &operand_data[10545],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5527 */
  {
    "aarch64_pred_cadd90vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7134 },
#else
    { 0, output_7134, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cadd90vnx2df },
    &operand_data[10550],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5527 */
  {
    "aarch64_pred_cadd270vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7135 },
#else
    { 0, output_7135, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cadd270vnx2df },
    &operand_data[10550],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5573 */
  {
    "*cond_cadd90vnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7136 },
#else
    { 0, output_7136, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5573 */
  {
    "*cond_cadd270vnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7137 },
#else
    { 0, output_7137, 0 },
#endif
    { 0 },
    &operand_data[10378],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5573 */
  {
    "*cond_cadd90vnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7138 },
#else
    { 0, output_7138, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5573 */
  {
    "*cond_cadd270vnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7139 },
#else
    { 0, output_7139, 0 },
#endif
    { 0 },
    &operand_data[10383],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5573 */
  {
    "*cond_cadd90vnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7140 },
#else
    { 0, output_7140, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5573 */
  {
    "*cond_cadd270vnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7141 },
#else
    { 0, output_7141, 0 },
#endif
    { 0 },
    &operand_data[10388],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5596 */
  {
    "*cond_cadd90vnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7142 },
#else
    { 0, output_7142, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5596 */
  {
    "*cond_cadd270vnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7143 },
#else
    { 0, output_7143, 0 },
#endif
    { 0 },
    &operand_data[10378],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5596 */
  {
    "*cond_cadd90vnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7144 },
#else
    { 0, output_7144, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5596 */
  {
    "*cond_cadd270vnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7145 },
#else
    { 0, output_7145, 0 },
#endif
    { 0 },
    &operand_data[10383],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5596 */
  {
    "*cond_cadd90vnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7146 },
#else
    { 0, output_7146, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5596 */
  {
    "*cond_cadd270vnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7147 },
#else
    { 0, output_7147, 0 },
#endif
    { 0 },
    &operand_data[10388],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5616 */
  {
    "*cond_cadd90vnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7148 },
#else
    { 0, output_7148, 0 },
#endif
    { 0 },
    &operand_data[10555],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5616 */
  {
    "*cond_cadd270vnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7149 },
#else
    { 0, output_7149, 0 },
#endif
    { 0 },
    &operand_data[10555],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5616 */
  {
    "*cond_cadd90vnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7150 },
#else
    { 0, output_7150, 0 },
#endif
    { 0 },
    &operand_data[10561],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5616 */
  {
    "*cond_cadd270vnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7151 },
#else
    { 0, output_7151, 0 },
#endif
    { 0 },
    &operand_data[10561],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5616 */
  {
    "*cond_cadd90vnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7152 },
#else
    { 0, output_7152, 0 },
#endif
    { 0 },
    &operand_data[10567],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5616 */
  {
    "*cond_cadd270vnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7153 },
#else
    { 0, output_7153, 0 },
#endif
    { 0 },
    &operand_data[10567],
    6,
    6,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5652 */
  {
    "*cond_cadd90vnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7154 },
#else
    { 0, output_7154, 0 },
#endif
    { 0 },
    &operand_data[10555],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5652 */
  {
    "*cond_cadd270vnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7155 },
#else
    { 0, output_7155, 0 },
#endif
    { 0 },
    &operand_data[10555],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5652 */
  {
    "*cond_cadd90vnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7156 },
#else
    { 0, output_7156, 0 },
#endif
    { 0 },
    &operand_data[10561],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5652 */
  {
    "*cond_cadd270vnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7157 },
#else
    { 0, output_7157, 0 },
#endif
    { 0 },
    &operand_data[10561],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5652 */
  {
    "*cond_cadd90vnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7158 },
#else
    { 0, output_7158, 0 },
#endif
    { 0 },
    &operand_data[10567],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5652 */
  {
    "*cond_cadd270vnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7159 },
#else
    { 0, output_7159, 0 },
#endif
    { 0 },
    &operand_data[10567],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5690 */
  {
    "aarch64_pred_subvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7160 },
#else
    { 0, output_7160, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_subvnx8hf },
    &operand_data[10573],
    5,
    5,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5690 */
  {
    "aarch64_pred_subvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7161 },
#else
    { 0, output_7161, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_subvnx4sf },
    &operand_data[10578],
    5,
    5,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5690 */
  {
    "aarch64_pred_subvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7162 },
#else
    { 0, output_7162, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_subvnx2df },
    &operand_data[10583],
    5,
    5,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5718 */
  {
    "*cond_subvnx8hf_3_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7163 },
#else
    { 0, output_7163, 0 },
#endif
    { 0 },
    &operand_data[10588],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5718 */
  {
    "*cond_subvnx4sf_3_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7164 },
#else
    { 0, output_7164, 0 },
#endif
    { 0 },
    &operand_data[10593],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5718 */
  {
    "*cond_subvnx2df_3_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7165 },
#else
    { 0, output_7165, 0 },
#endif
    { 0 },
    &operand_data[10598],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5741 */
  {
    "*cond_subvnx8hf_3_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7166 },
#else
    { 0, output_7166, 0 },
#endif
    { 0 },
    &operand_data[10588],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5741 */
  {
    "*cond_subvnx4sf_3_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7167 },
#else
    { 0, output_7167, 0 },
#endif
    { 0 },
    &operand_data[10593],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5741 */
  {
    "*cond_subvnx2df_3_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7168 },
#else
    { 0, output_7168, 0 },
#endif
    { 0 },
    &operand_data[10598],
    4,
    4,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5762 */
  {
    "*cond_subvnx8hf_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7169 },
#else
    { 0, output_7169, 0 },
#endif
    { 0 },
    &operand_data[10603],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5762 */
  {
    "*cond_subvnx4sf_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7170 },
#else
    { 0, output_7170, 0 },
#endif
    { 0 },
    &operand_data[10609],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5762 */
  {
    "*cond_subvnx2df_const_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7171 },
#else
    { 0, output_7171, 0 },
#endif
    { 0 },
    &operand_data[10615],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5797 */
  {
    "*cond_subvnx8hf_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7172 },
#else
    { 0, output_7172, 0 },
#endif
    { 0 },
    &operand_data[10603],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5797 */
  {
    "*cond_subvnx4sf_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7173 },
#else
    { 0, output_7173, 0 },
#endif
    { 0 },
    &operand_data[10609],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5797 */
  {
    "*cond_subvnx2df_const_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7174 },
#else
    { 0, output_7174, 0 },
#endif
    { 0 },
    &operand_data[10615],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5850 */
  {
    "*aarch64_pred_abdvnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7175 },
#else
    { 0, output_7175, 0 },
#endif
    { 0 },
    &operand_data[10621],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5850 */
  {
    "*aarch64_pred_abdvnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7176 },
#else
    { 0, output_7176, 0 },
#endif
    { 0 },
    &operand_data[10627],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5850 */
  {
    "*aarch64_pred_abdvnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7177 },
#else
    { 0, output_7177, 0 },
#endif
    { 0 },
    &operand_data[10633],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5873 */
  {
    "*aarch64_pred_abdvnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7178 },
#else
    { 0, output_7178, 0 },
#endif
    { 0 },
    &operand_data[10621],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5873 */
  {
    "*aarch64_pred_abdvnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7179 },
#else
    { 0, output_7179, 0 },
#endif
    { 0 },
    &operand_data[10627],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5873 */
  {
    "*aarch64_pred_abdvnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7180 },
#else
    { 0, output_7180, 0 },
#endif
    { 0 },
    &operand_data[10633],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5916 */
  {
    "*aarch64_cond_abdvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7181 },
#else
    { 0, output_7181, 0 },
#endif
    { 0 },
    &operand_data[10639],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5916 */
  {
    "*aarch64_cond_abdvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7182 },
#else
    { 0, output_7182, 0 },
#endif
    { 0 },
    &operand_data[10645],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5916 */
  {
    "*aarch64_cond_abdvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7183 },
#else
    { 0, output_7183, 0 },
#endif
    { 0 },
    &operand_data[10651],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5945 */
  {
    "*aarch64_cond_abdvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7184 },
#else
    { 0, output_7184, 0 },
#endif
    { 0 },
    &operand_data[10657],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5945 */
  {
    "*aarch64_cond_abdvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7185 },
#else
    { 0, output_7185, 0 },
#endif
    { 0 },
    &operand_data[10663],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5945 */
  {
    "*aarch64_cond_abdvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7186 },
#else
    { 0, output_7186, 0 },
#endif
    { 0 },
    &operand_data[10669],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5970 */
  {
    "*aarch64_cond_abdvnx8hf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7187 },
#else
    { 0, output_7187, 0 },
#endif
    { 0 },
    &operand_data[10675],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5970 */
  {
    "*aarch64_cond_abdvnx4sf_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7188 },
#else
    { 0, output_7188, 0 },
#endif
    { 0 },
    &operand_data[10681],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5970 */
  {
    "*aarch64_cond_abdvnx2df_3_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7189 },
#else
    { 0, output_7189, 0 },
#endif
    { 0 },
    &operand_data[10687],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5999 */
  {
    "*aarch64_cond_abdvnx8hf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7190 },
#else
    { 0, output_7190, 0 },
#endif
    { 0 },
    &operand_data[10693],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5999 */
  {
    "*aarch64_cond_abdvnx4sf_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7191 },
#else
    { 0, output_7191, 0 },
#endif
    { 0 },
    &operand_data[10699],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5999 */
  {
    "*aarch64_cond_abdvnx2df_3_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7192 },
#else
    { 0, output_7192, 0 },
#endif
    { 0 },
    &operand_data[10705],
    6,
    6,
    3,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6024 */
  {
    "*aarch64_cond_abdvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7193 },
#else
    { 0, output_7193, 0 },
#endif
    { 0 },
    &operand_data[10711],
    7,
    7,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6024 */
  {
    "*aarch64_cond_abdvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7194 },
#else
    { 0, output_7194, 0 },
#endif
    { 0 },
    &operand_data[10718],
    7,
    7,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6024 */
  {
    "*aarch64_cond_abdvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7195 },
#else
    { 0, output_7195, 0 },
#endif
    { 0 },
    &operand_data[10725],
    7,
    7,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6071 */
  {
    "*aarch64_cond_abdvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7196 },
#else
    { 0, output_7196, 0 },
#endif
    { 0 },
    &operand_data[10732],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6071 */
  {
    "*aarch64_cond_abdvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7197 },
#else
    { 0, output_7197, 0 },
#endif
    { 0 },
    &operand_data[10739],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6071 */
  {
    "*aarch64_cond_abdvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7198 },
#else
    { 0, output_7198, 0 },
#endif
    { 0 },
    &operand_data[10746],
    7,
    7,
    2,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6115 */
  {
    "aarch64_pred_mulvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7199 },
#else
    { 0, output_7199, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx8hf },
    &operand_data[10753],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6115 */
  {
    "aarch64_pred_mulvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7200 },
#else
    { 0, output_7200, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx4sf },
    &operand_data[10758],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6115 */
  {
    "aarch64_pred_mulvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7201 },
#else
    { 0, output_7201, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_mulvnx2df },
    &operand_data[10763],
    5,
    5,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6144 */
  {
    "aarch64_mul_lane_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.h, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mul_lane_vnx8hf },
    &operand_data[10768],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6144 */
  {
    "aarch64_mul_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.s, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mul_lane_vnx4sf },
    &operand_data[10772],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6144 */
  {
    "aarch64_mul_lane_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmul\t%0.d, %1.d, %2.d[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mul_lane_vnx2df },
    &operand_data[10776],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*andvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*iorvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*xorvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*andvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*iorvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*xorvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*andvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*iorvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6209 */
  {
    "*xorvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_fmax_nanvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7214 },
#else
    { 0, output_7214, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmax_nanvnx8hf },
    &operand_data[10780],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_smaxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7215 },
#else
    { 0, output_7215, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx8hf },
    &operand_data[10780],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_fmin_nanvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7216 },
#else
    { 0, output_7216, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmin_nanvnx8hf },
    &operand_data[10780],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_sminvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7217 },
#else
    { 0, output_7217, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx8hf },
    &operand_data[10780],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_fmax_nanvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7218 },
#else
    { 0, output_7218, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmax_nanvnx4sf },
    &operand_data[10785],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_smaxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7219 },
#else
    { 0, output_7219, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx4sf },
    &operand_data[10785],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_fmin_nanvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7220 },
#else
    { 0, output_7220, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmin_nanvnx4sf },
    &operand_data[10785],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_sminvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7221 },
#else
    { 0, output_7221, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx4sf },
    &operand_data[10785],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_fmax_nanvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7222 },
#else
    { 0, output_7222, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmax_nanvnx2df },
    &operand_data[10790],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_smaxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7223 },
#else
    { 0, output_7223, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxvnx2df },
    &operand_data[10790],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_fmin_nanvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7224 },
#else
    { 0, output_7224, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmin_nanvnx2df },
    &operand_data[10790],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6323 */
  {
    "aarch64_pred_sminvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7225 },
#else
    { 0, output_7225, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminvnx2df },
    &operand_data[10790],
    5,
    5,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6358 */
  {
    "andvnx16bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx16bi3 },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6358 */
  {
    "andvnx8bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx8bi3 },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6358 */
  {
    "andvnx4bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx4bi3 },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6358 */
  {
    "andvnx2bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_andvnx2bi3 },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_andvnx16bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_andvnx16bi_z },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_iorvnx16bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_iorvnx16bi_z },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_xorvnx16bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_xorvnx16bi_z },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_andvnx8bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_andvnx8bi_z },
    &operand_data[10799],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_iorvnx8bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_iorvnx8bi_z },
    &operand_data[10799],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_xorvnx8bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_xorvnx8bi_z },
    &operand_data[10799],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_andvnx4bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_andvnx4bi_z },
    &operand_data[10803],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_iorvnx4bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_iorvnx4bi_z },
    &operand_data[10803],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_xorvnx4bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_xorvnx4bi_z },
    &operand_data[10803],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_andvnx2bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "and\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_andvnx2bi_z },
    &operand_data[10807],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_iorvnx2bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orr\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_iorvnx2bi_z },
    &operand_data[10807],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6381 */
  {
    "aarch64_pred_xorvnx2bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_xorvnx2bi_z },
    &operand_data[10807],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*andvnx16bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10811],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*iorvnx16bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10811],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*xorvnx16bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10811],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*andvnx8bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10817],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*iorvnx8bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10817],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*xorvnx8bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10817],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*andvnx4bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10823],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*iorvnx4bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10823],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*xorvnx4bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10823],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*andvnx2bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10829],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*iorvnx2bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10829],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6395 */
  {
    "*xorvnx2bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10829],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*andvnx16bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10835],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*iorvnx16bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10835],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*xorvnx16bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10835],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*andvnx8bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10841],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*iorvnx8bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10841],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*xorvnx8bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10841],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*andvnx4bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10847],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*iorvnx4bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10847],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*xorvnx4bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10847],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*andvnx2bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10853],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*iorvnx2bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orrs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10853],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6415 */
  {
    "*xorvnx2bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10853],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_bicvnx16bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_bicvnx16bi_z },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_ornvnx16bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ornvnx16bi_z },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_bicvnx8bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_bicvnx8bi_z },
    &operand_data[10799],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_ornvnx8bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ornvnx8bi_z },
    &operand_data[10799],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_bicvnx4bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_bicvnx4bi_z },
    &operand_data[10803],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_ornvnx4bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ornvnx4bi_z },
    &operand_data[10803],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_bicvnx2bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bic\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_bicvnx2bi_z },
    &operand_data[10807],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6441 */
  {
    "aarch64_pred_ornvnx2bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orn\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ornvnx2bi_z },
    &operand_data[10807],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*bicvnx16bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10811],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*ornvnx16bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10811],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*bicvnx8bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10817],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*ornvnx8bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10817],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*bicvnx4bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10823],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*ornvnx4bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10823],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*bicvnx2bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10829],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6453 */
  {
    "*ornvnx2bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10829],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*bicvnx16bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10835],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*ornvnx16bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10835],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*bicvnx8bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10841],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*ornvnx8bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10841],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*bicvnx4bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10847],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*ornvnx4bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10847],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*bicvnx2bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bics\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10853],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6476 */
  {
    "*ornvnx2bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orns\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10853],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_norvnx16bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_norvnx16bi_z },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_nandvnx16bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nand\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nandvnx16bi_z },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_norvnx8bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_norvnx8bi_z },
    &operand_data[10799],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_nandvnx8bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nand\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nandvnx8bi_z },
    &operand_data[10799],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_norvnx4bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_norvnx4bi_z },
    &operand_data[10803],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_nandvnx4bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nand\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nandvnx4bi_z },
    &operand_data[10803],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_norvnx2bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nor\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_norvnx2bi_z },
    &operand_data[10807],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6503 */
  {
    "aarch64_pred_nandvnx2bi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nand\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nandvnx2bi_z },
    &operand_data[10807],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*norvnx16bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10811],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*nandvnx16bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10811],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*norvnx8bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10817],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*nandvnx8bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10817],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*norvnx4bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10823],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*nandvnx4bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10823],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*norvnx2bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10829],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6515 */
  {
    "*nandvnx2bi3_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10829],
    6,
    6,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*norvnx16bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10835],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*nandvnx16bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10835],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*norvnx8bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10841],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*nandvnx8bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10841],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*norvnx4bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10847],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*nandvnx4bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10847],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*norvnx2bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nors\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10853],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6539 */
  {
    "*nandvnx2bi3_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nands\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[10853],
    6,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7314 },
#else
    { 0, output_7314, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx16qi },
    &operand_data[10859],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7315 },
#else
    { 0, output_7315, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx8qi },
    &operand_data[10864],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7316 },
#else
    { 0, output_7316, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx4qi },
    &operand_data[10869],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7317 },
#else
    { 0, output_7317, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx2qi },
    &operand_data[10874],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7318 },
#else
    { 0, output_7318, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx8hi },
    &operand_data[10879],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7319 },
#else
    { 0, output_7319, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx4hi },
    &operand_data[10884],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7320 },
#else
    { 0, output_7320, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx2hi },
    &operand_data[10889],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7321 },
#else
    { 0, output_7321, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx4si },
    &operand_data[10894],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7322 },
#else
    { 0, output_7322, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx2si },
    &operand_data[10899],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6590 */
  {
    "aarch64_pred_fmavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7323 },
#else
    { 0, output_7323, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx2di },
    &operand_data[10904],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7324 },
#else
    { 0, output_7324, 0 },
#endif
    { 0 },
    &operand_data[10909],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7325 },
#else
    { 0, output_7325, 0 },
#endif
    { 0 },
    &operand_data[10914],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7326 },
#else
    { 0, output_7326, 0 },
#endif
    { 0 },
    &operand_data[10919],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7327 },
#else
    { 0, output_7327, 0 },
#endif
    { 0 },
    &operand_data[10924],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7328 },
#else
    { 0, output_7328, 0 },
#endif
    { 0 },
    &operand_data[10929],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7329 },
#else
    { 0, output_7329, 0 },
#endif
    { 0 },
    &operand_data[10934],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7330 },
#else
    { 0, output_7330, 0 },
#endif
    { 0 },
    &operand_data[10939],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7331 },
#else
    { 0, output_7331, 0 },
#endif
    { 0 },
    &operand_data[10944],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7332 },
#else
    { 0, output_7332, 0 },
#endif
    { 0 },
    &operand_data[10949],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6632 */
  {
    "*cond_fmavnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7333 },
#else
    { 0, output_7333, 0 },
#endif
    { 0 },
    &operand_data[10954],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx16qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7334 },
#else
    { 0, output_7334, 0 },
#endif
    { 0 },
    &operand_data[10959],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx8qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7335 },
#else
    { 0, output_7335, 0 },
#endif
    { 0 },
    &operand_data[10964],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx4qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7336 },
#else
    { 0, output_7336, 0 },
#endif
    { 0 },
    &operand_data[10969],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx2qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7337 },
#else
    { 0, output_7337, 0 },
#endif
    { 0 },
    &operand_data[10974],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx8hi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7338 },
#else
    { 0, output_7338, 0 },
#endif
    { 0 },
    &operand_data[10979],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx4hi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7339 },
#else
    { 0, output_7339, 0 },
#endif
    { 0 },
    &operand_data[10984],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx2hi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7340 },
#else
    { 0, output_7340, 0 },
#endif
    { 0 },
    &operand_data[10989],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx4si_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7341 },
#else
    { 0, output_7341, 0 },
#endif
    { 0 },
    &operand_data[10994],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx2si_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7342 },
#else
    { 0, output_7342, 0 },
#endif
    { 0 },
    &operand_data[10999],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6651 */
  {
    "*cond_fmavnx2di_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7343 },
#else
    { 0, output_7343, 0 },
#endif
    { 0 },
    &operand_data[11004],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7344 },
#else
    { 0, output_7344, 0 },
#endif
    { 0 },
    &operand_data[11009],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7345 },
#else
    { 0, output_7345, 0 },
#endif
    { 0 },
    &operand_data[11015],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7346 },
#else
    { 0, output_7346, 0 },
#endif
    { 0 },
    &operand_data[11021],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7347 },
#else
    { 0, output_7347, 0 },
#endif
    { 0 },
    &operand_data[11027],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7348 },
#else
    { 0, output_7348, 0 },
#endif
    { 0 },
    &operand_data[11033],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7349 },
#else
    { 0, output_7349, 0 },
#endif
    { 0 },
    &operand_data[11039],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7350 },
#else
    { 0, output_7350, 0 },
#endif
    { 0 },
    &operand_data[11045],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7351 },
#else
    { 0, output_7351, 0 },
#endif
    { 0 },
    &operand_data[11051],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7352 },
#else
    { 0, output_7352, 0 },
#endif
    { 0 },
    &operand_data[11057],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6670 */
  {
    "*cond_fmavnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7353 },
#else
    { 0, output_7353, 0 },
#endif
    { 0 },
    &operand_data[11063],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7354 },
#else
    { 0, output_7354, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx16qi },
    &operand_data[10859],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7355 },
#else
    { 0, output_7355, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx8qi },
    &operand_data[10864],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7356 },
#else
    { 0, output_7356, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx4qi },
    &operand_data[10869],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7357 },
#else
    { 0, output_7357, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx2qi },
    &operand_data[10874],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7358 },
#else
    { 0, output_7358, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx8hi },
    &operand_data[10879],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7359 },
#else
    { 0, output_7359, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx4hi },
    &operand_data[10884],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7360 },
#else
    { 0, output_7360, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx2hi },
    &operand_data[10889],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7361 },
#else
    { 0, output_7361, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx4si },
    &operand_data[10894],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7362 },
#else
    { 0, output_7362, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx2si },
    &operand_data[10899],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6731 */
  {
    "aarch64_pred_fnmavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7363 },
#else
    { 0, output_7363, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx2di },
    &operand_data[10904],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7364 },
#else
    { 0, output_7364, 0 },
#endif
    { 0 },
    &operand_data[10909],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx8qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7365 },
#else
    { 0, output_7365, 0 },
#endif
    { 0 },
    &operand_data[10914],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx4qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7366 },
#else
    { 0, output_7366, 0 },
#endif
    { 0 },
    &operand_data[10919],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx2qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7367 },
#else
    { 0, output_7367, 0 },
#endif
    { 0 },
    &operand_data[10924],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7368 },
#else
    { 0, output_7368, 0 },
#endif
    { 0 },
    &operand_data[10929],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx4hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7369 },
#else
    { 0, output_7369, 0 },
#endif
    { 0 },
    &operand_data[10934],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx2hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7370 },
#else
    { 0, output_7370, 0 },
#endif
    { 0 },
    &operand_data[10939],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7371 },
#else
    { 0, output_7371, 0 },
#endif
    { 0 },
    &operand_data[10944],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx2si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7372 },
#else
    { 0, output_7372, 0 },
#endif
    { 0 },
    &operand_data[10949],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6773 */
  {
    "*cond_fnmavnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7373 },
#else
    { 0, output_7373, 0 },
#endif
    { 0 },
    &operand_data[10954],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx16qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7374 },
#else
    { 0, output_7374, 0 },
#endif
    { 0 },
    &operand_data[10959],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx8qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7375 },
#else
    { 0, output_7375, 0 },
#endif
    { 0 },
    &operand_data[10964],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx4qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7376 },
#else
    { 0, output_7376, 0 },
#endif
    { 0 },
    &operand_data[10969],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx2qi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7377 },
#else
    { 0, output_7377, 0 },
#endif
    { 0 },
    &operand_data[10974],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx8hi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7378 },
#else
    { 0, output_7378, 0 },
#endif
    { 0 },
    &operand_data[10979],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx4hi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7379 },
#else
    { 0, output_7379, 0 },
#endif
    { 0 },
    &operand_data[10984],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx2hi_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7380 },
#else
    { 0, output_7380, 0 },
#endif
    { 0 },
    &operand_data[10989],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx4si_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7381 },
#else
    { 0, output_7381, 0 },
#endif
    { 0 },
    &operand_data[10994],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx2si_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7382 },
#else
    { 0, output_7382, 0 },
#endif
    { 0 },
    &operand_data[10999],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6792 */
  {
    "*cond_fnmavnx2di_4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7383 },
#else
    { 0, output_7383, 0 },
#endif
    { 0 },
    &operand_data[11004],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7384 },
#else
    { 0, output_7384, 0 },
#endif
    { 0 },
    &operand_data[11009],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx8qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7385 },
#else
    { 0, output_7385, 0 },
#endif
    { 0 },
    &operand_data[11015],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx4qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7386 },
#else
    { 0, output_7386, 0 },
#endif
    { 0 },
    &operand_data[11021],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx2qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7387 },
#else
    { 0, output_7387, 0 },
#endif
    { 0 },
    &operand_data[11027],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7388 },
#else
    { 0, output_7388, 0 },
#endif
    { 0 },
    &operand_data[11033],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx4hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7389 },
#else
    { 0, output_7389, 0 },
#endif
    { 0 },
    &operand_data[11039],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx2hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7390 },
#else
    { 0, output_7390, 0 },
#endif
    { 0 },
    &operand_data[11045],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7391 },
#else
    { 0, output_7391, 0 },
#endif
    { 0 },
    &operand_data[11051],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx2si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7392 },
#else
    { 0, output_7392, 0 },
#endif
    { 0 },
    &operand_data[11057],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6812 */
  {
    "*cond_fnmavnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7393 },
#else
    { 0, output_7393, 0 },
#endif
    { 0 },
    &operand_data[11063],
    6,
    6,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6856 */
  {
    "sdot_prodvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7394 },
#else
    { 0, output_7394, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdot_prodvnx16qi },
    &operand_data[11069],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6856 */
  {
    "udot_prodvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7395 },
#else
    { 0, output_7395, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udot_prodvnx16qi },
    &operand_data[11069],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6856 */
  {
    "sdot_prodvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7396 },
#else
    { 0, output_7396, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdot_prodvnx8hi },
    &operand_data[11073],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6856 */
  {
    "udot_prodvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7397 },
#else
    { 0, output_7397, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udot_prodvnx8hi },
    &operand_data[11073],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6872 */
  {
    "aarch64_sdot_prod_lanevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7398 },
#else
    { 0, output_7398, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sdot_prod_lanevnx16qi },
    &operand_data[11077],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6872 */
  {
    "aarch64_udot_prod_lanevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7399 },
#else
    { 0, output_7399, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_udot_prod_lanevnx16qi },
    &operand_data[11077],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6872 */
  {
    "aarch64_sdot_prod_lanevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7400 },
#else
    { 0, output_7400, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sdot_prod_lanevnx8hi },
    &operand_data[11082],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6872 */
  {
    "aarch64_udot_prod_lanevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7401 },
#else
    { 0, output_7401, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_udot_prod_lanevnx8hi },
    &operand_data[11082],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6890 */
  {
    "usdot_prodvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7402 },
#else
    { 0, output_7402, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usdot_prodvnx16qi },
    &operand_data[11069],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6905 */
  {
    "aarch64_usdot_prod_lanevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7403 },
#else
    { 0, output_7403, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usdot_prod_lanevnx16qi },
    &operand_data[11077],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6905 */
  {
    "aarch64_sudot_prod_lanevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7404 },
#else
    { 0, output_7404, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sudot_prod_lanevnx16qi },
    &operand_data[11077],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6962 */
  {
    "aarch64_sve_add_smatmulvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7405 },
#else
    { 0, output_7405, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smatmulvnx16qi },
    &operand_data[11087],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6962 */
  {
    "aarch64_sve_add_umatmulvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7406 },
#else
    { 0, output_7406, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umatmulvnx16qi },
    &operand_data[11087],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6962 */
  {
    "aarch64_sve_add_usmatmulvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7407 },
#else
    { 0, output_7407, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_usmatmulvnx16qi },
    &operand_data[11087],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fmavnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7408 },
#else
    { 0, output_7408, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx8hf },
    &operand_data[11091],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fnmavnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7409 },
#else
    { 0, output_7409, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx8hf },
    &operand_data[11091],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fnmsvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7410 },
#else
    { 0, output_7410, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmsvnx8hf },
    &operand_data[11091],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fmsvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7411 },
#else
    { 0, output_7411, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmsvnx8hf },
    &operand_data[11091],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fmavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7412 },
#else
    { 0, output_7412, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx4sf },
    &operand_data[11097],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fnmavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7413 },
#else
    { 0, output_7413, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx4sf },
    &operand_data[11097],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fnmsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7414 },
#else
    { 0, output_7414, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmsvnx4sf },
    &operand_data[11097],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fmsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7415 },
#else
    { 0, output_7415, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmsvnx4sf },
    &operand_data[11097],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fmavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7416 },
#else
    { 0, output_7416, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmavnx2df },
    &operand_data[11103],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fnmavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7417 },
#else
    { 0, output_7417, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmavnx2df },
    &operand_data[11103],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fnmsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7418 },
#else
    { 0, output_7418, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fnmsvnx2df },
    &operand_data[11103],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7008 */
  {
    "aarch64_pred_fmsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7419 },
#else
    { 0, output_7419, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmsvnx2df },
    &operand_data[11103],
    6,
    6,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fmavnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7420 },
#else
    { 0, output_7420, 0 },
#endif
    { 0 },
    &operand_data[11109],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fnmavnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7421 },
#else
    { 0, output_7421, 0 },
#endif
    { 0 },
    &operand_data[11109],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fnmsvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7422 },
#else
    { 0, output_7422, 0 },
#endif
    { 0 },
    &operand_data[11109],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fmsvnx8hf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7423 },
#else
    { 0, output_7423, 0 },
#endif
    { 0 },
    &operand_data[11109],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fmavnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7424 },
#else
    { 0, output_7424, 0 },
#endif
    { 0 },
    &operand_data[11115],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fnmavnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7425 },
#else
    { 0, output_7425, 0 },
#endif
    { 0 },
    &operand_data[11115],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fnmsvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7426 },
#else
    { 0, output_7426, 0 },
#endif
    { 0 },
    &operand_data[11115],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fmsvnx4sf_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7427 },
#else
    { 0, output_7427, 0 },
#endif
    { 0 },
    &operand_data[11115],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fmavnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7428 },
#else
    { 0, output_7428, 0 },
#endif
    { 0 },
    &operand_data[11121],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fnmavnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7429 },
#else
    { 0, output_7429, 0 },
#endif
    { 0 },
    &operand_data[11121],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fnmsvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7430 },
#else
    { 0, output_7430, 0 },
#endif
    { 0 },
    &operand_data[11121],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7049 */
  {
    "*cond_fmsvnx2df_2_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7431 },
#else
    { 0, output_7431, 0 },
#endif
    { 0 },
    &operand_data[11121],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fmavnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7432 },
#else
    { 0, output_7432, 0 },
#endif
    { 0 },
    &operand_data[11109],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fnmavnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7433 },
#else
    { 0, output_7433, 0 },
#endif
    { 0 },
    &operand_data[11109],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fnmsvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7434 },
#else
    { 0, output_7434, 0 },
#endif
    { 0 },
    &operand_data[11109],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fmsvnx8hf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7435 },
#else
    { 0, output_7435, 0 },
#endif
    { 0 },
    &operand_data[11109],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fmavnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7436 },
#else
    { 0, output_7436, 0 },
#endif
    { 0 },
    &operand_data[11115],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fnmavnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7437 },
#else
    { 0, output_7437, 0 },
#endif
    { 0 },
    &operand_data[11115],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fnmsvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7438 },
#else
    { 0, output_7438, 0 },
#endif
    { 0 },
    &operand_data[11115],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fmsvnx4sf_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7439 },
#else
    { 0, output_7439, 0 },
#endif
    { 0 },
    &operand_data[11115],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fmavnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7440 },
#else
    { 0, output_7440, 0 },
#endif
    { 0 },
    &operand_data[11121],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fnmavnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7441 },
#else
    { 0, output_7441, 0 },
#endif
    { 0 },
    &operand_data[11121],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fnmsvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7442 },
#else
    { 0, output_7442, 0 },
#endif
    { 0 },
    &operand_data[11121],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7073 */
  {
    "*cond_fmsvnx2df_2_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7443 },
#else
    { 0, output_7443, 0 },
#endif
    { 0 },
    &operand_data[11121],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fmavnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7444 },
#else
    { 0, output_7444, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fnmavnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7445 },
#else
    { 0, output_7445, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fnmsvnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7446 },
#else
    { 0, output_7446, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fmsvnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7447 },
#else
    { 0, output_7447, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fmavnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7448 },
#else
    { 0, output_7448, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fnmavnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7449 },
#else
    { 0, output_7449, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fnmsvnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7450 },
#else
    { 0, output_7450, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fmsvnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7451 },
#else
    { 0, output_7451, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fmavnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7452 },
#else
    { 0, output_7452, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fnmavnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7453 },
#else
    { 0, output_7453, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fnmsvnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7454 },
#else
    { 0, output_7454, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7095 */
  {
    "*cond_fmsvnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7455 },
#else
    { 0, output_7455, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fmavnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7456 },
#else
    { 0, output_7456, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fnmavnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7457 },
#else
    { 0, output_7457, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fnmsvnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7458 },
#else
    { 0, output_7458, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fmsvnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7459 },
#else
    { 0, output_7459, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fmavnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7460 },
#else
    { 0, output_7460, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fnmavnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7461 },
#else
    { 0, output_7461, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fnmsvnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7462 },
#else
    { 0, output_7462, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fmsvnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7463 },
#else
    { 0, output_7463, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fmavnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7464 },
#else
    { 0, output_7464, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fnmavnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7465 },
#else
    { 0, output_7465, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fnmsvnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7466 },
#else
    { 0, output_7466, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7119 */
  {
    "*cond_fmsvnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7467 },
#else
    { 0, output_7467, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fmavnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7468 },
#else
    { 0, output_7468, 0 },
#endif
    { 0 },
    &operand_data[11145],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fnmavnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7469 },
#else
    { 0, output_7469, 0 },
#endif
    { 0 },
    &operand_data[11145],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fnmsvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7470 },
#else
    { 0, output_7470, 0 },
#endif
    { 0 },
    &operand_data[11145],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fmsvnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7471 },
#else
    { 0, output_7471, 0 },
#endif
    { 0 },
    &operand_data[11145],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fmavnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7472 },
#else
    { 0, output_7472, 0 },
#endif
    { 0 },
    &operand_data[11152],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fnmavnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7473 },
#else
    { 0, output_7473, 0 },
#endif
    { 0 },
    &operand_data[11152],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fnmsvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7474 },
#else
    { 0, output_7474, 0 },
#endif
    { 0 },
    &operand_data[11152],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fmsvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7475 },
#else
    { 0, output_7475, 0 },
#endif
    { 0 },
    &operand_data[11152],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fmavnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7476 },
#else
    { 0, output_7476, 0 },
#endif
    { 0 },
    &operand_data[11159],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fnmavnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7477 },
#else
    { 0, output_7477, 0 },
#endif
    { 0 },
    &operand_data[11159],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fnmsvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7478 },
#else
    { 0, output_7478, 0 },
#endif
    { 0 },
    &operand_data[11159],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7141 */
  {
    "*cond_fmsvnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7479 },
#else
    { 0, output_7479, 0 },
#endif
    { 0 },
    &operand_data[11159],
    7,
    7,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fmavnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7480 },
#else
    { 0, output_7480, 0 },
#endif
    { 0 },
    &operand_data[11145],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fnmavnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7481 },
#else
    { 0, output_7481, 0 },
#endif
    { 0 },
    &operand_data[11145],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fnmsvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7482 },
#else
    { 0, output_7482, 0 },
#endif
    { 0 },
    &operand_data[11145],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fmsvnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7483 },
#else
    { 0, output_7483, 0 },
#endif
    { 0 },
    &operand_data[11145],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fmavnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7484 },
#else
    { 0, output_7484, 0 },
#endif
    { 0 },
    &operand_data[11152],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fnmavnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7485 },
#else
    { 0, output_7485, 0 },
#endif
    { 0 },
    &operand_data[11152],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fnmsvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7486 },
#else
    { 0, output_7486, 0 },
#endif
    { 0 },
    &operand_data[11152],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fmsvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7487 },
#else
    { 0, output_7487, 0 },
#endif
    { 0 },
    &operand_data[11152],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fmavnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7488 },
#else
    { 0, output_7488, 0 },
#endif
    { 0 },
    &operand_data[11159],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fnmavnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7489 },
#else
    { 0, output_7489, 0 },
#endif
    { 0 },
    &operand_data[11159],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fnmsvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7490 },
#else
    { 0, output_7490, 0 },
#endif
    { 0 },
    &operand_data[11159],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7183 */
  {
    "*cond_fmsvnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7491 },
#else
    { 0, output_7491, 0 },
#endif
    { 0 },
    &operand_data[11159],
    6,
    6,
    1,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7220 */
  {
    "aarch64_fma_lane_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7492 },
#else
    { 0, output_7492, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fma_lane_vnx8hf },
    &operand_data[11166],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7220 */
  {
    "aarch64_fnma_lane_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7493 },
#else
    { 0, output_7493, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fnma_lane_vnx8hf },
    &operand_data[11166],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7220 */
  {
    "aarch64_fma_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7494 },
#else
    { 0, output_7494, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fma_lane_vnx4sf },
    &operand_data[11171],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7220 */
  {
    "aarch64_fnma_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7495 },
#else
    { 0, output_7495, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fnma_lane_vnx4sf },
    &operand_data[11171],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7220 */
  {
    "aarch64_fma_lane_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7496 },
#else
    { 0, output_7496, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fma_lane_vnx2df },
    &operand_data[11176],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7220 */
  {
    "aarch64_fnma_lane_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7497 },
#else
    { 0, output_7497, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fnma_lane_vnx2df },
    &operand_data[11176],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmlavnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7498 },
#else
    { 0, output_7498, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmlavnx8hf },
    &operand_data[11181],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla90vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7499 },
#else
    { 0, output_7499, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla90vnx8hf },
    &operand_data[11181],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla180vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7500 },
#else
    { 0, output_7500, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla180vnx8hf },
    &operand_data[11181],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla270vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7501 },
#else
    { 0, output_7501, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla270vnx8hf },
    &operand_data[11181],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmlavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7502 },
#else
    { 0, output_7502, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmlavnx4sf },
    &operand_data[11187],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla90vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7503 },
#else
    { 0, output_7503, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla90vnx4sf },
    &operand_data[11187],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla180vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7504 },
#else
    { 0, output_7504, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla180vnx4sf },
    &operand_data[11187],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla270vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7505 },
#else
    { 0, output_7505, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla270vnx4sf },
    &operand_data[11187],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmlavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7506 },
#else
    { 0, output_7506, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmlavnx2df },
    &operand_data[11193],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla90vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7507 },
#else
    { 0, output_7507, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla90vnx2df },
    &operand_data[11193],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla180vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7508 },
#else
    { 0, output_7508, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla180vnx2df },
    &operand_data[11193],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7245 */
  {
    "aarch64_pred_fcmla270vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7509 },
#else
    { 0, output_7509, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmla270vnx2df },
    &operand_data[11193],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmlavnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7510 },
#else
    { 0, output_7510, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla90vnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7511 },
#else
    { 0, output_7511, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla180vnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7512 },
#else
    { 0, output_7512, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla270vnx8hf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7513 },
#else
    { 0, output_7513, 0 },
#endif
    { 0 },
    &operand_data[11127],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmlavnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7514 },
#else
    { 0, output_7514, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla90vnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7515 },
#else
    { 0, output_7515, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla180vnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7516 },
#else
    { 0, output_7516, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla270vnx4sf_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7517 },
#else
    { 0, output_7517, 0 },
#endif
    { 0 },
    &operand_data[11133],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmlavnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7518 },
#else
    { 0, output_7518, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla90vnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7519 },
#else
    { 0, output_7519, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla180vnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7520 },
#else
    { 0, output_7520, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7335 */
  {
    "*cond_fcmla270vnx2df_4_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7521 },
#else
    { 0, output_7521, 0 },
#endif
    { 0 },
    &operand_data[11139],
    6,
    6,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmlavnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7522 },
#else
    { 0, output_7522, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla90vnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7523 },
#else
    { 0, output_7523, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla180vnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7524 },
#else
    { 0, output_7524, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla270vnx8hf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7525 },
#else
    { 0, output_7525, 0 },
#endif
    { 0 },
    &operand_data[11127],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmlavnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7526 },
#else
    { 0, output_7526, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla90vnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7527 },
#else
    { 0, output_7527, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla180vnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7528 },
#else
    { 0, output_7528, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla270vnx4sf_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7529 },
#else
    { 0, output_7529, 0 },
#endif
    { 0 },
    &operand_data[11133],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmlavnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7530 },
#else
    { 0, output_7530, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla90vnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7531 },
#else
    { 0, output_7531, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla180vnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7532 },
#else
    { 0, output_7532, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7359 */
  {
    "*cond_fcmla270vnx2df_4_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7533 },
#else
    { 0, output_7533, 0 },
#endif
    { 0 },
    &operand_data[11139],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmlavnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7534 },
#else
    { 0, output_7534, 0 },
#endif
    { 0 },
    &operand_data[11199],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla90vnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7535 },
#else
    { 0, output_7535, 0 },
#endif
    { 0 },
    &operand_data[11199],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla180vnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7536 },
#else
    { 0, output_7536, 0 },
#endif
    { 0 },
    &operand_data[11199],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla270vnx8hf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7537 },
#else
    { 0, output_7537, 0 },
#endif
    { 0 },
    &operand_data[11199],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmlavnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7538 },
#else
    { 0, output_7538, 0 },
#endif
    { 0 },
    &operand_data[11206],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla90vnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7539 },
#else
    { 0, output_7539, 0 },
#endif
    { 0 },
    &operand_data[11206],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla180vnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7540 },
#else
    { 0, output_7540, 0 },
#endif
    { 0 },
    &operand_data[11206],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla270vnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7541 },
#else
    { 0, output_7541, 0 },
#endif
    { 0 },
    &operand_data[11206],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmlavnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7542 },
#else
    { 0, output_7542, 0 },
#endif
    { 0 },
    &operand_data[11213],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla90vnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7543 },
#else
    { 0, output_7543, 0 },
#endif
    { 0 },
    &operand_data[11213],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla180vnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7544 },
#else
    { 0, output_7544, 0 },
#endif
    { 0 },
    &operand_data[11213],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7380 */
  {
    "*cond_fcmla270vnx2df_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7545 },
#else
    { 0, output_7545, 0 },
#endif
    { 0 },
    &operand_data[11213],
    7,
    7,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmlavnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7546 },
#else
    { 0, output_7546, 0 },
#endif
    { 0 },
    &operand_data[11199],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla90vnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7547 },
#else
    { 0, output_7547, 0 },
#endif
    { 0 },
    &operand_data[11199],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla180vnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7548 },
#else
    { 0, output_7548, 0 },
#endif
    { 0 },
    &operand_data[11199],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla270vnx8hf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7549 },
#else
    { 0, output_7549, 0 },
#endif
    { 0 },
    &operand_data[11199],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmlavnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7550 },
#else
    { 0, output_7550, 0 },
#endif
    { 0 },
    &operand_data[11206],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla90vnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7551 },
#else
    { 0, output_7551, 0 },
#endif
    { 0 },
    &operand_data[11206],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla180vnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7552 },
#else
    { 0, output_7552, 0 },
#endif
    { 0 },
    &operand_data[11206],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla270vnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7553 },
#else
    { 0, output_7553, 0 },
#endif
    { 0 },
    &operand_data[11206],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmlavnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7554 },
#else
    { 0, output_7554, 0 },
#endif
    { 0 },
    &operand_data[11213],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla90vnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7555 },
#else
    { 0, output_7555, 0 },
#endif
    { 0 },
    &operand_data[11213],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla180vnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7556 },
#else
    { 0, output_7556, 0 },
#endif
    { 0 },
    &operand_data[11213],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7417 */
  {
    "*cond_fcmla270vnx2df_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7557 },
#else
    { 0, output_7557, 0 },
#endif
    { 0 },
    &operand_data[11213],
    6,
    6,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla_lane_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7558 },
#else
    { 0, output_7558, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane_vnx8hf },
    &operand_data[11166],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla90_lane_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7559 },
#else
    { 0, output_7559, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla90_lane_vnx8hf },
    &operand_data[11166],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla180_lane_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7560 },
#else
    { 0, output_7560, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla180_lane_vnx8hf },
    &operand_data[11166],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla270_lane_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7561 },
#else
    { 0, output_7561, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla270_lane_vnx8hf },
    &operand_data[11166],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7562 },
#else
    { 0, output_7562, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla_lane_vnx4sf },
    &operand_data[11220],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla90_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7563 },
#else
    { 0, output_7563, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla90_lane_vnx4sf },
    &operand_data[11220],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla180_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7564 },
#else
    { 0, output_7564, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla180_lane_vnx4sf },
    &operand_data[11220],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7448 */
  {
    "aarch64_fcmla270_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7565 },
#else
    { 0, output_7565, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fcmla270_lane_vnx4sf },
    &operand_data[11220],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7472 */
  {
    "aarch64_sve_tmadvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7566 },
#else
    { 0, output_7566, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tmadvnx8hf },
    &operand_data[11225],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7472 */
  {
    "aarch64_sve_tmadvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7567 },
#else
    { 0, output_7567, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tmadvnx4sf },
    &operand_data[11229],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7472 */
  {
    "aarch64_sve_tmadvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7568 },
#else
    { 0, output_7568, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tmadvnx2df },
    &operand_data[11233],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7496 */
  {
    "aarch64_sve_bfdotvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7569 },
#else
    { 0, output_7569, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bfdotvnx4sf },
    &operand_data[11237],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7496 */
  {
    "aarch64_sve_bfmlalbvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7570 },
#else
    { 0, output_7570, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bfmlalbvnx4sf },
    &operand_data[11237],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7496 */
  {
    "aarch64_sve_bfmlaltvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7571 },
#else
    { 0, output_7571, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bfmlaltvnx4sf },
    &operand_data[11237],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7496 */
  {
    "aarch64_sve_bfmmlavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7572 },
#else
    { 0, output_7572, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bfmmlavnx4sf },
    &operand_data[11237],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7511 */
  {
    "aarch64_sve_bfdot_lanevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7573 },
#else
    { 0, output_7573, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bfdot_lanevnx4sf },
    &operand_data[11241],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7511 */
  {
    "aarch64_sve_bfmlalb_lanevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7574 },
#else
    { 0, output_7574, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bfmlalb_lanevnx4sf },
    &operand_data[11241],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7511 */
  {
    "aarch64_sve_bfmlalt_lanevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7575 },
#else
    { 0, output_7575, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bfmlalt_lanevnx4sf },
    &operand_data[11241],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7534 */
  {
    "aarch64_sve_fmmlavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7576 },
#else
    { 0, output_7576, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fmmlavnx4sf },
    &operand_data[11246],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7534 */
  {
    "aarch64_sve_fmmlavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7577 },
#else
    { 0, output_7577, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fmmlavnx2df },
    &operand_data[11250],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx16qivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7578 },
#else
    { 0, output_7578, 0 },
#endif
    { 0 },
    &operand_data[11254],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx8qivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7579 },
#else
    { 0, output_7579, 0 },
#endif
    { 0 },
    &operand_data[11258],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx4qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7580 },
#else
    { 0, output_7580, 0 },
#endif
    { 0 },
    &operand_data[11262],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7581 },
#else
    { 0, output_7581, 0 },
#endif
    { 0 },
    &operand_data[11266],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx8hivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7582 },
#else
    { 0, output_7582, 0 },
#endif
    { 0 },
    &operand_data[11270],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx4hivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7583 },
#else
    { 0, output_7583, 0 },
#endif
    { 0 },
    &operand_data[11274],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7584 },
#else
    { 0, output_7584, 0 },
#endif
    { 0 },
    &operand_data[11278],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx8hfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7585 },
#else
    { 0, output_7585, 0 },
#endif
    { 0 },
    &operand_data[11282],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx4hfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7586 },
#else
    { 0, output_7586, 0 },
#endif
    { 0 },
    &operand_data[11286],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2hfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7587 },
#else
    { 0, output_7587, 0 },
#endif
    { 0 },
    &operand_data[11290],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx8bfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7588 },
#else
    { 0, output_7588, 0 },
#endif
    { 0 },
    &operand_data[11294],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx4bfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7589 },
#else
    { 0, output_7589, 0 },
#endif
    { 0 },
    &operand_data[11298],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2bfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7590 },
#else
    { 0, output_7590, 0 },
#endif
    { 0 },
    &operand_data[11302],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx4sivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7591 },
#else
    { 0, output_7591, 0 },
#endif
    { 0 },
    &operand_data[11306],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2sivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7592 },
#else
    { 0, output_7592, 0 },
#endif
    { 0 },
    &operand_data[11310],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx4sfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7593 },
#else
    { 0, output_7593, 0 },
#endif
    { 0 },
    &operand_data[11314],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2sfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7594 },
#else
    { 0, output_7594, 0 },
#endif
    { 0 },
    &operand_data[11318],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2divnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7595 },
#else
    { 0, output_7595, 0 },
#endif
    { 0 },
    &operand_data[11322],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7595 */
  {
    "*vcond_mask_vnx2dfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7596 },
#else
    { 0, output_7596, 0 },
#endif
    { 0 },
    &operand_data[11326],
    4,
    4,
    0,
    7,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7597 },
#else
    { 0, output_7597, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx16qi },
    &operand_data[11330],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7598 },
#else
    { 0, output_7598, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx8qi },
    &operand_data[11334],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7599 },
#else
    { 0, output_7599, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx4qi },
    &operand_data[11338],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7600 },
#else
    { 0, output_7600, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2qi },
    &operand_data[11342],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7601 },
#else
    { 0, output_7601, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx8hi },
    &operand_data[11346],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7602 },
#else
    { 0, output_7602, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx4hi },
    &operand_data[11350],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7603 },
#else
    { 0, output_7603, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2hi },
    &operand_data[11354],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7604 },
#else
    { 0, output_7604, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx8hf },
    &operand_data[11358],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7605 },
#else
    { 0, output_7605, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx4hf },
    &operand_data[11362],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7606 },
#else
    { 0, output_7606, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2hf },
    &operand_data[11366],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7607 },
#else
    { 0, output_7607, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx8bf },
    &operand_data[11370],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7608 },
#else
    { 0, output_7608, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx4bf },
    &operand_data[11374],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7609 },
#else
    { 0, output_7609, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2bf },
    &operand_data[11378],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7610 },
#else
    { 0, output_7610, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx4si },
    &operand_data[11382],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7611 },
#else
    { 0, output_7611, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2si },
    &operand_data[11386],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7612 },
#else
    { 0, output_7612, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx4sf },
    &operand_data[11390],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7613 },
#else
    { 0, output_7613, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2sf },
    &operand_data[11394],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7614 },
#else
    { 0, output_7614, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2di },
    &operand_data[11398],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7620 */
  {
    "aarch64_sel_dupvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7615 },
#else
    { 0, output_7615, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sel_dupvnx2df },
    &operand_data[11402],
    4,
    4,
    0,
    6,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7616 },
#else
    { 0, output_7616, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx16qi },
    &operand_data[11406],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7617 },
#else
    { 0, output_7617, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx16qi },
    &operand_data[11406],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7618 },
#else
    { 0, output_7618, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx16qi },
    &operand_data[11406],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7619 },
#else
    { 0, output_7619, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx16qi },
    &operand_data[11406],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7620 },
#else
    { 0, output_7620, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx16qi },
    &operand_data[11406],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7621 },
#else
    { 0, output_7621, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx16qi },
    &operand_data[11406],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7622 },
#else
    { 0, output_7622, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx16qi },
    &operand_data[11411],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7623 },
#else
    { 0, output_7623, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx16qi },
    &operand_data[11411],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7624 },
#else
    { 0, output_7624, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx16qi },
    &operand_data[11411],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7625 },
#else
    { 0, output_7625, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx16qi },
    &operand_data[11411],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7626 },
#else
    { 0, output_7626, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx8qi },
    &operand_data[11416],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7627 },
#else
    { 0, output_7627, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx8qi },
    &operand_data[11416],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7628 },
#else
    { 0, output_7628, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx8qi },
    &operand_data[11416],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7629 },
#else
    { 0, output_7629, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx8qi },
    &operand_data[11416],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7630 },
#else
    { 0, output_7630, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx8qi },
    &operand_data[11416],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7631 },
#else
    { 0, output_7631, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx8qi },
    &operand_data[11416],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7632 },
#else
    { 0, output_7632, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx8qi },
    &operand_data[11421],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7633 },
#else
    { 0, output_7633, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx8qi },
    &operand_data[11421],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7634 },
#else
    { 0, output_7634, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx8qi },
    &operand_data[11421],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7635 },
#else
    { 0, output_7635, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx8qi },
    &operand_data[11421],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7636 },
#else
    { 0, output_7636, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx4qi },
    &operand_data[11426],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7637 },
#else
    { 0, output_7637, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx4qi },
    &operand_data[11426],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7638 },
#else
    { 0, output_7638, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx4qi },
    &operand_data[11426],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7639 },
#else
    { 0, output_7639, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx4qi },
    &operand_data[11426],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7640 },
#else
    { 0, output_7640, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx4qi },
    &operand_data[11426],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7641 },
#else
    { 0, output_7641, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx4qi },
    &operand_data[11426],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7642 },
#else
    { 0, output_7642, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx4qi },
    &operand_data[11431],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7643 },
#else
    { 0, output_7643, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx4qi },
    &operand_data[11431],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7644 },
#else
    { 0, output_7644, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx4qi },
    &operand_data[11431],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7645 },
#else
    { 0, output_7645, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx4qi },
    &operand_data[11431],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7646 },
#else
    { 0, output_7646, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx2qi },
    &operand_data[11436],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7647 },
#else
    { 0, output_7647, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx2qi },
    &operand_data[11436],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7648 },
#else
    { 0, output_7648, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx2qi },
    &operand_data[11436],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7649 },
#else
    { 0, output_7649, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx2qi },
    &operand_data[11436],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7650 },
#else
    { 0, output_7650, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx2qi },
    &operand_data[11436],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7651 },
#else
    { 0, output_7651, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx2qi },
    &operand_data[11436],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7652 },
#else
    { 0, output_7652, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx2qi },
    &operand_data[11441],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7653 },
#else
    { 0, output_7653, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx2qi },
    &operand_data[11441],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7654 },
#else
    { 0, output_7654, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx2qi },
    &operand_data[11441],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7655 },
#else
    { 0, output_7655, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx2qi },
    &operand_data[11441],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7656 },
#else
    { 0, output_7656, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx8hi },
    &operand_data[11446],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7657 },
#else
    { 0, output_7657, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx8hi },
    &operand_data[11446],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7658 },
#else
    { 0, output_7658, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx8hi },
    &operand_data[11446],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7659 },
#else
    { 0, output_7659, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx8hi },
    &operand_data[11446],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7660 },
#else
    { 0, output_7660, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx8hi },
    &operand_data[11446],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7661 },
#else
    { 0, output_7661, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx8hi },
    &operand_data[11446],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7662 },
#else
    { 0, output_7662, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx8hi },
    &operand_data[11451],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7663 },
#else
    { 0, output_7663, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx8hi },
    &operand_data[11451],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7664 },
#else
    { 0, output_7664, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx8hi },
    &operand_data[11451],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7665 },
#else
    { 0, output_7665, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx8hi },
    &operand_data[11451],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7666 },
#else
    { 0, output_7666, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx4hi },
    &operand_data[11456],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7667 },
#else
    { 0, output_7667, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx4hi },
    &operand_data[11456],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7668 },
#else
    { 0, output_7668, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx4hi },
    &operand_data[11456],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7669 },
#else
    { 0, output_7669, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx4hi },
    &operand_data[11456],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7670 },
#else
    { 0, output_7670, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx4hi },
    &operand_data[11456],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7671 },
#else
    { 0, output_7671, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx4hi },
    &operand_data[11456],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7672 },
#else
    { 0, output_7672, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx4hi },
    &operand_data[11461],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7673 },
#else
    { 0, output_7673, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx4hi },
    &operand_data[11461],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7674 },
#else
    { 0, output_7674, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx4hi },
    &operand_data[11461],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7675 },
#else
    { 0, output_7675, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx4hi },
    &operand_data[11461],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7676 },
#else
    { 0, output_7676, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx2hi },
    &operand_data[11466],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7677 },
#else
    { 0, output_7677, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx2hi },
    &operand_data[11466],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7678 },
#else
    { 0, output_7678, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx2hi },
    &operand_data[11466],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7679 },
#else
    { 0, output_7679, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx2hi },
    &operand_data[11466],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7680 },
#else
    { 0, output_7680, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx2hi },
    &operand_data[11466],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7681 },
#else
    { 0, output_7681, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx2hi },
    &operand_data[11466],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7682 },
#else
    { 0, output_7682, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx2hi },
    &operand_data[11471],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7683 },
#else
    { 0, output_7683, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx2hi },
    &operand_data[11471],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7684 },
#else
    { 0, output_7684, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx2hi },
    &operand_data[11471],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7685 },
#else
    { 0, output_7685, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx2hi },
    &operand_data[11471],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7686 },
#else
    { 0, output_7686, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx4si },
    &operand_data[11476],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7687 },
#else
    { 0, output_7687, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx4si },
    &operand_data[11476],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7688 },
#else
    { 0, output_7688, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx4si },
    &operand_data[11476],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7689 },
#else
    { 0, output_7689, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx4si },
    &operand_data[11476],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7690 },
#else
    { 0, output_7690, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx4si },
    &operand_data[11476],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7691 },
#else
    { 0, output_7691, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx4si },
    &operand_data[11476],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7692 },
#else
    { 0, output_7692, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx4si },
    &operand_data[11481],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7693 },
#else
    { 0, output_7693, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx4si },
    &operand_data[11481],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7694 },
#else
    { 0, output_7694, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx4si },
    &operand_data[11481],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7695 },
#else
    { 0, output_7695, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx4si },
    &operand_data[11481],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7696 },
#else
    { 0, output_7696, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx2si },
    &operand_data[11486],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7697 },
#else
    { 0, output_7697, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx2si },
    &operand_data[11486],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7698 },
#else
    { 0, output_7698, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx2si },
    &operand_data[11486],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7699 },
#else
    { 0, output_7699, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx2si },
    &operand_data[11486],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7700 },
#else
    { 0, output_7700, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx2si },
    &operand_data[11486],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7701 },
#else
    { 0, output_7701, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx2si },
    &operand_data[11486],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7702 },
#else
    { 0, output_7702, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx2si },
    &operand_data[11491],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7703 },
#else
    { 0, output_7703, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx2si },
    &operand_data[11491],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7704 },
#else
    { 0, output_7704, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx2si },
    &operand_data[11491],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7705 },
#else
    { 0, output_7705, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx2si },
    &operand_data[11491],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7706 },
#else
    { 0, output_7706, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx2di },
    &operand_data[11496],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplevnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7707 },
#else
    { 0, output_7707, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx2di },
    &operand_data[11496],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpeqvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7708 },
#else
    { 0, output_7708, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx2di },
    &operand_data[11496],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpnevnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7709 },
#else
    { 0, output_7709, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx2di },
    &operand_data[11496],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgevnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7710 },
#else
    { 0, output_7710, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx2di },
    &operand_data[11496],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmpgtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7711 },
#else
    { 0, output_7711, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx2di },
    &operand_data[11496],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplovnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7712 },
#else
    { 0, output_7712, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx2di },
    &operand_data[11501],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmplsvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7713 },
#else
    { 0, output_7713, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx2di },
    &operand_data[11501],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphsvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7714 },
#else
    { 0, output_7714, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx2di },
    &operand_data[11501],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7773 */
  {
    "aarch64_pred_cmphivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7715 },
#else
    { 0, output_7715, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx2di },
    &operand_data[11501],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7716 },
#else
    { 0, output_7716, 0 },
#endif
    { 0 },
    &operand_data[11506],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7717 },
#else
    { 0, output_7717, 0 },
#endif
    { 0 },
    &operand_data[11506],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7718 },
#else
    { 0, output_7718, 0 },
#endif
    { 0 },
    &operand_data[11506],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7719 },
#else
    { 0, output_7719, 0 },
#endif
    { 0 },
    &operand_data[11506],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7720 },
#else
    { 0, output_7720, 0 },
#endif
    { 0 },
    &operand_data[11506],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7721 },
#else
    { 0, output_7721, 0 },
#endif
    { 0 },
    &operand_data[11506],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7722 },
#else
    { 0, output_7722, 0 },
#endif
    { 0 },
    &operand_data[11514],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7723 },
#else
    { 0, output_7723, 0 },
#endif
    { 0 },
    &operand_data[11514],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7724 },
#else
    { 0, output_7724, 0 },
#endif
    { 0 },
    &operand_data[11514],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7725 },
#else
    { 0, output_7725, 0 },
#endif
    { 0 },
    &operand_data[11514],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7726 },
#else
    { 0, output_7726, 0 },
#endif
    { 0 },
    &operand_data[11522],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7727 },
#else
    { 0, output_7727, 0 },
#endif
    { 0 },
    &operand_data[11522],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7728 },
#else
    { 0, output_7728, 0 },
#endif
    { 0 },
    &operand_data[11522],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7729 },
#else
    { 0, output_7729, 0 },
#endif
    { 0 },
    &operand_data[11522],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7730 },
#else
    { 0, output_7730, 0 },
#endif
    { 0 },
    &operand_data[11522],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7731 },
#else
    { 0, output_7731, 0 },
#endif
    { 0 },
    &operand_data[11522],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7732 },
#else
    { 0, output_7732, 0 },
#endif
    { 0 },
    &operand_data[11530],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7733 },
#else
    { 0, output_7733, 0 },
#endif
    { 0 },
    &operand_data[11530],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7734 },
#else
    { 0, output_7734, 0 },
#endif
    { 0 },
    &operand_data[11530],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx8qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7735 },
#else
    { 0, output_7735, 0 },
#endif
    { 0 },
    &operand_data[11530],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7736 },
#else
    { 0, output_7736, 0 },
#endif
    { 0 },
    &operand_data[11538],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7737 },
#else
    { 0, output_7737, 0 },
#endif
    { 0 },
    &operand_data[11538],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7738 },
#else
    { 0, output_7738, 0 },
#endif
    { 0 },
    &operand_data[11538],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7739 },
#else
    { 0, output_7739, 0 },
#endif
    { 0 },
    &operand_data[11538],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7740 },
#else
    { 0, output_7740, 0 },
#endif
    { 0 },
    &operand_data[11538],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7741 },
#else
    { 0, output_7741, 0 },
#endif
    { 0 },
    &operand_data[11538],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7742 },
#else
    { 0, output_7742, 0 },
#endif
    { 0 },
    &operand_data[11546],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7743 },
#else
    { 0, output_7743, 0 },
#endif
    { 0 },
    &operand_data[11546],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7744 },
#else
    { 0, output_7744, 0 },
#endif
    { 0 },
    &operand_data[11546],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx4qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7745 },
#else
    { 0, output_7745, 0 },
#endif
    { 0 },
    &operand_data[11546],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7746 },
#else
    { 0, output_7746, 0 },
#endif
    { 0 },
    &operand_data[11554],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7747 },
#else
    { 0, output_7747, 0 },
#endif
    { 0 },
    &operand_data[11554],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7748 },
#else
    { 0, output_7748, 0 },
#endif
    { 0 },
    &operand_data[11554],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7749 },
#else
    { 0, output_7749, 0 },
#endif
    { 0 },
    &operand_data[11554],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7750 },
#else
    { 0, output_7750, 0 },
#endif
    { 0 },
    &operand_data[11554],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7751 },
#else
    { 0, output_7751, 0 },
#endif
    { 0 },
    &operand_data[11554],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7752 },
#else
    { 0, output_7752, 0 },
#endif
    { 0 },
    &operand_data[11562],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7753 },
#else
    { 0, output_7753, 0 },
#endif
    { 0 },
    &operand_data[11562],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7754 },
#else
    { 0, output_7754, 0 },
#endif
    { 0 },
    &operand_data[11562],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx2qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7755 },
#else
    { 0, output_7755, 0 },
#endif
    { 0 },
    &operand_data[11562],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7756 },
#else
    { 0, output_7756, 0 },
#endif
    { 0 },
    &operand_data[11570],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7757 },
#else
    { 0, output_7757, 0 },
#endif
    { 0 },
    &operand_data[11570],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7758 },
#else
    { 0, output_7758, 0 },
#endif
    { 0 },
    &operand_data[11570],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7759 },
#else
    { 0, output_7759, 0 },
#endif
    { 0 },
    &operand_data[11570],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7760 },
#else
    { 0, output_7760, 0 },
#endif
    { 0 },
    &operand_data[11570],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7761 },
#else
    { 0, output_7761, 0 },
#endif
    { 0 },
    &operand_data[11570],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7762 },
#else
    { 0, output_7762, 0 },
#endif
    { 0 },
    &operand_data[11578],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7763 },
#else
    { 0, output_7763, 0 },
#endif
    { 0 },
    &operand_data[11578],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7764 },
#else
    { 0, output_7764, 0 },
#endif
    { 0 },
    &operand_data[11578],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7765 },
#else
    { 0, output_7765, 0 },
#endif
    { 0 },
    &operand_data[11578],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7766 },
#else
    { 0, output_7766, 0 },
#endif
    { 0 },
    &operand_data[11586],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7767 },
#else
    { 0, output_7767, 0 },
#endif
    { 0 },
    &operand_data[11586],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7768 },
#else
    { 0, output_7768, 0 },
#endif
    { 0 },
    &operand_data[11586],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7769 },
#else
    { 0, output_7769, 0 },
#endif
    { 0 },
    &operand_data[11586],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7770 },
#else
    { 0, output_7770, 0 },
#endif
    { 0 },
    &operand_data[11586],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7771 },
#else
    { 0, output_7771, 0 },
#endif
    { 0 },
    &operand_data[11586],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7772 },
#else
    { 0, output_7772, 0 },
#endif
    { 0 },
    &operand_data[11594],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7773 },
#else
    { 0, output_7773, 0 },
#endif
    { 0 },
    &operand_data[11594],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7774 },
#else
    { 0, output_7774, 0 },
#endif
    { 0 },
    &operand_data[11594],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx4hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7775 },
#else
    { 0, output_7775, 0 },
#endif
    { 0 },
    &operand_data[11594],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7776 },
#else
    { 0, output_7776, 0 },
#endif
    { 0 },
    &operand_data[11602],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7777 },
#else
    { 0, output_7777, 0 },
#endif
    { 0 },
    &operand_data[11602],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7778 },
#else
    { 0, output_7778, 0 },
#endif
    { 0 },
    &operand_data[11602],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7779 },
#else
    { 0, output_7779, 0 },
#endif
    { 0 },
    &operand_data[11602],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7780 },
#else
    { 0, output_7780, 0 },
#endif
    { 0 },
    &operand_data[11602],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7781 },
#else
    { 0, output_7781, 0 },
#endif
    { 0 },
    &operand_data[11602],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7782 },
#else
    { 0, output_7782, 0 },
#endif
    { 0 },
    &operand_data[11610],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7783 },
#else
    { 0, output_7783, 0 },
#endif
    { 0 },
    &operand_data[11610],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7784 },
#else
    { 0, output_7784, 0 },
#endif
    { 0 },
    &operand_data[11610],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx2hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7785 },
#else
    { 0, output_7785, 0 },
#endif
    { 0 },
    &operand_data[11610],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7786 },
#else
    { 0, output_7786, 0 },
#endif
    { 0 },
    &operand_data[11618],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7787 },
#else
    { 0, output_7787, 0 },
#endif
    { 0 },
    &operand_data[11618],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7788 },
#else
    { 0, output_7788, 0 },
#endif
    { 0 },
    &operand_data[11618],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7789 },
#else
    { 0, output_7789, 0 },
#endif
    { 0 },
    &operand_data[11618],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7790 },
#else
    { 0, output_7790, 0 },
#endif
    { 0 },
    &operand_data[11618],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7791 },
#else
    { 0, output_7791, 0 },
#endif
    { 0 },
    &operand_data[11618],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7792 },
#else
    { 0, output_7792, 0 },
#endif
    { 0 },
    &operand_data[11626],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7793 },
#else
    { 0, output_7793, 0 },
#endif
    { 0 },
    &operand_data[11626],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7794 },
#else
    { 0, output_7794, 0 },
#endif
    { 0 },
    &operand_data[11626],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx4si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7795 },
#else
    { 0, output_7795, 0 },
#endif
    { 0 },
    &operand_data[11626],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7796 },
#else
    { 0, output_7796, 0 },
#endif
    { 0 },
    &operand_data[11634],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7797 },
#else
    { 0, output_7797, 0 },
#endif
    { 0 },
    &operand_data[11634],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7798 },
#else
    { 0, output_7798, 0 },
#endif
    { 0 },
    &operand_data[11634],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7799 },
#else
    { 0, output_7799, 0 },
#endif
    { 0 },
    &operand_data[11634],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7800 },
#else
    { 0, output_7800, 0 },
#endif
    { 0 },
    &operand_data[11634],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7801 },
#else
    { 0, output_7801, 0 },
#endif
    { 0 },
    &operand_data[11634],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7802 },
#else
    { 0, output_7802, 0 },
#endif
    { 0 },
    &operand_data[11642],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7803 },
#else
    { 0, output_7803, 0 },
#endif
    { 0 },
    &operand_data[11642],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7804 },
#else
    { 0, output_7804, 0 },
#endif
    { 0 },
    &operand_data[11642],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx2si_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7805 },
#else
    { 0, output_7805, 0 },
#endif
    { 0 },
    &operand_data[11642],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpltvnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7806 },
#else
    { 0, output_7806, 0 },
#endif
    { 0 },
    &operand_data[11650],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplevnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7807 },
#else
    { 0, output_7807, 0 },
#endif
    { 0 },
    &operand_data[11650],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpeqvnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7808 },
#else
    { 0, output_7808, 0 },
#endif
    { 0 },
    &operand_data[11650],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpnevnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7809 },
#else
    { 0, output_7809, 0 },
#endif
    { 0 },
    &operand_data[11650],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgevnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7810 },
#else
    { 0, output_7810, 0 },
#endif
    { 0 },
    &operand_data[11650],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmpgtvnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7811 },
#else
    { 0, output_7811, 0 },
#endif
    { 0 },
    &operand_data[11650],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplovnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7812 },
#else
    { 0, output_7812, 0 },
#endif
    { 0 },
    &operand_data[11658],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmplsvnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7813 },
#else
    { 0, output_7813, 0 },
#endif
    { 0 },
    &operand_data[11658],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphsvnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7814 },
#else
    { 0, output_7814, 0 },
#endif
    { 0 },
    &operand_data[11658],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7791 */
  {
    "*cmphivnx2di_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7815 },
#else
    { 0, output_7815, 0 },
#endif
    { 0 },
    &operand_data[11658],
    8,
    8,
    4,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7816 },
#else
    { 0, output_7816, 0 },
#endif
    { 0 },
    &operand_data[11666],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7817 },
#else
    { 0, output_7817, 0 },
#endif
    { 0 },
    &operand_data[11666],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7818 },
#else
    { 0, output_7818, 0 },
#endif
    { 0 },
    &operand_data[11666],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7819 },
#else
    { 0, output_7819, 0 },
#endif
    { 0 },
    &operand_data[11666],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7820 },
#else
    { 0, output_7820, 0 },
#endif
    { 0 },
    &operand_data[11666],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7821 },
#else
    { 0, output_7821, 0 },
#endif
    { 0 },
    &operand_data[11666],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7822 },
#else
    { 0, output_7822, 0 },
#endif
    { 0 },
    &operand_data[11674],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7823 },
#else
    { 0, output_7823, 0 },
#endif
    { 0 },
    &operand_data[11674],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7824 },
#else
    { 0, output_7824, 0 },
#endif
    { 0 },
    &operand_data[11674],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7825 },
#else
    { 0, output_7825, 0 },
#endif
    { 0 },
    &operand_data[11674],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7826 },
#else
    { 0, output_7826, 0 },
#endif
    { 0 },
    &operand_data[11682],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7827 },
#else
    { 0, output_7827, 0 },
#endif
    { 0 },
    &operand_data[11682],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7828 },
#else
    { 0, output_7828, 0 },
#endif
    { 0 },
    &operand_data[11682],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7829 },
#else
    { 0, output_7829, 0 },
#endif
    { 0 },
    &operand_data[11682],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7830 },
#else
    { 0, output_7830, 0 },
#endif
    { 0 },
    &operand_data[11682],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7831 },
#else
    { 0, output_7831, 0 },
#endif
    { 0 },
    &operand_data[11682],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7832 },
#else
    { 0, output_7832, 0 },
#endif
    { 0 },
    &operand_data[11690],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7833 },
#else
    { 0, output_7833, 0 },
#endif
    { 0 },
    &operand_data[11690],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7834 },
#else
    { 0, output_7834, 0 },
#endif
    { 0 },
    &operand_data[11690],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx8qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7835 },
#else
    { 0, output_7835, 0 },
#endif
    { 0 },
    &operand_data[11690],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7836 },
#else
    { 0, output_7836, 0 },
#endif
    { 0 },
    &operand_data[11698],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7837 },
#else
    { 0, output_7837, 0 },
#endif
    { 0 },
    &operand_data[11698],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7838 },
#else
    { 0, output_7838, 0 },
#endif
    { 0 },
    &operand_data[11698],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7839 },
#else
    { 0, output_7839, 0 },
#endif
    { 0 },
    &operand_data[11698],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7840 },
#else
    { 0, output_7840, 0 },
#endif
    { 0 },
    &operand_data[11698],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7841 },
#else
    { 0, output_7841, 0 },
#endif
    { 0 },
    &operand_data[11698],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7842 },
#else
    { 0, output_7842, 0 },
#endif
    { 0 },
    &operand_data[11706],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7843 },
#else
    { 0, output_7843, 0 },
#endif
    { 0 },
    &operand_data[11706],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7844 },
#else
    { 0, output_7844, 0 },
#endif
    { 0 },
    &operand_data[11706],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx4qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7845 },
#else
    { 0, output_7845, 0 },
#endif
    { 0 },
    &operand_data[11706],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7846 },
#else
    { 0, output_7846, 0 },
#endif
    { 0 },
    &operand_data[11714],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7847 },
#else
    { 0, output_7847, 0 },
#endif
    { 0 },
    &operand_data[11714],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7848 },
#else
    { 0, output_7848, 0 },
#endif
    { 0 },
    &operand_data[11714],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7849 },
#else
    { 0, output_7849, 0 },
#endif
    { 0 },
    &operand_data[11714],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7850 },
#else
    { 0, output_7850, 0 },
#endif
    { 0 },
    &operand_data[11714],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7851 },
#else
    { 0, output_7851, 0 },
#endif
    { 0 },
    &operand_data[11714],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7852 },
#else
    { 0, output_7852, 0 },
#endif
    { 0 },
    &operand_data[11722],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7853 },
#else
    { 0, output_7853, 0 },
#endif
    { 0 },
    &operand_data[11722],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7854 },
#else
    { 0, output_7854, 0 },
#endif
    { 0 },
    &operand_data[11722],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx2qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7855 },
#else
    { 0, output_7855, 0 },
#endif
    { 0 },
    &operand_data[11722],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7856 },
#else
    { 0, output_7856, 0 },
#endif
    { 0 },
    &operand_data[11730],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7857 },
#else
    { 0, output_7857, 0 },
#endif
    { 0 },
    &operand_data[11730],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7858 },
#else
    { 0, output_7858, 0 },
#endif
    { 0 },
    &operand_data[11730],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7859 },
#else
    { 0, output_7859, 0 },
#endif
    { 0 },
    &operand_data[11730],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7860 },
#else
    { 0, output_7860, 0 },
#endif
    { 0 },
    &operand_data[11730],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7861 },
#else
    { 0, output_7861, 0 },
#endif
    { 0 },
    &operand_data[11730],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7862 },
#else
    { 0, output_7862, 0 },
#endif
    { 0 },
    &operand_data[11738],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7863 },
#else
    { 0, output_7863, 0 },
#endif
    { 0 },
    &operand_data[11738],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7864 },
#else
    { 0, output_7864, 0 },
#endif
    { 0 },
    &operand_data[11738],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7865 },
#else
    { 0, output_7865, 0 },
#endif
    { 0 },
    &operand_data[11738],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7866 },
#else
    { 0, output_7866, 0 },
#endif
    { 0 },
    &operand_data[11746],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7867 },
#else
    { 0, output_7867, 0 },
#endif
    { 0 },
    &operand_data[11746],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7868 },
#else
    { 0, output_7868, 0 },
#endif
    { 0 },
    &operand_data[11746],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7869 },
#else
    { 0, output_7869, 0 },
#endif
    { 0 },
    &operand_data[11746],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7870 },
#else
    { 0, output_7870, 0 },
#endif
    { 0 },
    &operand_data[11746],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7871 },
#else
    { 0, output_7871, 0 },
#endif
    { 0 },
    &operand_data[11746],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7872 },
#else
    { 0, output_7872, 0 },
#endif
    { 0 },
    &operand_data[11754],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7873 },
#else
    { 0, output_7873, 0 },
#endif
    { 0 },
    &operand_data[11754],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7874 },
#else
    { 0, output_7874, 0 },
#endif
    { 0 },
    &operand_data[11754],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx4hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7875 },
#else
    { 0, output_7875, 0 },
#endif
    { 0 },
    &operand_data[11754],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7876 },
#else
    { 0, output_7876, 0 },
#endif
    { 0 },
    &operand_data[11762],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7877 },
#else
    { 0, output_7877, 0 },
#endif
    { 0 },
    &operand_data[11762],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7878 },
#else
    { 0, output_7878, 0 },
#endif
    { 0 },
    &operand_data[11762],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7879 },
#else
    { 0, output_7879, 0 },
#endif
    { 0 },
    &operand_data[11762],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7880 },
#else
    { 0, output_7880, 0 },
#endif
    { 0 },
    &operand_data[11762],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7881 },
#else
    { 0, output_7881, 0 },
#endif
    { 0 },
    &operand_data[11762],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7882 },
#else
    { 0, output_7882, 0 },
#endif
    { 0 },
    &operand_data[11770],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7883 },
#else
    { 0, output_7883, 0 },
#endif
    { 0 },
    &operand_data[11770],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7884 },
#else
    { 0, output_7884, 0 },
#endif
    { 0 },
    &operand_data[11770],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx2hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7885 },
#else
    { 0, output_7885, 0 },
#endif
    { 0 },
    &operand_data[11770],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7886 },
#else
    { 0, output_7886, 0 },
#endif
    { 0 },
    &operand_data[11778],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7887 },
#else
    { 0, output_7887, 0 },
#endif
    { 0 },
    &operand_data[11778],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7888 },
#else
    { 0, output_7888, 0 },
#endif
    { 0 },
    &operand_data[11778],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7889 },
#else
    { 0, output_7889, 0 },
#endif
    { 0 },
    &operand_data[11778],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7890 },
#else
    { 0, output_7890, 0 },
#endif
    { 0 },
    &operand_data[11778],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7891 },
#else
    { 0, output_7891, 0 },
#endif
    { 0 },
    &operand_data[11778],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7892 },
#else
    { 0, output_7892, 0 },
#endif
    { 0 },
    &operand_data[11786],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7893 },
#else
    { 0, output_7893, 0 },
#endif
    { 0 },
    &operand_data[11786],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7894 },
#else
    { 0, output_7894, 0 },
#endif
    { 0 },
    &operand_data[11786],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx4si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7895 },
#else
    { 0, output_7895, 0 },
#endif
    { 0 },
    &operand_data[11786],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7896 },
#else
    { 0, output_7896, 0 },
#endif
    { 0 },
    &operand_data[11794],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7897 },
#else
    { 0, output_7897, 0 },
#endif
    { 0 },
    &operand_data[11794],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7898 },
#else
    { 0, output_7898, 0 },
#endif
    { 0 },
    &operand_data[11794],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7899 },
#else
    { 0, output_7899, 0 },
#endif
    { 0 },
    &operand_data[11794],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7900 },
#else
    { 0, output_7900, 0 },
#endif
    { 0 },
    &operand_data[11794],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7901 },
#else
    { 0, output_7901, 0 },
#endif
    { 0 },
    &operand_data[11794],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7902 },
#else
    { 0, output_7902, 0 },
#endif
    { 0 },
    &operand_data[11802],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7903 },
#else
    { 0, output_7903, 0 },
#endif
    { 0 },
    &operand_data[11802],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7904 },
#else
    { 0, output_7904, 0 },
#endif
    { 0 },
    &operand_data[11802],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx2si_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7905 },
#else
    { 0, output_7905, 0 },
#endif
    { 0 },
    &operand_data[11802],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpltvnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7906 },
#else
    { 0, output_7906, 0 },
#endif
    { 0 },
    &operand_data[11810],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplevnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7907 },
#else
    { 0, output_7907, 0 },
#endif
    { 0 },
    &operand_data[11810],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpeqvnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7908 },
#else
    { 0, output_7908, 0 },
#endif
    { 0 },
    &operand_data[11810],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpnevnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7909 },
#else
    { 0, output_7909, 0 },
#endif
    { 0 },
    &operand_data[11810],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgevnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7910 },
#else
    { 0, output_7910, 0 },
#endif
    { 0 },
    &operand_data[11810],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmpgtvnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7911 },
#else
    { 0, output_7911, 0 },
#endif
    { 0 },
    &operand_data[11810],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplovnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7912 },
#else
    { 0, output_7912, 0 },
#endif
    { 0 },
    &operand_data[11818],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmplsvnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7913 },
#else
    { 0, output_7913, 0 },
#endif
    { 0 },
    &operand_data[11818],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphsvnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7914 },
#else
    { 0, output_7914, 0 },
#endif
    { 0 },
    &operand_data[11818],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7827 */
  {
    "*cmphivnx2di_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_7915 },
#else
    { 0, output_7915, 0 },
#endif
    { 0 },
    &operand_data[11818],
    8,
    8,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11506],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11506],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11506],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11506],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11506],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11506],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11514],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11514],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11514],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx16qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11514],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11826],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11826],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11826],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11826],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11826],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11826],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11831],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11831],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11831],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx8qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11831],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11836],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11836],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11836],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11836],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11836],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11836],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11841],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11841],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11841],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx4qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11841],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11846],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11846],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11846],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11846],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11846],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11846],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11851],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11851],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11851],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx2qi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11851],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11856],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11856],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11856],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11856],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11856],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11856],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11861],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11861],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11861],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx8hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11861],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11866],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11866],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11866],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11866],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11866],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11866],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11871],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11871],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11871],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx4hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11871],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11876],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11876],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11876],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11876],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11876],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11876],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11881],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11881],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11881],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx2hi_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11881],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11886],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11886],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11886],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11886],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11886],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11886],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11891],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11891],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11891],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx4si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11891],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11896],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11896],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11896],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11896],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11896],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11896],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11901],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11901],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11901],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx2si_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11901],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpltvnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11906],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplevnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11906],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpeqvnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11906],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpnevnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11906],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgevnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11906],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmpgtvnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11906],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplovnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11911],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmplsvnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11911],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphsvnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11911],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7858 */
  {
    "*cmphivnx2di_and",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11911],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpeqvnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpgevnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpgtvnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmphivnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmphsvnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplevnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplovnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplsvnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpltvnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpnevnx16qi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.b, %1/z, %3.b, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx16qi_wide },
    &operand_data[11916],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpeqvnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpgevnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpgtvnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmphivnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmphsvnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplevnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplovnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplsvnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpltvnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpnevnx8hi_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.h, %1/z, %3.h, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx8hi_wide },
    &operand_data[11921],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpeqvnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpeqvnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpgevnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgevnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpgtvnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpgtvnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmphivnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphivnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmphsvnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmphsvnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplevnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplevnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplovnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplovnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmplsvnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmplsvnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpltvnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpltvnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7886 */
  {
    "aarch64_pred_cmpnevnx4si_wide",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.s, %1/z, %3.s, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cmpnevnx4si_wide },
    &operand_data[11926],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpeqvnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpgevnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpgtvnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmphivnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmphsvnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplevnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplovnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplsvnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpltvnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpnevnx16qi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11931],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpeqvnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpgevnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpgtvnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmphivnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmphsvnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplevnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplovnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplsvnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpltvnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpnevnx8hi_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11939],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpeqvnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpgevnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpgtvnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmphivnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmphsvnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplevnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplovnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmplsvnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpltvnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7903 */
  {
    "*aarch64_pred_cmpnevnx4si_wide_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11947],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpeqvnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpgevnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpgtvnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmphivnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmphsvnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplevnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplovnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplsvnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpltvnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpnevnx16qi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.b, %1/z, %2.b, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11955],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpeqvnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpgevnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpgtvnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmphivnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmphsvnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplevnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplovnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplsvnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpltvnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpnevnx8hi_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.h, %1/z, %2.h, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11963],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpeqvnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpeq\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpgevnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpge\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpgtvnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpgt\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmphivnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphi\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmphsvnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmphs\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplevnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmple\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplovnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplo\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmplsvnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpls\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpltvnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmplt\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7934 */
  {
    "*aarch64_pred_cmpnevnx4si_wide_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cmpne\t%0.s, %1/z, %2.s, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[11971],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_lesivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultsivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ulesivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltsivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gesivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtsivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtsivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugesivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwsivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrsivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx16bi },
    &operand_data[11979],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ledivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultdivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_uledivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltdivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gedivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtdivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtdivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugedivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwdivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrdivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx16bi },
    &operand_data[11982],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_lesivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultsivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ulesivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltsivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gesivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtsivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtsivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugesivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwsivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrsivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx8bi },
    &operand_data[11985],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ledivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultdivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_uledivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltdivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gedivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtdivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtdivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugedivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwdivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrdivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx8bi },
    &operand_data[11988],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_lesivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultsivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ulesivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltsivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gesivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtsivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtsivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugesivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwsivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrsivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx4bi },
    &operand_data[11991],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ledivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultdivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_uledivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltdivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gedivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtdivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtdivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugedivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwdivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrdivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx4bi },
    &operand_data[11994],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_lesivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultsivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ulesivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltsivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gesivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtsivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtsivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugesivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwsivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrsivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx2bi },
    &operand_data[11997],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ledivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ultdivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_uledivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ltdivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gedivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_gtdivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugtdivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_ugedivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_rwdivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7973 */
  {
    "while_wrdivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx2bi },
    &operand_data[12000],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_lesivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultsivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ulesivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltsivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gesivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtsivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtsivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugesivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwsivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrsivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12003],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ledivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultdivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_uledivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltdivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gedivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtdivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtdivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugedivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwdivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrdivnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12008],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_lesivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultsivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ulesivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltsivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gesivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtsivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtsivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugesivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwsivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrsivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12013],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ledivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultdivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_uledivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltdivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gedivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtdivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtdivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugedivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwdivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrdivnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12018],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_lesivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultsivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ulesivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltsivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gesivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtsivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtsivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugesivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwsivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrsivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12023],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ledivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultdivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_uledivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltdivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gedivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtdivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtdivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugedivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwdivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrdivnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12028],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_lesivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultsivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ulesivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltsivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gesivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtsivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtsivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugesivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwsivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrsivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12033],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ledivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ultdivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_uledivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ltdivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gedivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_gtdivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugtdivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_ugedivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_rwdivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7986 */
  {
    "*while_wrdivnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12038],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_lesivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultsivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ulesivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltsivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gesivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtsivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtsivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugesivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwsivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrsivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.b, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx16bi_ptest },
    &operand_data[12043],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ledivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultdivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_uledivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltdivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gedivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtdivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtdivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugedivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwdivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrdivnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.b, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx16bi_ptest },
    &operand_data[12048],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_lesivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultsivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ulesivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltsivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gesivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtsivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtsivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugesivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwsivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrsivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.h, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx8bi_ptest },
    &operand_data[12053],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ledivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultdivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_uledivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltdivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gedivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtdivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtdivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugedivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwdivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrdivnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.h, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx8bi_ptest },
    &operand_data[12058],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_lesivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultsivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ulesivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltsivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gesivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtsivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtsivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugesivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwsivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrsivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.s, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx4bi_ptest },
    &operand_data[12063],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ledivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultdivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_uledivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltdivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gedivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtdivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtdivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugedivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwdivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrdivnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.s, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx4bi_ptest },
    &operand_data[12068],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_lesivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_lesivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultsivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultsivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ulesivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ulesivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltsivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltsivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gesivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gesivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtsivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtsivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtsivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtsivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugesivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugesivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwsivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwsivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrsivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.d, %w1, %w2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrsivnx2bi_ptest },
    &operand_data[12073],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ledivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilele\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ledivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ultdivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelo\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ultdivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_uledivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilels\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_uledivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ltdivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilelt\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ltdivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gedivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilege\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gedivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_gtdivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilegt\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_gtdivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugtdivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehi\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugtdivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_ugedivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilehs\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_ugedivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_rwdivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilerw\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_rwdivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8013 */
  {
    "while_wrdivnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "whilewr\t%0.d, %x1, %x2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_while_wrdivnx2bi_ptest },
    &operand_data[12078],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmeqvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8346 },
#else
    { 0, output_8346, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmeqvnx8hf },
    &operand_data[12083],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmgevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8347 },
#else
    { 0, output_8347, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmgevnx8hf },
    &operand_data[12083],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmgtvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8348 },
#else
    { 0, output_8348, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmgtvnx8hf },
    &operand_data[12083],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmlevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8349 },
#else
    { 0, output_8349, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmlevnx8hf },
    &operand_data[12083],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmltvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8350 },
#else
    { 0, output_8350, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmltvnx8hf },
    &operand_data[12083],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmnevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8351 },
#else
    { 0, output_8351, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmnevnx8hf },
    &operand_data[12083],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmeqvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8352 },
#else
    { 0, output_8352, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmeqvnx4sf },
    &operand_data[12088],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmgevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8353 },
#else
    { 0, output_8353, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmgevnx4sf },
    &operand_data[12088],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmgtvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8354 },
#else
    { 0, output_8354, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmgtvnx4sf },
    &operand_data[12088],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmlevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8355 },
#else
    { 0, output_8355, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmlevnx4sf },
    &operand_data[12088],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmltvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8356 },
#else
    { 0, output_8356, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmltvnx4sf },
    &operand_data[12088],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmnevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8357 },
#else
    { 0, output_8357, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmnevnx4sf },
    &operand_data[12088],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmeqvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8358 },
#else
    { 0, output_8358, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmeqvnx2df },
    &operand_data[12093],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmgevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8359 },
#else
    { 0, output_8359, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmgevnx2df },
    &operand_data[12093],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmgtvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8360 },
#else
    { 0, output_8360, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmgtvnx2df },
    &operand_data[12093],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmlevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8361 },
#else
    { 0, output_8361, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmlevnx2df },
    &operand_data[12093],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmltvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8362 },
#else
    { 0, output_8362, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmltvnx2df },
    &operand_data[12093],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8066 */
  {
    "aarch64_pred_fcmnevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8363 },
#else
    { 0, output_8363, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmnevnx2df },
    &operand_data[12093],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8081 */
  {
    "aarch64_pred_fcmuovnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmuo\t%0.h, %1/z, %3.h, %4.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmuovnx8hf },
    &operand_data[12098],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8081 */
  {
    "aarch64_pred_fcmuovnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmuo\t%0.s, %1/z, %3.s, %4.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmuovnx4sf },
    &operand_data[12103],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8081 */
  {
    "aarch64_pred_fcmuovnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcmuo\t%0.d, %1/z, %3.d, %4.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcmuovnx2df },
    &operand_data[12108],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmeqvnx8hf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12113],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmgevnx8hf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12113],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmgtvnx8hf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12113],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmlevnx8hf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12113],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmltvnx8hf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12113],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmnevnx8hf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12113],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmeqvnx4sf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12118],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmgevnx4sf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12118],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmgtvnx4sf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12118],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmlevnx4sf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12118],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmltvnx4sf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12118],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmnevnx4sf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12118],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmeqvnx2df_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12123],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmgevnx2df_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12123],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmgtvnx2df_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12123],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmlevnx2df_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12123],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmltvnx2df_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12123],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8101 */
  {
    "*fcmnevnx2df_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12123],
    5,
    5,
    0,
    2,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8124 */
  {
    "*fcmuovnx8hf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12128],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8124 */
  {
    "*fcmuovnx4sf_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12133],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8124 */
  {
    "*fcmuovnx2df_and_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12138],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmeqvnx8hf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmgevnx8hf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmgtvnx8hf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmlevnx8hf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmltvnx8hf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmnevnx8hf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmeqvnx4sf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmgevnx4sf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmgtvnx4sf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmlevnx4sf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmltvnx4sf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmnevnx4sf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmeqvnx2df_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmgevnx2df_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmgtvnx2df_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmlevnx2df_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmltvnx2df_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8149 */
  {
    "*fcmnevnx2df_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmeqvnx8hf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmgevnx8hf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmgtvnx8hf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmlevnx8hf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmltvnx8hf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmnevnx8hf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmeqvnx4sf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmgevnx4sf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmgtvnx4sf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmlevnx4sf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmltvnx4sf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmnevnx4sf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmeqvnx2df_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmgevnx2df_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmgtvnx2df_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmlevnx2df_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmltvnx2df_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8186 */
  {
    "*fcmnevnx2df_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8225 */
  {
    "*fcmuovnx8hf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8225 */
  {
    "*fcmuovnx4sf_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8225 */
  {
    "*fcmuovnx2df_bic_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8261 */
  {
    "*fcmuovnx8hf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12143],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8261 */
  {
    "*fcmuovnx4sf_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12149],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8261 */
  {
    "*fcmuovnx2df_nor_combine",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "#",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12155],
    5,
    6,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facgevnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12161],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facgtvnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12161],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_faclevnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facle\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12161],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facltvnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faclt\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12161],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facgevnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12168],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facgtvnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12168],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_faclevnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facle\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12168],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facltvnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faclt\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12168],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facgevnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12175],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facgtvnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12175],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_faclevnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facle\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12175],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8330 */
  {
    "*aarch64_pred_facltvnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faclt\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12175],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facgevnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12182],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facgtvnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12182],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_faclevnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facle\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12182],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facltvnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faclt\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12182],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facgevnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12189],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facgtvnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12189],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_faclevnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facle\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12189],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facltvnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faclt\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12189],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facgevnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facge\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12196],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facgtvnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facgt\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12196],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_faclevnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "facle\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12196],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8356 */
  {
    "*aarch64_pred_facltvnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faclt\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12196],
    7,
    7,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8383 */
  {
    "vcond_mask_vnx16bivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sel\t%0.b, %3, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx16bivnx16bi },
    &operand_data[10795],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8383 */
  {
    "vcond_mask_vnx8bivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sel\t%0.b, %3, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx8bivnx8bi },
    &operand_data[10799],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8383 */
  {
    "vcond_mask_vnx4bivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sel\t%0.b, %3, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx4bivnx4bi },
    &operand_data[10803],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8383 */
  {
    "vcond_mask_vnx2bivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sel\t%0.b, %3, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2bivnx2bi },
    &operand_data[10807],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8433 */
  {
    "aarch64_ptestvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ptest\t%0, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ptestvnx16bi },
    &operand_data[12203],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8433 */
  {
    "aarch64_ptestvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ptest\t%0, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ptestvnx8bi },
    &operand_data[12206],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8433 */
  {
    "aarch64_ptestvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ptest\t%0, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ptestvnx4bi },
    &operand_data[12210],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8433 */
  {
    "aarch64_ptestvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ptest\t%0, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ptestvnx2bi },
    &operand_data[12214],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8462 },
#else
    { 0, output_8462, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx16qi },
    &operand_data[12218],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8463 },
#else
    { 0, output_8463, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx16qi },
    &operand_data[12218],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8464 },
#else
    { 0, output_8464, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx8hi },
    &operand_data[12222],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8465 },
#else
    { 0, output_8465, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx8hi },
    &operand_data[12222],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8466 },
#else
    { 0, output_8466, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx4si },
    &operand_data[12226],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8467 },
#else
    { 0, output_8467, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx4si },
    &operand_data[12226],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8468 },
#else
    { 0, output_8468, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx2di },
    &operand_data[12230],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8469 },
#else
    { 0, output_8469, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx2di },
    &operand_data[12230],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8470 },
#else
    { 0, output_8470, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx8bf },
    &operand_data[12234],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8471 },
#else
    { 0, output_8471, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx8bf },
    &operand_data[12234],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8472 },
#else
    { 0, output_8472, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx8hf },
    &operand_data[12238],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8473 },
#else
    { 0, output_8473, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx8hf },
    &operand_data[12238],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8474 },
#else
    { 0, output_8474, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx4sf },
    &operand_data[12242],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8475 },
#else
    { 0, output_8475, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx4sf },
    &operand_data[12242],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_after_last_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8476 },
#else
    { 0, output_8476, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_after_last_vnx2df },
    &operand_data[12246],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8458 */
  {
    "fold_extract_last_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8477 },
#else
    { 0, output_8477, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_extract_last_vnx2df },
    &operand_data[12246],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8478 },
#else
    { 0, output_8478, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx16qi },
    &operand_data[12250],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8479 },
#else
    { 0, output_8479, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx16qi },
    &operand_data[12250],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8480 },
#else
    { 0, output_8480, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx8hi },
    &operand_data[12254],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8481 },
#else
    { 0, output_8481, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx8hi },
    &operand_data[12254],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8482 },
#else
    { 0, output_8482, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx4si },
    &operand_data[12258],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8483 },
#else
    { 0, output_8483, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx4si },
    &operand_data[12258],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8484 },
#else
    { 0, output_8484, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx2di },
    &operand_data[12262],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8485 },
#else
    { 0, output_8485, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx2di },
    &operand_data[12262],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8486 },
#else
    { 0, output_8486, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx8bf },
    &operand_data[12266],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8487 },
#else
    { 0, output_8487, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx8bf },
    &operand_data[12266],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8488 },
#else
    { 0, output_8488, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx8hf },
    &operand_data[12270],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8489 },
#else
    { 0, output_8489, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx8hf },
    &operand_data[12270],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8490 },
#else
    { 0, output_8490, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx4sf },
    &operand_data[12274],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8491 },
#else
    { 0, output_8491, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx4sf },
    &operand_data[12274],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_after_last_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8492 },
#else
    { 0, output_8492, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_after_last_vnx2df },
    &operand_data[12278],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8471 */
  {
    "aarch64_fold_extract_vector_last_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8493 },
#else
    { 0, output_8493, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fold_extract_vector_last_vnx2df },
    &operand_data[12278],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8515 */
  {
    "aarch64_pred_reduc_sadd_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddv\t%d0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_sadd_vnx16qi },
    &operand_data[12282],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8515 */
  {
    "aarch64_pred_reduc_uadd_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddv\t%d0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_uadd_vnx16qi },
    &operand_data[12282],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8515 */
  {
    "aarch64_pred_reduc_sadd_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddv\t%d0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_sadd_vnx8hi },
    &operand_data[12285],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8515 */
  {
    "aarch64_pred_reduc_uadd_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddv\t%d0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_uadd_vnx8hi },
    &operand_data[12285],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8515 */
  {
    "aarch64_pred_reduc_sadd_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddv\t%d0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_sadd_vnx4si },
    &operand_data[12288],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8515 */
  {
    "aarch64_pred_reduc_uadd_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddv\t%d0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_uadd_vnx4si },
    &operand_data[12288],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8515 */
  {
    "aarch64_pred_reduc_uadd_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_uadd_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_and_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "andv\t%b0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_and_vnx16qi },
    &operand_data[12294],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_ior_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orv\t%b0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_ior_vnx16qi },
    &operand_data[12294],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smax_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%b0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_vnx16qi },
    &operand_data[12294],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smin_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%b0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_vnx16qi },
    &operand_data[12294],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umax_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%b0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umax_vnx16qi },
    &operand_data[12294],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umin_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%b0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umin_vnx16qi },
    &operand_data[12294],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_xor_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eorv\t%b0, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_xor_vnx16qi },
    &operand_data[12294],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_and_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "andv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_and_vnx8hi },
    &operand_data[12297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_ior_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_ior_vnx8hi },
    &operand_data[12297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smax_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_vnx8hi },
    &operand_data[12297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smin_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_vnx8hi },
    &operand_data[12297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umax_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umax_vnx8hi },
    &operand_data[12297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umin_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umin_vnx8hi },
    &operand_data[12297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_xor_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eorv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_xor_vnx8hi },
    &operand_data[12297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_and_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "andv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_and_vnx4si },
    &operand_data[12300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_ior_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_ior_vnx4si },
    &operand_data[12300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smax_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_vnx4si },
    &operand_data[12300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smin_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_vnx4si },
    &operand_data[12300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umax_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umax_vnx4si },
    &operand_data[12300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umin_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umin_vnx4si },
    &operand_data[12300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_xor_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eorv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_xor_vnx4si },
    &operand_data[12300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_and_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "andv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_and_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_ior_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "orv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_ior_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smax_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smaxv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_smin_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sminv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umax_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umaxv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umax_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_umin_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uminv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_umin_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8537 */
  {
    "aarch64_pred_reduc_xor_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "eorv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_xor_vnx2di },
    &operand_data[12291],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_plus_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_plus_vnx8hf },
    &operand_data[12303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smax_nan_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_nan_vnx8hf },
    &operand_data[12303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smax_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_vnx8hf },
    &operand_data[12303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smin_nan_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_nan_vnx8hf },
    &operand_data[12303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smin_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmv\t%h0, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_vnx8hf },
    &operand_data[12303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_plus_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_plus_vnx4sf },
    &operand_data[12306],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smax_nan_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_nan_vnx4sf },
    &operand_data[12306],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smax_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_vnx4sf },
    &operand_data[12306],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smin_nan_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_nan_vnx4sf },
    &operand_data[12306],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smin_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmv\t%s0, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_vnx4sf },
    &operand_data[12306],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_plus_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "faddv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_plus_vnx2df },
    &operand_data[12309],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smax_nan_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_nan_vnx2df },
    &operand_data[12309],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smax_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fmaxnmv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smax_vnx2df },
    &operand_data[12309],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smin_nan_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_nan_vnx2df },
    &operand_data[12309],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8581 */
  {
    "aarch64_pred_reduc_smin_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fminnmv\t%d0, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_reduc_smin_vnx2df },
    &operand_data[12309],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8611 */
  {
    "mask_fold_left_plus_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadda\t%h0, %3, %h0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_fold_left_plus_vnx8hf },
    &operand_data[12312],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8611 */
  {
    "mask_fold_left_plus_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadda\t%s0, %3, %s0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_fold_left_plus_vnx4sf },
    &operand_data[12316],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8611 */
  {
    "mask_fold_left_plus_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fadda\t%d0, %3, %d0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mask_fold_left_plus_vnx2df },
    &operand_data[12320],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx8bf },
    &operand_data[12324],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx8hf },
    &operand_data[10297],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx4sf },
    &operand_data[10300],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8645 */
  {
    "aarch64_sve_tblvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_tblvnx2df },
    &operand_data[10303],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8665 */
  {
    "aarch64_sve_compactvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "compact\t%0.s, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_compactvnx4si },
    &operand_data[12327],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8665 */
  {
    "aarch64_sve_compactvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "compact\t%0.d, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_compactvnx2di },
    &operand_data[12330],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8665 */
  {
    "aarch64_sve_compactvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "compact\t%0.s, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_compactvnx4sf },
    &operand_data[12333],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8665 */
  {
    "aarch64_sve_compactvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "compact\t%0.d, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_compactvnx2df },
    &operand_data[12336],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.b, %1.b[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx16qi },
    &operand_data[12339],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.h, %1.h[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx8qi },
    &operand_data[12342],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.s, %1.s[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx4qi },
    &operand_data[12345],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2qi },
    &operand_data[12348],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.h, %1.h[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx8hi },
    &operand_data[12351],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.s, %1.s[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx4hi },
    &operand_data[12354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2hi },
    &operand_data[12357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.h, %1.h[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx8hf },
    &operand_data[12360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.s, %1.s[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx4hf },
    &operand_data[12363],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2hf },
    &operand_data[12366],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.h, %1.h[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx8bf },
    &operand_data[12369],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.s, %1.s[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx4bf },
    &operand_data[12372],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2bf },
    &operand_data[12375],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.s, %1.s[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx4si },
    &operand_data[12378],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2si },
    &operand_data[12381],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.s, %1.s[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx4sf },
    &operand_data[12384],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2sf },
    &operand_data[12387],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2di },
    &operand_data[12390],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8676 */
  {
    "aarch64_sve_dup_lanevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "dup\t%0.d, %1.d[%2]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dup_lanevnx2df },
    &operand_data[12393],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8578 },
#else
    { 0, 0, output_8578 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx16qi },
    &operand_data[12396],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8579 },
#else
    { 0, 0, output_8579 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx8hi },
    &operand_data[12399],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8580 },
#else
    { 0, 0, output_8580 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx4si },
    &operand_data[12402],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8581 },
#else
    { 0, 0, output_8581 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx2di },
    &operand_data[12405],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8582 },
#else
    { 0, 0, output_8582 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx8bf },
    &operand_data[12408],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8583 },
#else
    { 0, 0, output_8583 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx8hf },
    &operand_data[12411],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8584 },
#else
    { 0, 0, output_8584 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx4sf },
    &operand_data[12414],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8704 */
  {
    "aarch64_sve_dupq_lanevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8585 },
#else
    { 0, 0, output_8585 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_dupq_lanevnx2df },
    &operand_data[12417],
    3,
    3,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.b, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx16qi },
    &operand_data[9635],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx8qi },
    &operand_data[9639],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx4qi },
    &operand_data[9296],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2qi },
    &operand_data[9276],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx8hi },
    &operand_data[9651],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx4hi },
    &operand_data[9301],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2hi },
    &operand_data[9281],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx8hf },
    &operand_data[8878],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx4hf },
    &operand_data[12363],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2hf },
    &operand_data[12366],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx8bf },
    &operand_data[12324],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx4bf },
    &operand_data[12372],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2bf },
    &operand_data[12375],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx4si },
    &operand_data[9265],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2si },
    &operand_data[9286],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx4sf },
    &operand_data[8880],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2sf },
    &operand_data[12387],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2di },
    &operand_data[9268],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8724 */
  {
    "aarch64_sve_revvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2df },
    &operand_data[8882],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8605 },
#else
    { 0, output_8605, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx16qi },
    &operand_data[9075],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8606 },
#else
    { 0, output_8606, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx8hi },
    &operand_data[9091],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8607 },
#else
    { 0, output_8607, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx4si },
    &operand_data[9103],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8608 },
#else
    { 0, output_8608, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx2di },
    &operand_data[9111],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8609 },
#else
    { 0, output_8609, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx8bf },
    &operand_data[12420],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8610 },
#else
    { 0, output_8610, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx8hf },
    &operand_data[10378],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8611 },
#else
    { 0, output_8611, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx4sf },
    &operand_data[10383],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8747 */
  {
    "aarch64_sve_splicevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8612 },
#else
    { 0, output_8612, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_splicevnx2df },
    &operand_data[10388],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx8qi },
    &operand_data[9639],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx8qi },
    &operand_data[9639],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx8qi },
    &operand_data[9639],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx8qi },
    &operand_data[9639],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx8qi },
    &operand_data[9639],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx8qi },
    &operand_data[9639],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx4qi },
    &operand_data[9296],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx4qi },
    &operand_data[9296],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx4qi },
    &operand_data[9296],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx4qi },
    &operand_data[9296],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx4qi },
    &operand_data[9296],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx4qi },
    &operand_data[9296],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2qi },
    &operand_data[9276],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2qi },
    &operand_data[9276],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2qi },
    &operand_data[9276],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2qi },
    &operand_data[9276],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2qi },
    &operand_data[9276],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2qi },
    &operand_data[9276],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx4hi },
    &operand_data[9301],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx4hi },
    &operand_data[9301],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx4hi },
    &operand_data[9301],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx4hi },
    &operand_data[9301],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx4hi },
    &operand_data[9301],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx4hi },
    &operand_data[9301],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2hi },
    &operand_data[9281],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2hi },
    &operand_data[9281],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2hi },
    &operand_data[9281],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2hi },
    &operand_data[9281],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2hi },
    &operand_data[9281],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2hi },
    &operand_data[9281],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx4hf },
    &operand_data[12424],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx4hf },
    &operand_data[12424],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx4hf },
    &operand_data[12424],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx4hf },
    &operand_data[12424],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx4hf },
    &operand_data[12424],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx4hf },
    &operand_data[12424],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2hf },
    &operand_data[12427],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2hf },
    &operand_data[12427],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2hf },
    &operand_data[12427],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2hf },
    &operand_data[12427],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2hf },
    &operand_data[12427],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2hf },
    &operand_data[12427],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx4bf },
    &operand_data[12433],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx4bf },
    &operand_data[12433],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx4bf },
    &operand_data[12433],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx4bf },
    &operand_data[12433],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx4bf },
    &operand_data[12433],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx4bf },
    &operand_data[12433],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2bf },
    &operand_data[12436],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2bf },
    &operand_data[12436],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2bf },
    &operand_data[12436],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2bf },
    &operand_data[12436],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2bf },
    &operand_data[12436],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2bf },
    &operand_data[12436],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2si },
    &operand_data[9286],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2si },
    &operand_data[9286],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2si },
    &operand_data[9286],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2si },
    &operand_data[9286],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2si },
    &operand_data[9286],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2si },
    &operand_data[9286],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2sf },
    &operand_data[12439],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2sf },
    &operand_data[12439],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2sf },
    &operand_data[12439],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2sf },
    &operand_data[12439],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2sf },
    &operand_data[12439],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2sf },
    &operand_data[12439],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip1vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_zip2vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn1vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_trn2vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp1vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8763 */
  {
    "aarch64_sve_uzp2vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx8bf },
    &operand_data[12430],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx8hf },
    &operand_data[10354],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx4sf },
    &operand_data[10357],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip1qvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1qvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_zip2qvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2qvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn1qvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1qvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_trn2qvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2qvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp1qvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1qvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8775 */
  {
    "aarch64_sve_uzp2qvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.q, %1.q, %2.q",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2qvnx2df },
    &operand_data[10360],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8775 },
#else
    { 0, 0, output_8775 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx16qi },
    &operand_data[12442],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8776 },
#else
    { 0, 0, output_8776 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx8qi },
    &operand_data[12446],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8777 },
#else
    { 0, 0, output_8777 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx4qi },
    &operand_data[12450],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8778 },
#else
    { 0, 0, output_8778 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2qi },
    &operand_data[12454],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8779 },
#else
    { 0, 0, output_8779 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx8hi },
    &operand_data[12458],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8780 },
#else
    { 0, 0, output_8780 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx4hi },
    &operand_data[12462],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8781 },
#else
    { 0, 0, output_8781 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2hi },
    &operand_data[12466],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8782 },
#else
    { 0, 0, output_8782 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx8hf },
    &operand_data[12470],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8783 },
#else
    { 0, 0, output_8783 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx4hf },
    &operand_data[12474],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8784 },
#else
    { 0, 0, output_8784 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2hf },
    &operand_data[12478],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8785 },
#else
    { 0, 0, output_8785 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx8bf },
    &operand_data[12482],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8786 },
#else
    { 0, 0, output_8786 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx4bf },
    &operand_data[12486],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8787 },
#else
    { 0, 0, output_8787 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2bf },
    &operand_data[12490],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8788 },
#else
    { 0, 0, output_8788 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx4si },
    &operand_data[12494],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8789 },
#else
    { 0, 0, output_8789 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2si },
    &operand_data[12498],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8790 },
#else
    { 0, 0, output_8790 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx4sf },
    &operand_data[12502],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8791 },
#else
    { 0, 0, output_8791 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2sf },
    &operand_data[12506],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8792 },
#else
    { 0, 0, output_8792 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2di },
    &operand_data[12510],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8787 */
  {
    "aarch64_sve_extvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8793 },
#else
    { 0, 0, output_8793 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_extvnx2df },
    &operand_data[12514],
    4,
    4,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8812 */
  {
    "aarch64_sve_revvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.b, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx16bi },
    &operand_data[6555],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8812 */
  {
    "aarch64_sve_revvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.h, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx8bi },
    &operand_data[8926],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8812 */
  {
    "aarch64_sve_revvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.s, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx4bi },
    &operand_data[8929],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8812 */
  {
    "aarch64_sve_revvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rev\t%0.d, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_revvnx2bi },
    &operand_data[8932],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip1vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx16bi },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip2vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx16bi },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn1vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx16bi },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn2vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx16bi },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp1vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx16bi },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp2vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx16bi },
    &operand_data[8923],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip1vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx8bi },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip2vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx8bi },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn1vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx8bi },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn2vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx8bi },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp1vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx8bi },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp2vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx8bi },
    &operand_data[8926],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip1vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx4bi },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip2vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx4bi },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn1vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx4bi },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn2vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx4bi },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp1vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx4bi },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp2vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx4bi },
    &operand_data[8929],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip1vnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip1vnx2bi },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_zip2vnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "zip2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_zip2vnx2bi },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn1vnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1vnx2bi },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_trn2vnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn2vnx2bi },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp1vnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp1vnx2bi },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8833 */
  {
    "aarch64_sve_uzp2vnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp2\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uzp2vnx2bi },
    &operand_data[8932],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8846 */
  {
    "aarch64_sve_trn1_convvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1_convvnx16bi },
    &operand_data[12518],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8846 */
  {
    "aarch64_sve_trn1_convvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1_convvnx8bi },
    &operand_data[12522],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8846 */
  {
    "aarch64_sve_trn1_convvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1_convvnx4bi },
    &operand_data[12526],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8846 */
  {
    "aarch64_sve_trn1_convvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "trn1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_trn1_convvnx2bi },
    &operand_data[12530],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8869 */
  {
    "vec_pack_trunc_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx8hi },
    &operand_data[12534],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8869 */
  {
    "vec_pack_trunc_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx4si },
    &operand_data[12537],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8869 */
  {
    "vec_pack_trunc_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx2di },
    &operand_data[12540],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_sunpkhi_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sunpkhi\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sunpkhi_vnx16qi },
    &operand_data[12543],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_uunpkhi_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uunpkhi\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uunpkhi_vnx16qi },
    &operand_data[12543],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_sunpklo_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sunpklo\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sunpklo_vnx16qi },
    &operand_data[12543],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_uunpklo_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uunpklo\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uunpklo_vnx16qi },
    &operand_data[12543],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_sunpkhi_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sunpkhi\t%0.s, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sunpkhi_vnx8hi },
    &operand_data[12545],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_uunpkhi_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uunpkhi\t%0.s, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uunpkhi_vnx8hi },
    &operand_data[12545],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_sunpklo_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sunpklo\t%0.s, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sunpklo_vnx8hi },
    &operand_data[12545],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_uunpklo_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uunpklo\t%0.s, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uunpklo_vnx8hi },
    &operand_data[12545],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_sunpkhi_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sunpkhi\t%0.d, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sunpkhi_vnx4si },
    &operand_data[12547],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_uunpkhi_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uunpkhi\t%0.d, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uunpkhi_vnx4si },
    &operand_data[12547],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_sunpklo_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sunpklo\t%0.d, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sunpklo_vnx4si },
    &operand_data[12547],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8906 */
  {
    "aarch64_sve_uunpklo_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uunpklo\t%0.d, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uunpklo_vnx4si },
    &operand_data[12547],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fix_trunc_nontruncvnx8hfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8841 },
#else
    { 0, output_8841, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fix_trunc_nontruncvnx8hfvnx8hi },
    &operand_data[12549],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fixuns_trunc_nontruncvnx8hfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8842 },
#else
    { 0, output_8842, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fixuns_trunc_nontruncvnx8hfvnx8hi },
    &operand_data[12549],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fix_trunc_nontruncvnx8hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8843 },
#else
    { 0, output_8843, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fix_trunc_nontruncvnx8hfvnx4si },
    &operand_data[12553],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fixuns_trunc_nontruncvnx8hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8844 },
#else
    { 0, output_8844, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fixuns_trunc_nontruncvnx8hfvnx4si },
    &operand_data[12553],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fix_trunc_nontruncvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8845 },
#else
    { 0, output_8845, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fix_trunc_nontruncvnx4sfvnx4si },
    &operand_data[12557],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fixuns_trunc_nontruncvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8846 },
#else
    { 0, output_8846, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fixuns_trunc_nontruncvnx4sfvnx4si },
    &operand_data[12557],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fix_trunc_nontruncvnx8hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8847 },
#else
    { 0, output_8847, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fix_trunc_nontruncvnx8hfvnx2di },
    &operand_data[12561],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fixuns_trunc_nontruncvnx8hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8848 },
#else
    { 0, output_8848, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fixuns_trunc_nontruncvnx8hfvnx2di },
    &operand_data[12561],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fix_trunc_nontruncvnx4sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8849 },
#else
    { 0, output_8849, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fix_trunc_nontruncvnx4sfvnx2di },
    &operand_data[12565],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fixuns_trunc_nontruncvnx4sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8850 },
#else
    { 0, output_8850, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fixuns_trunc_nontruncvnx4sfvnx2di },
    &operand_data[12565],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fix_trunc_nontruncvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8851 },
#else
    { 0, output_8851, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fix_trunc_nontruncvnx2dfvnx2di },
    &operand_data[12569],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8939 */
  {
    "aarch64_sve_fixuns_trunc_nontruncvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8852 },
#else
    { 0, output_8852, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fixuns_trunc_nontruncvnx2dfvnx2di },
    &operand_data[12569],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8954 */
  {
    "aarch64_sve_fix_trunc_truncvnx2dfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8853 },
#else
    { 0, output_8853, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fix_trunc_truncvnx2dfvnx4si },
    &operand_data[12573],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8954 */
  {
    "aarch64_sve_fixuns_trunc_truncvnx2dfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8854 },
#else
    { 0, output_8854, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fixuns_trunc_truncvnx2dfvnx4si },
    &operand_data[12573],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fix_trunc_nontruncvnx8hfvnx8hi_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8855 },
#else
    { 0, output_8855, 0 },
#endif
    { 0 },
    &operand_data[12577],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fixuns_trunc_nontruncvnx8hfvnx8hi_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8856 },
#else
    { 0, output_8856, 0 },
#endif
    { 0 },
    &operand_data[12577],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fix_trunc_nontruncvnx8hfvnx4si_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8857 },
#else
    { 0, output_8857, 0 },
#endif
    { 0 },
    &operand_data[12582],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fixuns_trunc_nontruncvnx8hfvnx4si_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8858 },
#else
    { 0, output_8858, 0 },
#endif
    { 0 },
    &operand_data[12582],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fix_trunc_nontruncvnx4sfvnx4si_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8859 },
#else
    { 0, output_8859, 0 },
#endif
    { 0 },
    &operand_data[12587],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fixuns_trunc_nontruncvnx4sfvnx4si_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8860 },
#else
    { 0, output_8860, 0 },
#endif
    { 0 },
    &operand_data[12587],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fix_trunc_nontruncvnx8hfvnx2di_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8861 },
#else
    { 0, output_8861, 0 },
#endif
    { 0 },
    &operand_data[12592],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fixuns_trunc_nontruncvnx8hfvnx2di_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8862 },
#else
    { 0, output_8862, 0 },
#endif
    { 0 },
    &operand_data[12592],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fix_trunc_nontruncvnx4sfvnx2di_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8863 },
#else
    { 0, output_8863, 0 },
#endif
    { 0 },
    &operand_data[12597],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fixuns_trunc_nontruncvnx4sfvnx2di_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8864 },
#else
    { 0, output_8864, 0 },
#endif
    { 0 },
    &operand_data[12597],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fix_trunc_nontruncvnx2dfvnx2di_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8865 },
#else
    { 0, output_8865, 0 },
#endif
    { 0 },
    &operand_data[12602],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8989 */
  {
    "*cond_fixuns_trunc_nontruncvnx2dfvnx2di_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8866 },
#else
    { 0, output_8866, 0 },
#endif
    { 0 },
    &operand_data[12602],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fix_trunc_nontruncvnx8hfvnx8hi_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8867 },
#else
    { 0, output_8867, 0 },
#endif
    { 0 },
    &operand_data[12577],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fixuns_trunc_nontruncvnx8hfvnx8hi_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8868 },
#else
    { 0, output_8868, 0 },
#endif
    { 0 },
    &operand_data[12577],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fix_trunc_nontruncvnx8hfvnx4si_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8869 },
#else
    { 0, output_8869, 0 },
#endif
    { 0 },
    &operand_data[12582],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fixuns_trunc_nontruncvnx8hfvnx4si_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8870 },
#else
    { 0, output_8870, 0 },
#endif
    { 0 },
    &operand_data[12582],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fix_trunc_nontruncvnx4sfvnx4si_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8871 },
#else
    { 0, output_8871, 0 },
#endif
    { 0 },
    &operand_data[12587],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fixuns_trunc_nontruncvnx4sfvnx4si_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8872 },
#else
    { 0, output_8872, 0 },
#endif
    { 0 },
    &operand_data[12587],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fix_trunc_nontruncvnx8hfvnx2di_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8873 },
#else
    { 0, output_8873, 0 },
#endif
    { 0 },
    &operand_data[12592],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fixuns_trunc_nontruncvnx8hfvnx2di_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8874 },
#else
    { 0, output_8874, 0 },
#endif
    { 0 },
    &operand_data[12592],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fix_trunc_nontruncvnx4sfvnx2di_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8875 },
#else
    { 0, output_8875, 0 },
#endif
    { 0 },
    &operand_data[12597],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fixuns_trunc_nontruncvnx4sfvnx2di_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8876 },
#else
    { 0, output_8876, 0 },
#endif
    { 0 },
    &operand_data[12597],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fix_trunc_nontruncvnx2dfvnx2di_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8877 },
#else
    { 0, output_8877, 0 },
#endif
    { 0 },
    &operand_data[12602],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9012 */
  {
    "*cond_fixuns_trunc_nontruncvnx2dfvnx2di_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8878 },
#else
    { 0, output_8878, 0 },
#endif
    { 0 },
    &operand_data[12602],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9046 */
  {
    "*cond_fix_trunc_truncvnx2dfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8879 },
#else
    { 0, output_8879, 0 },
#endif
    { 0 },
    &operand_data[12607],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9046 */
  {
    "*cond_fixuns_trunc_truncvnx2dfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8880 },
#else
    { 0, output_8880, 0 },
#endif
    { 0 },
    &operand_data[12607],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_float_nonextendvnx8hivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8881 },
#else
    { 0, output_8881, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_float_nonextendvnx8hivnx8hf },
    &operand_data[12612],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_floatuns_nonextendvnx8hivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8882 },
#else
    { 0, output_8882, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_floatuns_nonextendvnx8hivnx8hf },
    &operand_data[12612],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_float_nonextendvnx4sivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8883 },
#else
    { 0, output_8883, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_float_nonextendvnx4sivnx8hf },
    &operand_data[12616],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_floatuns_nonextendvnx4sivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8884 },
#else
    { 0, output_8884, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_floatuns_nonextendvnx4sivnx8hf },
    &operand_data[12616],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_float_nonextendvnx4sivnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8885 },
#else
    { 0, output_8885, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_float_nonextendvnx4sivnx4sf },
    &operand_data[12620],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_floatuns_nonextendvnx4sivnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8886 },
#else
    { 0, output_8886, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_floatuns_nonextendvnx4sivnx4sf },
    &operand_data[12620],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_float_nonextendvnx2divnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8887 },
#else
    { 0, output_8887, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_float_nonextendvnx2divnx8hf },
    &operand_data[12624],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_floatuns_nonextendvnx2divnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8888 },
#else
    { 0, output_8888, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_floatuns_nonextendvnx2divnx8hf },
    &operand_data[12624],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_float_nonextendvnx2divnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8889 },
#else
    { 0, output_8889, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_float_nonextendvnx2divnx4sf },
    &operand_data[12628],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_floatuns_nonextendvnx2divnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8890 },
#else
    { 0, output_8890, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_floatuns_nonextendvnx2divnx4sf },
    &operand_data[12628],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_float_nonextendvnx2divnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8891 },
#else
    { 0, output_8891, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_float_nonextendvnx2divnx2df },
    &operand_data[12632],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9126 */
  {
    "aarch64_sve_floatuns_nonextendvnx2divnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8892 },
#else
    { 0, output_8892, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_floatuns_nonextendvnx2divnx2df },
    &operand_data[12632],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9141 */
  {
    "aarch64_sve_float_extendvnx4sivnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8893 },
#else
    { 0, output_8893, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_float_extendvnx4sivnx2df },
    &operand_data[12636],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9141 */
  {
    "aarch64_sve_floatuns_extendvnx4sivnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8894 },
#else
    { 0, output_8894, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_floatuns_extendvnx4sivnx2df },
    &operand_data[12636],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_float_nonextendvnx8hivnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8895 },
#else
    { 0, output_8895, 0 },
#endif
    { 0 },
    &operand_data[12640],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_floatuns_nonextendvnx8hivnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8896 },
#else
    { 0, output_8896, 0 },
#endif
    { 0 },
    &operand_data[12640],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_float_nonextendvnx4sivnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8897 },
#else
    { 0, output_8897, 0 },
#endif
    { 0 },
    &operand_data[12645],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_floatuns_nonextendvnx4sivnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8898 },
#else
    { 0, output_8898, 0 },
#endif
    { 0 },
    &operand_data[12645],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_float_nonextendvnx4sivnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8899 },
#else
    { 0, output_8899, 0 },
#endif
    { 0 },
    &operand_data[12650],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_floatuns_nonextendvnx4sivnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8900 },
#else
    { 0, output_8900, 0 },
#endif
    { 0 },
    &operand_data[12650],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_float_nonextendvnx2divnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8901 },
#else
    { 0, output_8901, 0 },
#endif
    { 0 },
    &operand_data[12655],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_floatuns_nonextendvnx2divnx8hf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8902 },
#else
    { 0, output_8902, 0 },
#endif
    { 0 },
    &operand_data[12655],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_float_nonextendvnx2divnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8903 },
#else
    { 0, output_8903, 0 },
#endif
    { 0 },
    &operand_data[12660],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_floatuns_nonextendvnx2divnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8904 },
#else
    { 0, output_8904, 0 },
#endif
    { 0 },
    &operand_data[12660],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_float_nonextendvnx2divnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8905 },
#else
    { 0, output_8905, 0 },
#endif
    { 0 },
    &operand_data[12665],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9176 */
  {
    "*cond_floatuns_nonextendvnx2divnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8906 },
#else
    { 0, output_8906, 0 },
#endif
    { 0 },
    &operand_data[12665],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_float_nonextendvnx8hivnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8907 },
#else
    { 0, output_8907, 0 },
#endif
    { 0 },
    &operand_data[12640],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_floatuns_nonextendvnx8hivnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8908 },
#else
    { 0, output_8908, 0 },
#endif
    { 0 },
    &operand_data[12640],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_float_nonextendvnx4sivnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8909 },
#else
    { 0, output_8909, 0 },
#endif
    { 0 },
    &operand_data[12645],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_floatuns_nonextendvnx4sivnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8910 },
#else
    { 0, output_8910, 0 },
#endif
    { 0 },
    &operand_data[12645],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_float_nonextendvnx4sivnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8911 },
#else
    { 0, output_8911, 0 },
#endif
    { 0 },
    &operand_data[12650],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_floatuns_nonextendvnx4sivnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8912 },
#else
    { 0, output_8912, 0 },
#endif
    { 0 },
    &operand_data[12650],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_float_nonextendvnx2divnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8913 },
#else
    { 0, output_8913, 0 },
#endif
    { 0 },
    &operand_data[12655],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_floatuns_nonextendvnx2divnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8914 },
#else
    { 0, output_8914, 0 },
#endif
    { 0 },
    &operand_data[12655],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_float_nonextendvnx2divnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8915 },
#else
    { 0, output_8915, 0 },
#endif
    { 0 },
    &operand_data[12660],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_floatuns_nonextendvnx2divnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8916 },
#else
    { 0, output_8916, 0 },
#endif
    { 0 },
    &operand_data[12660],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_float_nonextendvnx2divnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8917 },
#else
    { 0, output_8917, 0 },
#endif
    { 0 },
    &operand_data[12665],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9199 */
  {
    "*cond_floatuns_nonextendvnx2divnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8918 },
#else
    { 0, output_8918, 0 },
#endif
    { 0 },
    &operand_data[12665],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9233 */
  {
    "*cond_float_extendvnx4sivnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8919 },
#else
    { 0, output_8919, 0 },
#endif
    { 0 },
    &operand_data[12670],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9233 */
  {
    "*cond_floatuns_extendvnx4sivnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8920 },
#else
    { 0, output_8920, 0 },
#endif
    { 0 },
    &operand_data[12670],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9324 */
  {
    "aarch64_sve_fcvt_truncvnx4sfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8921 },
#else
    { 0, output_8921, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fcvt_truncvnx4sfvnx8hf },
    &operand_data[12675],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9324 */
  {
    "aarch64_sve_fcvt_truncvnx2dfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8922 },
#else
    { 0, output_8922, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fcvt_truncvnx2dfvnx8hf },
    &operand_data[12679],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9324 */
  {
    "aarch64_sve_fcvt_truncvnx2dfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8923 },
#else
    { 0, output_8923, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fcvt_truncvnx2dfvnx4sf },
    &operand_data[12683],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9353 */
  {
    "*cond_fcvt_truncvnx4sfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8924 },
#else
    { 0, output_8924, 0 },
#endif
    { 0 },
    &operand_data[12687],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9353 */
  {
    "*cond_fcvt_truncvnx2dfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8925 },
#else
    { 0, output_8925, 0 },
#endif
    { 0 },
    &operand_data[12692],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9353 */
  {
    "*cond_fcvt_truncvnx2dfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8926 },
#else
    { 0, output_8926, 0 },
#endif
    { 0 },
    &operand_data[12697],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9381 */
  {
    "aarch64_sve_fcvt_truncvnx4sfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8927 },
#else
    { 0, output_8927, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fcvt_truncvnx4sfvnx8bf },
    &operand_data[12702],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9410 */
  {
    "*cond_fcvt_truncvnx4sfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8928 },
#else
    { 0, output_8928, 0 },
#endif
    { 0 },
    &operand_data[12706],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9434 */
  {
    "aarch64_sve_cvtntvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bfcvtnt\t%0.h, %2/m, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cvtntvnx8bf },
    &operand_data[12711],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9481 */
  {
    "aarch64_sve_fcvt_nontruncvnx8hfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8930 },
#else
    { 0, output_8930, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fcvt_nontruncvnx8hfvnx4sf },
    &operand_data[12715],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9481 */
  {
    "aarch64_sve_fcvt_nontruncvnx8hfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8931 },
#else
    { 0, output_8931, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fcvt_nontruncvnx8hfvnx2df },
    &operand_data[12719],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9481 */
  {
    "aarch64_sve_fcvt_nontruncvnx4sfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8932 },
#else
    { 0, output_8932, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fcvt_nontruncvnx4sfvnx2df },
    &operand_data[12723],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9510 */
  {
    "*cond_fcvt_nontruncvnx8hfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8933 },
#else
    { 0, output_8933, 0 },
#endif
    { 0 },
    &operand_data[12727],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9510 */
  {
    "*cond_fcvt_nontruncvnx8hfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8934 },
#else
    { 0, output_8934, 0 },
#endif
    { 0 },
    &operand_data[12732],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9510 */
  {
    "*cond_fcvt_nontruncvnx4sfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8935 },
#else
    { 0, output_8935, 0 },
#endif
    { 0 },
    &operand_data[12737],
    5,
    5,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9538 */
  {
    "vec_pack_trunc_vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx8bi },
    &operand_data[12742],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9538 */
  {
    "vec_pack_trunc_vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx4bi },
    &operand_data[12745],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9538 */
  {
    "vec_pack_trunc_vnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uzp1\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx2bi },
    &operand_data[12748],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9573 */
  {
    "aarch64_sve_punpklo_vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "punpklo\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_punpklo_vnx16bi },
    &operand_data[10817],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9573 */
  {
    "aarch64_sve_punpkhi_vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "punpkhi\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_punpkhi_vnx16bi },
    &operand_data[10817],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9573 */
  {
    "aarch64_sve_punpklo_vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "punpklo\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_punpklo_vnx8bi },
    &operand_data[12751],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9573 */
  {
    "aarch64_sve_punpkhi_vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "punpkhi\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_punpkhi_vnx8bi },
    &operand_data[12751],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9573 */
  {
    "aarch64_sve_punpklo_vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "punpklo\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_punpklo_vnx4bi },
    &operand_data[12753],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9573 */
  {
    "aarch64_sve_punpkhi_vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "punpkhi\t%0.h, %1.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_punpkhi_vnx4bi },
    &operand_data[12753],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9598 */
  {
    "aarch64_brka",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8945 },
#else
    { 0, output_8945, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_brka },
    &operand_data[12755],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9598 */
  {
    "aarch64_brkb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8946 },
#else
    { 0, output_8946, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_brkb },
    &operand_data[12755],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9612 */
  {
    "*aarch64_brka_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8947 },
#else
    { 0, output_8947, 0 },
#endif
    { 0 },
    &operand_data[12755],
    5,
    5,
    5,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9612 */
  {
    "*aarch64_brkb_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8948 },
#else
    { 0, output_8948, 0 },
#endif
    { 0 },
    &operand_data[12755],
    5,
    5,
    5,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9637 */
  {
    "*aarch64_brka_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8949 },
#else
    { 0, output_8949, 0 },
#endif
    { 0 },
    &operand_data[12760],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9637 */
  {
    "*aarch64_brkb_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_8950 },
#else
    { 0, output_8950, 0 },
#endif
    { 0 },
    &operand_data[12760],
    5,
    5,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9669 */
  {
    "aarch64_brkn",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkn\t%0.b, %1/z, %2.b, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_brkn },
    &operand_data[12765],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9669 */
  {
    "aarch64_brkpa",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkpa\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_brkpa },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9669 */
  {
    "aarch64_brkpb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkpb\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_brkpb },
    &operand_data[10795],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9681 */
  {
    "*aarch64_brkn_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkns\t%0.b, %1/z, %2.b, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12765],
    5,
    5,
    5,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9681 */
  {
    "*aarch64_brkpa_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkpas\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12770],
    5,
    5,
    5,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9681 */
  {
    "*aarch64_brkpb_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkpbs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12770],
    5,
    5,
    5,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9704 */
  {
    "*aarch64_brkn_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkns\t%0.b, %1/z, %2.b, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12775],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9704 */
  {
    "*aarch64_brkpa_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkpas\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12780],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9704 */
  {
    "*aarch64_brkpb_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "brkpbs\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12780],
    5,
    5,
    2,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9729 */
  {
    "aarch64_sve_pfirstvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pfirst\t%0.b, %1, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pfirstvnx16bi },
    &operand_data[12785],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9729 */
  {
    "aarch64_sve_pnextvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.b, %1, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pnextvnx16bi },
    &operand_data[12785],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9729 */
  {
    "aarch64_sve_pnextvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.h, %1, %0.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pnextvnx8bi },
    &operand_data[12789],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9729 */
  {
    "aarch64_sve_pnextvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.s, %1, %0.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pnextvnx4bi },
    &operand_data[12793],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9729 */
  {
    "aarch64_sve_pnextvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.d, %1, %0.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pnextvnx2bi },
    &operand_data[12797],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9742 */
  {
    "*aarch64_sve_pfirstvnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pfirst\t%0.b, %1, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12801],
    7,
    7,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9742 */
  {
    "*aarch64_sve_pnextvnx16bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.b, %1, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12801],
    7,
    7,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9742 */
  {
    "*aarch64_sve_pnextvnx8bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.h, %1, %0.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12808],
    7,
    7,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9742 */
  {
    "*aarch64_sve_pnextvnx4bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.s, %1, %0.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12815],
    7,
    7,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9742 */
  {
    "*aarch64_sve_pnextvnx2bi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.d, %1, %0.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12822],
    7,
    7,
    3,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9772 */
  {
    "*aarch64_sve_pfirstvnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pfirst\t%0.b, %1, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12829],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9772 */
  {
    "*aarch64_sve_pnextvnx16bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.b, %1, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12829],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9772 */
  {
    "*aarch64_sve_pnextvnx8bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.h, %1, %0.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12836],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9772 */
  {
    "*aarch64_sve_pnextvnx4bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.s, %1, %0.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12843],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9772 */
  {
    "*aarch64_sve_pnextvnx2bi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pnext\t%0.d, %1, %0.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12850],
    7,
    7,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9815 */
  {
    "aarch64_sve_cnt_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8975 },
#else
    { 0, 0, output_8975 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cnt_pat },
    &operand_data[12857],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9839 */
  {
    "aarch64_sve_incdi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8976 },
#else
    { 0, 0, output_8976 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incdi_pat },
    &operand_data[12861],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9839 */
  {
    "aarch64_sve_sqincdi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8977 },
#else
    { 0, 0, output_8977 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincdi_pat },
    &operand_data[12861],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9839 */
  {
    "aarch64_sve_uqincdi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8978 },
#else
    { 0, 0, output_8978 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincdi_pat },
    &operand_data[12861],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9857 */
  {
    "*aarch64_sve_incsi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8979 },
#else
    { 0, 0, output_8979 },
#endif
    { 0 },
    &operand_data[12866],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9874 */
  {
    "aarch64_sve_sqincsi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8980 },
#else
    { 0, 0, output_8980 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincsi_pat },
    &operand_data[12871],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9874 */
  {
    "aarch64_sve_uqincsi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8981 },
#else
    { 0, 0, output_8981 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincsi_pat },
    &operand_data[12871],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9902 */
  {
    "aarch64_sve_incvnx2di_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8982 },
#else
    { 0, 0, output_8982 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incvnx2di_pat },
    &operand_data[12876],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9902 */
  {
    "aarch64_sve_sqincvnx2di_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8983 },
#else
    { 0, 0, output_8983 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincvnx2di_pat },
    &operand_data[12876],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9902 */
  {
    "aarch64_sve_uqincvnx2di_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8984 },
#else
    { 0, 0, output_8984 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincvnx2di_pat },
    &operand_data[12876],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9924 */
  {
    "aarch64_sve_incvnx4si_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8985 },
#else
    { 0, 0, output_8985 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incvnx4si_pat },
    &operand_data[12881],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9924 */
  {
    "aarch64_sve_sqincvnx4si_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8986 },
#else
    { 0, 0, output_8986 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincvnx4si_pat },
    &operand_data[12881],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9924 */
  {
    "aarch64_sve_uqincvnx4si_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8987 },
#else
    { 0, 0, output_8987 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincvnx4si_pat },
    &operand_data[12881],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9958 */
  {
    "*aarch64_sve_incvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8988 },
#else
    { 0, 0, output_8988 },
#endif
    { 0 },
    &operand_data[12886],
    6,
    6,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9958 */
  {
    "*aarch64_sve_sqincvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8989 },
#else
    { 0, 0, output_8989 },
#endif
    { 0 },
    &operand_data[12886],
    6,
    6,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9958 */
  {
    "*aarch64_sve_uqincvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8990 },
#else
    { 0, 0, output_8990 },
#endif
    { 0 },
    &operand_data[12886],
    6,
    6,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9989 */
  {
    "aarch64_sve_decdi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8991 },
#else
    { 0, 0, output_8991 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decdi_pat },
    &operand_data[12861],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9989 */
  {
    "aarch64_sve_sqdecdi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8992 },
#else
    { 0, 0, output_8992 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecdi_pat },
    &operand_data[12861],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9989 */
  {
    "aarch64_sve_uqdecdi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8993 },
#else
    { 0, 0, output_8993 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecdi_pat },
    &operand_data[12861],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10007 */
  {
    "*aarch64_sve_decsi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8994 },
#else
    { 0, 0, output_8994 },
#endif
    { 0 },
    &operand_data[12866],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10024 */
  {
    "aarch64_sve_sqdecsi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8995 },
#else
    { 0, 0, output_8995 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecsi_pat },
    &operand_data[12871],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10024 */
  {
    "aarch64_sve_uqdecsi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8996 },
#else
    { 0, 0, output_8996 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecsi_pat },
    &operand_data[12871],
    5,
    5,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10052 */
  {
    "aarch64_sve_decvnx2di_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8997 },
#else
    { 0, 0, output_8997 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decvnx2di_pat },
    &operand_data[12876],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10052 */
  {
    "aarch64_sve_sqdecvnx2di_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8998 },
#else
    { 0, 0, output_8998 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecvnx2di_pat },
    &operand_data[12876],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10052 */
  {
    "aarch64_sve_uqdecvnx2di_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_8999 },
#else
    { 0, 0, output_8999 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecvnx2di_pat },
    &operand_data[12876],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10074 */
  {
    "aarch64_sve_decvnx4si_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9000 },
#else
    { 0, 0, output_9000 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decvnx4si_pat },
    &operand_data[12881],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10074 */
  {
    "aarch64_sve_sqdecvnx4si_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9001 },
#else
    { 0, 0, output_9001 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecvnx4si_pat },
    &operand_data[12881],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10074 */
  {
    "aarch64_sve_uqdecvnx4si_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9002 },
#else
    { 0, 0, output_9002 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecvnx4si_pat },
    &operand_data[12881],
    5,
    5,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10108 */
  {
    "*aarch64_sve_decvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9003 },
#else
    { 0, 0, output_9003 },
#endif
    { 0 },
    &operand_data[12886],
    6,
    6,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10108 */
  {
    "*aarch64_sve_sqdecvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9004 },
#else
    { 0, 0, output_9004 },
#endif
    { 0 },
    &operand_data[12886],
    6,
    6,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10108 */
  {
    "*aarch64_sve_uqdecvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9005 },
#else
    { 0, 0, output_9005 },
#endif
    { 0 },
    &operand_data[12886],
    6,
    6,
    0,
    2,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10137 */
  {
    "aarch64_pred_cntpvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cntp\t%x0, %1, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cntpvnx16bi },
    &operand_data[12892],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10137 */
  {
    "aarch64_pred_cntpvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cntp\t%x0, %1, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cntpvnx8bi },
    &operand_data[12896],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10137 */
  {
    "aarch64_pred_cntpvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cntp\t%x0, %1, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cntpvnx4bi },
    &operand_data[12900],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10137 */
  {
    "aarch64_pred_cntpvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "cntp\t%x0, %1, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cntpvnx2bi },
    &operand_data[12904],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_incdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_sqincdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqincp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_uqincdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqincp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_incdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_sqincdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqincp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_uqincdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqincp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_incdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_sqincdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqincp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_uqincdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqincp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_incdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12920],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_sqincdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqincp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12920],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10173 */
  {
    "*aarch64_sve_uqincdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqincp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12920],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10193 */
  {
    "*aarch64_incsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12924],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10193 */
  {
    "*aarch64_incsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12928],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10193 */
  {
    "*aarch64_incsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12932],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10193 */
  {
    "*aarch64_incsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "incp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12936],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_sqincsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9026 },
#else
    { 0, 0, output_9026 },
#endif
    { 0 },
    &operand_data[12940],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_uqincsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9027 },
#else
    { 0, 0, output_9027 },
#endif
    { 0 },
    &operand_data[12940],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_sqincsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9028 },
#else
    { 0, 0, output_9028 },
#endif
    { 0 },
    &operand_data[12944],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_uqincsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9029 },
#else
    { 0, 0, output_9029 },
#endif
    { 0 },
    &operand_data[12944],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_sqincsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9030 },
#else
    { 0, 0, output_9030 },
#endif
    { 0 },
    &operand_data[12948],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_uqincsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9031 },
#else
    { 0, 0, output_9031 },
#endif
    { 0 },
    &operand_data[12948],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_sqincsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9032 },
#else
    { 0, 0, output_9032 },
#endif
    { 0 },
    &operand_data[12952],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10228 */
  {
    "*aarch64_sve_uqincsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9033 },
#else
    { 0, 0, output_9033 },
#endif
    { 0 },
    &operand_data[12952],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10278 */
  {
    "*aarch64_sve_incvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9034 },
#else
    { 0, output_9034, 0 },
#endif
    { 0 },
    &operand_data[12956],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10278 */
  {
    "*aarch64_sve_sqincvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9035 },
#else
    { 0, output_9035, 0 },
#endif
    { 0 },
    &operand_data[12956],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10278 */
  {
    "*aarch64_sve_uqincvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9036 },
#else
    { 0, output_9036, 0 },
#endif
    { 0 },
    &operand_data[12956],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10318 */
  {
    "*aarch64_sve_incvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9037 },
#else
    { 0, output_9037, 0 },
#endif
    { 0 },
    &operand_data[12960],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10318 */
  {
    "*aarch64_sve_sqincvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9038 },
#else
    { 0, output_9038, 0 },
#endif
    { 0 },
    &operand_data[12960],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10318 */
  {
    "*aarch64_sve_uqincvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9039 },
#else
    { 0, output_9039, 0 },
#endif
    { 0 },
    &operand_data[12960],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10358 */
  {
    "*aarch64_sve_incvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9040 },
#else
    { 0, output_9040, 0 },
#endif
    { 0 },
    &operand_data[12964],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10358 */
  {
    "*aarch64_sve_sqincvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9041 },
#else
    { 0, output_9041, 0 },
#endif
    { 0 },
    &operand_data[12964],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10358 */
  {
    "*aarch64_sve_uqincvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9042 },
#else
    { 0, output_9042, 0 },
#endif
    { 0 },
    &operand_data[12964],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_decdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_sqdecdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdecp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_uqdecdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqdecp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12908],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_decdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_sqdecdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdecp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_uqdecdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqdecp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12912],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_decdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_sqdecdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdecp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_uqdecdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqdecp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12916],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_decdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12920],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_sqdecdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdecp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12920],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10406 */
  {
    "*aarch64_sve_uqdecdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqdecp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12920],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10426 */
  {
    "*aarch64_decsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12924],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10426 */
  {
    "*aarch64_decsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12928],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10426 */
  {
    "*aarch64_decsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12932],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10426 */
  {
    "*aarch64_decsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "decp\t%x0, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[12936],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_sqdecsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9059 },
#else
    { 0, 0, output_9059 },
#endif
    { 0 },
    &operand_data[12940],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_uqdecsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9060 },
#else
    { 0, 0, output_9060 },
#endif
    { 0 },
    &operand_data[12940],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_sqdecsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9061 },
#else
    { 0, 0, output_9061 },
#endif
    { 0 },
    &operand_data[12944],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_uqdecsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9062 },
#else
    { 0, 0, output_9062 },
#endif
    { 0 },
    &operand_data[12944],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_sqdecsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9063 },
#else
    { 0, 0, output_9063 },
#endif
    { 0 },
    &operand_data[12948],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_uqdecsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9064 },
#else
    { 0, 0, output_9064 },
#endif
    { 0 },
    &operand_data[12948],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_sqdecsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9065 },
#else
    { 0, 0, output_9065 },
#endif
    { 0 },
    &operand_data[12952],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10461 */
  {
    "*aarch64_sve_uqdecsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .function = output_9066 },
#else
    { 0, 0, output_9066 },
#endif
    { 0 },
    &operand_data[12952],
    4,
    4,
    0,
    1,
    3
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10511 */
  {
    "*aarch64_sve_decvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9067 },
#else
    { 0, output_9067, 0 },
#endif
    { 0 },
    &operand_data[12956],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10511 */
  {
    "*aarch64_sve_sqdecvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9068 },
#else
    { 0, output_9068, 0 },
#endif
    { 0 },
    &operand_data[12956],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10511 */
  {
    "*aarch64_sve_uqdecvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9069 },
#else
    { 0, output_9069, 0 },
#endif
    { 0 },
    &operand_data[12956],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10551 */
  {
    "*aarch64_sve_decvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9070 },
#else
    { 0, output_9070, 0 },
#endif
    { 0 },
    &operand_data[12960],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10551 */
  {
    "*aarch64_sve_sqdecvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9071 },
#else
    { 0, output_9071, 0 },
#endif
    { 0 },
    &operand_data[12960],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10551 */
  {
    "*aarch64_sve_uqdecvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9072 },
#else
    { 0, output_9072, 0 },
#endif
    { 0 },
    &operand_data[12960],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10591 */
  {
    "*aarch64_sve_decvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9073 },
#else
    { 0, output_9073, 0 },
#endif
    { 0 },
    &operand_data[12964],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10591 */
  {
    "*aarch64_sve_sqdecvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9074 },
#else
    { 0, output_9074, 0 },
#endif
    { 0 },
    &operand_data[12964],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10591 */
  {
    "*aarch64_sve_uqdecvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9075 },
#else
    { 0, output_9075, 0 },
#endif
    { 0 },
    &operand_data[12964],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:104 */
  {
    "aarch64_gather_ldntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9076 },
#else
    { 0, output_9076, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldntvnx4si },
    &operand_data[12969],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:104 */
  {
    "aarch64_gather_ldntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9077 },
#else
    { 0, output_9077, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldntvnx2di },
    &operand_data[12973],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:104 */
  {
    "aarch64_gather_ldntvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9078 },
#else
    { 0, output_9078, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldntvnx4sf },
    &operand_data[12977],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:104 */
  {
    "aarch64_gather_ldntvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9079 },
#else
    { 0, output_9079, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldntvnx2df },
    &operand_data[12981],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9080 },
#else
    { 0, output_9080, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_extendvnx4sivnx4qi },
    &operand_data[12985],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_zero_extendvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9081 },
#else
    { 0, output_9081, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_zero_extendvnx4sivnx4qi },
    &operand_data[12985],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9082 },
#else
    { 0, output_9082, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_extendvnx2divnx2qi },
    &operand_data[12990],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_zero_extendvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9083 },
#else
    { 0, output_9083, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_zero_extendvnx2divnx2qi },
    &operand_data[12990],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9084 },
#else
    { 0, output_9084, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_extendvnx4sivnx4hi },
    &operand_data[12985],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_zero_extendvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9085 },
#else
    { 0, output_9085, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_zero_extendvnx4sivnx4hi },
    &operand_data[12985],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9086 },
#else
    { 0, output_9086, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_extendvnx2divnx2hi },
    &operand_data[12990],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_zero_extendvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9087 },
#else
    { 0, output_9087, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_zero_extendvnx2divnx2hi },
    &operand_data[12990],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9088 },
#else
    { 0, output_9088, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_extendvnx2divnx2si },
    &operand_data[12990],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:119 */
  {
    "aarch64_gather_ldnt_zero_extendvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9089 },
#else
    { 0, output_9089, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_gather_ldnt_zero_extendvnx2divnx2si },
    &operand_data[12990],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:153 */
  {
    "aarch64_scatter_stntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9090 },
#else
    { 0, output_9090, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stntvnx4si },
    &operand_data[12995],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:153 */
  {
    "aarch64_scatter_stntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9091 },
#else
    { 0, output_9091, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stntvnx2di },
    &operand_data[12999],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:153 */
  {
    "aarch64_scatter_stntvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9092 },
#else
    { 0, output_9092, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stntvnx4sf },
    &operand_data[13003],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:153 */
  {
    "aarch64_scatter_stntvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9093 },
#else
    { 0, output_9093, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stntvnx2df },
    &operand_data[13007],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:169 */
  {
    "aarch64_scatter_stnt_vnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9094 },
#else
    { 0, output_9094, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stnt_vnx4sivnx4qi },
    &operand_data[12995],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:169 */
  {
    "aarch64_scatter_stnt_vnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9095 },
#else
    { 0, output_9095, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stnt_vnx2divnx2qi },
    &operand_data[12999],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:169 */
  {
    "aarch64_scatter_stnt_vnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9096 },
#else
    { 0, output_9096, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stnt_vnx4sivnx4hi },
    &operand_data[12995],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:169 */
  {
    "aarch64_scatter_stnt_vnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9097 },
#else
    { 0, output_9097, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stnt_vnx2divnx2hi },
    &operand_data[12999],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:169 */
  {
    "aarch64_scatter_stnt_vnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9098 },
#else
    { 0, output_9098, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_scatter_stnt_vnx2divnx2si },
    &operand_data[12999],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:196 */
  {
    "aarch64_mul_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.h, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mul_lane_vnx8hi },
    &operand_data[13011],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:196 */
  {
    "aarch64_mul_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.s, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mul_lane_vnx4si },
    &operand_data[13015],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:196 */
  {
    "aarch64_mul_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "mul\t%0.d, %1.d, %2.d[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_mul_lane_vnx2di },
    &operand_data[13019],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:315 */
  {
    "aarch64_sve_suqaddvnx16qi_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9102 },
#else
    { 0, output_9102, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_suqaddvnx16qi_const },
    &operand_data[13023],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:315 */
  {
    "aarch64_sve_suqaddvnx8hi_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9103 },
#else
    { 0, output_9103, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_suqaddvnx8hi_const },
    &operand_data[13026],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:315 */
  {
    "aarch64_sve_suqaddvnx4si_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9104 },
#else
    { 0, output_9104, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_suqaddvnx4si_const },
    &operand_data[13029],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:315 */
  {
    "aarch64_sve_suqaddvnx2di_const",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9105 },
#else
    { 0, output_9105, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_suqaddvnx2di_const },
    &operand_data[13032],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9106 },
#else
    { 0, output_9106, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shaddvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shsubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9107 },
#else
    { 0, output_9107, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shsubvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_sqrshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9108 },
#else
    { 0, output_9108, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqrshlvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srhaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9109 },
#else
    { 0, output_9109, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srhaddvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9110 },
#else
    { 0, output_9110, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srshlvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9111 },
#else
    { 0, output_9111, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhaddvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhsubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9112 },
#else
    { 0, output_9112, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhsubvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uqrshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9113 },
#else
    { 0, output_9113, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqrshlvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urhaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9114 },
#else
    { 0, output_9114, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urhaddvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9115 },
#else
    { 0, output_9115, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urshlvnx16qi },
    &operand_data[13035],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9116 },
#else
    { 0, output_9116, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shaddvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shsubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9117 },
#else
    { 0, output_9117, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shsubvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_sqrshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9118 },
#else
    { 0, output_9118, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqrshlvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srhaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9119 },
#else
    { 0, output_9119, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srhaddvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9120 },
#else
    { 0, output_9120, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srshlvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9121 },
#else
    { 0, output_9121, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhaddvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhsubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9122 },
#else
    { 0, output_9122, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhsubvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uqrshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9123 },
#else
    { 0, output_9123, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqrshlvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urhaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9124 },
#else
    { 0, output_9124, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urhaddvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9125 },
#else
    { 0, output_9125, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urshlvnx8hi },
    &operand_data[13039],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9126 },
#else
    { 0, output_9126, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shaddvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shsubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9127 },
#else
    { 0, output_9127, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shsubvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_sqrshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9128 },
#else
    { 0, output_9128, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqrshlvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srhaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9129 },
#else
    { 0, output_9129, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srhaddvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9130 },
#else
    { 0, output_9130, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srshlvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9131 },
#else
    { 0, output_9131, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhaddvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhsubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9132 },
#else
    { 0, output_9132, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhsubvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uqrshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9133 },
#else
    { 0, output_9133, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqrshlvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urhaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9134 },
#else
    { 0, output_9134, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urhaddvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9135 },
#else
    { 0, output_9135, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urshlvnx4si },
    &operand_data[9597],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9136 },
#else
    { 0, output_9136, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shaddvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_shsubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9137 },
#else
    { 0, output_9137, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_shsubvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_sqrshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9138 },
#else
    { 0, output_9138, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqrshlvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srhaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9139 },
#else
    { 0, output_9139, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srhaddvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_srshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9140 },
#else
    { 0, output_9140, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_srshlvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9141 },
#else
    { 0, output_9141, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhaddvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uhsubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9142 },
#else
    { 0, output_9142, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uhsubvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_uqrshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9143 },
#else
    { 0, output_9143, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqrshlvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urhaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9144 },
#else
    { 0, output_9144, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urhaddvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:330 */
  {
    "aarch64_pred_urshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9145 },
#else
    { 0, output_9145, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urshlvnx2di },
    &operand_data[9601],
    4,
    4,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9146 },
#else
    { 0, output_9146, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shsubvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9147 },
#else
    { 0, output_9147, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_sqrshlvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9148 },
#else
    { 0, output_9148, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srhaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9149 },
#else
    { 0, output_9149, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srshlvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9150 },
#else
    { 0, output_9150, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_suqaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9151 },
#else
    { 0, output_9151, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9152 },
#else
    { 0, output_9152, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhsubvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9153 },
#else
    { 0, output_9153, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uqrshlvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9154 },
#else
    { 0, output_9154, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urhaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9155 },
#else
    { 0, output_9155, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urshlvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9156 },
#else
    { 0, output_9156, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_usqaddvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9157 },
#else
    { 0, output_9157, 0 },
#endif
    { 0 },
    &operand_data[9363],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9158 },
#else
    { 0, output_9158, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shsubvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9159 },
#else
    { 0, output_9159, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_sqrshlvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9160 },
#else
    { 0, output_9160, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srhaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9161 },
#else
    { 0, output_9161, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srshlvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9162 },
#else
    { 0, output_9162, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_suqaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9163 },
#else
    { 0, output_9163, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9164 },
#else
    { 0, output_9164, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhsubvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9165 },
#else
    { 0, output_9165, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uqrshlvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9166 },
#else
    { 0, output_9166, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urhaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9167 },
#else
    { 0, output_9167, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urshlvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9168 },
#else
    { 0, output_9168, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_usqaddvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9169 },
#else
    { 0, output_9169, 0 },
#endif
    { 0 },
    &operand_data[9387],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9170 },
#else
    { 0, output_9170, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shsubvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9171 },
#else
    { 0, output_9171, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_sqrshlvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9172 },
#else
    { 0, output_9172, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srhaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9173 },
#else
    { 0, output_9173, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srshlvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9174 },
#else
    { 0, output_9174, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_suqaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9175 },
#else
    { 0, output_9175, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9176 },
#else
    { 0, output_9176, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhsubvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9177 },
#else
    { 0, output_9177, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uqrshlvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9178 },
#else
    { 0, output_9178, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urhaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9179 },
#else
    { 0, output_9179, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urshlvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9180 },
#else
    { 0, output_9180, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_usqaddvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9181 },
#else
    { 0, output_9181, 0 },
#endif
    { 0 },
    &operand_data[9405],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9182 },
#else
    { 0, output_9182, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_shsubvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9183 },
#else
    { 0, output_9183, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_sqrshlvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9184 },
#else
    { 0, output_9184, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srhaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9185 },
#else
    { 0, output_9185, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_srshlvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9186 },
#else
    { 0, output_9186, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_suqaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9187 },
#else
    { 0, output_9187, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9188 },
#else
    { 0, output_9188, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uhsubvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9189 },
#else
    { 0, output_9189, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_uqrshlvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9190 },
#else
    { 0, output_9190, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urhaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9191 },
#else
    { 0, output_9191, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_urshlvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9192 },
#else
    { 0, output_9192, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:368 */
  {
    "*cond_usqaddvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9193 },
#else
    { 0, output_9193, 0 },
#endif
    { 0 },
    &operand_data[9417],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shaddvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9194 },
#else
    { 0, output_9194, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shsubvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9195 },
#else
    { 0, output_9195, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_sqrshlvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9196 },
#else
    { 0, output_9196, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srhaddvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9197 },
#else
    { 0, output_9197, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srshlvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9198 },
#else
    { 0, output_9198, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhaddvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9199 },
#else
    { 0, output_9199, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhsubvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9200 },
#else
    { 0, output_9200, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uqrshlvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9201 },
#else
    { 0, output_9201, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urhaddvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9202 },
#else
    { 0, output_9202, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urshlvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9203 },
#else
    { 0, output_9203, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shaddvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9204 },
#else
    { 0, output_9204, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shsubvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9205 },
#else
    { 0, output_9205, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_sqrshlvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9206 },
#else
    { 0, output_9206, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srhaddvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9207 },
#else
    { 0, output_9207, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srshlvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9208 },
#else
    { 0, output_9208, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhaddvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9209 },
#else
    { 0, output_9209, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhsubvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9210 },
#else
    { 0, output_9210, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uqrshlvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9211 },
#else
    { 0, output_9211, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urhaddvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9212 },
#else
    { 0, output_9212, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urshlvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9213 },
#else
    { 0, output_9213, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shaddvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9214 },
#else
    { 0, output_9214, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shsubvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9215 },
#else
    { 0, output_9215, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_sqrshlvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9216 },
#else
    { 0, output_9216, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srhaddvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9217 },
#else
    { 0, output_9217, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srshlvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9218 },
#else
    { 0, output_9218, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhaddvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9219 },
#else
    { 0, output_9219, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhsubvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9220 },
#else
    { 0, output_9220, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uqrshlvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9221 },
#else
    { 0, output_9221, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urhaddvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9222 },
#else
    { 0, output_9222, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urshlvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9223 },
#else
    { 0, output_9223, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shaddvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9224 },
#else
    { 0, output_9224, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_shsubvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9225 },
#else
    { 0, output_9225, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_sqrshlvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9226 },
#else
    { 0, output_9226, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srhaddvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9227 },
#else
    { 0, output_9227, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_srshlvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9228 },
#else
    { 0, output_9228, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhaddvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9229 },
#else
    { 0, output_9229, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uhsubvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9230 },
#else
    { 0, output_9230, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_uqrshlvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9231 },
#else
    { 0, output_9231, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urhaddvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9232 },
#else
    { 0, output_9232, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:393 */
  {
    "*cond_urshlvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9233 },
#else
    { 0, output_9233, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shaddvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9234 },
#else
    { 0, output_9234, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shsubvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9235 },
#else
    { 0, output_9235, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_sqrshlvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9236 },
#else
    { 0, output_9236, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srhaddvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9237 },
#else
    { 0, output_9237, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srshlvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9238 },
#else
    { 0, output_9238, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhaddvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9239 },
#else
    { 0, output_9239, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhsubvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9240 },
#else
    { 0, output_9240, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uqrshlvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9241 },
#else
    { 0, output_9241, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urhaddvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9242 },
#else
    { 0, output_9242, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urshlvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9243 },
#else
    { 0, output_9243, 0 },
#endif
    { 0 },
    &operand_data[9483],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shaddvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9244 },
#else
    { 0, output_9244, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shsubvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9245 },
#else
    { 0, output_9245, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_sqrshlvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9246 },
#else
    { 0, output_9246, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srhaddvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9247 },
#else
    { 0, output_9247, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srshlvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9248 },
#else
    { 0, output_9248, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhaddvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9249 },
#else
    { 0, output_9249, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhsubvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9250 },
#else
    { 0, output_9250, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uqrshlvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9251 },
#else
    { 0, output_9251, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urhaddvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9252 },
#else
    { 0, output_9252, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urshlvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9253 },
#else
    { 0, output_9253, 0 },
#endif
    { 0 },
    &operand_data[9511],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shaddvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9254 },
#else
    { 0, output_9254, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shsubvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9255 },
#else
    { 0, output_9255, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_sqrshlvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9256 },
#else
    { 0, output_9256, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srhaddvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9257 },
#else
    { 0, output_9257, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srshlvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9258 },
#else
    { 0, output_9258, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhaddvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9259 },
#else
    { 0, output_9259, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhsubvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9260 },
#else
    { 0, output_9260, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uqrshlvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9261 },
#else
    { 0, output_9261, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urhaddvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9262 },
#else
    { 0, output_9262, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urshlvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9263 },
#else
    { 0, output_9263, 0 },
#endif
    { 0 },
    &operand_data[9532],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shaddvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9264 },
#else
    { 0, output_9264, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_shsubvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9265 },
#else
    { 0, output_9265, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_sqrshlvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9266 },
#else
    { 0, output_9266, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srhaddvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9267 },
#else
    { 0, output_9267, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_srshlvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9268 },
#else
    { 0, output_9268, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhaddvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9269 },
#else
    { 0, output_9269, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uhsubvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9270 },
#else
    { 0, output_9270, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_uqrshlvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9271 },
#else
    { 0, output_9271, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urhaddvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9272 },
#else
    { 0, output_9272, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:418 */
  {
    "*cond_urshlvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9273 },
#else
    { 0, output_9273, 0 },
#endif
    { 0 },
    &operand_data[9546],
    6,
    6,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_suqaddvnx16qi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9274 },
#else
    { 0, output_9274, 0 },
#endif
    { 0 },
    &operand_data[13043],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_usqaddvnx16qi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9275 },
#else
    { 0, output_9275, 0 },
#endif
    { 0 },
    &operand_data[13043],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_suqaddvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9276 },
#else
    { 0, output_9276, 0 },
#endif
    { 0 },
    &operand_data[13049],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_usqaddvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9277 },
#else
    { 0, output_9277, 0 },
#endif
    { 0 },
    &operand_data[13049],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_suqaddvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9278 },
#else
    { 0, output_9278, 0 },
#endif
    { 0 },
    &operand_data[13055],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_usqaddvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9279 },
#else
    { 0, output_9279, 0 },
#endif
    { 0 },
    &operand_data[13055],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_suqaddvnx2di_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9280 },
#else
    { 0, output_9280, 0 },
#endif
    { 0 },
    &operand_data[13061],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:462 */
  {
    "*cond_usqaddvnx2di_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9281 },
#else
    { 0, output_9281, 0 },
#endif
    { 0 },
    &operand_data[13061],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqdmulhvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulhvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqrdmulhvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmulhvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqdmulhvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulhvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqrdmulhvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmulhvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqdmulhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulhvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqrdmulhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmulhvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqdmulhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulhvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:494 */
  {
    "aarch64_sve_sqrdmulhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmulhvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:504 */
  {
    "aarch64_sve_sqdmulh_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.h, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulh_lane_vnx8hi },
    &operand_data[13011],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:504 */
  {
    "aarch64_sve_sqrdmulh_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.h, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmulh_lane_vnx8hi },
    &operand_data[13011],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:504 */
  {
    "aarch64_sve_sqdmulh_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.s, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulh_lane_vnx4si },
    &operand_data[13015],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:504 */
  {
    "aarch64_sve_sqrdmulh_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.s, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmulh_lane_vnx4si },
    &operand_data[13015],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:504 */
  {
    "aarch64_sve_sqdmulh_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmulh\t%0.d, %1.d, %2.d[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulh_lane_vnx2di },
    &operand_data[13019],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:504 */
  {
    "aarch64_sve_sqrdmulh_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrdmulh\t%0.d, %1.d, %2.d[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmulh_lane_vnx2di },
    &operand_data[13019],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_sqshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9296 },
#else
    { 0, output_9296, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqshlvnx16qi },
    &operand_data[13067],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_uqshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9297 },
#else
    { 0, output_9297, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqshlvnx16qi },
    &operand_data[13067],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_sqshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9298 },
#else
    { 0, output_9298, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqshlvnx8hi },
    &operand_data[13071],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_uqshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9299 },
#else
    { 0, output_9299, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqshlvnx8hi },
    &operand_data[13071],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_sqshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9300 },
#else
    { 0, output_9300, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqshlvnx4si },
    &operand_data[13075],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_uqshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9301 },
#else
    { 0, output_9301, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqshlvnx4si },
    &operand_data[13075],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_sqshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9302 },
#else
    { 0, output_9302, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sqshlvnx2di },
    &operand_data[13079],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:528 */
  {
    "aarch64_pred_uqshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9303 },
#else
    { 0, output_9303, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uqshlvnx2di },
    &operand_data[13079],
    4,
    4,
    0,
    5,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_sqshlvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9304 },
#else
    { 0, output_9304, 0 },
#endif
    { 0 },
    &operand_data[13083],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_uqshlvnx16qi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9305 },
#else
    { 0, output_9305, 0 },
#endif
    { 0 },
    &operand_data[13083],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_sqshlvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9306 },
#else
    { 0, output_9306, 0 },
#endif
    { 0 },
    &operand_data[13088],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_uqshlvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9307 },
#else
    { 0, output_9307, 0 },
#endif
    { 0 },
    &operand_data[13088],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_sqshlvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9308 },
#else
    { 0, output_9308, 0 },
#endif
    { 0 },
    &operand_data[13093],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_uqshlvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9309 },
#else
    { 0, output_9309, 0 },
#endif
    { 0 },
    &operand_data[13093],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_sqshlvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9310 },
#else
    { 0, output_9310, 0 },
#endif
    { 0 },
    &operand_data[13098],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:568 */
  {
    "*cond_uqshlvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9311 },
#else
    { 0, output_9311, 0 },
#endif
    { 0 },
    &operand_data[13098],
    5,
    5,
    1,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_sqshlvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9312 },
#else
    { 0, output_9312, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_uqshlvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9313 },
#else
    { 0, output_9313, 0 },
#endif
    { 0 },
    &operand_data[9423],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_sqshlvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9314 },
#else
    { 0, output_9314, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_uqshlvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9315 },
#else
    { 0, output_9315, 0 },
#endif
    { 0 },
    &operand_data[9447],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_sqshlvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9316 },
#else
    { 0, output_9316, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_uqshlvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9317 },
#else
    { 0, output_9317, 0 },
#endif
    { 0 },
    &operand_data[9465],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_sqshlvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9318 },
#else
    { 0, output_9318, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:595 */
  {
    "*cond_uqshlvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9319 },
#else
    { 0, output_9319, 0 },
#endif
    { 0 },
    &operand_data[9477],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_sqshlvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9320 },
#else
    { 0, output_9320, 0 },
#endif
    { 0 },
    &operand_data[13103],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_uqshlvnx16qi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9321 },
#else
    { 0, output_9321, 0 },
#endif
    { 0 },
    &operand_data[13103],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_sqshlvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9322 },
#else
    { 0, output_9322, 0 },
#endif
    { 0 },
    &operand_data[13109],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_uqshlvnx8hi_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9323 },
#else
    { 0, output_9323, 0 },
#endif
    { 0 },
    &operand_data[13109],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_sqshlvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9324 },
#else
    { 0, output_9324, 0 },
#endif
    { 0 },
    &operand_data[13115],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_uqshlvnx4si_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9325 },
#else
    { 0, output_9325, 0 },
#endif
    { 0 },
    &operand_data[13115],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_sqshlvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9326 },
#else
    { 0, output_9326, 0 },
#endif
    { 0 },
    &operand_data[13121],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:620 */
  {
    "*cond_uqshlvnx2di_any",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9327 },
#else
    { 0, output_9327, 0 },
#endif
    { 0 },
    &operand_data[13121],
    6,
    6,
    0,
    9,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adclbvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9328 },
#else
    { 0, output_9328, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adclbvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adcltvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9329 },
#else
    { 0, output_9329, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adcltvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eorbtvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9330 },
#else
    { 0, output_9330, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eorbtvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eortbvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9331 },
#else
    { 0, output_9331, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eortbvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbclbvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9332 },
#else
    { 0, output_9332, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbclbvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbcltvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9333 },
#else
    { 0, output_9333, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbcltvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlahvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9334 },
#else
    { 0, output_9334, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlahvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlshvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9335 },
#else
    { 0, output_9335, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlshvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adclbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9336 },
#else
    { 0, output_9336, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adclbvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adcltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9337 },
#else
    { 0, output_9337, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adcltvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eorbtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9338 },
#else
    { 0, output_9338, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eorbtvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eortbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9339 },
#else
    { 0, output_9339, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eortbvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbclbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9340 },
#else
    { 0, output_9340, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbclbvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbcltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9341 },
#else
    { 0, output_9341, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbcltvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlahvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9342 },
#else
    { 0, output_9342, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlahvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlshvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9343 },
#else
    { 0, output_9343, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlshvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adclbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9344 },
#else
    { 0, output_9344, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adclbvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adcltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9345 },
#else
    { 0, output_9345, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adcltvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eorbtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9346 },
#else
    { 0, output_9346, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eorbtvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eortbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9347 },
#else
    { 0, output_9347, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eortbvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbclbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9348 },
#else
    { 0, output_9348, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbclbvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbcltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9349 },
#else
    { 0, output_9349, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbcltvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlahvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9350 },
#else
    { 0, output_9350, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlahvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlshvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9351 },
#else
    { 0, output_9351, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlshvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adclbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9352 },
#else
    { 0, output_9352, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adclbvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_adcltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9353 },
#else
    { 0, output_9353, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_adcltvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eorbtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9354 },
#else
    { 0, output_9354, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eorbtvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_eortbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9355 },
#else
    { 0, output_9355, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_eortbvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbclbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9356 },
#else
    { 0, output_9356, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbclbvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sbcltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9357 },
#else
    { 0, output_9357, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sbcltvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlahvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9358 },
#else
    { 0, output_9358, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlahvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:682 */
  {
    "aarch64_sve_sqrdmlshvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9359 },
#else
    { 0, output_9359, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlshvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:696 */
  {
    "aarch64_sve_sqrdmlah_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9360 },
#else
    { 0, output_9360, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlah_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:696 */
  {
    "aarch64_sve_sqrdmlsh_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9361 },
#else
    { 0, output_9361, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlsh_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:696 */
  {
    "aarch64_sve_sqrdmlah_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9362 },
#else
    { 0, output_9362, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlah_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:696 */
  {
    "aarch64_sve_sqrdmlsh_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9363 },
#else
    { 0, output_9363, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlsh_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:696 */
  {
    "aarch64_sve_sqrdmlah_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9364 },
#else
    { 0, output_9364, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlah_lane_vnx2di },
    &operand_data[13153],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:696 */
  {
    "aarch64_sve_sqrdmlsh_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9365 },
#else
    { 0, output_9365, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdmlsh_lane_vnx2di },
    &operand_data[13153],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:721 */
  {
    "aarch64_sve_add_mul_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9366 },
#else
    { 0, output_9366, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_mul_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:721 */
  {
    "aarch64_sve_add_mul_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9367 },
#else
    { 0, output_9367, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_mul_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:721 */
  {
    "aarch64_sve_add_mul_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9368 },
#else
    { 0, output_9368, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_mul_lane_vnx2di },
    &operand_data[13153],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:738 */
  {
    "aarch64_sve_sub_mul_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9369 },
#else
    { 0, output_9369, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_mul_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:738 */
  {
    "aarch64_sve_sub_mul_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9370 },
#else
    { 0, output_9370, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_mul_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:738 */
  {
    "aarch64_sve_sub_mul_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9371 },
#else
    { 0, output_9371, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_mul_lane_vnx2di },
    &operand_data[13153],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:762 */
  {
    "aarch64_sve2_xarvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9372 },
#else
    { 0, output_9372, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_xarvnx16qi },
    &operand_data[13158],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:762 */
  {
    "aarch64_sve2_xarvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9373 },
#else
    { 0, output_9373, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_xarvnx8hi },
    &operand_data[13162],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:762 */
  {
    "aarch64_sve2_xarvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9374 },
#else
    { 0, output_9374, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_xarvnx4si },
    &operand_data[13166],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:762 */
  {
    "aarch64_sve2_xarvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9375 },
#else
    { 0, output_9375, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_xarvnx2di },
    &operand_data[13170],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:806 */
  {
    "*aarch64_sve2_bcaxvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9376 },
#else
    { 0, output_9376, 0 },
#endif
    { 0 },
    &operand_data[13174],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:806 */
  {
    "*aarch64_sve2_bcaxvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9377 },
#else
    { 0, output_9377, 0 },
#endif
    { 0 },
    &operand_data[13179],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:806 */
  {
    "*aarch64_sve2_bcaxvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9378 },
#else
    { 0, output_9378, 0 },
#endif
    { 0 },
    &operand_data[13184],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:806 */
  {
    "*aarch64_sve2_bcaxvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9379 },
#else
    { 0, output_9379, 0 },
#endif
    { 0 },
    &operand_data[13189],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:829 */
  {
    "aarch64_sve2_eor3vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9380 },
#else
    { 0, output_9380, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_eor3vnx16qi },
    &operand_data[13194],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:829 */
  {
    "aarch64_sve2_eor3vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9381 },
#else
    { 0, output_9381, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_eor3vnx8hi },
    &operand_data[13198],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:829 */
  {
    "aarch64_sve2_eor3vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9382 },
#else
    { 0, output_9382, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_eor3vnx4si },
    &operand_data[13202],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:829 */
  {
    "aarch64_sve2_eor3vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9383 },
#else
    { 0, output_9383, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_eor3vnx2di },
    &operand_data[13206],
    4,
    4,
    0,
    4,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:846 */
  {
    "*aarch64_sve2_norvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9384 },
#else
    { 0, output_9384, 0 },
#endif
    { 0 },
    &operand_data[13210],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:846 */
  {
    "*aarch64_sve2_norvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9385 },
#else
    { 0, output_9385, 0 },
#endif
    { 0 },
    &operand_data[13214],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:846 */
  {
    "*aarch64_sve2_norvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9386 },
#else
    { 0, output_9386, 0 },
#endif
    { 0 },
    &operand_data[13218],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:846 */
  {
    "*aarch64_sve2_norvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9387 },
#else
    { 0, output_9387, 0 },
#endif
    { 0 },
    &operand_data[13222],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:868 */
  {
    "*aarch64_sve2_nandvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9388 },
#else
    { 0, output_9388, 0 },
#endif
    { 0 },
    &operand_data[13210],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:868 */
  {
    "*aarch64_sve2_nandvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9389 },
#else
    { 0, output_9389, 0 },
#endif
    { 0 },
    &operand_data[13214],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:868 */
  {
    "*aarch64_sve2_nandvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9390 },
#else
    { 0, output_9390, 0 },
#endif
    { 0 },
    &operand_data[13218],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:868 */
  {
    "*aarch64_sve2_nandvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9391 },
#else
    { 0, output_9391, 0 },
#endif
    { 0 },
    &operand_data[13222],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9392 },
#else
    { 0, output_9392, 0 },
#endif
    { 0 },
    &operand_data[13226],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9393 },
#else
    { 0, output_9393, 0 },
#endif
    { 0 },
    &operand_data[13127],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9394 },
#else
    { 0, output_9394, 0 },
#endif
    { 0 },
    &operand_data[13230],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9395 },
#else
    { 0, output_9395, 0 },
#endif
    { 0 },
    &operand_data[13131],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9396 },
#else
    { 0, output_9396, 0 },
#endif
    { 0 },
    &operand_data[13234],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9397 },
#else
    { 0, output_9397, 0 },
#endif
    { 0 },
    &operand_data[13135],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9398 },
#else
    { 0, output_9398, 0 },
#endif
    { 0 },
    &operand_data[13238],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:903 */
  {
    "*aarch64_sve2_bslvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9399 },
#else
    { 0, output_9399, 0 },
#endif
    { 0 },
    &operand_data[13139],
    4,
    4,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9400 },
#else
    { 0, output_9400, 0 },
#endif
    { 0 },
    &operand_data[13242],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9401 },
#else
    { 0, output_9401, 0 },
#endif
    { 0 },
    &operand_data[13174],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9402 },
#else
    { 0, output_9402, 0 },
#endif
    { 0 },
    &operand_data[13247],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9403 },
#else
    { 0, output_9403, 0 },
#endif
    { 0 },
    &operand_data[13179],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9404 },
#else
    { 0, output_9404, 0 },
#endif
    { 0 },
    &operand_data[13252],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9405 },
#else
    { 0, output_9405, 0 },
#endif
    { 0 },
    &operand_data[13184],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9406 },
#else
    { 0, output_9406, 0 },
#endif
    { 0 },
    &operand_data[13257],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:940 */
  {
    "*aarch64_sve2_nbslvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9407 },
#else
    { 0, output_9407, 0 },
#endif
    { 0 },
    &operand_data[13189],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9408 },
#else
    { 0, output_9408, 0 },
#endif
    { 0 },
    &operand_data[13242],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9409 },
#else
    { 0, output_9409, 0 },
#endif
    { 0 },
    &operand_data[13174],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9410 },
#else
    { 0, output_9410, 0 },
#endif
    { 0 },
    &operand_data[13247],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9411 },
#else
    { 0, output_9411, 0 },
#endif
    { 0 },
    &operand_data[13179],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9412 },
#else
    { 0, output_9412, 0 },
#endif
    { 0 },
    &operand_data[13252],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9413 },
#else
    { 0, output_9413, 0 },
#endif
    { 0 },
    &operand_data[13184],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9414 },
#else
    { 0, output_9414, 0 },
#endif
    { 0 },
    &operand_data[13257],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:985 */
  {
    "*aarch64_sve2_bsl1nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9415 },
#else
    { 0, output_9415, 0 },
#endif
    { 0 },
    &operand_data[13189],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9416 },
#else
    { 0, output_9416, 0 },
#endif
    { 0 },
    &operand_data[13242],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9417 },
#else
    { 0, output_9417, 0 },
#endif
    { 0 },
    &operand_data[13174],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9418 },
#else
    { 0, output_9418, 0 },
#endif
    { 0 },
    &operand_data[13247],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9419 },
#else
    { 0, output_9419, 0 },
#endif
    { 0 },
    &operand_data[13179],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9420 },
#else
    { 0, output_9420, 0 },
#endif
    { 0 },
    &operand_data[13252],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9421 },
#else
    { 0, output_9421, 0 },
#endif
    { 0 },
    &operand_data[13184],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9422 },
#else
    { 0, output_9422, 0 },
#endif
    { 0 },
    &operand_data[13257],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1031 */
  {
    "*aarch64_sve2_bsl2nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9423 },
#else
    { 0, output_9423, 0 },
#endif
    { 0 },
    &operand_data[13189],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9424 },
#else
    { 0, output_9424, 0 },
#endif
    { 0 },
    &operand_data[13242],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9425 },
#else
    { 0, output_9425, 0 },
#endif
    { 0 },
    &operand_data[13174],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9426 },
#else
    { 0, output_9426, 0 },
#endif
    { 0 },
    &operand_data[13247],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9427 },
#else
    { 0, output_9427, 0 },
#endif
    { 0 },
    &operand_data[13179],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9428 },
#else
    { 0, output_9428, 0 },
#endif
    { 0 },
    &operand_data[13252],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9429 },
#else
    { 0, output_9429, 0 },
#endif
    { 0 },
    &operand_data[13184],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9430 },
#else
    { 0, output_9430, 0 },
#endif
    { 0 },
    &operand_data[13257],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1058 */
  {
    "*aarch64_sve2_bsl2nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9431 },
#else
    { 0, output_9431, 0 },
#endif
    { 0 },
    &operand_data[13189],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9432 },
#else
    { 0, output_9432, 0 },
#endif
    { 0 },
    &operand_data[13262],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9433 },
#else
    { 0, output_9433, 0 },
#endif
    { 0 },
    &operand_data[13262],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9434 },
#else
    { 0, output_9434, 0 },
#endif
    { 0 },
    &operand_data[13267],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9435 },
#else
    { 0, output_9435, 0 },
#endif
    { 0 },
    &operand_data[13267],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9436 },
#else
    { 0, output_9436, 0 },
#endif
    { 0 },
    &operand_data[13272],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9437 },
#else
    { 0, output_9437, 0 },
#endif
    { 0 },
    &operand_data[13272],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9438 },
#else
    { 0, output_9438, 0 },
#endif
    { 0 },
    &operand_data[13277],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1112 */
  {
    "*aarch64_sve2_sravnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9439 },
#else
    { 0, output_9439, 0 },
#endif
    { 0 },
    &operand_data[13277],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_srshrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9440 },
#else
    { 0, output_9440, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_srshrvnx16qi },
    &operand_data[13262],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_urshrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9441 },
#else
    { 0, output_9441, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_urshrvnx16qi },
    &operand_data[13262],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_srshrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9442 },
#else
    { 0, output_9442, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_srshrvnx8hi },
    &operand_data[13267],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_urshrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9443 },
#else
    { 0, output_9443, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_urshrvnx8hi },
    &operand_data[13267],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_srshrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9444 },
#else
    { 0, output_9444, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_srshrvnx4si },
    &operand_data[13272],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_urshrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9445 },
#else
    { 0, output_9445, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_urshrvnx4si },
    &operand_data[13272],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_srshrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9446 },
#else
    { 0, output_9446, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_srshrvnx2di },
    &operand_data[13277],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1134 */
  {
    "aarch64_sve_add_urshrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9447 },
#else
    { 0, output_9447, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_urshrvnx2di },
    &operand_data[13277],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_slivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.b, %2.b, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_slivnx16qi },
    &operand_data[13282],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_srivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.b, %2.b, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_srivnx16qi },
    &operand_data[13286],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_slivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.h, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_slivnx8hi },
    &operand_data[13290],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_srivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.h, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_srivnx8hi },
    &operand_data[13294],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_slivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.s, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_slivnx4si },
    &operand_data[13298],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_srivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.s, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_srivnx4si },
    &operand_data[13302],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_slivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sli\t%0.d, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_slivnx2di },
    &operand_data[13306],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1158 */
  {
    "aarch64_sve_srivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sri\t%0.d, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_srivnx2di },
    &operand_data[13310],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_sabavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9456 },
#else
    { 0, output_9456, 0 },
#endif
    { 0 },
    &operand_data[13314],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_uabavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9457 },
#else
    { 0, output_9457, 0 },
#endif
    { 0 },
    &operand_data[13314],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_sabavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9458 },
#else
    { 0, output_9458, 0 },
#endif
    { 0 },
    &operand_data[13320],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_uabavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9459 },
#else
    { 0, output_9459, 0 },
#endif
    { 0 },
    &operand_data[13320],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_sabavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9460 },
#else
    { 0, output_9460, 0 },
#endif
    { 0 },
    &operand_data[13326],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_uabavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9461 },
#else
    { 0, output_9461, 0 },
#endif
    { 0 },
    &operand_data[13326],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_sabavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9462 },
#else
    { 0, output_9462, 0 },
#endif
    { 0 },
    &operand_data[13332],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1203 */
  {
    "*aarch64_sve2_uabavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9463 },
#else
    { 0, output_9463, 0 },
#endif
    { 0 },
    &operand_data[13332],
    6,
    6,
    2,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_saddwbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddwb\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddwbvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_saddwtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddwt\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddwtvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_ssubwbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubwb\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubwbvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_ssubwtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubwt\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubwtvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_uaddwbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddwb\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddwbvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_uaddwtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddwt\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddwtvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_usubwbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubwb\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubwbvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_usubwtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubwt\t%0.h, %1.h, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubwtvnx8hi },
    &operand_data[13338],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_saddwbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddwb\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddwbvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_saddwtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddwt\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddwtvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_ssubwbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubwb\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubwbvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_ssubwtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubwt\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubwtvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_uaddwbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddwb\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddwbvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_uaddwtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddwt\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddwtvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_usubwbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubwb\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubwbvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_usubwtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubwt\t%0.s, %1.s, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubwtvnx4si },
    &operand_data[13341],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_saddwbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddwb\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddwbvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_saddwtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddwt\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddwtvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_ssubwbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubwb\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubwbvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_ssubwtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubwt\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubwtvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_uaddwbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddwb\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddwbvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_uaddwtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddwt\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddwtvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_usubwbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubwb\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubwbvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1245 */
  {
    "aarch64_sve_usubwtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usubwt\t%0.d, %1.d, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubwtvnx2di },
    &operand_data[13344],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sabdlbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdlb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sabdlbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sabdltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdlt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sabdltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddlbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddlbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddlbtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlbt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddlbtvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_smullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smullbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_smulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smulltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sqdmullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmullbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sqdmulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssublbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssublbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssublbtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublbt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssublbtvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssubltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssubltbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubltb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubltbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uabdlbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdlb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uabdlbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uabdltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdlt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uabdltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uaddlbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddlbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uaddltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_umullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umullbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_umulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umulltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_usublbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usublb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usublbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_usubltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usublt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sabdlbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdlb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sabdlbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sabdltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdlt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sabdltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddlbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddlbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddlbtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlbt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddlbtvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_smullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smullbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_smulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smulltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sqdmullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmullbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sqdmulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssublbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssublbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssublbtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublbt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssublbtvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssubltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssubltbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubltb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubltbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uabdlbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdlb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uabdlbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uabdltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdlt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uabdltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uaddlbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddlbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uaddltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_umullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umullbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_umulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umulltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_usublbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usublb\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usublbvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_usubltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usublt\t%0.s, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubltvnx4si },
    &operand_data[13350],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sabdlbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdlb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sabdlbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sabdltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sabdlt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sabdltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddlbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddlbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddlbtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlbt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddlbtvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_saddltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "saddlt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_saddltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_smullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smullbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_smulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smulltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sqdmullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmullbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_sqdmulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmulltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssublbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssublbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssublbtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublbt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssublbtvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssubltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssublt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_ssubltbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ssubltb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ssubltbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uabdlbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdlb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uabdlbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uabdltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uabdlt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uabdltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uaddlbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddlbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_uaddltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uaddlt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uaddltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_umullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umullbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_umulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umulltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_usublbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usublb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usublbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1282 */
  {
    "aarch64_sve_usubltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "usublt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_usubltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_smullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullb\t%0.s, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smullb_lane_vnx4si },
    &operand_data[13356],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_smullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullt\t%0.s, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smullt_lane_vnx4si },
    &operand_data[13356],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_sqdmullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullb\t%0.s, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmullb_lane_vnx4si },
    &operand_data[13356],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_sqdmullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullt\t%0.s, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmullt_lane_vnx4si },
    &operand_data[13356],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_umullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullb\t%0.s, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umullb_lane_vnx4si },
    &operand_data[13356],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_umullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullt\t%0.s, %1.h, %2.h[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umullt_lane_vnx4si },
    &operand_data[13356],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_smullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullb\t%0.d, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smullb_lane_vnx2di },
    &operand_data[13360],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_smullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "smullt\t%0.d, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_smullt_lane_vnx2di },
    &operand_data[13360],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_sqdmullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullb\t%0.d, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmullb_lane_vnx2di },
    &operand_data[13360],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_sqdmullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqdmullt\t%0.d, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdmullt_lane_vnx2di },
    &operand_data[13360],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_umullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullb\t%0.d, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umullb_lane_vnx2di },
    &operand_data[13360],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1292 */
  {
    "aarch64_sve_umullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "umullt\t%0.d, %1.s, %2.s[%3]",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_umullt_lane_vnx2di },
    &operand_data[13360],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_sshllbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshllb\t%0.h, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sshllbvnx8hi },
    &operand_data[13364],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_sshlltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshllt\t%0.h, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sshlltvnx8hi },
    &operand_data[13364],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_ushllbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushllb\t%0.h, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ushllbvnx8hi },
    &operand_data[13364],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_ushlltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushllt\t%0.h, %1.b, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ushlltvnx8hi },
    &operand_data[13364],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_sshllbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshllb\t%0.s, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sshllbvnx4si },
    &operand_data[13367],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_sshlltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshllt\t%0.s, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sshlltvnx4si },
    &operand_data[13367],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_ushllbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushllb\t%0.s, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ushllbvnx4si },
    &operand_data[13367],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_ushlltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushllt\t%0.s, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ushlltvnx4si },
    &operand_data[13367],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_sshllbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshllb\t%0.d, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sshllbvnx2di },
    &operand_data[13370],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_sshlltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sshllt\t%0.d, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sshlltvnx2di },
    &operand_data[13370],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_ushllbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushllb\t%0.d, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ushllbvnx2di },
    &operand_data[13370],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1316 */
  {
    "aarch64_sve_ushlltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "ushllt\t%0.d, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_ushlltvnx2di },
    &operand_data[13370],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_sabdlbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9575 },
#else
    { 0, output_9575, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_sabdlbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_sabdltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9576 },
#else
    { 0, output_9576, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_sabdltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_smullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9577 },
#else
    { 0, output_9577, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smullbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_smulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9578 },
#else
    { 0, output_9578, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smulltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_uabdlbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9579 },
#else
    { 0, output_9579, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_uabdlbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_uabdltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9580 },
#else
    { 0, output_9580, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_uabdltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_umullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9581 },
#else
    { 0, output_9581, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umullbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_umulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9582 },
#else
    { 0, output_9582, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umulltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_sabdlbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9583 },
#else
    { 0, output_9583, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_sabdlbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_sabdltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9584 },
#else
    { 0, output_9584, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_sabdltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_smullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9585 },
#else
    { 0, output_9585, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smullbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_smulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9586 },
#else
    { 0, output_9586, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smulltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_uabdlbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9587 },
#else
    { 0, output_9587, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_uabdlbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_uabdltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9588 },
#else
    { 0, output_9588, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_uabdltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_umullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9589 },
#else
    { 0, output_9589, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umullbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_umulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9590 },
#else
    { 0, output_9590, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umulltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_sabdlbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9591 },
#else
    { 0, output_9591, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_sabdlbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_sabdltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9592 },
#else
    { 0, output_9592, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_sabdltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_smullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9593 },
#else
    { 0, output_9593, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smullbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_smulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9594 },
#else
    { 0, output_9594, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smulltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_uabdlbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9595 },
#else
    { 0, output_9595, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_uabdlbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_uabdltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9596 },
#else
    { 0, output_9596, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_uabdltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_umullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9597 },
#else
    { 0, output_9597, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umullbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1351 */
  {
    "aarch64_sve_add_umulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9598 },
#else
    { 0, output_9598, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umulltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_smullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9599 },
#else
    { 0, output_9599, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smullb_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_smullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9600 },
#else
    { 0, output_9600, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smullt_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_umullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9601 },
#else
    { 0, output_9601, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umullb_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_umullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9602 },
#else
    { 0, output_9602, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umullt_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_smullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9603 },
#else
    { 0, output_9603, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smullb_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_smullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9604 },
#else
    { 0, output_9604, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_smullt_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_umullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9605 },
#else
    { 0, output_9605, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umullb_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1367 */
  {
    "aarch64_sve_add_umullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9606 },
#else
    { 0, output_9606, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_umullt_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9607 },
#else
    { 0, output_9607, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmullbtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9608 },
#else
    { 0, output_9608, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullbtvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9609 },
#else
    { 0, output_9609, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmulltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9610 },
#else
    { 0, output_9610, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmullbtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9611 },
#else
    { 0, output_9611, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullbtvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9612 },
#else
    { 0, output_9612, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmulltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9613 },
#else
    { 0, output_9613, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmullbtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9614 },
#else
    { 0, output_9614, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullbtvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1386 */
  {
    "aarch64_sve_qadd_sqdmulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9615 },
#else
    { 0, output_9615, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmulltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1402 */
  {
    "aarch64_sve_qadd_sqdmullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9616 },
#else
    { 0, output_9616, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullb_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1402 */
  {
    "aarch64_sve_qadd_sqdmullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9617 },
#else
    { 0, output_9617, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullt_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1402 */
  {
    "aarch64_sve_qadd_sqdmullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9618 },
#else
    { 0, output_9618, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullb_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1402 */
  {
    "aarch64_sve_qadd_sqdmullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9619 },
#else
    { 0, output_9619, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qadd_sqdmullt_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_smullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9620 },
#else
    { 0, output_9620, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smullbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_smulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9621 },
#else
    { 0, output_9621, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smulltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_umullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9622 },
#else
    { 0, output_9622, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umullbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_umulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9623 },
#else
    { 0, output_9623, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umulltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_smullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9624 },
#else
    { 0, output_9624, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smullbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_smulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9625 },
#else
    { 0, output_9625, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smulltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_umullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9626 },
#else
    { 0, output_9626, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umullbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_umulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9627 },
#else
    { 0, output_9627, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umulltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_smullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9628 },
#else
    { 0, output_9628, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smullbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_smulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9629 },
#else
    { 0, output_9629, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smulltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_umullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9630 },
#else
    { 0, output_9630, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umullbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1421 */
  {
    "aarch64_sve_sub_umulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9631 },
#else
    { 0, output_9631, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umulltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_smullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9632 },
#else
    { 0, output_9632, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smullb_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_smullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9633 },
#else
    { 0, output_9633, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smullt_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_umullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9634 },
#else
    { 0, output_9634, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umullb_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_umullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9635 },
#else
    { 0, output_9635, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umullt_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_smullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9636 },
#else
    { 0, output_9636, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smullb_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_smullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9637 },
#else
    { 0, output_9637, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_smullt_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_umullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9638 },
#else
    { 0, output_9638, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umullb_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1437 */
  {
    "aarch64_sve_sub_umullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9639 },
#else
    { 0, output_9639, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sub_umullt_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9640 },
#else
    { 0, output_9640, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullbvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmullbtvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9641 },
#else
    { 0, output_9641, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullbtvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9642 },
#else
    { 0, output_9642, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmulltvnx8hi },
    &operand_data[13373],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmullbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9643 },
#else
    { 0, output_9643, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullbvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmullbtvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9644 },
#else
    { 0, output_9644, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullbtvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmulltvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9645 },
#else
    { 0, output_9645, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmulltvnx4si },
    &operand_data[13377],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9646 },
#else
    { 0, output_9646, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullbvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmullbtvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9647 },
#else
    { 0, output_9647, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullbtvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1456 */
  {
    "aarch64_sve_qsub_sqdmulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9648 },
#else
    { 0, output_9648, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmulltvnx2di },
    &operand_data[13381],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1472 */
  {
    "aarch64_sve_qsub_sqdmullb_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9649 },
#else
    { 0, output_9649, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullb_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1472 */
  {
    "aarch64_sve_qsub_sqdmullt_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9650 },
#else
    { 0, output_9650, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullt_lane_vnx4si },
    &operand_data[13385],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1472 */
  {
    "aarch64_sve_qsub_sqdmullb_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9651 },
#else
    { 0, output_9651, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullb_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1472 */
  {
    "aarch64_sve_qsub_sqdmullt_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9652 },
#else
    { 0, output_9652, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_qsub_sqdmullt_lane_vnx2di },
    &operand_data[13390],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1499 */
  {
    "aarch64_sve_fmlalbvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9653 },
#else
    { 0, output_9653, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fmlalbvnx4sf },
    &operand_data[13395],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1499 */
  {
    "aarch64_sve_fmlaltvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9654 },
#else
    { 0, output_9654, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fmlaltvnx4sf },
    &operand_data[13395],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1499 */
  {
    "aarch64_sve_fmlslbvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9655 },
#else
    { 0, output_9655, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fmlslbvnx4sf },
    &operand_data[13395],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1499 */
  {
    "aarch64_sve_fmlsltvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9656 },
#else
    { 0, output_9656, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_fmlsltvnx4sf },
    &operand_data[13395],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1513 */
  {
    "aarch64_fmlalb_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9657 },
#else
    { 0, output_9657, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalb_lane_vnx4sf },
    &operand_data[13399],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1513 */
  {
    "aarch64_fmlalt_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9658 },
#else
    { 0, output_9658, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalt_lane_vnx4sf },
    &operand_data[13399],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1513 */
  {
    "aarch64_fmlslb_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9659 },
#else
    { 0, output_9659, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslb_lane_vnx4sf },
    &operand_data[13399],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1513 */
  {
    "aarch64_fmlslt_lane_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9660 },
#else
    { 0, output_9660, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslt_lane_vnx4sf },
    &operand_data[13399],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_sqxtnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtnb\t%0.b, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtnbvnx8hi },
    &operand_data[12534],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_sqxtunbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtunb\t%0.b, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtunbvnx8hi },
    &operand_data[12534],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_uqxtnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtnb\t%0.b, %1.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqxtnbvnx8hi },
    &operand_data[12534],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_sqxtnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtnb\t%0.h, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtnbvnx4si },
    &operand_data[12537],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_sqxtunbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtunb\t%0.h, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtunbvnx4si },
    &operand_data[12537],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_uqxtnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtnb\t%0.h, %1.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqxtnbvnx4si },
    &operand_data[12537],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_sqxtnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtnb\t%0.s, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtnbvnx2di },
    &operand_data[12540],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_sqxtunbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtunb\t%0.s, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtunbvnx2di },
    &operand_data[12540],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1546 */
  {
    "aarch64_sve_uqxtnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtnb\t%0.s, %1.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqxtnbvnx2di },
    &operand_data[12540],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_sqxtntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtnt\t%0.b, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtntvnx8hi },
    &operand_data[13404],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_sqxtuntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtunt\t%0.b, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtuntvnx8hi },
    &operand_data[13404],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_uqxtntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtnt\t%0.b, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqxtntvnx8hi },
    &operand_data[13404],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_sqxtntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtnt\t%0.h, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtntvnx4si },
    &operand_data[13407],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_sqxtuntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtunt\t%0.h, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtuntvnx4si },
    &operand_data[13407],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_uqxtntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtnt\t%0.h, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqxtntvnx4si },
    &operand_data[13407],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_sqxtntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtnt\t%0.s, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtntvnx2di },
    &operand_data[13410],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_sqxtuntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqxtunt\t%0.s, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqxtuntvnx2di },
    &operand_data[13410],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1556 */
  {
    "aarch64_sve_uqxtntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqxtnt\t%0.s, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqxtntvnx2di },
    &operand_data[13410],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_addhnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhnb\t%0.b, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_addhnbvnx8hi },
    &operand_data[12534],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_raddhnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhnb\t%0.b, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_raddhnbvnx8hi },
    &operand_data[12534],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_rsubhnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhnb\t%0.b, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rsubhnbvnx8hi },
    &operand_data[12534],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_subhnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhnb\t%0.b, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_subhnbvnx8hi },
    &operand_data[12534],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_addhnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhnb\t%0.h, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_addhnbvnx4si },
    &operand_data[12537],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_raddhnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhnb\t%0.h, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_raddhnbvnx4si },
    &operand_data[12537],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_rsubhnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhnb\t%0.h, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rsubhnbvnx4si },
    &operand_data[12537],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_subhnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhnb\t%0.h, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_subhnbvnx4si },
    &operand_data[12537],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_addhnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhnb\t%0.s, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_addhnbvnx2di },
    &operand_data[12540],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_raddhnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhnb\t%0.s, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_raddhnbvnx2di },
    &operand_data[12540],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_rsubhnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhnb\t%0.s, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rsubhnbvnx2di },
    &operand_data[12540],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1580 */
  {
    "aarch64_sve_subhnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhnb\t%0.s, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_subhnbvnx2di },
    &operand_data[12540],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_addhntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhnt\t%0.b, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_addhntvnx8hi },
    &operand_data[13413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_raddhntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhnt\t%0.b, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_raddhntvnx8hi },
    &operand_data[13413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_rsubhntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhnt\t%0.b, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rsubhntvnx8hi },
    &operand_data[13413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_subhntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhnt\t%0.b, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_subhntvnx8hi },
    &operand_data[13413],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_addhntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhnt\t%0.h, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_addhntvnx4si },
    &operand_data[13417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_raddhntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhnt\t%0.h, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_raddhntvnx4si },
    &operand_data[13417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_rsubhntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhnt\t%0.h, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rsubhntvnx4si },
    &operand_data[13417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_subhntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhnt\t%0.h, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_subhntvnx4si },
    &operand_data[13417],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_addhntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "addhnt\t%0.s, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_addhntvnx2di },
    &operand_data[13421],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_raddhntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "raddhnt\t%0.s, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_raddhntvnx2di },
    &operand_data[13421],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_rsubhntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rsubhnt\t%0.s, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rsubhntvnx2di },
    &operand_data[13421],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1591 */
  {
    "aarch64_sve_subhntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "subhnt\t%0.s, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_subhntvnx2di },
    &operand_data[13421],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_rshrnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrnb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rshrnbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_shrnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrnb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_shrnbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqrshrnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrnb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrnbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqrshrunbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrunb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrunbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqshrnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrnb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrnbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqshrunbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrunb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrunbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_uqrshrnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrnb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqrshrnbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_uqshrnbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrnb\t%0.b, %1.h, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqshrnbvnx8hi },
    &operand_data[13425],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_rshrnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrnb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rshrnbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_shrnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrnb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_shrnbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqrshrnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrnb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrnbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqrshrunbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrunb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrunbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqshrnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrnb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrnbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqshrunbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrunb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrunbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_uqrshrnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrnb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqrshrnbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_uqshrnbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrnb\t%0.h, %1.s, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqshrnbvnx4si },
    &operand_data[13428],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_rshrnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrnb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rshrnbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_shrnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrnb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_shrnbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqrshrnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrnb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrnbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqrshrunbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrunb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrunbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqshrnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrnb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrnbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_sqshrunbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrunb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrunbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_uqrshrnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrnb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqrshrnbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1625 */
  {
    "aarch64_sve_uqshrnbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrnb\t%0.s, %1.d, #%2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqshrnbvnx2di },
    &operand_data[13431],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_rshrntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrnt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rshrntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_shrntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrnt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_shrntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqrshrntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrnt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqrshruntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrunt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshruntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqshrntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrnt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqshruntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrunt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshruntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_uqrshrntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrnt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqrshrntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_uqshrntvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrnt\t%0.b, %2.h, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqshrntvnx8hi },
    &operand_data[13434],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_rshrntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrnt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rshrntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_shrntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrnt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_shrntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqrshrntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrnt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqrshruntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrunt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshruntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqshrntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrnt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqshruntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrunt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshruntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_uqrshrntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrnt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqrshrntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_uqshrntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrnt\t%0.h, %2.s, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqshrntvnx4si },
    &operand_data[13438],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_rshrntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rshrnt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_rshrntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_shrntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "shrnt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_shrntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqrshrntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrnt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshrntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqrshruntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqrshrunt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrshruntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqshrntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrnt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshrntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_sqshruntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sqshrunt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqshruntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_uqrshrntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqrshrnt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqrshrntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1637 */
  {
    "aarch64_sve_uqshrntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "uqshrnt\t%0.s, %2.d, #%3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqshrntvnx2di },
    &operand_data[13442],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_addpvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9751 },
#else
    { 0, output_9751, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_addpvnx16qi },
    &operand_data[9075],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_smaxpvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9752 },
#else
    { 0, output_9752, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxpvnx16qi },
    &operand_data[9075],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_sminpvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9753 },
#else
    { 0, output_9753, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminpvnx16qi },
    &operand_data[9075],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_umaxpvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9754 },
#else
    { 0, output_9754, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxpvnx16qi },
    &operand_data[9075],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_uminpvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9755 },
#else
    { 0, output_9755, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminpvnx16qi },
    &operand_data[9075],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_addpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9756 },
#else
    { 0, output_9756, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_addpvnx8hi },
    &operand_data[9091],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_smaxpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9757 },
#else
    { 0, output_9757, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxpvnx8hi },
    &operand_data[9091],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_sminpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9758 },
#else
    { 0, output_9758, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminpvnx8hi },
    &operand_data[9091],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_umaxpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9759 },
#else
    { 0, output_9759, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxpvnx8hi },
    &operand_data[9091],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_uminpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9760 },
#else
    { 0, output_9760, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminpvnx8hi },
    &operand_data[9091],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_addpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9761 },
#else
    { 0, output_9761, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_addpvnx4si },
    &operand_data[9103],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_smaxpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9762 },
#else
    { 0, output_9762, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxpvnx4si },
    &operand_data[9103],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_sminpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9763 },
#else
    { 0, output_9763, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminpvnx4si },
    &operand_data[9103],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_umaxpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9764 },
#else
    { 0, output_9764, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxpvnx4si },
    &operand_data[9103],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_uminpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9765 },
#else
    { 0, output_9765, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminpvnx4si },
    &operand_data[9103],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_addpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9766 },
#else
    { 0, output_9766, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_addpvnx2di },
    &operand_data[9111],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_smaxpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9767 },
#else
    { 0, output_9767, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_smaxpvnx2di },
    &operand_data[9111],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_sminpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9768 },
#else
    { 0, output_9768, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_sminpvnx2di },
    &operand_data[9111],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_umaxpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9769 },
#else
    { 0, output_9769, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_umaxpvnx2di },
    &operand_data[9111],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1663 */
  {
    "aarch64_pred_uminpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9770 },
#else
    { 0, output_9770, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_uminpvnx2di },
    &operand_data[9111],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_faddpvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9771 },
#else
    { 0, output_9771, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_faddpvnx8hf },
    &operand_data[10378],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fmaxpvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9772 },
#else
    { 0, output_9772, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmaxpvnx8hf },
    &operand_data[10378],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fmaxnmpvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9773 },
#else
    { 0, output_9773, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmaxnmpvnx8hf },
    &operand_data[10378],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fminpvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9774 },
#else
    { 0, output_9774, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fminpvnx8hf },
    &operand_data[10378],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fminnmpvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9775 },
#else
    { 0, output_9775, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fminnmpvnx8hf },
    &operand_data[10378],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_faddpvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9776 },
#else
    { 0, output_9776, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_faddpvnx4sf },
    &operand_data[10383],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fmaxpvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9777 },
#else
    { 0, output_9777, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmaxpvnx4sf },
    &operand_data[10383],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fmaxnmpvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9778 },
#else
    { 0, output_9778, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmaxnmpvnx4sf },
    &operand_data[10383],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fminpvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9779 },
#else
    { 0, output_9779, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fminpvnx4sf },
    &operand_data[10383],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fminnmpvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9780 },
#else
    { 0, output_9780, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fminnmpvnx4sf },
    &operand_data[10383],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_faddpvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9781 },
#else
    { 0, output_9781, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_faddpvnx2df },
    &operand_data[10388],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fmaxpvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9782 },
#else
    { 0, output_9782, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmaxpvnx2df },
    &operand_data[10388],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fmaxnmpvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9783 },
#else
    { 0, output_9783, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fmaxnmpvnx2df },
    &operand_data[10388],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fminpvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9784 },
#else
    { 0, output_9784, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fminpvnx2df },
    &operand_data[10388],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1688 */
  {
    "aarch64_pred_fminnmpvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9785 },
#else
    { 0, output_9785, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fminnmpvnx2df },
    &operand_data[10388],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1732 */
  {
    "*cond_sadalpvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9786 },
#else
    { 0, output_9786, 0 },
#endif
    { 0 },
    &operand_data[13446],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1732 */
  {
    "*cond_uadalpvnx8hi_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9787 },
#else
    { 0, output_9787, 0 },
#endif
    { 0 },
    &operand_data[13446],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1732 */
  {
    "*cond_sadalpvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9788 },
#else
    { 0, output_9788, 0 },
#endif
    { 0 },
    &operand_data[13451],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1732 */
  {
    "*cond_uadalpvnx4si_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9789 },
#else
    { 0, output_9789, 0 },
#endif
    { 0 },
    &operand_data[13451],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1732 */
  {
    "*cond_sadalpvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9790 },
#else
    { 0, output_9790, 0 },
#endif
    { 0 },
    &operand_data[13456],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1732 */
  {
    "*cond_uadalpvnx2di_2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9791 },
#else
    { 0, output_9791, 0 },
#endif
    { 0 },
    &operand_data[13456],
    5,
    5,
    1,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1755 */
  {
    "*cond_sadalpvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9792 },
#else
    { 0, output_9792, 0 },
#endif
    { 0 },
    &operand_data[13461],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1755 */
  {
    "*cond_uadalpvnx8hi_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9793 },
#else
    { 0, output_9793, 0 },
#endif
    { 0 },
    &operand_data[13461],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1755 */
  {
    "*cond_sadalpvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9794 },
#else
    { 0, output_9794, 0 },
#endif
    { 0 },
    &operand_data[13467],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1755 */
  {
    "*cond_uadalpvnx4si_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9795 },
#else
    { 0, output_9795, 0 },
#endif
    { 0 },
    &operand_data[13467],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1755 */
  {
    "*cond_sadalpvnx2di_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9796 },
#else
    { 0, output_9796, 0 },
#endif
    { 0 },
    &operand_data[13473],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1755 */
  {
    "*cond_uadalpvnx2di_z",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9797 },
#else
    { 0, output_9797, 0 },
#endif
    { 0 },
    &operand_data[13473],
    6,
    6,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd90vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9798 },
#else
    { 0, output_9798, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd90vnx16qi },
    &operand_data[12442],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd270vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9799 },
#else
    { 0, output_9799, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd270vnx16qi },
    &operand_data[12442],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd90vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9800 },
#else
    { 0, output_9800, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd90vnx16qi },
    &operand_data[12442],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd270vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9801 },
#else
    { 0, output_9801, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd270vnx16qi },
    &operand_data[12442],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd90vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9802 },
#else
    { 0, output_9802, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd90vnx8hi },
    &operand_data[12458],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd270vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9803 },
#else
    { 0, output_9803, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd270vnx8hi },
    &operand_data[12458],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd90vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9804 },
#else
    { 0, output_9804, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd90vnx8hi },
    &operand_data[12458],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd270vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9805 },
#else
    { 0, output_9805, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd270vnx8hi },
    &operand_data[12458],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd90vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9806 },
#else
    { 0, output_9806, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd90vnx4si },
    &operand_data[12494],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd270vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9807 },
#else
    { 0, output_9807, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd270vnx4si },
    &operand_data[12494],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd90vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9808 },
#else
    { 0, output_9808, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd90vnx4si },
    &operand_data[12494],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd270vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9809 },
#else
    { 0, output_9809, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd270vnx4si },
    &operand_data[12494],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd90vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9810 },
#else
    { 0, output_9810, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd90vnx2di },
    &operand_data[12510],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_cadd270vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9811 },
#else
    { 0, output_9811, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cadd270vnx2di },
    &operand_data[12510],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd90vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9812 },
#else
    { 0, output_9812, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd90vnx2di },
    &operand_data[12510],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1789 */
  {
    "aarch64_sve_sqcadd270vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9813 },
#else
    { 0, output_9813, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqcadd270vnx2di },
    &operand_data[12510],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmlavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9814 },
#else
    { 0, output_9814, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmlavnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla90vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9815 },
#else
    { 0, output_9815, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla90vnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla180vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9816 },
#else
    { 0, output_9816, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla180vnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla270vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9817 },
#else
    { 0, output_9817, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla270vnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlahvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9818 },
#else
    { 0, output_9818, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlahvnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah90vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9819 },
#else
    { 0, output_9819, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah90vnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah180vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9820 },
#else
    { 0, output_9820, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah180vnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah270vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9821 },
#else
    { 0, output_9821, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah270vnx16qi },
    &operand_data[13127],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmlavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9822 },
#else
    { 0, output_9822, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmlavnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla90vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9823 },
#else
    { 0, output_9823, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla90vnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla180vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9824 },
#else
    { 0, output_9824, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla180vnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla270vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9825 },
#else
    { 0, output_9825, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla270vnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlahvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9826 },
#else
    { 0, output_9826, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlahvnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah90vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9827 },
#else
    { 0, output_9827, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah90vnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah180vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9828 },
#else
    { 0, output_9828, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah180vnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah270vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9829 },
#else
    { 0, output_9829, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah270vnx8hi },
    &operand_data[13131],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmlavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9830 },
#else
    { 0, output_9830, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmlavnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla90vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9831 },
#else
    { 0, output_9831, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla90vnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla180vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9832 },
#else
    { 0, output_9832, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla180vnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla270vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9833 },
#else
    { 0, output_9833, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla270vnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlahvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9834 },
#else
    { 0, output_9834, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlahvnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah90vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9835 },
#else
    { 0, output_9835, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah90vnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah180vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9836 },
#else
    { 0, output_9836, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah180vnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah270vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9837 },
#else
    { 0, output_9837, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah270vnx4si },
    &operand_data[13135],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmlavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9838 },
#else
    { 0, output_9838, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmlavnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla90vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9839 },
#else
    { 0, output_9839, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla90vnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla180vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9840 },
#else
    { 0, output_9840, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla180vnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_cmla270vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9841 },
#else
    { 0, output_9841, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cmla270vnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlahvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9842 },
#else
    { 0, output_9842, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlahvnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah90vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9843 },
#else
    { 0, output_9843, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah90vnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah180vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9844 },
#else
    { 0, output_9844, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah180vnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1820 */
  {
    "aarch64_sve_sqrdcmlah270vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9845 },
#else
    { 0, output_9845, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqrdcmlah270vnx2di },
    &operand_data[13139],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9846 },
#else
    { 0, output_9846, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla90_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9847 },
#else
    { 0, output_9847, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla90_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla180_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9848 },
#else
    { 0, output_9848, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla180_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla270_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9849 },
#else
    { 0, output_9849, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla270_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9850 },
#else
    { 0, output_9850, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah90_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9851 },
#else
    { 0, output_9851, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah90_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah180_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9852 },
#else
    { 0, output_9852, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah180_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah270_lane_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9853 },
#else
    { 0, output_9853, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah270_lane_vnx8hi },
    &operand_data[13143],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9854 },
#else
    { 0, output_9854, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla90_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9855 },
#else
    { 0, output_9855, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla90_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla180_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9856 },
#else
    { 0, output_9856, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla180_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_cmla270_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9857 },
#else
    { 0, output_9857, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cmla270_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9858 },
#else
    { 0, output_9858, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah90_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9859 },
#else
    { 0, output_9859, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah90_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah180_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9860 },
#else
    { 0, output_9860, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah180_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1834 */
  {
    "aarch64_sqrdcmlah270_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9861 },
#else
    { 0, output_9861, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrdcmlah270_lane_vnx4si },
    &operand_data[13148],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdotvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9862 },
#else
    { 0, output_9862, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdotvnx4si },
    &operand_data[11087],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdot90vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9863 },
#else
    { 0, output_9863, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdot90vnx4si },
    &operand_data[11087],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdot180vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9864 },
#else
    { 0, output_9864, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdot180vnx4si },
    &operand_data[11087],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdot270vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9865 },
#else
    { 0, output_9865, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdot270vnx4si },
    &operand_data[11087],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdotvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9866 },
#else
    { 0, output_9866, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdotvnx2di },
    &operand_data[13479],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdot90vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9867 },
#else
    { 0, output_9867, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdot90vnx2di },
    &operand_data[13479],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdot180vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9868 },
#else
    { 0, output_9868, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdot180vnx2di },
    &operand_data[13479],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1900 */
  {
    "aarch64_sve_cdot270vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9869 },
#else
    { 0, output_9869, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cdot270vnx2di },
    &operand_data[13479],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9870 },
#else
    { 0, output_9870, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot_lane_vnx4si },
    &operand_data[13483],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot90_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9871 },
#else
    { 0, output_9871, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot90_lane_vnx4si },
    &operand_data[13483],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot180_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9872 },
#else
    { 0, output_9872, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot180_lane_vnx4si },
    &operand_data[13483],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot270_lane_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9873 },
#else
    { 0, output_9873, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot270_lane_vnx4si },
    &operand_data[13483],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9874 },
#else
    { 0, output_9874, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot_lane_vnx2di },
    &operand_data[13488],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot90_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9875 },
#else
    { 0, output_9875, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot90_lane_vnx2di },
    &operand_data[13488],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot180_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9876 },
#else
    { 0, output_9876, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot180_lane_vnx2di },
    &operand_data[13488],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1914 */
  {
    "aarch64_cdot270_lane_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9877 },
#else
    { 0, output_9877, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cdot270_lane_vnx2di },
    &operand_data[13488],
    5,
    5,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1943 */
  {
    "aarch64_pred_fcvtltvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtlt\t%0.s, %1/m, %0.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcvtltvnx4sf },
    &operand_data[13493],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1943 */
  {
    "aarch64_pred_fcvtltvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtlt\t%0.d, %1/m, %0.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcvtltvnx2df },
    &operand_data[13497],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1970 */
  {
    "*cond_fcvtltvnx4sf_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtlt\t%0.s, %1/m, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13501],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1970 */
  {
    "*cond_fcvtltvnx2df_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtlt\t%0.d, %1/m, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13506],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1989 */
  {
    "*cond_fcvtltvnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtlt\t%0.s, %1/m, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13501],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1989 */
  {
    "*cond_fcvtltvnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtlt\t%0.d, %1/m, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13506],
    4,
    4,
    1,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2018 */
  {
    "aarch64_sve_cvtntvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnt\t%0.h, %2/m, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cvtntvnx8hf },
    &operand_data[13511],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2018 */
  {
    "aarch64_sve_cvtntvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtnt\t%0.s, %2/m, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_cvtntvnx4sf },
    &operand_data[13515],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2032 */
  {
    "aarch64_pred_fcvtxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9886 },
#else
    { 0, output_9886, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_fcvtxvnx4sf },
    &operand_data[12683],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2061 */
  {
    "*cond_fcvtxvnx4sf_any_relaxed",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9887 },
#else
    { 0, output_9887, 0 },
#endif
    { 0 },
    &operand_data[13519],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2084 */
  {
    "*cond_fcvtxvnx4sf_any_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9888 },
#else
    { 0, output_9888, 0 },
#endif
    { 0 },
    &operand_data[13519],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2108 */
  {
    "aarch64_sve2_cvtxntvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "fcvtxnt\t%0.s, %2/m, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_cvtxntvnx2df },
    &operand_data[13515],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2133 */
  {
    "aarch64_pred_urecpevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9890 },
#else
    { 0, output_9890, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_urecpevnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2133 */
  {
    "aarch64_pred_ursqrtevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9891 },
#else
    { 0, output_9891, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_ursqrtevnx4si },
    &operand_data[8426],
    3,
    3,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2167 */
  {
    "*cond_urecpevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9892 },
#else
    { 0, output_9892, 0 },
#endif
    { 0 },
    &operand_data[13524],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2167 */
  {
    "*cond_ursqrtevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9893 },
#else
    { 0, output_9893, 0 },
#endif
    { 0 },
    &operand_data[13524],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2199 */
  {
    "aarch64_pred_flogbvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9894 },
#else
    { 0, output_9894, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_flogbvnx8hf },
    &operand_data[12549],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2199 */
  {
    "aarch64_pred_flogbvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9895 },
#else
    { 0, output_9895, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_flogbvnx4sf },
    &operand_data[12557],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2199 */
  {
    "aarch64_pred_flogbvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9896 },
#else
    { 0, output_9896, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_flogbvnx2df },
    &operand_data[12569],
    4,
    4,
    0,
    2,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2228 */
  {
    "*cond_flogbvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9897 },
#else
    { 0, output_9897, 0 },
#endif
    { 0 },
    &operand_data[13529],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2228 */
  {
    "*cond_flogbvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9898 },
#else
    { 0, output_9898, 0 },
#endif
    { 0 },
    &operand_data[13534],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2228 */
  {
    "*cond_flogbvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9899 },
#else
    { 0, output_9899, 0 },
#endif
    { 0 },
    &operand_data[13539],
    5,
    5,
    0,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2251 */
  {
    "*cond_flogbvnx8hf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9900 },
#else
    { 0, output_9900, 0 },
#endif
    { 0 },
    &operand_data[13529],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2251 */
  {
    "*cond_flogbvnx4sf_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9901 },
#else
    { 0, output_9901, 0 },
#endif
    { 0 },
    &operand_data[13534],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2251 */
  {
    "*cond_flogbvnx2df_strict",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .multi = output_9902 },
#else
    { 0, output_9902, 0 },
#endif
    { 0 },
    &operand_data[13539],
    4,
    4,
    1,
    3,
    2
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2280 */
  {
    "aarch64_sve2_pmulvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmul\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_pmulvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2292 */
  {
    "aarch64_sve_pmullbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullbvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2292 */
  {
    "aarch64_sve_pmulltvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmulltvnx8hi },
    &operand_data[13347],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2292 */
  {
    "aarch64_sve_pmullbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullbvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2292 */
  {
    "aarch64_sve_pmulltvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmulltvnx2di },
    &operand_data[13353],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2305 */
  {
    "aarch64_sve_pmullb_pairvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullb\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullb_pairvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2305 */
  {
    "aarch64_sve_pmullt_pairvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullt\t%0.h, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullt_pairvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2305 */
  {
    "aarch64_sve_pmullb_pairvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullb\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullb_pairvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2305 */
  {
    "aarch64_sve_pmullt_pairvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullt\t%0.d, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullt_pairvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2305 */
  {
    "aarch64_sve_pmullb_pairvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullb\t%0.q, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullb_pairvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2305 */
  {
    "aarch64_sve_pmullt_pairvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "pmullt\t%0.q, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_pmullt_pairvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.b, %1, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx16qi },
    &operand_data[13544],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.h, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx8hi },
    &operand_data[13547],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.s, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx4si },
    &operand_data[13550],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.d, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx2di },
    &operand_data[13553],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.h, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx8bf },
    &operand_data[13556],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.h, %1, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx8hf },
    &operand_data[13559],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.s, %1, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx4sf },
    &operand_data[13562],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2328 */
  {
    "aarch64_sve2_tbl2vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbl\t%0.d, %1, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbl2vnx2df },
    &operand_data[13565],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.b, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx16qi },
    &operand_data[13568],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.h, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx8hi },
    &operand_data[13572],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.s, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx4si },
    &operand_data[13576],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.d, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx2di },
    &operand_data[13580],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.h, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx8bf },
    &operand_data[13584],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.h, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx8hf },
    &operand_data[13588],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.s, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx4sf },
    &operand_data[13592],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2339 */
  {
    "aarch64_sve2_tbxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "tbx\t%0.d, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_tbxvnx2df },
    &operand_data[13596],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bdepvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bdep\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bdepvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bextvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bext\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bextvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bgrpvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bgrp\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bgrpvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bdepvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bdep\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bdepvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bextvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bext\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bextvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bgrpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bgrp\t%0.h, %1.h, %2.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bgrpvnx8hi },
    &operand_data[9651],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bdepvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bdep\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bdepvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bextvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bext\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bextvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bgrpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bgrp\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bgrpvnx4si },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bdepvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bdep\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bdepvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bextvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bext\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bextvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2359 */
  {
    "aarch64_sve_bgrpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "bgrp\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_bgrpvnx2di },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2422 */
  {
    "aarch64_sve2_histcntvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "histcnt\t%0.s, %1/z, %2.s, %3.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_histcntvnx4si },
    &operand_data[13600],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2422 */
  {
    "aarch64_sve2_histcntvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "histcnt\t%0.d, %1/z, %2.d, %3.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_histcntvnx2di },
    &operand_data[13604],
    4,
    4,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2433 */
  {
    "aarch64_sve2_histsegvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "histseg\t%0.b, %1.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_histsegvnx16qi },
    &operand_data[9635],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2452 */
  {
    "aarch64_pred_matchvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "match\t%0.b, %1/z, %3.b, %4.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_matchvnx16qi },
    &operand_data[13608],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2452 */
  {
    "aarch64_pred_nmatchvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nmatch\t%0.b, %1/z, %3.b, %4.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nmatchvnx16qi },
    &operand_data[13608],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2452 */
  {
    "aarch64_pred_matchvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "match\t%0.h, %1/z, %3.h, %4.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_matchvnx8hi },
    &operand_data[13613],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2452 */
  {
    "aarch64_pred_nmatchvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nmatch\t%0.h, %1/z, %3.h, %4.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_nmatchvnx8hi },
    &operand_data[13613],
    5,
    5,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2469 */
  {
    "*aarch64_pred_matchvnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "match\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13618],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2469 */
  {
    "*aarch64_pred_nmatchvnx16qi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nmatch\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13618],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2469 */
  {
    "*aarch64_pred_matchvnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "match\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13626],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2469 */
  {
    "*aarch64_pred_nmatchvnx8hi_cc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nmatch\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13626],
    8,
    8,
    4,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2504 */
  {
    "*aarch64_pred_matchvnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "match\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13634],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2504 */
  {
    "*aarch64_pred_nmatchvnx16qi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nmatch\t%0.b, %1/z, %2.b, %3.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13634],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2504 */
  {
    "*aarch64_pred_matchvnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "match\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13642],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2504 */
  {
    "*aarch64_pred_nmatchvnx8hi_ptest",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "nmatch\t%0.h, %1/z, %2.h, %3.h",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13642],
    8,
    8,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2545 */
  {
    "aarch64_sve2_aese",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aese\t%0.b, %0.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_aese },
    &operand_data[13650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2545 */
  {
    "aarch64_sve2_aesd",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesd\t%0.b, %0.b, %2.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_aesd },
    &operand_data[13650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2558 */
  {
    "aarch64_sve2_aesmc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesmc\t%0.b, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_aesmc },
    &operand_data[13282],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2558 */
  {
    "aarch64_sve2_aesimc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesimc\t%0.b, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_aesimc },
    &operand_data[13282],
    2,
    2,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2573 */
  {
    "*aarch64_sve2_aese_fused",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aese\t%0.b, %0.b, %2.b\n\taesmc\t%0.b, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2588 */
  {
    "*aarch64_sve2_aesd_fused",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "aesd\t%0.b, %0.b, %2.b\n\taesimc\t%0.b, %0.b",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { 0 },
    &operand_data[13650],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2610 */
  {
    "aarch64_sve2_rax1",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "rax1\t%0.d, %1.d, %2.d",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_rax1 },
    &operand_data[9268],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2631 */
  {
    "aarch64_sve2_sm4e",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm4e\t%0.s, %0.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_sm4e },
    &operand_data[13298],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2642 */
  {
    "aarch64_sve2_sm4ekey",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { .single =
#else
    {
#endif
    "sm4ekey\t%0.s, %1.s, %2.s",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    },
#else
    0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_sm4ekey },
    &operand_data[9265],
    3,
    3,
    0,
    1,
    1
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:502 */
  {
    "cbranchsi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchsi4 },
    &operand_data[13653],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:502 */
  {
    "cbranchdi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchdi4 },
    &operand_data[13657],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:516 */
  {
    "cbranchsf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchsf4 },
    &operand_data[13661],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:516 */
  {
    "cbranchdf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchdf4 },
    &operand_data[13665],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:530 */
  {
    "cbranchcc4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchcc4 },
    &operand_data[13669],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:621 */
  {
    "modsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_modsi3 },
    &operand_data[13673],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:621 */
  {
    "moddi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_moddi3 },
    &operand_data[13676],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:735 */
  {
    "casesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_casesi },
    &operand_data[13679],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:787 */
  {
    "casesi_dispatch",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_casesi_dispatch },
    &operand_data[13683],
    2,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:858 */
  {
    "prologue",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_prologue },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:867 */
  {
    "epilogue",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_epilogue },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:876 */
  {
    "sibcall_epilogue",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sibcall_epilogue },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:907 */
  {
    "return",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_return },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1032 */
  {
    "call",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call },
    &operand_data[13687],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1057 */
  {
    "call_value",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_call_value },
    &operand_data[13690],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1085 */
  {
    "sibcall",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sibcall },
    &operand_data[13687],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1098 */
  {
    "sibcall_value",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sibcall_value },
    &operand_data[13690],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1152 */
  {
    "untyped_call",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_untyped_call },
    &operand_data[13694],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1183 */
  {
    "movqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movqi },
    &operand_data[13697],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1183 */
  {
    "movhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movhi },
    &operand_data[13699],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1240 */
  {
    "movsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsi },
    &operand_data[13701],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1240 */
  {
    "movdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdi },
    &operand_data[13703],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1379 */
  {
    "movti",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movti },
    &operand_data[13705],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1435 */
  {
    "movhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movhf },
    &operand_data[13707],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1435 */
  {
    "movbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movbf },
    &operand_data[13709],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1435 */
  {
    "movsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsf },
    &operand_data[13711],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1435 */
  {
    "movdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdf },
    &operand_data[13713],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1435 */
  {
    "movtf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movtf },
    &operand_data[13715],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1584 */
  {
    "aarch64_cpymemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cpymemdi },
    &operand_data[13694],
    3,
    3,
    3,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1614 */
  {
    "cpymemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cpymemdi },
    &operand_data[13717],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1644 */
  {
    "movmemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmemdi },
    &operand_data[13717],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1673 */
  {
    "aarch64_setmemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_setmemdi },
    &operand_data[13694],
    3,
    3,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1701 */
  {
    "setmemdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_setmemdi },
    &operand_data[13721],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1917 */
  {
    "extendsidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendsidi2 },
    &operand_data[13725],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1917 */
  {
    "zero_extendsidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendsidi2 },
    &operand_data[13725],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "extendqisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendqisi2 },
    &operand_data[13727],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "zero_extendqisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendqisi2 },
    &operand_data[13727],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "extendhisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendhisi2 },
    &operand_data[13729],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "zero_extendhisi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendhisi2 },
    &operand_data[13729],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "extendqidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendqidi2 },
    &operand_data[13731],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "zero_extendqidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendqidi2 },
    &operand_data[13731],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "extendhidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendhidi2 },
    &operand_data[13733],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:1977 */
  {
    "zero_extendhidi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendhidi2 },
    &operand_data[13733],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2008 */
  {
    "extendqihi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendqihi2 },
    &operand_data[13735],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2008 */
  {
    "zero_extendqihi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendqihi2 },
    &operand_data[13735],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2038 */
  {
    "addsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3 },
    &operand_data[13737],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2038 */
  {
    "adddi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3 },
    &operand_data[13740],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2215 */
  {
    "addvsi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvsi4 },
    &operand_data[13743],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2215 */
  {
    "addvdi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvdi4 },
    &operand_data[13747],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2232 */
  {
    "uaddvsi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uaddvsi4 },
    &operand_data[13751],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2232 */
  {
    "uaddvdi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uaddvdi4 },
    &operand_data[13755],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2245 */
  {
    "addti3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addti3 },
    &operand_data[13759],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2278 */
  {
    "addvti4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvti4 },
    &operand_data[13759],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2312 */
  {
    "uaddvti4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uaddvti4 },
    &operand_data[13759],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2669 */
  {
    "addsi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3_carryin },
    &operand_data[13763],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2669 */
  {
    "adddi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_carryin },
    &operand_data[13766],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2709 */
  {
    "addsi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3_carryinC },
    &operand_data[13751],
    3,
    3,
    6,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2709 */
  {
    "adddi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_carryinC },
    &operand_data[13755],
    3,
    3,
    6,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2772 */
  {
    "addsi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addsi3_carryinV },
    &operand_data[13751],
    3,
    3,
    7,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2772 */
  {
    "adddi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_adddi3_carryinV },
    &operand_data[13755],
    3,
    3,
    7,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2902 */
  {
    "subvsi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvsi4 },
    &operand_data[13743],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2902 */
  {
    "subvdi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvdi4 },
    &operand_data[13747],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2952 */
  {
    "negvsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvsi3 },
    &operand_data[13752],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:2952 */
  {
    "negvdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvdi3 },
    &operand_data[13756],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3005 */
  {
    "usubvsi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usubvsi4 },
    &operand_data[13769],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3005 */
  {
    "usubvdi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usubvdi4 },
    &operand_data[13773],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3018 */
  {
    "subti3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subti3 },
    &operand_data[13777],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3038 */
  {
    "subvti4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvti4 },
    &operand_data[13759],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3057 */
  {
    "usubvti4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usubvti4 },
    &operand_data[13759],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3076 */
  {
    "negvti3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvti3 },
    &operand_data[13779],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3347 */
  {
    "subsi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsi3_carryin },
    &operand_data[13782],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3347 */
  {
    "subdi3_carryin",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi3_carryin },
    &operand_data[13785],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3412 */
  {
    "usubsi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usubsi3_carryinC },
    &operand_data[13782],
    3,
    3,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3412 */
  {
    "usubdi3_carryinC",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usubdi3_carryinC },
    &operand_data[13785],
    3,
    3,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3479 */
  {
    "subsi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subsi3_carryinV },
    &operand_data[13782],
    3,
    3,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3479 */
  {
    "subdi3_carryinV",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subdi3_carryinV },
    &operand_data[13785],
    3,
    3,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3574 */
  {
    "abssi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_abssi2 },
    &operand_data[13673],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3574 */
  {
    "absdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absdi2 },
    &operand_data[13676],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3828 */
  {
    "mulditi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulditi3 },
    &operand_data[13788],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3828 */
  {
    "umulditi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulditi3 },
    &operand_data[13788],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3847 */
  {
    "multi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_multi3 },
    &operand_data[13791],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3978 */
  {
    "cstoresi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoresi4 },
    &operand_data[13794],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3978 */
  {
    "cstoredi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoredi4 },
    &operand_data[13798],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:3991 */
  {
    "cstorecc4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstorecc4 },
    &operand_data[13802],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4003 */
  {
    "cstoresf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoresf4 },
    &operand_data[13806],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4003 */
  {
    "cstoredf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cstoredf4 },
    &operand_data[13810],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4091 */
  {
    "cmovsi6",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmovsi6 },
    &operand_data[13814],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4091 */
  {
    "cmovdi6",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmovdi6 },
    &operand_data[13820],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4107 */
  {
    "cmovsf6",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmovsf6 },
    &operand_data[13826],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4107 */
  {
    "cmovdf6",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmovdf6 },
    &operand_data[13832],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4191 */
  {
    "movqicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movqicc },
    &operand_data[13838],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4191 */
  {
    "movhicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movhicc },
    &operand_data[13842],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4191 */
  {
    "movsicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsicc },
    &operand_data[13846],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4191 */
  {
    "movdicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdicc },
    &operand_data[13850],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4210 */
  {
    "movsfsicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsfsicc },
    &operand_data[13854],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4210 */
  {
    "movdfsicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdfsicc },
    &operand_data[13858],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4210 */
  {
    "movsfdicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsfdicc },
    &operand_data[13862],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4210 */
  {
    "movdfdicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdfdicc },
    &operand_data[13866],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4229 */
  {
    "movsfcc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movsfcc },
    &operand_data[13870],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4229 */
  {
    "movdfcc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movdfcc },
    &operand_data[13874],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4248 */
  {
    "negsicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negsicc },
    &operand_data[13846],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4248 */
  {
    "notsicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_notsicc },
    &operand_data[13846],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4248 */
  {
    "negdicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negdicc },
    &operand_data[13850],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4248 */
  {
    "notdicc",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_notdicc },
    &operand_data[13850],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4402 */
  {
    "umaxsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxsi3 },
    &operand_data[13878],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4402 */
  {
    "umaxdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxdi3 },
    &operand_data[13881],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4907 */
  {
    "ffssi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ffssi2 },
    &operand_data[13673],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4907 */
  {
    "ffsdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ffsdi2 },
    &operand_data[13676],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4929 */
  {
    "popcountsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountsi2 },
    &operand_data[13673],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:4929 */
  {
    "popcountdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountdi2 },
    &operand_data[13676],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5097 */
  {
    "ashlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlsi3 },
    &operand_data[13884],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5097 */
  {
    "ashrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrsi3 },
    &operand_data[13884],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5097 */
  {
    "lshrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrsi3 },
    &operand_data[13884],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5097 */
  {
    "ashldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashldi3 },
    &operand_data[13887],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5097 */
  {
    "ashrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrdi3 },
    &operand_data[13887],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5097 */
  {
    "lshrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrdi3 },
    &operand_data[13887],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5117 */
  {
    "ashlqi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlqi3 },
    &operand_data[13890],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5117 */
  {
    "ashlhi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlhi3 },
    &operand_data[13893],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5133 */
  {
    "rotrsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rotrsi3 },
    &operand_data[13884],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5133 */
  {
    "rotrdi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rotrdi3 },
    &operand_data[13887],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5153 */
  {
    "rotlsi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rotlsi3 },
    &operand_data[13884],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5153 */
  {
    "rotldi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rotldi3 },
    &operand_data[13887],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5634 */
  {
    "extv",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extv },
    &operand_data[13896],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5634 */
  {
    "extzv",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extzv },
    &operand_data[13896],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5683 */
  {
    "insvsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_insvsi },
    &operand_data[13900],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:5683 */
  {
    "insvdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_insvdi },
    &operand_data[13904],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6124 */
  {
    "fmahf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmahf4 },
    &operand_data[13908],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6124 */
  {
    "fmasf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmasf4 },
    &operand_data[13912],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6124 */
  {
    "fmadf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmadf4 },
    &operand_data[13916],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6142 */
  {
    "fnmahf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmahf4 },
    &operand_data[13908],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6142 */
  {
    "fnmasf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmasf4 },
    &operand_data[13912],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6142 */
  {
    "fnmadf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmadf4 },
    &operand_data[13916],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6163 */
  {
    "fmssf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmssf4 },
    &operand_data[13912],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6163 */
  {
    "fmsdf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmsdf4 },
    &operand_data[13916],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6181 */
  {
    "fnmssf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmssf4 },
    &operand_data[13912],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6181 */
  {
    "fnmsdf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmsdf4 },
    &operand_data[13916],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6380 */
  {
    "floatsihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatsihf2 },
    &operand_data[13920],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6380 */
  {
    "floatunssihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunssihf2 },
    &operand_data[13920],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6409 */
  {
    "floatdihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatdihf2 },
    &operand_data[13922],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6409 */
  {
    "floatunsdihf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsdihf2 },
    &operand_data[13922],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6549 */
  {
    "divhf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divhf3 },
    &operand_data[13924],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6549 */
  {
    "divsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divsf3 },
    &operand_data[13927],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6549 */
  {
    "divdf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divdf3 },
    &operand_data[13930],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6578 */
  {
    "sqrthf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrthf2 },
    &operand_data[13908],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6578 */
  {
    "sqrtsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtsf2 },
    &operand_data[13830],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6578 */
  {
    "sqrtdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtdf2 },
    &operand_data[13836],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6638 */
  {
    "lrintsfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrintsfsi2 },
    &operand_data[13933],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6638 */
  {
    "lrintdfsi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrintdfsi2 },
    &operand_data[13935],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6638 */
  {
    "lrintsfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrintsfdi2 },
    &operand_data[13825],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6638 */
  {
    "lrintdfdi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lrintdfdi2 },
    &operand_data[13937],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6667 */
  {
    "copysignsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignsf3 },
    &operand_data[13912],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6667 */
  {
    "copysigndf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysigndf3 },
    &operand_data[13916],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6705 */
  {
    "xorsignsf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignsf3 },
    &operand_data[13912],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6705 */
  {
    "xorsigndf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsigndf3 },
    &operand_data[13916],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6740 */
  {
    "aarch64_reload_movcpsfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpsfsi },
    &operand_data[13939],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6740 */
  {
    "aarch64_reload_movcpdfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpdfsi },
    &operand_data[13942],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6740 */
  {
    "aarch64_reload_movcptfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcptfsi },
    &operand_data[13945],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6740 */
  {
    "aarch64_reload_movcpsfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpsfdi },
    &operand_data[13948],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6740 */
  {
    "aarch64_reload_movcpdfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpdfdi },
    &operand_data[13951],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6740 */
  {
    "aarch64_reload_movcptfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcptfdi },
    &operand_data[13954],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv8qisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv8qisi },
    &operand_data[13957],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv8qidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv8qidi },
    &operand_data[13960],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv16qisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv16qisi },
    &operand_data[13963],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv16qidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv16qidi },
    &operand_data[13966],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv4hisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv4hisi },
    &operand_data[13969],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv4hidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv4hidi },
    &operand_data[13972],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv8hisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv8hisi },
    &operand_data[13975],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv8hidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv8hidi },
    &operand_data[13978],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2sisi },
    &operand_data[13981],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2sidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2sidi },
    &operand_data[13984],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv4sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv4sisi },
    &operand_data[13987],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv4sidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv4sidi },
    &operand_data[13990],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2disi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2disi },
    &operand_data[13993],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2didi },
    &operand_data[13996],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2sfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2sfsi },
    &operand_data[13999],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2sfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2sfdi },
    &operand_data[14002],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv4sfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv4sfsi },
    &operand_data[14005],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv4sfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv4sfdi },
    &operand_data[14008],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2dfsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2dfsi },
    &operand_data[14011],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6753 */
  {
    "aarch64_reload_movcpv2dfdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movcpv2dfdi },
    &operand_data[14014],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6765 */
  {
    "aarch64_reload_movti",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movti },
    &operand_data[14017],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6765 */
  {
    "aarch64_reload_movtf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_reload_movtf },
    &operand_data[14020],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6839 */
  {
    "add_losym",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_add_losym },
    &operand_data[14023],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6917 */
  {
    "tlsgd_small_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsgd_small_si },
    &operand_data[14026],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:6917 */
  {
    "tlsgd_small_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsgd_small_di },
    &operand_data[14028],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7027 */
  {
    "tlsdesc_small_si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsdesc_small_si },
    &operand_data[1349],
    1,
    1,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7027 */
  {
    "tlsdesc_small_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_tlsdesc_small_di },
    &operand_data[1349],
    1,
    1,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7129 */
  {
    "scs_push",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scs_push },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7134 */
  {
    "scs_pop",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scs_pop },
    &operand_data[0],
    0,
    0,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7181 */
  {
    "get_thread_pointerdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_get_thread_pointerdi },
    &operand_data[1324],
    1,
    1,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7194 */
  {
    "stack_protect_set",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_set },
    &operand_data[14030],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7203 */
  {
    "stack_protect_combined_set",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_combined_set },
    &operand_data[14030],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7247 */
  {
    "stack_protect_test",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_test },
    &operand_data[14030],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7258 */
  {
    "stack_protect_combined_test",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_stack_protect_combined_test },
    &operand_data[14030],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7308 */
  {
    "doloop_end",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_doloop_end },
    &operand_data[6508],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7414 */
  {
    "despeculate_copyqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_copyqi },
    &operand_data[14033],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7414 */
  {
    "despeculate_copyhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_copyhi },
    &operand_data[14036],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7414 */
  {
    "despeculate_copysi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_copysi },
    &operand_data[14039],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7414 */
  {
    "despeculate_copydi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_copydi },
    &operand_data[14042],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64.md:7414 */
  {
    "despeculate_copyti",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_despeculate_copyti },
    &operand_data[14045],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv8qi },
    &operand_data[14048],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv16qi },
    &operand_data[14050],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4hi },
    &operand_data[14052],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv8hi },
    &operand_data[14054],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2si },
    &operand_data[14056],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4si },
    &operand_data[14058],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2di },
    &operand_data[14060],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4hf },
    &operand_data[14062],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv8hf },
    &operand_data[14064],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4bf },
    &operand_data[14066],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv8bf },
    &operand_data[14068],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2sf },
    &operand_data[14070],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4sf },
    &operand_data[14072],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:21 */
  {
    "movv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2df },
    &operand_data[14074],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv8qi },
    &operand_data[14048],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv16qi },
    &operand_data[14050],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv4hi },
    &operand_data[14052],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv8hi },
    &operand_data[14054],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv2si },
    &operand_data[14056],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv4si },
    &operand_data[14058],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv2di },
    &operand_data[14060],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv4hf },
    &operand_data[14062],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv8hf },
    &operand_data[14064],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv4bf },
    &operand_data[14066],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv8bf },
    &operand_data[14068],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv2sf },
    &operand_data[14070],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv4sf },
    &operand_data[14072],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:52 */
  {
    "movmisalignv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignv2df },
    &operand_data[14074],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv16qi },
    &operand_data[14076],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv8hi },
    &operand_data[14078],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv4si },
    &operand_data[14080],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv2di },
    &operand_data[14082],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv8hf },
    &operand_data[14084],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv8bf },
    &operand_data[14086],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv4sf },
    &operand_data[14088],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:273 */
  {
    "aarch64_split_simd_movv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_split_simd_movv2df },
    &operand_data[14090],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv16qi },
    &operand_data[14092],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv8hi },
    &operand_data[14095],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv4si },
    &operand_data[14098],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv2di },
    &operand_data[14101],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv8hf },
    &operand_data[14104],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv8bf },
    &operand_data[14107],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv4sf },
    &operand_data[14110],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:304 */
  {
    "aarch64_get_halfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_halfv2df },
    &operand_data[14113],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv16qi },
    &operand_data[14092],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv8hi },
    &operand_data[14095],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv4si },
    &operand_data[14098],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv2di },
    &operand_data[14101],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv8hf },
    &operand_data[14104],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv8bf },
    &operand_data[14107],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv4sf },
    &operand_data[14110],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:312 */
  {
    "aarch64_get_lowv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_lowv2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv16qi },
    &operand_data[14092],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv8hi },
    &operand_data[14095],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv4si },
    &operand_data[14098],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv2di },
    &operand_data[14101],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv8hf },
    &operand_data[14104],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv8bf },
    &operand_data[14107],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv4sf },
    &operand_data[14110],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:323 */
  {
    "aarch64_get_highv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_get_highv2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:427 */
  {
    "ctzv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ctzv2si2 },
    &operand_data[14116],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:427 */
  {
    "ctzv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ctzv4si2 },
    &operand_data[14118],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:441 */
  {
    "xorsignv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignv4hf3 },
    &operand_data[14120],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:441 */
  {
    "xorsignv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignv8hf3 },
    &operand_data[14123],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:441 */
  {
    "xorsignv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignv2sf3 },
    &operand_data[14126],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:441 */
  {
    "xorsignv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignv4sf3 },
    &operand_data[14129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:441 */
  {
    "xorsignv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignv2df3 },
    &operand_data[14132],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd90v4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90v4hf3 },
    &operand_data[14120],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd270v4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270v4hf3 },
    &operand_data[14120],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd90v8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90v8hf3 },
    &operand_data[14123],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd270v8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270v8hf3 },
    &operand_data[14123],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd90v2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90v2sf3 },
    &operand_data[14126],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd270v2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270v2sf3 },
    &operand_data[14126],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd90v4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90v4sf3 },
    &operand_data[14129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd270v4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270v4sf3 },
    &operand_data[14129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd90v2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90v2df3 },
    &operand_data[14132],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:486 */
  {
    "cadd270v2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270v2df3 },
    &operand_data[14132],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlav4hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlav4hf4 },
    &operand_data[14135],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlsv4hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsv4hf4 },
    &operand_data[14135],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmla_conjv4hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjv4hf4 },
    &operand_data[14135],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmls_conjv4hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjv4hf4 },
    &operand_data[14135],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlav8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlav8hf4 },
    &operand_data[14139],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlsv8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsv8hf4 },
    &operand_data[14139],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmla_conjv8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjv8hf4 },
    &operand_data[14139],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmls_conjv8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjv8hf4 },
    &operand_data[14139],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlav2sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlav2sf4 },
    &operand_data[14143],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlsv2sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsv2sf4 },
    &operand_data[14143],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmla_conjv2sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjv2sf4 },
    &operand_data[14143],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmls_conjv2sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjv2sf4 },
    &operand_data[14143],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlav4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlav4sf4 },
    &operand_data[14147],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlsv4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsv4sf4 },
    &operand_data[14147],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmla_conjv4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjv4sf4 },
    &operand_data[14147],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmls_conjv4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjv4sf4 },
    &operand_data[14147],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlav2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlav2df4 },
    &operand_data[14151],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmlsv2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsv2df4 },
    &operand_data[14151],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmla_conjv2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjv2df4 },
    &operand_data[14151],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:556 */
  {
    "cmls_conjv2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjv2df4 },
    &operand_data[14151],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmulv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulv4hf3 },
    &operand_data[14120],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmul_conjv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjv4hf3 },
    &operand_data[14120],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmulv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulv8hf3 },
    &operand_data[14123],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmul_conjv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjv8hf3 },
    &operand_data[14123],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmulv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulv2sf3 },
    &operand_data[14126],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmul_conjv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjv2sf3 },
    &operand_data[14126],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmulv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulv4sf3 },
    &operand_data[14129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmul_conjv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjv4sf3 },
    &operand_data[14129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmulv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulv2df3 },
    &operand_data[14132],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:575 */
  {
    "cmul_conjv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjv2df3 },
    &operand_data[14132],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:692 */
  {
    "copysignv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignv4hf3 },
    &operand_data[14120],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:692 */
  {
    "copysignv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignv8hf3 },
    &operand_data[14123],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:692 */
  {
    "copysignv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignv2sf3 },
    &operand_data[14126],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:692 */
  {
    "copysignv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignv4sf3 },
    &operand_data[14129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:692 */
  {
    "copysignv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignv2df3 },
    &operand_data[14132],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:770 */
  {
    "rsqrtv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rsqrtv2sf2 },
    &operand_data[14126],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:770 */
  {
    "rsqrtv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rsqrtv4sf2 },
    &operand_data[14129],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:770 */
  {
    "rsqrtv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rsqrtv2df2 },
    &operand_data[14132],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:770 */
  {
    "rsqrtsf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rsqrtsf2 },
    &operand_data[13830],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:770 */
  {
    "rsqrtdf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rsqrtdf2 },
    &operand_data[13836],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:924 */
  {
    "ssadv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ssadv16qi },
    &operand_data[14155],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:924 */
  {
    "usadv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usadv16qi },
    &operand_data[14155],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1106 */
  {
    "signbitv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_signbitv2sf2 },
    &operand_data[14159],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1106 */
  {
    "signbitv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_signbitv4sf2 },
    &operand_data[14161],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1191 */
  {
    "ashlv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlv8qi3 },
    &operand_data[14163],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1191 */
  {
    "ashlv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlv16qi3 },
    &operand_data[14166],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1191 */
  {
    "ashlv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlv4hi3 },
    &operand_data[14169],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1191 */
  {
    "ashlv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlv8hi3 },
    &operand_data[14172],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1191 */
  {
    "ashlv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlv2si3 },
    &operand_data[14175],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1191 */
  {
    "ashlv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlv4si3 },
    &operand_data[14178],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1191 */
  {
    "ashlv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlv2di3 },
    &operand_data[14181],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1224 */
  {
    "lshrv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrv8qi3 },
    &operand_data[14163],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1224 */
  {
    "lshrv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrv16qi3 },
    &operand_data[14166],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1224 */
  {
    "lshrv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrv4hi3 },
    &operand_data[14169],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1224 */
  {
    "lshrv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrv8hi3 },
    &operand_data[14172],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1224 */
  {
    "lshrv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrv2si3 },
    &operand_data[14175],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1224 */
  {
    "lshrv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrv4si3 },
    &operand_data[14178],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1224 */
  {
    "lshrv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrv2di3 },
    &operand_data[14181],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1259 */
  {
    "ashrv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrv8qi3 },
    &operand_data[14163],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1259 */
  {
    "ashrv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrv16qi3 },
    &operand_data[14166],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1259 */
  {
    "ashrv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrv4hi3 },
    &operand_data[14169],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1259 */
  {
    "ashrv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrv8hi3 },
    &operand_data[14172],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1259 */
  {
    "ashrv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrv2si3 },
    &operand_data[14175],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1259 */
  {
    "ashrv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrv4si3 },
    &operand_data[14178],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1259 */
  {
    "ashrv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrv2di3 },
    &operand_data[14181],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1294 */
  {
    "vashlv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlv8qi3 },
    &operand_data[14184],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1294 */
  {
    "vashlv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlv16qi3 },
    &operand_data[14187],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1294 */
  {
    "vashlv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlv4hi3 },
    &operand_data[14190],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1294 */
  {
    "vashlv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlv8hi3 },
    &operand_data[14193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1294 */
  {
    "vashlv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlv2si3 },
    &operand_data[14196],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1294 */
  {
    "vashlv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlv4si3 },
    &operand_data[14199],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1294 */
  {
    "vashlv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlv2di3 },
    &operand_data[14202],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1305 */
  {
    "vashrv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrv8qi3 },
    &operand_data[14184],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1305 */
  {
    "vashrv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrv16qi3 },
    &operand_data[14187],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1305 */
  {
    "vashrv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrv4hi3 },
    &operand_data[14190],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1305 */
  {
    "vashrv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrv8hi3 },
    &operand_data[14193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1305 */
  {
    "vashrv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrv2si3 },
    &operand_data[14196],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1305 */
  {
    "vashrv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrv4si3 },
    &operand_data[14199],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1305 */
  {
    "vashrv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrv2di3 },
    &operand_data[14202],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1319 */
  {
    "aarch64_ashr_simddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ashr_simddi },
    &operand_data[14205],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1335 */
  {
    "vlshrv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrv8qi3 },
    &operand_data[14184],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1335 */
  {
    "vlshrv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrv16qi3 },
    &operand_data[14187],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1335 */
  {
    "vlshrv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrv4hi3 },
    &operand_data[14190],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1335 */
  {
    "vlshrv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrv8hi3 },
    &operand_data[14193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1335 */
  {
    "vlshrv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrv2si3 },
    &operand_data[14196],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1335 */
  {
    "vlshrv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrv4si3 },
    &operand_data[14199],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1335 */
  {
    "vlshrv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrv2di3 },
    &operand_data[14202],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1348 */
  {
    "aarch64_lshr_simddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_lshr_simddi },
    &operand_data[14205],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv8qi },
    &operand_data[14208],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv16qi },
    &operand_data[14211],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv4hi },
    &operand_data[14214],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv8hi },
    &operand_data[14217],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv2si },
    &operand_data[14220],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv4si },
    &operand_data[14223],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv2di },
    &operand_data[14226],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv4hf },
    &operand_data[14229],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv8hf },
    &operand_data[14232],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv4bf },
    &operand_data[14235],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv8bf },
    &operand_data[14238],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv2sf },
    &operand_data[14241],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv4sf },
    &operand_data[14244],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1378 */
  {
    "vec_setv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_setv2df },
    &operand_data[14247],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1521 */
  {
    "smaxv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxv2di3 },
    &operand_data[14202],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1521 */
  {
    "sminv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminv2di3 },
    &operand_data[14202],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1521 */
  {
    "umaxv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxv2di3 },
    &operand_data[14202],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1521 */
  {
    "uminv2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminv2di3 },
    &operand_data[14202],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1604 */
  {
    "aarch64_xtnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv8hi },
    &operand_data[14250],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1604 */
  {
    "aarch64_xtnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv4si },
    &operand_data[14252],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1604 */
  {
    "aarch64_xtnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtnv2di },
    &operand_data[14254],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1645 */
  {
    "aarch64_xtn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v8hi },
    &operand_data[14256],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1645 */
  {
    "aarch64_xtn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v4si },
    &operand_data[14251],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1645 */
  {
    "aarch64_xtn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_xtn2v2di },
    &operand_data[14253],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1680 */
  {
    "vec_pack_trunc_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_v4hi },
    &operand_data[14259],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1680 */
  {
    "vec_pack_trunc_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_v2si },
    &operand_data[14262],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1680 */
  {
    "vec_pack_trunc_di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_di },
    &operand_data[14265],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1694 */
  {
    "vec_pack_trunc_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_v8hi },
    &operand_data[14268],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1694 */
  {
    "vec_pack_trunc_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_v4si },
    &operand_data[14270],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1694 */
  {
    "vec_pack_trunc_v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_v2di },
    &operand_data[14201],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1803 */
  {
    "aarch64_shrnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv8hi },
    &operand_data[14273],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1803 */
  {
    "aarch64_shrnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv4si },
    &operand_data[14276],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1803 */
  {
    "aarch64_shrnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrnv2di },
    &operand_data[14279],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1852 */
  {
    "aarch64_rshrnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv8hi },
    &operand_data[14273],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1852 */
  {
    "aarch64_rshrnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv4si },
    &operand_data[14276],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1852 */
  {
    "aarch64_rshrnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrnv2di },
    &operand_data[14279],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1913 */
  {
    "aarch64_shrn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1913 */
  {
    "aarch64_shrn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1913 */
  {
    "aarch64_shrn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_shrn2v2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1956 */
  {
    "aarch64_rshrn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1956 */
  {
    "aarch64_rshrn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:1956 */
  {
    "aarch64_rshrn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rshrn2v2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2012 */
  {
    "vec_unpacks_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_v16qi },
    &operand_data[14294],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2012 */
  {
    "vec_unpacku_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_v16qi },
    &operand_data[14294],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2012 */
  {
    "vec_unpacks_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_v8hi },
    &operand_data[14296],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2012 */
  {
    "vec_unpacku_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_v8hi },
    &operand_data[14296],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2012 */
  {
    "vec_unpacks_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_v4si },
    &operand_data[14298],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2012 */
  {
    "vec_unpacku_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_v4si },
    &operand_data[14298],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2024 */
  {
    "vec_unpacks_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_v16qi },
    &operand_data[14294],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2024 */
  {
    "vec_unpacku_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_v16qi },
    &operand_data[14294],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2024 */
  {
    "vec_unpacks_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_v8hi },
    &operand_data[14296],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2024 */
  {
    "vec_unpacku_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_v8hi },
    &operand_data[14296],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2024 */
  {
    "vec_unpacks_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_v4si },
    &operand_data[14298],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2024 */
  {
    "vec_unpacku_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_v4si },
    &operand_data[14298],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2070 */
  {
    "aarch64_smlal_hiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hiv16qi },
    &operand_data[14300],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2070 */
  {
    "aarch64_umlal_hiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hiv16qi },
    &operand_data[14300],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2070 */
  {
    "aarch64_smlal_hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hiv8hi },
    &operand_data[14304],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2070 */
  {
    "aarch64_umlal_hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hiv8hi },
    &operand_data[14304],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2070 */
  {
    "aarch64_smlal_hiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hiv4si },
    &operand_data[14308],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2070 */
  {
    "aarch64_umlal_hiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hiv4si },
    &operand_data[14308],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2101 */
  {
    "aarch64_smlal_hi_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_nv8hi },
    &operand_data[14310],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2101 */
  {
    "aarch64_umlal_hi_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_nv8hi },
    &operand_data[14310],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2101 */
  {
    "aarch64_smlal_hi_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_nv4si },
    &operand_data[14314],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2101 */
  {
    "aarch64_umlal_hi_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_nv4si },
    &operand_data[14314],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2147 */
  {
    "aarch64_smlsl_hiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hiv16qi },
    &operand_data[14300],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2147 */
  {
    "aarch64_umlsl_hiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hiv16qi },
    &operand_data[14300],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2147 */
  {
    "aarch64_smlsl_hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hiv8hi },
    &operand_data[14304],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2147 */
  {
    "aarch64_umlsl_hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hiv8hi },
    &operand_data[14304],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2147 */
  {
    "aarch64_smlsl_hiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hiv4si },
    &operand_data[14308],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2147 */
  {
    "aarch64_umlsl_hiv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hiv4si },
    &operand_data[14308],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2178 */
  {
    "aarch64_smlsl_hi_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_nv8hi },
    &operand_data[14310],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2178 */
  {
    "aarch64_umlsl_hi_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_nv8hi },
    &operand_data[14310],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2178 */
  {
    "aarch64_smlsl_hi_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_nv4si },
    &operand_data[14314],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2178 */
  {
    "aarch64_umlsl_hi_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_nv4si },
    &operand_data[14314],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2274 */
  {
    "vec_widen_smult_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_smult_lo_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2274 */
  {
    "vec_widen_umult_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_umult_lo_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2274 */
  {
    "vec_widen_smult_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_smult_lo_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2274 */
  {
    "vec_widen_umult_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_umult_lo_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2274 */
  {
    "vec_widen_smult_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_smult_lo_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2274 */
  {
    "vec_widen_umult_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_umult_lo_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2301 */
  {
    "vec_widen_smult_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_smult_hi_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2301 */
  {
    "vec_widen_umult_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_umult_hi_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2301 */
  {
    "vec_widen_smult_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_smult_hi_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2301 */
  {
    "vec_widen_umult_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_umult_hi_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2301 */
  {
    "vec_widen_smult_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_smult_hi_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2301 */
  {
    "vec_widen_umult_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_umult_hi_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2355 */
  {
    "aarch64_smull_hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_lanev8hi },
    &operand_data[14318],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2355 */
  {
    "aarch64_umull_hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_lanev8hi },
    &operand_data[14318],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2355 */
  {
    "aarch64_smull_hi_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_lanev4si },
    &operand_data[14322],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2355 */
  {
    "aarch64_umull_hi_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_lanev4si },
    &operand_data[14322],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2389 */
  {
    "aarch64_smull_hi_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_laneqv8hi },
    &operand_data[14326],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2389 */
  {
    "aarch64_umull_hi_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_laneqv8hi },
    &operand_data[14326],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2389 */
  {
    "aarch64_smull_hi_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_laneqv4si },
    &operand_data[14330],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2389 */
  {
    "aarch64_umull_hi_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_laneqv4si },
    &operand_data[14330],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2431 */
  {
    "aarch64_smull_hi_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_nv8hi },
    &operand_data[14311],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2431 */
  {
    "aarch64_umull_hi_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_nv8hi },
    &operand_data[14311],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2431 */
  {
    "aarch64_smull_hi_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smull_hi_nv4si },
    &operand_data[14315],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2431 */
  {
    "aarch64_umull_hi_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umull_hi_nv4si },
    &operand_data[14315],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2487 */
  {
    "aarch64_smlal_hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_lanev8hi },
    &operand_data[14334],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2487 */
  {
    "aarch64_umlal_hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_lanev8hi },
    &operand_data[14334],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2487 */
  {
    "aarch64_smlal_hi_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_lanev4si },
    &operand_data[14339],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2487 */
  {
    "aarch64_umlal_hi_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_lanev4si },
    &operand_data[14339],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2524 */
  {
    "aarch64_smlal_hi_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_laneqv8hi },
    &operand_data[14344],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2524 */
  {
    "aarch64_umlal_hi_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_laneqv8hi },
    &operand_data[14344],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2524 */
  {
    "aarch64_smlal_hi_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlal_hi_laneqv4si },
    &operand_data[14349],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2524 */
  {
    "aarch64_umlal_hi_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlal_hi_laneqv4si },
    &operand_data[14349],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2582 */
  {
    "aarch64_smlsl_hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_lanev8hi },
    &operand_data[14334],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2582 */
  {
    "aarch64_umlsl_hi_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_lanev8hi },
    &operand_data[14334],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2582 */
  {
    "aarch64_smlsl_hi_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_lanev4si },
    &operand_data[14339],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2582 */
  {
    "aarch64_umlsl_hi_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_lanev4si },
    &operand_data[14339],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2620 */
  {
    "aarch64_smlsl_hi_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_laneqv8hi },
    &operand_data[14344],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2620 */
  {
    "aarch64_umlsl_hi_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_laneqv8hi },
    &operand_data[14344],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2620 */
  {
    "aarch64_smlsl_hi_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_smlsl_hi_laneqv4si },
    &operand_data[14349],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2620 */
  {
    "aarch64_umlsl_hi_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_umlsl_hi_laneqv4si },
    &operand_data[14349],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2687 */
  {
    "divv4hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divv4hf3 },
    &operand_data[14120],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2687 */
  {
    "divv8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divv8hf3 },
    &operand_data[14123],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2687 */
  {
    "divv2sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divv2sf3 },
    &operand_data[14126],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2687 */
  {
    "divv4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divv4sf3 },
    &operand_data[14129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2687 */
  {
    "divv2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divv2df3 },
    &operand_data[14132],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2724 */
  {
    "aarch64_float_mlav2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mlav2sf },
    &operand_data[14143],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2724 */
  {
    "aarch64_float_mlav4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mlav4sf },
    &operand_data[14147],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2724 */
  {
    "aarch64_float_mlav2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mlav2df },
    &operand_data[14151],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2724 */
  {
    "aarch64_float_mladf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mladf },
    &operand_data[13916],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2740 */
  {
    "aarch64_float_mlsv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mlsv2sf },
    &operand_data[14143],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2740 */
  {
    "aarch64_float_mlsv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mlsv4sf },
    &operand_data[14147],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2740 */
  {
    "aarch64_float_mlsv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mlsv2df },
    &operand_data[14151],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2740 */
  {
    "aarch64_float_mlsdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mlsdf },
    &operand_data[13916],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2756 */
  {
    "aarch64_float_mla_nv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mla_nv2sf },
    &operand_data[14354],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2756 */
  {
    "aarch64_float_mla_nv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mla_nv4sf },
    &operand_data[14358],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2773 */
  {
    "aarch64_float_mls_nv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mls_nv2sf },
    &operand_data[14354],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2773 */
  {
    "aarch64_float_mls_nv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mls_nv4sf },
    &operand_data[14358],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2790 */
  {
    "aarch64_float_mla_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mla_lanev2sf },
    &operand_data[14362],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2790 */
  {
    "aarch64_float_mla_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mla_lanev4sf },
    &operand_data[14367],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2810 */
  {
    "aarch64_float_mls_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mls_lanev2sf },
    &operand_data[14362],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2810 */
  {
    "aarch64_float_mls_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mls_lanev4sf },
    &operand_data[14367],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2830 */
  {
    "aarch64_float_mla_laneqv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mla_laneqv2sf },
    &operand_data[14372],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2830 */
  {
    "aarch64_float_mla_laneqv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mla_laneqv4sf },
    &operand_data[14377],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2850 */
  {
    "aarch64_float_mls_laneqv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mls_laneqv2sf },
    &operand_data[14372],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:2850 */
  {
    "aarch64_float_mls_laneqv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_mls_laneqv4sf },
    &operand_data[14377],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixv4hfv4hi2 },
    &operand_data[14382],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixunsv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixunsv4hfv4hi2 },
    &operand_data[14382],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixv8hfv8hi2 },
    &operand_data[14384],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixunsv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixunsv8hfv8hi2 },
    &operand_data[14384],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixv2sfv2si2 },
    &operand_data[14159],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixunsv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixunsv2sfv2si2 },
    &operand_data[14159],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixv4sfv4si2 },
    &operand_data[14161],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixunsv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixunsv4sfv4si2 },
    &operand_data[14161],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixv2dfv2di2 },
    &operand_data[14386],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3088 */
  {
    "fixunsv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixunsv2dfv2di2 },
    &operand_data[14386],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fix_truncv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncv4hfv4hi2 },
    &operand_data[14382],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fixuns_truncv4hfv4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncv4hfv4hi2 },
    &operand_data[14382],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fix_truncv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncv8hfv8hi2 },
    &operand_data[14384],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fixuns_truncv8hfv8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncv8hfv8hi2 },
    &operand_data[14384],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fix_truncv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncv2sfv2si2 },
    &operand_data[14159],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fixuns_truncv2sfv2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncv2sfv2si2 },
    &operand_data[14159],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fix_truncv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncv4sfv4si2 },
    &operand_data[14161],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fixuns_truncv4sfv4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncv4sfv4si2 },
    &operand_data[14161],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fix_truncv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncv2dfv2di2 },
    &operand_data[14386],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3096 */
  {
    "fixuns_truncv2dfv2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncv2dfv2di2 },
    &operand_data[14386],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3104 */
  {
    "ftruncv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ftruncv4hf2 },
    &operand_data[14120],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3104 */
  {
    "ftruncv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ftruncv8hf2 },
    &operand_data[14123],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3104 */
  {
    "ftruncv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ftruncv2sf2 },
    &operand_data[14126],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3104 */
  {
    "ftruncv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ftruncv4sf2 },
    &operand_data[14129],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3104 */
  {
    "ftruncv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ftruncv2df2 },
    &operand_data[14132],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3170 */
  {
    "vec_unpacks_lo_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_v8hf },
    &operand_data[14388],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3170 */
  {
    "vec_unpacks_lo_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_v4sf },
    &operand_data[14387],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3193 */
  {
    "vec_unpacks_hi_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_v8hf },
    &operand_data[14388],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3193 */
  {
    "vec_unpacks_hi_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_v4sf },
    &operand_data[14387],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3255 */
  {
    "aarch64_float_trunc_rodd_hi_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_trunc_rodd_hi_v4sf },
    &operand_data[14390],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3300 */
  {
    "aarch64_float_truncate_hi_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_hi_v4sf },
    &operand_data[14390],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3300 */
  {
    "aarch64_float_truncate_hi_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_float_truncate_hi_v8hf },
    &operand_data[14393],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3314 */
  {
    "vec_pack_trunc_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_v2df },
    &operand_data[14131],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3335 */
  {
    "vec_pack_trunc_df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_df },
    &operand_data[14396],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3436 */
  {
    "reduc_plus_scal_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_v4sf },
    &operand_data[14357],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_nan_scal_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_v4hf },
    &operand_data[14399],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_nan_scal_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_v4hf },
    &operand_data[14399],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_scal_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v4hf },
    &operand_data[14399],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_scal_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v4hf },
    &operand_data[14399],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_nan_scal_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_v8hf },
    &operand_data[14401],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_nan_scal_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_v8hf },
    &operand_data[14401],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_scal_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v8hf },
    &operand_data[14401],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_scal_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v8hf },
    &operand_data[14401],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_nan_scal_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_v2sf },
    &operand_data[14361],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_nan_scal_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_v2sf },
    &operand_data[14361],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_scal_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v2sf },
    &operand_data[14361],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_scal_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v2sf },
    &operand_data[14361],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_nan_scal_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_v4sf },
    &operand_data[14357],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_nan_scal_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_v4sf },
    &operand_data[14357],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_scal_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v4sf },
    &operand_data[14357],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_scal_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v4sf },
    &operand_data[14357],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_nan_scal_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_v2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_nan_scal_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_v2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smax_scal_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3496 */
  {
    "reduc_smin_scal_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmax_scal_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_v4hf },
    &operand_data[14399],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmin_scal_v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_v4hf },
    &operand_data[14399],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmax_scal_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_v8hf },
    &operand_data[14401],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmin_scal_v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_v8hf },
    &operand_data[14401],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmax_scal_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_v2sf },
    &operand_data[14361],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmin_scal_v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_v2sf },
    &operand_data[14361],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmax_scal_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_v4sf },
    &operand_data[14357],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmin_scal_v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_v4sf },
    &operand_data[14357],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmax_scal_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_v2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3511 */
  {
    "reduc_fmin_scal_v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_v2df },
    &operand_data[14113],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umax_scal_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_v8qi },
    &operand_data[14403],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umin_scal_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_v8qi },
    &operand_data[14403],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smax_scal_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v8qi },
    &operand_data[14403],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smin_scal_v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v8qi },
    &operand_data[14403],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umax_scal_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_v16qi },
    &operand_data[14405],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umin_scal_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_v16qi },
    &operand_data[14405],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smax_scal_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v16qi },
    &operand_data[14405],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smin_scal_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v16qi },
    &operand_data[14405],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umax_scal_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_v4hi },
    &operand_data[14407],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umin_scal_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_v4hi },
    &operand_data[14407],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smax_scal_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v4hi },
    &operand_data[14407],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smin_scal_v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v4hi },
    &operand_data[14407],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umax_scal_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_v8hi },
    &operand_data[14409],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umin_scal_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_v8hi },
    &operand_data[14409],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smax_scal_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v8hi },
    &operand_data[14409],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smin_scal_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v8hi },
    &operand_data[14409],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umax_scal_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_v2si },
    &operand_data[14411],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umin_scal_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_v2si },
    &operand_data[14411],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smax_scal_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v2si },
    &operand_data[14411],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smin_scal_v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v2si },
    &operand_data[14411],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umax_scal_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_v4si },
    &operand_data[14317],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_umin_scal_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_v4si },
    &operand_data[14317],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smax_scal_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_v4si },
    &operand_data[14317],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3523 */
  {
    "reduc_smin_scal_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_v4si },
    &operand_data[14317],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv8qi },
    &operand_data[14413],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv16qi },
    &operand_data[14417],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv4hi },
    &operand_data[14421],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv8hi },
    &operand_data[14425],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv2si },
    &operand_data[14429],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv4si },
    &operand_data[14433],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv4bf },
    &operand_data[14437],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv8bf },
    &operand_data[14441],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv2di },
    &operand_data[14445],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv4hf },
    &operand_data[14449],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv8hf },
    &operand_data[14453],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv2sf },
    &operand_data[14457],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv4sf },
    &operand_data[14461],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bslv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bslv2df },
    &operand_data[14465],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bsldi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bsldi },
    &operand_data[14469],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3720 */
  {
    "aarch64_simd_bsldf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_simd_bsldf },
    &operand_data[14473],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v8qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v8qiv8qi },
    &operand_data[14477],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v16qiv16qi },
    &operand_data[14481],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v4hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v4hiv4hi },
    &operand_data[14485],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v8hiv8hi },
    &operand_data[14489],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v2siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v2siv2si },
    &operand_data[14493],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v4siv4si },
    &operand_data[14497],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v2div2di },
    &operand_data[14501],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v2sfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v2sfv2si },
    &operand_data[14505],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v4sfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v4sfv4si },
    &operand_data[14509],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_v2dfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_v2dfv2di },
    &operand_data[14513],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3746 */
  {
    "vcond_mask_didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_didi },
    &operand_data[14517],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpv8qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv8qiv8qi },
    &operand_data[14521],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpv16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv16qiv16qi },
    &operand_data[14525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpv4hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv4hiv4hi },
    &operand_data[14529],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpv8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv8hiv8hi },
    &operand_data[14533],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpv2siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv2siv2si },
    &operand_data[14537],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpv4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv4siv4si },
    &operand_data[14541],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpv2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv2div2di },
    &operand_data[14545],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3777 */
  {
    "vec_cmpdidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpdidi },
    &operand_data[14549],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3857 */
  {
    "vec_cmpv2sfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv2sfv2si },
    &operand_data[14553],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3857 */
  {
    "vec_cmpv4sfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv4sfv4si },
    &operand_data[14557],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:3857 */
  {
    "vec_cmpv2dfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpv2dfv2di },
    &operand_data[14561],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpuv8qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuv8qiv8qi },
    &operand_data[14521],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpuv16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuv16qiv16qi },
    &operand_data[14525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpuv4hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuv4hiv4hi },
    &operand_data[14529],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpuv8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuv8hiv8hi },
    &operand_data[14533],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpuv2siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuv2siv2si },
    &operand_data[14537],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpuv4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuv4siv4si },
    &operand_data[14541],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpuv2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuv2div2di },
    &operand_data[14545],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4030 */
  {
    "vec_cmpudidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpudidi },
    &operand_data[14549],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv8qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv8qiv8qi },
    &operand_data[14565],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv16qiv16qi },
    &operand_data[14571],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv4hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv4hiv4hi },
    &operand_data[14577],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv8hiv8hi },
    &operand_data[14583],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv2siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2siv2si },
    &operand_data[14589],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv4siv4si },
    &operand_data[14595],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2div2di },
    &operand_data[14601],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv2sfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2sfv2sf },
    &operand_data[14607],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv4sfv4sf },
    &operand_data[14613],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vcondv2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2dfv2df },
    &operand_data[14619],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4042 */
  {
    "vconddidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconddidi },
    &operand_data[14625],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4072 */
  {
    "vcondv2siv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2siv2sf },
    &operand_data[14631],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4072 */
  {
    "vcondv2sfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2sfv2si },
    &operand_data[14635],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4072 */
  {
    "vcondv4siv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv4siv4sf },
    &operand_data[14641],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4072 */
  {
    "vcondv4sfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv4sfv4si },
    &operand_data[14645],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4072 */
  {
    "vcondv2div2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2div2df },
    &operand_data[14651],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4072 */
  {
    "vcondv2dfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondv2dfv2di },
    &operand_data[14655],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vconduv8qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv8qiv8qi },
    &operand_data[14565],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vconduv16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv16qiv16qi },
    &operand_data[14571],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vconduv4hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv4hiv4hi },
    &operand_data[14577],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vconduv8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv8hiv8hi },
    &operand_data[14583],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vconduv2siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv2siv2si },
    &operand_data[14589],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vconduv4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv4siv4si },
    &operand_data[14595],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vconduv2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv2div2di },
    &operand_data[14601],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4103 */
  {
    "vcondudidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondudidi },
    &operand_data[14625],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4132 */
  {
    "vconduv2sfv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv2sfv2si },
    &operand_data[14635],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4132 */
  {
    "vconduv4sfv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv4sfv4si },
    &operand_data[14645],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4132 */
  {
    "vconduv2dfv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduv2dfv2di },
    &operand_data[14655],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatv8qi },
    &operand_data[14661],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatv4hi },
    &operand_data[14664],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatv4bf },
    &operand_data[14667],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatv4hf },
    &operand_data[14670],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatv2si },
    &operand_data[14673],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatv2sf },
    &operand_data[14676],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatsi },
    &operand_data[14679],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatsf },
    &operand_data[14682],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatdi },
    &operand_data[14685],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4348 */
  {
    "aarch64_vec_concatdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vec_concatdf },
    &operand_data[14688],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinev8qi },
    &operand_data[14661],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinev4hi },
    &operand_data[14664],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinev4bf },
    &operand_data[14667],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinev4hf },
    &operand_data[14670],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinev2si },
    &operand_data[14673],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinev2sf },
    &operand_data[14676],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinedi },
    &operand_data[14685],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4389 */
  {
    "aarch64_combinedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_combinedf },
    &operand_data[14688],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4431 */
  {
    "vec_widen_saddl_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_saddl_lo_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4431 */
  {
    "vec_widen_uaddl_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_uaddl_lo_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4431 */
  {
    "vec_widen_saddl_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_saddl_lo_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4431 */
  {
    "vec_widen_uaddl_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_uaddl_lo_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4431 */
  {
    "vec_widen_saddl_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_saddl_lo_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4431 */
  {
    "vec_widen_uaddl_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_uaddl_lo_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4443 */
  {
    "vec_widen_saddl_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_saddl_hi_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4443 */
  {
    "vec_widen_uaddl_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_uaddl_hi_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4443 */
  {
    "vec_widen_saddl_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_saddl_hi_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4443 */
  {
    "vec_widen_uaddl_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_uaddl_hi_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4443 */
  {
    "vec_widen_saddl_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_saddl_hi_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4443 */
  {
    "vec_widen_uaddl_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_uaddl_hi_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4455 */
  {
    "vec_widen_ssubl_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ssubl_lo_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4455 */
  {
    "vec_widen_usubl_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_usubl_lo_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4455 */
  {
    "vec_widen_ssubl_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ssubl_lo_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4455 */
  {
    "vec_widen_usubl_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_usubl_lo_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4455 */
  {
    "vec_widen_ssubl_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ssubl_lo_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4455 */
  {
    "vec_widen_usubl_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_usubl_lo_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4467 */
  {
    "vec_widen_ssubl_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ssubl_hi_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4467 */
  {
    "vec_widen_usubl_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_usubl_hi_v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4467 */
  {
    "vec_widen_ssubl_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ssubl_hi_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4467 */
  {
    "vec_widen_usubl_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_usubl_hi_v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4467 */
  {
    "vec_widen_ssubl_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ssubl_hi_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4467 */
  {
    "vec_widen_usubl_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_usubl_hi_v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4479 */
  {
    "aarch64_saddl2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddl2v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4479 */
  {
    "aarch64_saddl2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddl2v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4479 */
  {
    "aarch64_saddl2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddl2v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4491 */
  {
    "aarch64_uaddl2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddl2v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4491 */
  {
    "aarch64_uaddl2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddl2v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4491 */
  {
    "aarch64_uaddl2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddl2v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4503 */
  {
    "aarch64_ssubl2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubl2v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4503 */
  {
    "aarch64_ssubl2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubl2v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4503 */
  {
    "aarch64_ssubl2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubl2v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4515 */
  {
    "aarch64_usubl2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubl2v16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4515 */
  {
    "aarch64_usubl2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubl2v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4515 */
  {
    "aarch64_usubl2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubl2v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4540 */
  {
    "widen_ssumv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_ssumv16qi3 },
    &operand_data[14691],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4540 */
  {
    "widen_ssumv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_ssumv8hi3 },
    &operand_data[14694],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4540 */
  {
    "widen_ssumv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_ssumv4si3 },
    &operand_data[14697],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4557 */
  {
    "widen_ssumv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_ssumv8qi3 },
    &operand_data[14700],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4557 */
  {
    "widen_ssumv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_ssumv4hi3 },
    &operand_data[14703],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4557 */
  {
    "widen_ssumv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_ssumv2si3 },
    &operand_data[14706],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4568 */
  {
    "widen_usumv16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_usumv16qi3 },
    &operand_data[14691],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4568 */
  {
    "widen_usumv8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_usumv8hi3 },
    &operand_data[14694],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4568 */
  {
    "widen_usumv4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_usumv4si3 },
    &operand_data[14697],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4585 */
  {
    "widen_usumv8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_usumv8qi3 },
    &operand_data[14700],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4585 */
  {
    "widen_usumv4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_usumv4hi3 },
    &operand_data[14703],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4585 */
  {
    "widen_usumv2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_widen_usumv2si3 },
    &operand_data[14706],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4666 */
  {
    "aarch64_saddw2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddw2v16qi },
    &operand_data[14300],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4666 */
  {
    "aarch64_saddw2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddw2v8hi },
    &operand_data[14304],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4666 */
  {
    "aarch64_saddw2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_saddw2v4si },
    &operand_data[14308],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4678 */
  {
    "aarch64_uaddw2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddw2v16qi },
    &operand_data[14300],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4678 */
  {
    "aarch64_uaddw2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddw2v8hi },
    &operand_data[14304],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4678 */
  {
    "aarch64_uaddw2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uaddw2v4si },
    &operand_data[14308],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4691 */
  {
    "aarch64_ssubw2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubw2v16qi },
    &operand_data[14300],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4691 */
  {
    "aarch64_ssubw2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubw2v8hi },
    &operand_data[14304],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4691 */
  {
    "aarch64_ssubw2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ssubw2v4si },
    &operand_data[14308],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4703 */
  {
    "aarch64_usubw2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubw2v16qi },
    &operand_data[14300],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4703 */
  {
    "aarch64_usubw2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubw2v8hi },
    &operand_data[14304],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4703 */
  {
    "aarch64_usubw2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_usubw2v4si },
    &operand_data[14308],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "avgv8qi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv8qi3_floor },
    &operand_data[14184],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "uavgv8qi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv8qi3_floor },
    &operand_data[14184],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "avgv16qi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv16qi3_floor },
    &operand_data[14187],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "uavgv16qi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv16qi3_floor },
    &operand_data[14187],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "avgv4hi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv4hi3_floor },
    &operand_data[14190],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "uavgv4hi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv4hi3_floor },
    &operand_data[14190],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "avgv8hi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv8hi3_floor },
    &operand_data[14193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "uavgv8hi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv8hi3_floor },
    &operand_data[14193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "avgv2si3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv2si3_floor },
    &operand_data[14196],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "uavgv2si3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv2si3_floor },
    &operand_data[14196],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "avgv4si3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv4si3_floor },
    &operand_data[14199],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4717 */
  {
    "uavgv4si3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv4si3_floor },
    &operand_data[14199],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "avgv8qi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv8qi3_ceil },
    &operand_data[14184],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "uavgv8qi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv8qi3_ceil },
    &operand_data[14184],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "avgv16qi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv16qi3_ceil },
    &operand_data[14187],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "uavgv16qi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv16qi3_ceil },
    &operand_data[14187],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "avgv4hi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv4hi3_ceil },
    &operand_data[14190],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "uavgv4hi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv4hi3_ceil },
    &operand_data[14190],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "avgv8hi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv8hi3_ceil },
    &operand_data[14193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "uavgv8hi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv8hi3_ceil },
    &operand_data[14193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "avgv2si3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv2si3_ceil },
    &operand_data[14196],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "uavgv2si3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv2si3_ceil },
    &operand_data[14196],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "avgv4si3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgv4si3_ceil },
    &operand_data[14199],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4725 */
  {
    "uavgv4si3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgv4si3_ceil },
    &operand_data[14199],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_addhnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv8hi },
    &operand_data[14709],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_raddhnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv8hi },
    &operand_data[14709],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_subhnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv8hi },
    &operand_data[14709],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_rsubhnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv8hi },
    &operand_data[14709],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_addhnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv4si },
    &operand_data[14712],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_raddhnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv4si },
    &operand_data[14712],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_subhnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv4si },
    &operand_data[14712],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_rsubhnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv4si },
    &operand_data[14712],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_addhnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhnv2di },
    &operand_data[14715],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_raddhnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhnv2di },
    &operand_data[14715],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_subhnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhnv2di },
    &operand_data[14715],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4769 */
  {
    "aarch64_rsubhnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhnv2di },
    &operand_data[14715],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_addhn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v8hi },
    &operand_data[14718],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_raddhn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v8hi },
    &operand_data[14718],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_subhn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v8hi },
    &operand_data[14718],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_rsubhn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v8hi },
    &operand_data[14718],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_addhn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v4si },
    &operand_data[14711],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_raddhn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v4si },
    &operand_data[14711],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_subhn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v4si },
    &operand_data[14711],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_rsubhn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v4si },
    &operand_data[14711],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_addhn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_addhn2v2di },
    &operand_data[14714],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_raddhn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_raddhn2v2di },
    &operand_data[14714],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_subhn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_subhn2v2di },
    &operand_data[14714],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4816 */
  {
    "aarch64_rsubhn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsubhn2v2di },
    &operand_data[14714],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:4871 */
  {
    "aarch64_pmull_hiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pmull_hiv16qi },
    &operand_data[14301],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5024 */
  {
    "aarch64_sqmovnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv8hi },
    &operand_data[14250],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5024 */
  {
    "aarch64_uqmovnv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv8hi },
    &operand_data[14250],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5024 */
  {
    "aarch64_sqmovnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv4si },
    &operand_data[14252],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5024 */
  {
    "aarch64_uqmovnv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv4si },
    &operand_data[14252],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5024 */
  {
    "aarch64_sqmovnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovnv2di },
    &operand_data[14254],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5024 */
  {
    "aarch64_uqmovnv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqmovnv2di },
    &operand_data[14254],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5068 */
  {
    "aarch64_sqxtn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v8hi },
    &operand_data[14256],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5068 */
  {
    "aarch64_uqxtn2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v8hi },
    &operand_data[14256],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5068 */
  {
    "aarch64_sqxtn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v4si },
    &operand_data[14251],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5068 */
  {
    "aarch64_uqxtn2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v4si },
    &operand_data[14251],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5068 */
  {
    "aarch64_sqxtn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtn2v2di },
    &operand_data[14253],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5068 */
  {
    "aarch64_uqxtn2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqxtn2v2di },
    &operand_data[14253],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5118 */
  {
    "aarch64_sqmovunv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv8hi },
    &operand_data[14250],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5118 */
  {
    "aarch64_sqmovunv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv4si },
    &operand_data[14252],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5118 */
  {
    "aarch64_sqmovunv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqmovunv2di },
    &operand_data[14254],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5162 */
  {
    "aarch64_sqxtun2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v8hi },
    &operand_data[14256],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5162 */
  {
    "aarch64_sqxtun2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v4si },
    &operand_data[14251],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5162 */
  {
    "aarch64_sqxtun2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqxtun2v2di },
    &operand_data[14253],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5673 */
  {
    "aarch64_sqdmlal2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2v8hi },
    &operand_data[14304],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5673 */
  {
    "aarch64_sqdmlsl2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2v8hi },
    &operand_data[14304],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5673 */
  {
    "aarch64_sqdmlal2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2v4si },
    &operand_data[14308],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5673 */
  {
    "aarch64_sqdmlsl2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2v4si },
    &operand_data[14308],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5795 */
  {
    "aarch64_sqdmlal2_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_lanev8hi },
    &operand_data[14334],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5795 */
  {
    "aarch64_sqdmlsl2_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_lanev8hi },
    &operand_data[14334],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5795 */
  {
    "aarch64_sqdmlal2_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_lanev4si },
    &operand_data[14339],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5795 */
  {
    "aarch64_sqdmlsl2_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_lanev4si },
    &operand_data[14339],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5812 */
  {
    "aarch64_sqdmlal2_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_laneqv8hi },
    &operand_data[14344],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5812 */
  {
    "aarch64_sqdmlsl2_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_laneqv8hi },
    &operand_data[14344],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5812 */
  {
    "aarch64_sqdmlal2_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_laneqv4si },
    &operand_data[14349],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5812 */
  {
    "aarch64_sqdmlsl2_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_laneqv4si },
    &operand_data[14349],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5867 */
  {
    "aarch64_sqdmlal2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_nv8hi },
    &operand_data[14310],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5867 */
  {
    "aarch64_sqdmlsl2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_nv8hi },
    &operand_data[14310],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5867 */
  {
    "aarch64_sqdmlal2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlal2_nv4si },
    &operand_data[14314],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:5867 */
  {
    "aarch64_sqdmlsl2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmlsl2_nv4si },
    &operand_data[14314],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6022 */
  {
    "aarch64_sqdmull2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2v8hi },
    &operand_data[14299],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6022 */
  {
    "aarch64_sqdmull2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2v4si },
    &operand_data[14309],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6082 */
  {
    "aarch64_sqdmull2_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_lanev8hi },
    &operand_data[14318],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6082 */
  {
    "aarch64_sqdmull2_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_lanev4si },
    &operand_data[14322],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6096 */
  {
    "aarch64_sqdmull2_laneqv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_laneqv8hi },
    &operand_data[14326],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6096 */
  {
    "aarch64_sqdmull2_laneqv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_laneqv4si },
    &operand_data[14330],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6130 */
  {
    "aarch64_sqdmull2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_nv8hi },
    &operand_data[14311],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6130 */
  {
    "aarch64_sqdmull2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqdmull2_nv4si },
    &operand_data[14315],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6169 */
  {
    "vec_widen_sshiftl_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_sshiftl_lo_v16qi },
    &operand_data[14722],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6169 */
  {
    "vec_widen_ushiftl_lo_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ushiftl_lo_v16qi },
    &operand_data[14722],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6169 */
  {
    "vec_widen_sshiftl_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_sshiftl_lo_v8hi },
    &operand_data[14725],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6169 */
  {
    "vec_widen_ushiftl_lo_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ushiftl_lo_v8hi },
    &operand_data[14725],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6169 */
  {
    "vec_widen_sshiftl_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_sshiftl_lo_v4si },
    &operand_data[14728],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6169 */
  {
    "vec_widen_ushiftl_lo_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ushiftl_lo_v4si },
    &operand_data[14728],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6184 */
  {
    "vec_widen_sshiftl_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_sshiftl_hi_v16qi },
    &operand_data[14731],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6184 */
  {
    "vec_widen_ushiftl_hi_v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ushiftl_hi_v16qi },
    &operand_data[14731],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6184 */
  {
    "vec_widen_sshiftl_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_sshiftl_hi_v8hi },
    &operand_data[14734],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6184 */
  {
    "vec_widen_ushiftl_hi_v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ushiftl_hi_v8hi },
    &operand_data[14734],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6184 */
  {
    "vec_widen_sshiftl_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_sshiftl_hi_v4si },
    &operand_data[14737],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6184 */
  {
    "vec_widen_ushiftl_hi_v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_widen_ushiftl_hi_v4si },
    &operand_data[14737],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqshrun_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv8hi },
    &operand_data[14740],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqrshrun_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv8hi },
    &operand_data[14740],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqshrn_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv8hi },
    &operand_data[14740],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_uqshrn_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv8hi },
    &operand_data[14740],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqrshrn_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv8hi },
    &operand_data[14740],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_uqrshrn_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv8hi },
    &operand_data[14740],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqshrun_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv4si },
    &operand_data[14743],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqrshrun_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv4si },
    &operand_data[14743],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqshrn_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv4si },
    &operand_data[14743],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_uqshrn_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv4si },
    &operand_data[14743],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqrshrn_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv4si },
    &operand_data[14743],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_uqrshrn_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv4si },
    &operand_data[14743],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqshrun_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun_nv2di },
    &operand_data[14746],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqrshrun_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun_nv2di },
    &operand_data[14746],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqshrn_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn_nv2di },
    &operand_data[14746],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_uqshrn_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn_nv2di },
    &operand_data[14746],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_sqrshrn_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn_nv2di },
    &operand_data[14746],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6364 */
  {
    "aarch64_uqrshrn_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn_nv2di },
    &operand_data[14746],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqshrun2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqrshrun2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqshrn2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_uqshrn2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqrshrn2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_uqrshrn2_nv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv8hi },
    &operand_data[14282],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqshrun2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqrshrun2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqshrn2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_uqshrn2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqrshrn2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_uqrshrn2_nv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv4si },
    &operand_data[14286],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqshrun2_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrun2_nv2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqrshrun2_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrun2_nv2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqshrn2_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqshrn2_nv2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_uqshrn2_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqshrn2_nv2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_sqrshrn2_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sqrshrn2_nv2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6416 */
  {
    "aarch64_uqrshrn2_nv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uqrshrn2_nv2di },
    &operand_data[14290],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6717 */
  {
    "sqrtv4hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtv4hf2 },
    &operand_data[14120],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6717 */
  {
    "sqrtv8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtv8hf2 },
    &operand_data[14123],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6717 */
  {
    "sqrtv2sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtv2sf2 },
    &operand_data[14126],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6717 */
  {
    "sqrtv4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtv4sf2 },
    &operand_data[14129],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6717 */
  {
    "sqrtv2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtv2df2 },
    &operand_data[14132],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x16qiv16qi },
    &operand_data[14749],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x8hiv8hi },
    &operand_data[14751],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x4siv4si },
    &operand_data[14753],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x2div2di },
    &operand_data[14755],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x8hfv8hf },
    &operand_data[14757],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x4sfv4sf },
    &operand_data[14759],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x2dfv2df },
    &operand_data[14761],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6772 */
  {
    "vec_load_lanesv2x8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv2x8bfv8bf },
    &operand_data[14763],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x16qiv16qi },
    &operand_data[14765],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x8hiv8hi },
    &operand_data[14767],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x4siv4si },
    &operand_data[14769],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x2div2di },
    &operand_data[14771],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x8hfv8hf },
    &operand_data[14773],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x4sfv4sf },
    &operand_data[14775],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x2dfv2df },
    &operand_data[14777],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6817 */
  {
    "vec_store_lanesv2x8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv2x8bfv8bf },
    &operand_data[14779],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x16qiv16qi },
    &operand_data[14781],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x8hiv8hi },
    &operand_data[14783],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x4siv4si },
    &operand_data[14785],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x2div2di },
    &operand_data[14787],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x8hfv8hf },
    &operand_data[14789],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x4sfv4sf },
    &operand_data[14791],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x2dfv2df },
    &operand_data[14793],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6872 */
  {
    "vec_load_lanesv3x8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv3x8bfv8bf },
    &operand_data[14795],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x16qiv16qi },
    &operand_data[14797],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x8hiv8hi },
    &operand_data[14799],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x4siv4si },
    &operand_data[14801],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x2div2di },
    &operand_data[14803],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x8hfv8hf },
    &operand_data[14805],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x4sfv4sf },
    &operand_data[14807],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x2dfv2df },
    &operand_data[14809],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6916 */
  {
    "vec_store_lanesv3x8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv3x8bfv8bf },
    &operand_data[14811],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x16qiv16qi },
    &operand_data[14813],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x8hiv8hi },
    &operand_data[14815],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x4siv4si },
    &operand_data[14817],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x2div2di },
    &operand_data[14819],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x8hfv8hf },
    &operand_data[14821],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x4sfv4sf },
    &operand_data[14823],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x2dfv2df },
    &operand_data[14825],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:6972 */
  {
    "vec_load_lanesv4x8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesv4x8bfv8bf },
    &operand_data[14827],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x16qiv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x16qiv16qi },
    &operand_data[14829],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x8hiv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x8hiv8hi },
    &operand_data[14831],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x4siv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x4siv4si },
    &operand_data[14833],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x2div2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x2div2di },
    &operand_data[14835],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x8hfv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x8hfv8hf },
    &operand_data[14837],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x4sfv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x4sfv4sf },
    &operand_data[14839],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x2dfv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x2dfv2df },
    &operand_data[14841],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7017 */
  {
    "vec_store_lanesv4x8bfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesv4x8bfv8bf },
    &operand_data[14843],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x8qi },
    &operand_data[14845],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x4hi },
    &operand_data[14847],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x2si },
    &operand_data[14849],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x1di },
    &operand_data[14851],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x4hf },
    &operand_data[14853],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x2sf },
    &operand_data[14855],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x1df },
    &operand_data[14857],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x4bf },
    &operand_data[14859],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x8qi },
    &operand_data[14861],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x4hi },
    &operand_data[14863],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x2si },
    &operand_data[14865],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x1di },
    &operand_data[14867],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x4hf },
    &operand_data[14869],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x2sf },
    &operand_data[14871],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x1df },
    &operand_data[14873],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x4bf },
    &operand_data[14875],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x8qi },
    &operand_data[14877],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x4hi },
    &operand_data[14879],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x2si },
    &operand_data[14881],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x1di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x1di },
    &operand_data[14883],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x4hf },
    &operand_data[14885],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x2sf },
    &operand_data[14887],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x1df },
    &operand_data[14889],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x4bf },
    &operand_data[14891],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x16qi },
    &operand_data[14893],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x8hi },
    &operand_data[14895],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x4si },
    &operand_data[14897],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x2di },
    &operand_data[14899],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x8hf },
    &operand_data[14901],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x4sf },
    &operand_data[14903],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x2df },
    &operand_data[14905],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv2x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv2x8bf },
    &operand_data[14907],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x16qi },
    &operand_data[14909],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x8hi },
    &operand_data[14911],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x4si },
    &operand_data[14913],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x2di },
    &operand_data[14915],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x8hf },
    &operand_data[14917],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x4sf },
    &operand_data[14919],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x2df },
    &operand_data[14921],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv3x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv3x8bf },
    &operand_data[14923],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x16qi },
    &operand_data[14925],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x8hi },
    &operand_data[14927],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x4si },
    &operand_data[14929],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x2di },
    &operand_data[14931],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x8hf },
    &operand_data[14933],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x4sf },
    &operand_data[14935],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x2df },
    &operand_data[14937],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7063 */
  {
    "movv4x8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv4x8bf },
    &operand_data[14939],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7075 */
  {
    "movoi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movoi },
    &operand_data[14941],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7075 */
  {
    "movci",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movci },
    &operand_data[14943],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7075 */
  {
    "movxi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movxi },
    &operand_data[14945],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7087 */
  {
    "movv8di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movv8di },
    &operand_data[14947],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v8qi },
    &operand_data[14949],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v4hi },
    &operand_data[14951],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v2si },
    &operand_data[14953],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3di },
    &operand_data[14955],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v4hf },
    &operand_data[14957],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v2sf },
    &operand_data[14959],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3df },
    &operand_data[14961],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v4bf },
    &operand_data[14963],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v16qi },
    &operand_data[14965],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v8hi },
    &operand_data[14967],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v4si },
    &operand_data[14969],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v2di },
    &operand_data[14971],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v8hf },
    &operand_data[14973],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v4sf },
    &operand_data[14975],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v2df },
    &operand_data[14977],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7096 */
  {
    "aarch64_ld1x3v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x3v8bf },
    &operand_data[14979],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v8qi },
    &operand_data[14981],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v4hi },
    &operand_data[14983],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v2si },
    &operand_data[14985],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4di },
    &operand_data[14987],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v4hf },
    &operand_data[14989],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v2sf },
    &operand_data[14991],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4df },
    &operand_data[14993],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v4bf },
    &operand_data[14995],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v16qi },
    &operand_data[14997],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v8hi },
    &operand_data[14999],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v4si },
    &operand_data[15001],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v2di },
    &operand_data[15003],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v8hf },
    &operand_data[15005],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v4sf },
    &operand_data[15007],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v2df },
    &operand_data[15009],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7116 */
  {
    "aarch64_ld1x4v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x4v8bf },
    &operand_data[15011],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v8qi },
    &operand_data[15013],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v4hi },
    &operand_data[15015],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v2si },
    &operand_data[15017],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2di },
    &operand_data[15019],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v4hf },
    &operand_data[15021],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v2sf },
    &operand_data[15023],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2df },
    &operand_data[15025],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v4bf },
    &operand_data[15027],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v16qi },
    &operand_data[15029],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v8hi },
    &operand_data[15031],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v4si },
    &operand_data[15033],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v2di },
    &operand_data[15035],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v8hf },
    &operand_data[15037],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v4sf },
    &operand_data[15039],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v2df },
    &operand_data[15041],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7136 */
  {
    "aarch64_st1x2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x2v8bf },
    &operand_data[15043],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v8qi },
    &operand_data[15045],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v4hi },
    &operand_data[14950],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v2si },
    &operand_data[14952],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3di },
    &operand_data[14954],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v4hf },
    &operand_data[14956],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v2sf },
    &operand_data[14958],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3df },
    &operand_data[14960],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v4bf },
    &operand_data[14962],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v16qi },
    &operand_data[14964],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v8hi },
    &operand_data[14966],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v4si },
    &operand_data[14968],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v2di },
    &operand_data[14970],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v8hf },
    &operand_data[14972],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v4sf },
    &operand_data[14974],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v2df },
    &operand_data[14976],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7156 */
  {
    "aarch64_st1x3v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x3v8bf },
    &operand_data[14978],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v8qi },
    &operand_data[15047],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v4hi },
    &operand_data[15049],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v2si },
    &operand_data[15051],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4di },
    &operand_data[15053],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v4hf },
    &operand_data[15055],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v2sf },
    &operand_data[15057],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4df },
    &operand_data[15059],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v4bf },
    &operand_data[15061],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v16qi },
    &operand_data[15063],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v8hi },
    &operand_data[15065],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v4si },
    &operand_data[15067],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v2di },
    &operand_data[15069],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v8hf },
    &operand_data[15071],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v4sf },
    &operand_data[15073],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v2df },
    &operand_data[15075],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7176 */
  {
    "aarch64_st1x4v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1x4v8bf },
    &operand_data[15077],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv8qi },
    &operand_data[15014],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv4hi },
    &operand_data[15016],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv2si },
    &operand_data[15018],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rdi },
    &operand_data[15020],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv4hf },
    &operand_data[15022],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv2sf },
    &operand_data[15024],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rdf },
    &operand_data[15026],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv4bf },
    &operand_data[15028],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv8qi },
    &operand_data[14949],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv4hi },
    &operand_data[14951],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv2si },
    &operand_data[14953],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rdi },
    &operand_data[14955],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv4hf },
    &operand_data[14957],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv2sf },
    &operand_data[14959],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rdf },
    &operand_data[14961],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv4bf },
    &operand_data[14963],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv8qi },
    &operand_data[15048],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv4hi },
    &operand_data[15050],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv2si },
    &operand_data[15052],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rdi },
    &operand_data[15054],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv4hf },
    &operand_data[15056],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv2sf },
    &operand_data[15058],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rdf },
    &operand_data[15060],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv4bf },
    &operand_data[15062],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv16qi },
    &operand_data[15030],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv8hi },
    &operand_data[15032],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv4si },
    &operand_data[15034],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv2di },
    &operand_data[15036],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv8hf },
    &operand_data[15038],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv4sf },
    &operand_data[15040],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv2df },
    &operand_data[15042],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld2rv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2rv8bf },
    &operand_data[15044],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv16qi },
    &operand_data[14965],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv8hi },
    &operand_data[14967],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv4si },
    &operand_data[14969],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv2di },
    &operand_data[14971],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv8hf },
    &operand_data[14973],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv4sf },
    &operand_data[14975],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv2df },
    &operand_data[14977],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld3rv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3rv8bf },
    &operand_data[14979],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv16qi },
    &operand_data[15064],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv8hi },
    &operand_data[15066],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv4si },
    &operand_data[15068],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv2di },
    &operand_data[15070],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv8hf },
    &operand_data[15072],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv4sf },
    &operand_data[15074],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv2df },
    &operand_data[15076],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7507 */
  {
    "aarch64_ld4rv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4rv8bf },
    &operand_data[15078],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v8qi },
    &operand_data[15014],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4hi },
    &operand_data[15016],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v2si },
    &operand_data[15018],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2di },
    &operand_data[15020],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4hf },
    &operand_data[15022],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v2sf },
    &operand_data[15024],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2df },
    &operand_data[15026],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld2v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4bf },
    &operand_data[15028],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v8qi },
    &operand_data[14949],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4hi },
    &operand_data[14951],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v2si },
    &operand_data[14953],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3di },
    &operand_data[14955],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4hf },
    &operand_data[14957],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v2sf },
    &operand_data[14959],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3df },
    &operand_data[14961],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld3v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4bf },
    &operand_data[14963],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v8qi },
    &operand_data[15048],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4hi },
    &operand_data[15050],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v2si },
    &operand_data[15052],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4di },
    &operand_data[15054],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4hf },
    &operand_data[15056],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v2sf },
    &operand_data[15058],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4df },
    &operand_data[15060],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7579 */
  {
    "aarch64_ld4v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4bf },
    &operand_data[15062],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v8qi },
    &operand_data[15080],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v16qi },
    &operand_data[15082],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v4hi },
    &operand_data[15084],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v8hi },
    &operand_data[15086],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v2si },
    &operand_data[15088],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v4si },
    &operand_data[15090],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v2di },
    &operand_data[14204],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v4hf },
    &operand_data[15092],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v8hf },
    &operand_data[15094],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v4bf },
    &operand_data[15096],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v8bf },
    &operand_data[15098],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v2sf },
    &operand_data[15100],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v4sf },
    &operand_data[15102],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7589 */
  {
    "aarch64_ld1v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1v2df },
    &operand_data[14468],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v16qi },
    &operand_data[15030],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v8hi },
    &operand_data[15032],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4si },
    &operand_data[15034],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v2di },
    &operand_data[15036],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v8hf },
    &operand_data[15038],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v4sf },
    &operand_data[15040],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v2df },
    &operand_data[15042],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2v8bf },
    &operand_data[15044],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v16qi },
    &operand_data[14965],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v8hi },
    &operand_data[14967],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4si },
    &operand_data[14969],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v2di },
    &operand_data[14971],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v8hf },
    &operand_data[14973],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v4sf },
    &operand_data[14975],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v2df },
    &operand_data[14977],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld3v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3v8bf },
    &operand_data[14979],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v16qi },
    &operand_data[15064],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v8hi },
    &operand_data[15066],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4si },
    &operand_data[15068],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v2di },
    &operand_data[15070],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v8hf },
    &operand_data[15072],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v4sf },
    &operand_data[15074],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v2df },
    &operand_data[15076],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7604 */
  {
    "aarch64_ld4v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4v8bf },
    &operand_data[15078],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v8qi },
    &operand_data[15014],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v4hi },
    &operand_data[15016],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v2si },
    &operand_data[15018],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2di },
    &operand_data[15020],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v4hf },
    &operand_data[15022],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v2sf },
    &operand_data[15024],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2df },
    &operand_data[15026],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v4bf },
    &operand_data[15028],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v16qi },
    &operand_data[15030],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v8hi },
    &operand_data[15032],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v4si },
    &operand_data[15034],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v2di },
    &operand_data[15036],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v8hf },
    &operand_data[15038],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v4sf },
    &operand_data[15040],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v2df },
    &operand_data[15042],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7614 */
  {
    "aarch64_ld1x2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld1x2v8bf },
    &operand_data[15044],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev8qi },
    &operand_data[15104],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev4hi },
    &operand_data[15108],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev2si },
    &operand_data[15112],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanedi },
    &operand_data[15116],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev4hf },
    &operand_data[15120],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev2sf },
    &operand_data[15124],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanedf },
    &operand_data[15128],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev4bf },
    &operand_data[15132],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev8qi },
    &operand_data[15136],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev4hi },
    &operand_data[15140],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev2si },
    &operand_data[15144],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanedi },
    &operand_data[15148],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev4hf },
    &operand_data[15152],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev2sf },
    &operand_data[15156],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanedf },
    &operand_data[15160],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev4bf },
    &operand_data[15164],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev8qi },
    &operand_data[15168],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev4hi },
    &operand_data[15172],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev2si },
    &operand_data[15176],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanedi },
    &operand_data[15180],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev4hf },
    &operand_data[15184],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev2sf },
    &operand_data[15188],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanedf },
    &operand_data[15192],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev4bf },
    &operand_data[15196],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev16qi },
    &operand_data[15200],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev8hi },
    &operand_data[15204],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev4si },
    &operand_data[15208],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev2di },
    &operand_data[15212],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev8hf },
    &operand_data[15216],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev4sf },
    &operand_data[15220],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev2df },
    &operand_data[15224],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld2_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld2_lanev8bf },
    &operand_data[15228],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev16qi },
    &operand_data[15232],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev8hi },
    &operand_data[15236],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev4si },
    &operand_data[15240],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev2di },
    &operand_data[15244],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev8hf },
    &operand_data[15248],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev4sf },
    &operand_data[15252],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev2df },
    &operand_data[15256],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld3_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld3_lanev8bf },
    &operand_data[15260],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev16qi },
    &operand_data[15264],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev8hi },
    &operand_data[15268],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev4si },
    &operand_data[15272],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev2di },
    &operand_data[15276],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev8hf },
    &operand_data[15280],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev4sf },
    &operand_data[15284],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev2df },
    &operand_data[15288],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7626 */
  {
    "aarch64_ld4_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_ld4_lanev8bf },
    &operand_data[15292],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7649 */
  {
    "vec_permv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permv8qi },
    &operand_data[14413],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7649 */
  {
    "vec_permv16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permv16qi },
    &operand_data[14417],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v8qi },
    &operand_data[15013],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4hi },
    &operand_data[15015],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v2si },
    &operand_data[15017],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2di },
    &operand_data[15019],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4hf },
    &operand_data[15021],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v2sf },
    &operand_data[15023],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2df },
    &operand_data[15025],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st2v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4bf },
    &operand_data[15027],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v8qi },
    &operand_data[15045],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4hi },
    &operand_data[14950],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v2si },
    &operand_data[14952],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3di },
    &operand_data[14954],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4hf },
    &operand_data[14956],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v2sf },
    &operand_data[14958],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3df },
    &operand_data[14960],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st3v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4bf },
    &operand_data[14962],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v8qi },
    &operand_data[15047],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4hi },
    &operand_data[15049],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v2si },
    &operand_data[15051],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4di },
    &operand_data[15053],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4hf },
    &operand_data[15055],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v2sf },
    &operand_data[15057],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4df },
    &operand_data[15059],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7871 */
  {
    "aarch64_st4v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4bf },
    &operand_data[15061],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v16qi },
    &operand_data[15029],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v8hi },
    &operand_data[15031],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4si },
    &operand_data[15033],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v2di },
    &operand_data[15035],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v8hf },
    &operand_data[15037],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v4sf },
    &operand_data[15039],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v2df },
    &operand_data[15041],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st2v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2v8bf },
    &operand_data[15043],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v16qi },
    &operand_data[14964],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v8hi },
    &operand_data[14966],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4si },
    &operand_data[14968],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v2di },
    &operand_data[14970],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v8hf },
    &operand_data[14972],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v4sf },
    &operand_data[14974],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v2df },
    &operand_data[14976],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st3v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3v8bf },
    &operand_data[14978],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v16qi },
    &operand_data[15063],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v8hi },
    &operand_data[15065],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4si },
    &operand_data[15067],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v2di },
    &operand_data[15069],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v8hf },
    &operand_data[15071],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v4sf },
    &operand_data[15073],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v2df },
    &operand_data[15075],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7881 */
  {
    "aarch64_st4v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4v8bf },
    &operand_data[15077],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev8qi },
    &operand_data[15105],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev4hi },
    &operand_data[15109],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev2si },
    &operand_data[15113],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanedi },
    &operand_data[15117],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev4hf },
    &operand_data[15121],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev2sf },
    &operand_data[15125],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanedf },
    &operand_data[15129],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev4bf },
    &operand_data[15133],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev8qi },
    &operand_data[15137],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev4hi },
    &operand_data[15141],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev2si },
    &operand_data[15145],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanedi },
    &operand_data[15149],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev4hf },
    &operand_data[15153],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev2sf },
    &operand_data[15157],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanedf },
    &operand_data[15161],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev4bf },
    &operand_data[15165],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev8qi },
    &operand_data[15169],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev4hi },
    &operand_data[15173],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev2si },
    &operand_data[15177],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanedi },
    &operand_data[15181],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev4hf },
    &operand_data[15185],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev2sf },
    &operand_data[15189],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanedf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanedf },
    &operand_data[15193],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev4bf },
    &operand_data[15197],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev16qi },
    &operand_data[15201],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev8hi },
    &operand_data[15205],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev4si },
    &operand_data[15209],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev2di },
    &operand_data[15213],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev8hf },
    &operand_data[15217],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev4sf },
    &operand_data[15221],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev2df },
    &operand_data[15225],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st2_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st2_lanev8bf },
    &operand_data[15229],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev16qi },
    &operand_data[15233],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev8hi },
    &operand_data[15237],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev4si },
    &operand_data[15241],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev2di },
    &operand_data[15245],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev8hf },
    &operand_data[15249],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev4sf },
    &operand_data[15253],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev2df },
    &operand_data[15257],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st3_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st3_lanev8bf },
    &operand_data[15261],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev16qi },
    &operand_data[15265],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev8hi },
    &operand_data[15269],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev4si },
    &operand_data[15273],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev2di },
    &operand_data[15277],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev8hf },
    &operand_data[15281],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev4sf },
    &operand_data[15285],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev2df },
    &operand_data[15289],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7891 */
  {
    "aarch64_st4_lanev8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st4_lanev8bf },
    &operand_data[15293],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v8qi },
    &operand_data[14520],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v16qi },
    &operand_data[15081],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v4hi },
    &operand_data[15083],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v8hi },
    &operand_data[15085],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v2si },
    &operand_data[15087],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v4si },
    &operand_data[15089],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v2di },
    &operand_data[14101],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v4hf },
    &operand_data[15091],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v8hf },
    &operand_data[15093],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v4bf },
    &operand_data[15095],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v8bf },
    &operand_data[15097],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v2sf },
    &operand_data[15099],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v4sf },
    &operand_data[15101],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7907 */
  {
    "aarch64_st1v2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_st1v2df },
    &operand_data[15296],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv8qiqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv8qiqi },
    &operand_data[15298],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv16qiqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv16qiqi },
    &operand_data[15300],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv4hihi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv4hihi },
    &operand_data[15302],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv8hihi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv8hihi },
    &operand_data[15304],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv2sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv2sisi },
    &operand_data[15306],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv4sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv4sisi },
    &operand_data[15308],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv2didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv2didi },
    &operand_data[15310],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv4hfhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv4hfhf },
    &operand_data[15312],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv8hfhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv8hfhf },
    &operand_data[15314],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv4bfbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv4bfbf },
    &operand_data[15316],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv8bfbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv8bfbf },
    &operand_data[15318],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv2sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv2sfsf },
    &operand_data[15320],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv4sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv4sfsf },
    &operand_data[15322],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7924 */
  {
    "vec_initv2dfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv2dfdf },
    &operand_data[15324],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7933 */
  {
    "vec_initv16qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv16qiv8qi },
    &operand_data[15300],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7933 */
  {
    "vec_initv8hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv8hiv4hi },
    &operand_data[15304],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7933 */
  {
    "vec_initv4siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv4siv2si },
    &operand_data[15308],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7933 */
  {
    "vec_initv8hfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv8hfv4hf },
    &operand_data[15314],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7933 */
  {
    "vec_initv4sfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv4sfv2sf },
    &operand_data[15322],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:7933 */
  {
    "vec_initv8bfv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initv8bfv4bf },
    &operand_data[15318],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv8qiqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv8qiqi },
    &operand_data[15326],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv16qiqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv16qiqi },
    &operand_data[15329],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv4hihi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv4hihi },
    &operand_data[15332],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv8hihi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv8hihi },
    &operand_data[15335],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv2sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv2sisi },
    &operand_data[15338],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv4sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv4sisi },
    &operand_data[15341],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv2didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv2didi },
    &operand_data[15344],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv4hfhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv4hfhf },
    &operand_data[15347],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv8hfhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv8hfhf },
    &operand_data[15350],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv4bfbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv4bfbf },
    &operand_data[15353],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv8bfbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv8bfbf },
    &operand_data[15356],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv2sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv2sfsf },
    &operand_data[15359],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv4sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv4sfsf },
    &operand_data[15362],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8002 */
  {
    "vec_extractv2dfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv2dfdf },
    &operand_data[15365],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8014 */
  {
    "vec_extractv16qiv8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv16qiv8qi },
    &operand_data[15368],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8014 */
  {
    "vec_extractv8hiv4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv8hiv4hi },
    &operand_data[15371],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8014 */
  {
    "vec_extractv4siv2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv4siv2si },
    &operand_data[15374],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8014 */
  {
    "vec_extractv8hfv4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv8hfv4hf },
    &operand_data[15377],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8014 */
  {
    "vec_extractv8bfv4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv8bfv4bf },
    &operand_data[15380],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8014 */
  {
    "vec_extractv4sfv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv4sfv2sf },
    &operand_data[15383],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8029 */
  {
    "vec_extractv2dfv1df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractv2dfv1df },
    &operand_data[15386],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8350 */
  {
    "aarch64_fmlal_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlal_lowv2sf },
    &operand_data[15389],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8350 */
  {
    "aarch64_fmlsl_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlsl_lowv2sf },
    &operand_data[15389],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8350 */
  {
    "aarch64_fmlalq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalq_lowv4sf },
    &operand_data[15393],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8350 */
  {
    "aarch64_fmlslq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslq_lowv4sf },
    &operand_data[15393],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8373 */
  {
    "aarch64_fmlal_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlal_highv2sf },
    &operand_data[15389],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8373 */
  {
    "aarch64_fmlsl_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlsl_highv2sf },
    &operand_data[15389],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8373 */
  {
    "aarch64_fmlalq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalq_highv4sf },
    &operand_data[15393],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8373 */
  {
    "aarch64_fmlslq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslq_highv4sf },
    &operand_data[15393],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8463 */
  {
    "aarch64_fmlal_lane_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlal_lane_lowv2sf },
    &operand_data[15397],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8463 */
  {
    "aarch64_fmlsl_lane_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlsl_lane_lowv2sf },
    &operand_data[15397],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8484 */
  {
    "aarch64_fmlal_lane_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlal_lane_highv2sf },
    &operand_data[15397],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8484 */
  {
    "aarch64_fmlsl_lane_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlsl_lane_highv2sf },
    &operand_data[15397],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8578 */
  {
    "aarch64_fmlalq_laneq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalq_laneq_lowv4sf },
    &operand_data[15402],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8578 */
  {
    "aarch64_fmlslq_laneq_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslq_laneq_lowv4sf },
    &operand_data[15402],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8598 */
  {
    "aarch64_fmlalq_laneq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalq_laneq_highv4sf },
    &operand_data[15402],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8598 */
  {
    "aarch64_fmlslq_laneq_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslq_laneq_highv4sf },
    &operand_data[15402],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8692 */
  {
    "aarch64_fmlal_laneq_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlal_laneq_lowv2sf },
    &operand_data[15407],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8692 */
  {
    "aarch64_fmlsl_laneq_lowv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlsl_laneq_lowv2sf },
    &operand_data[15407],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8713 */
  {
    "aarch64_fmlal_laneq_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlal_laneq_highv2sf },
    &operand_data[15407],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8713 */
  {
    "aarch64_fmlsl_laneq_highv2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlsl_laneq_highv2sf },
    &operand_data[15407],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8808 */
  {
    "aarch64_fmlalq_lane_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalq_lane_lowv4sf },
    &operand_data[15412],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8808 */
  {
    "aarch64_fmlslq_lane_lowv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslq_lane_lowv4sf },
    &operand_data[15412],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8828 */
  {
    "aarch64_fmlalq_lane_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlalq_lane_highv4sf },
    &operand_data[15412],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8828 */
  {
    "aarch64_fmlslq_lane_highv4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_fmlslq_lane_highv4sf },
    &operand_data[15412],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8953 */
  {
    "aarch64_sxtlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sxtlv8hi },
    &operand_data[2672],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8953 */
  {
    "aarch64_uxtlv8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uxtlv8hi },
    &operand_data[2672],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8953 */
  {
    "aarch64_sxtlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sxtlv4si },
    &operand_data[2675],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8953 */
  {
    "aarch64_uxtlv4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uxtlv4si },
    &operand_data[2675],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8953 */
  {
    "aarch64_sxtlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sxtlv2di },
    &operand_data[2678],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:8953 */
  {
    "aarch64_uxtlv2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_uxtlv2di },
    &operand_data[2678],
    2,
    2,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9002 */
  {
    "aarch64_vget_lo_halfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vget_lo_halfv8bf },
    &operand_data[14107],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-simd.md:9012 */
  {
    "aarch64_vget_hi_halfv8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_vget_hi_halfv8bf },
    &operand_data[14107],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:23 */
  {
    "atomic_compare_and_swapqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_compare_and_swapqi },
    &operand_data[15417],
    8,
    8,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:23 */
  {
    "atomic_compare_and_swaphi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_compare_and_swaphi },
    &operand_data[15425],
    8,
    8,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:23 */
  {
    "atomic_compare_and_swapsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_compare_and_swapsi },
    &operand_data[15433],
    8,
    8,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:23 */
  {
    "atomic_compare_and_swapdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_compare_and_swapdi },
    &operand_data[15441],
    8,
    8,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:23 */
  {
    "atomic_compare_and_swapti",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_compare_and_swapti },
    &operand_data[15449],
    8,
    8,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:185 */
  {
    "atomic_exchangeqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_exchangeqi },
    &operand_data[15457],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:185 */
  {
    "atomic_exchangehi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_exchangehi },
    &operand_data[15461],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:185 */
  {
    "atomic_exchangesi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_exchangesi },
    &operand_data[15465],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:185 */
  {
    "atomic_exchangedi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_exchangedi },
    &operand_data[15469],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_addqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_addqi },
    &operand_data[15473],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_subqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_subqi },
    &operand_data[15473],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_orqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_orqi },
    &operand_data[15476],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_xorqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xorqi },
    &operand_data[15476],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_andqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_andqi },
    &operand_data[15476],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_addhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_addhi },
    &operand_data[15479],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_subhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_subhi },
    &operand_data[15479],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_orhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_orhi },
    &operand_data[15482],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_xorhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xorhi },
    &operand_data[15482],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_andhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_andhi },
    &operand_data[15482],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_addsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_addsi },
    &operand_data[15485],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_subsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_subsi },
    &operand_data[15485],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_orsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_orsi },
    &operand_data[15488],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_xorsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xorsi },
    &operand_data[15488],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_andsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_andsi },
    &operand_data[15488],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_adddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_adddi },
    &operand_data[15491],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_subdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_subdi },
    &operand_data[15491],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_ordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_ordi },
    &operand_data[15494],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_xordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xordi },
    &operand_data[15494],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:260 */
  {
    "atomic_anddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_anddi },
    &operand_data[15494],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_addqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_addqi },
    &operand_data[15497],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_subqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_subqi },
    &operand_data[15497],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_orqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_orqi },
    &operand_data[15501],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_xorqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_xorqi },
    &operand_data[15501],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_andqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_andqi },
    &operand_data[15501],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_addhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_addhi },
    &operand_data[15505],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_subhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_subhi },
    &operand_data[15505],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_orhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_orhi },
    &operand_data[15509],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_xorhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_xorhi },
    &operand_data[15509],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_andhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_andhi },
    &operand_data[15509],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_addsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_addsi },
    &operand_data[15513],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_subsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_subsi },
    &operand_data[15513],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_orsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_orsi },
    &operand_data[15517],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_xorsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_xorsi },
    &operand_data[15517],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_andsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_andsi },
    &operand_data[15517],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_adddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_adddi },
    &operand_data[15521],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_subdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_subdi },
    &operand_data[15521],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_ordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_ordi },
    &operand_data[15525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_xordi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_xordi },
    &operand_data[15525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:417 */
  {
    "atomic_fetch_anddi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_fetch_anddi },
    &operand_data[15525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_add_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_add_fetchqi },
    &operand_data[15497],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_sub_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_sub_fetchqi },
    &operand_data[15497],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_or_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_or_fetchqi },
    &operand_data[15501],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_xor_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xor_fetchqi },
    &operand_data[15501],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_and_fetchqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_and_fetchqi },
    &operand_data[15501],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_add_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_add_fetchhi },
    &operand_data[15505],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_sub_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_sub_fetchhi },
    &operand_data[15505],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_or_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_or_fetchhi },
    &operand_data[15509],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_xor_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xor_fetchhi },
    &operand_data[15509],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_and_fetchhi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_and_fetchhi },
    &operand_data[15509],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_add_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_add_fetchsi },
    &operand_data[15513],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_sub_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_sub_fetchsi },
    &operand_data[15513],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_or_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_or_fetchsi },
    &operand_data[15517],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_xor_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xor_fetchsi },
    &operand_data[15517],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_and_fetchsi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_and_fetchsi },
    &operand_data[15517],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_add_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_add_fetchdi },
    &operand_data[15521],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_sub_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_sub_fetchdi },
    &operand_data[15521],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_or_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_or_fetchdi },
    &operand_data[15525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_xor_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_xor_fetchdi },
    &operand_data[15525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:568 */
  {
    "atomic_and_fetchdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_atomic_and_fetchdi },
    &operand_data[15525],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:766 */
  {
    "mem_thread_fence",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mem_thread_fence },
    &operand_data[92],
    1,
    1,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/atomics.md:777 */
  {
    "dmb",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_dmb },
    &operand_data[92],
    1,
    1,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx16qi },
    &operand_data[15529],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8qi },
    &operand_data[15531],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4qi },
    &operand_data[15533],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2qi },
    &operand_data[15535],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8hi },
    &operand_data[15537],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4hi },
    &operand_data[15539],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2hi },
    &operand_data[15541],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8hf },
    &operand_data[15543],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4hf },
    &operand_data[15545],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2hf },
    &operand_data[15547],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8bf },
    &operand_data[15549],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4bf },
    &operand_data[15551],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2bf },
    &operand_data[15553],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4si },
    &operand_data[15555],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2si },
    &operand_data[15557],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4sf },
    &operand_data[15559],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2sf },
    &operand_data[15561],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2di },
    &operand_data[15563],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:644 */
  {
    "movvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2df },
    &operand_data[15565],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx16qi },
    &operand_data[15529],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx8qi },
    &operand_data[15531],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx4qi },
    &operand_data[15533],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2qi },
    &operand_data[15535],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx8hi },
    &operand_data[15537],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx4hi },
    &operand_data[15539],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2hi },
    &operand_data[15541],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx8hf },
    &operand_data[15543],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx4hf },
    &operand_data[15545],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2hf },
    &operand_data[15547],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx8bf },
    &operand_data[15549],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx4bf },
    &operand_data[15551],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2bf },
    &operand_data[15553],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx4si },
    &operand_data[15555],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2si },
    &operand_data[15557],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx4sf },
    &operand_data[15559],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2sf },
    &operand_data[15561],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2di },
    &operand_data[15563],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:674 */
  {
    "movmisalignvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movmisalignvnx2df },
    &operand_data[15565],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:722 */
  {
    "aarch64_sve_reload_mem",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reload_mem },
    &operand_data[15567],
    3,
    3,
    0,
    1,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx16qi },
    &operand_data[15570],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx8qi },
    &operand_data[15572],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx4qi },
    &operand_data[15574],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2qi },
    &operand_data[15576],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx8hi },
    &operand_data[15578],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx4hi },
    &operand_data[15580],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2hi },
    &operand_data[15582],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx8hf },
    &operand_data[15584],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx4hf },
    &operand_data[15586],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2hf },
    &operand_data[15588],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx8bf },
    &operand_data[15590],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx4bf },
    &operand_data[15592],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2bf },
    &operand_data[15594],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx4si },
    &operand_data[15596],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2si },
    &operand_data[15598],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx4sf },
    &operand_data[15600],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2sf },
    &operand_data[15602],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2di },
    &operand_data[15604],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:786 */
  {
    "aarch64_sve_reinterpretvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_reinterpretvnx2df },
    &operand_data[15606],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx32qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx32qi },
    &operand_data[15608],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx16hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx16hi },
    &operand_data[15610],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx8si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8si },
    &operand_data[15612],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx4di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4di },
    &operand_data[15614],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx16bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx16bf },
    &operand_data[15616],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx16hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx16hf },
    &operand_data[15618],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx8sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8sf },
    &operand_data[15620],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx4df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4df },
    &operand_data[15622],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx48qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx48qi },
    &operand_data[15624],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx24hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx24hi },
    &operand_data[15626],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx12si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx12si },
    &operand_data[15628],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx6di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx6di },
    &operand_data[15630],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx24bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx24bf },
    &operand_data[15632],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx24hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx24hf },
    &operand_data[15634],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx12sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx12sf },
    &operand_data[15636],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx6df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx6df },
    &operand_data[15638],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx64qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx64qi },
    &operand_data[15640],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx32hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx32hi },
    &operand_data[15642],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx16si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx16si },
    &operand_data[15644],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx8di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8di },
    &operand_data[15646],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx32bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx32bf },
    &operand_data[15648],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx32hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx32hf },
    &operand_data[15650],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx16sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx16sf },
    &operand_data[15652],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:825 */
  {
    "movvnx8df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8df },
    &operand_data[15654],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:935 */
  {
    "movvnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx16bi },
    &operand_data[15656],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:935 */
  {
    "movvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx8bi },
    &operand_data[15658],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:935 */
  {
    "movvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx4bi },
    &operand_data[15660],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:935 */
  {
    "movvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_movvnx2bi },
    &operand_data[15662],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx32qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx32qivnx16qi },
    &operand_data[15664],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx16hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx16hivnx8hi },
    &operand_data[15666],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx8sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx8sivnx4si },
    &operand_data[15668],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx4divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx4divnx2di },
    &operand_data[15670],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx16bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx16bfvnx8bf },
    &operand_data[15672],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx16hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx16hfvnx8hf },
    &operand_data[15674],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx8sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx8sfvnx4sf },
    &operand_data[15676],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx4dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx4dfvnx2df },
    &operand_data[15678],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx48qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx48qivnx16qi },
    &operand_data[15680],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx24hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx24hivnx8hi },
    &operand_data[15682],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx12sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx12sivnx4si },
    &operand_data[15684],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx6divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx6divnx2di },
    &operand_data[15686],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx24bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx24bfvnx8bf },
    &operand_data[15688],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx24hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx24hfvnx8hf },
    &operand_data[15690],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx12sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx12sfvnx4sf },
    &operand_data[15692],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx6dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx6dfvnx2df },
    &operand_data[15694],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx64qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx64qivnx16qi },
    &operand_data[15696],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx32hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx32hivnx8hi },
    &operand_data[15698],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx16sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx16sivnx4si },
    &operand_data[15700],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx8divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx8divnx2di },
    &operand_data[15702],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx32bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx32bfvnx8bf },
    &operand_data[15704],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx32hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx32hfvnx8hf },
    &operand_data[15706],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx16sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx16sfvnx4sf },
    &operand_data[15708],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1254 */
  {
    "vec_load_lanesvnx8dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_load_lanesvnx8dfvnx2df },
    &operand_data[15710],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2qivnx2di },
    &operand_data[15712],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2hivnx2di },
    &operand_data[15717],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2hfvnx2di },
    &operand_data[15722],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2bfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2bfvnx2di },
    &operand_data[15727],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2sivnx2di },
    &operand_data[15732],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2sfvnx2di },
    &operand_data[15737],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2divnx2di },
    &operand_data[15742],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx2dfvnx2di },
    &operand_data[15747],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx4qivnx4si },
    &operand_data[15752],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx4hivnx4si },
    &operand_data[15757],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx4hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx4hfvnx4si },
    &operand_data[15762],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx4bfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx4bfvnx4si },
    &operand_data[15767],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx4sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx4sivnx4si },
    &operand_data[15772],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:1402 */
  {
    "gather_loadvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_gather_loadvnx4sfvnx4si },
    &operand_data[15777],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx32qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx32qivnx16qi },
    &operand_data[15782],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx16hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx16hivnx8hi },
    &operand_data[15784],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx8sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx8sivnx4si },
    &operand_data[15786],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx4divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx4divnx2di },
    &operand_data[15788],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx16bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx16bfvnx8bf },
    &operand_data[15790],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx16hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx16hfvnx8hf },
    &operand_data[15792],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx8sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx8sfvnx4sf },
    &operand_data[15794],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx4dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx4dfvnx2df },
    &operand_data[15796],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx48qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx48qivnx16qi },
    &operand_data[15798],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx24hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx24hivnx8hi },
    &operand_data[15800],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx12sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx12sivnx4si },
    &operand_data[15802],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx6divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx6divnx2di },
    &operand_data[15804],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx24bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx24bfvnx8bf },
    &operand_data[15806],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx24hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx24hfvnx8hf },
    &operand_data[15808],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx12sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx12sfvnx4sf },
    &operand_data[15810],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx6dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx6dfvnx2df },
    &operand_data[15812],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx64qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx64qivnx16qi },
    &operand_data[15814],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx32hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx32hivnx8hi },
    &operand_data[15816],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx16sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx16sivnx4si },
    &operand_data[15818],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx8divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx8divnx2di },
    &operand_data[15820],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx32bfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx32bfvnx8bf },
    &operand_data[15822],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx32hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx32hfvnx8hf },
    &operand_data[15824],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx16sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx16sfvnx4sf },
    &operand_data[15826],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2132 */
  {
    "vec_store_lanesvnx8dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_store_lanesvnx8dfvnx2df },
    &operand_data[15828],
    2,
    2,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2qivnx2di },
    &operand_data[15830],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2hivnx2di },
    &operand_data[15835],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2hfvnx2di },
    &operand_data[15718],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2bfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2bfvnx2di },
    &operand_data[15723],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2sivnx2di },
    &operand_data[15840],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2sfvnx2di },
    &operand_data[15733],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2divnx2di },
    &operand_data[15845],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx2dfvnx2di },
    &operand_data[15743],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx4qivnx4si },
    &operand_data[15850],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx4hivnx4si },
    &operand_data[15855],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx4hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx4hfvnx4si },
    &operand_data[15758],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx4bfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx4bfvnx4si },
    &operand_data[15763],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx4sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx4sivnx4si },
    &operand_data[15860],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2235 */
  {
    "scatter_storevnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_scatter_storevnx4sfvnx4si },
    &operand_data[15773],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx16qi },
    &operand_data[15865],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx8qi },
    &operand_data[15867],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx4qi },
    &operand_data[15869],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2qi },
    &operand_data[15871],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx8hi },
    &operand_data[15873],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx4hi },
    &operand_data[15875],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2hi },
    &operand_data[15877],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx8hf },
    &operand_data[15879],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx4hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx4hf },
    &operand_data[15881],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2hf },
    &operand_data[15883],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx8bf },
    &operand_data[15885],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx4bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx4bf },
    &operand_data[15887],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2bf },
    &operand_data[15889],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx4si },
    &operand_data[15891],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2si },
    &operand_data[15893],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx4sf },
    &operand_data[15895],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2sf },
    &operand_data[15897],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2di },
    &operand_data[15899],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2489 */
  {
    "vec_duplicatevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2df },
    &operand_data[15901],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx16qiqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx16qiqi },
    &operand_data[15903],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx8hihi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx8hihi },
    &operand_data[15905],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx4sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx4sisi },
    &operand_data[15907],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx2didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx2didi },
    &operand_data[15909],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx8bfbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx8bfbf },
    &operand_data[15911],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx8hfhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx8hfhf },
    &operand_data[15913],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx4sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx4sfsf },
    &operand_data[15915],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2619 */
  {
    "vec_initvnx2dfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_initvnx2dfdf },
    &operand_data[15917],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2688 */
  {
    "vec_duplicatevnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx16bi },
    &operand_data[15919],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2688 */
  {
    "vec_duplicatevnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx8bi },
    &operand_data[15921],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2688 */
  {
    "vec_duplicatevnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx4bi },
    &operand_data[15923],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2688 */
  {
    "vec_duplicatevnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_duplicatevnx2bi },
    &operand_data[15925],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx16qiqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx16qiqi },
    &operand_data[15926],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx8hihi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx8hihi },
    &operand_data[15929],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx4sisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx4sisi },
    &operand_data[15932],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx2didi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx2didi },
    &operand_data[15935],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx8bfbf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx8bfbf },
    &operand_data[15938],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx8hfhf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx8hfhf },
    &operand_data[15941],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx4sfsf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx4sfsf },
    &operand_data[15944],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2716 */
  {
    "vec_extractvnx2dfdf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx2dfdf },
    &operand_data[15947],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2879 */
  {
    "vec_extractvnx16biqi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx16biqi },
    &operand_data[15950],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2879 */
  {
    "vec_extractvnx8bihi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx8bihi },
    &operand_data[15953],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2879 */
  {
    "vec_extractvnx4bisi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx4bisi },
    &operand_data[15956],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2879 */
  {
    "vec_extractvnx2bidi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_extractvnx2bidi },
    &operand_data[15959],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx16qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx16qi2 },
    &operand_data[15962],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx8qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx8qi2 },
    &operand_data[15964],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx4qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx4qi2 },
    &operand_data[15966],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx2qi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx2qi2 },
    &operand_data[15968],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx8hi2 },
    &operand_data[15970],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx4hi2 },
    &operand_data[15972],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx2hi2 },
    &operand_data[15974],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx4si2 },
    &operand_data[15976],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx2si2 },
    &operand_data[15978],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "absvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "negvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "one_cmplvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clrsbvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clrsbvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "clzvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_clzvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "popcountvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_popcountvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qabsvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qabsvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2913 */
  {
    "qnegvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_qnegvnx2di2 },
    &operand_data[15980],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx16qi },
    &operand_data[15982],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx8qi },
    &operand_data[15986],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx4qi },
    &operand_data[15990],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx2qi },
    &operand_data[15994],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx8hi },
    &operand_data[15998],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx4hi },
    &operand_data[16002],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx2hi },
    &operand_data[16006],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx4si },
    &operand_data[16010],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx2si },
    &operand_data[16014],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_absvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_negvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_one_cmplvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_one_cmplvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clrsbvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clrsbvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_clzvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_clzvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_popcountvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_popcountvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qabsvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qabsvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:2942 */
  {
    "cond_qnegvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_qnegvnx2di },
    &operand_data[16018],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx8qivnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx8qivnx8hi2 },
    &operand_data[16022],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx8qivnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx8qivnx8hi2 },
    &operand_data[16022],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx4qivnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx4qivnx4hi2 },
    &operand_data[16024],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx4qivnx4hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx4qivnx4hi2 },
    &operand_data[16024],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx2qivnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx2qivnx2hi2 },
    &operand_data[16026],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx2qivnx2hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx2qivnx2hi2 },
    &operand_data[16026],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx4qivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx4qivnx4si2 },
    &operand_data[16028],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx4qivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx4qivnx4si2 },
    &operand_data[16028],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx4hivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx4hivnx4si2 },
    &operand_data[16030],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx4hivnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx4hivnx4si2 },
    &operand_data[16030],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx2qivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx2qivnx2si2 },
    &operand_data[16032],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx2qivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx2qivnx2si2 },
    &operand_data[16032],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx2hivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx2hivnx2si2 },
    &operand_data[16034],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx2hivnx2si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx2hivnx2si2 },
    &operand_data[16034],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx2qivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx2qivnx2di2 },
    &operand_data[16036],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx2qivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx2qivnx2di2 },
    &operand_data[16036],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx2hivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx2hivnx2di2 },
    &operand_data[16038],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx2hivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx2hivnx2di2 },
    &operand_data[16038],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "extendvnx2sivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_extendvnx2sivnx2di2 },
    &operand_data[16040],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3068 */
  {
    "zero_extendvnx2sivnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_zero_extendvnx2sivnx2di2 },
    &operand_data[16040],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3209 */
  {
    "aarch64_pred_cnotvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cnotvnx16qi },
    &operand_data[16042],
    4,
    4,
    3,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3209 */
  {
    "aarch64_pred_cnotvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cnotvnx8hi },
    &operand_data[16046],
    4,
    4,
    3,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3209 */
  {
    "aarch64_pred_cnotvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cnotvnx4si },
    &operand_data[16050],
    4,
    4,
    3,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3209 */
  {
    "aarch64_pred_cnotvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_cnotvnx2di },
    &operand_data[16054],
    4,
    4,
    3,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3250 */
  {
    "cond_cnotvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cnotvnx16qi },
    &operand_data[15982],
    4,
    4,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3250 */
  {
    "cond_cnotvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cnotvnx8hi },
    &operand_data[15998],
    4,
    4,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3250 */
  {
    "cond_cnotvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cnotvnx4si },
    &operand_data[16010],
    4,
    4,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3250 */
  {
    "cond_cnotvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cnotvnx2di },
    &operand_data[16018],
    4,
    4,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "absvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "negvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "frecpxvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_frecpxvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "roundvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "nearbyintvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "floorvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "frintnvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_frintnvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "ceilvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "rintvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "btruncvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "absvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "negvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "frecpxvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_frecpxvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "roundvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "nearbyintvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "floorvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "frintnvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_frintnvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "ceilvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "rintvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "btruncvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "absvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_absvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "negvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_negvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "frecpxvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_frecpxvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "roundvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_roundvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "nearbyintvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_nearbyintvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "floorvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floorvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "frintnvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_frintnvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "ceilvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ceilvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "rintvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rintvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3389 */
  {
    "btruncvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_btruncvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_absvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_negvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_frecpxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_frecpxvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_roundvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_roundvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_nearbyintvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_nearbyintvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_floorvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floorvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_frintnvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_frintnvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_ceilvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ceilvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_rintvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_rintvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_btruncvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_btruncvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_sqrtvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqrtvnx8hf },
    &operand_data[16064],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_absvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_negvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_frecpxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_frecpxvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_roundvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_roundvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_nearbyintvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_nearbyintvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_floorvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floorvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_frintnvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_frintnvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_ceilvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ceilvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_rintvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_rintvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_btruncvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_btruncvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_sqrtvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqrtvnx4sf },
    &operand_data[16068],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_absvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_absvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_negvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_negvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_frecpxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_frecpxvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_roundvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_roundvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_nearbyintvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_nearbyintvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_floorvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floorvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_frintnvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_frintnvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_ceilvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ceilvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_rintvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_rintvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_btruncvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_btruncvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3418 */
  {
    "cond_sqrtvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqrtvnx2df },
    &operand_data[16072],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3527 */
  {
    "sqrtvnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtvnx8hf2 },
    &operand_data[16058],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3527 */
  {
    "sqrtvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3527 */
  {
    "sqrtvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sqrtvnx2df2 },
    &operand_data[16062],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3545 */
  {
    "rsqrtvnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rsqrtvnx4sf2 },
    &operand_data[16060],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3545 */
  {
    "rsqrtvnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_rsqrtvnx2df2 },
    &operand_data[16062],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3556 */
  {
    "aarch64_rsqrtevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtevnx4sf },
    &operand_data[16060],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3556 */
  {
    "aarch64_rsqrtevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtevnx2df },
    &operand_data[16062],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3564 */
  {
    "aarch64_rsqrtsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsvnx4sf },
    &operand_data[16076],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3564 */
  {
    "aarch64_rsqrtsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_rsqrtsvnx2df },
    &operand_data[16079],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3581 */
  {
    "one_cmplvnx16bi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx16bi2 },
    &operand_data[16082],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3581 */
  {
    "one_cmplvnx8bi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx8bi2 },
    &operand_data[16084],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3581 */
  {
    "one_cmplvnx4bi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx4bi2 },
    &operand_data[16086],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3581 */
  {
    "one_cmplvnx2bi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_one_cmplvnx2bi2 },
    &operand_data[16088],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx16qi3 },
    &operand_data[16090],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx16qi3 },
    &operand_data[16090],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx16qi3 },
    &operand_data[16090],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx16qi3 },
    &operand_data[16093],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx16qi3 },
    &operand_data[16093],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx8qi3 },
    &operand_data[16096],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx8qi3 },
    &operand_data[16096],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx8qi3 },
    &operand_data[16096],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx8qi3 },
    &operand_data[16099],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx8qi3 },
    &operand_data[16099],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx4qi3 },
    &operand_data[16102],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx4qi3 },
    &operand_data[16102],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx4qi3 },
    &operand_data[16102],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx4qi3 },
    &operand_data[16105],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx4qi3 },
    &operand_data[16105],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx2qi3 },
    &operand_data[16108],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx2qi3 },
    &operand_data[16108],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx2qi3 },
    &operand_data[16108],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx2qi3 },
    &operand_data[16111],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx2qi3 },
    &operand_data[16111],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx8hi3 },
    &operand_data[16114],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx8hi3 },
    &operand_data[16114],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx8hi3 },
    &operand_data[16114],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx8hi3 },
    &operand_data[16117],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx8hi3 },
    &operand_data[16117],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx4hi3 },
    &operand_data[16120],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx4hi3 },
    &operand_data[16120],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx4hi3 },
    &operand_data[16120],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx4hi3 },
    &operand_data[16123],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx4hi3 },
    &operand_data[16123],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx2hi3 },
    &operand_data[16126],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx2hi3 },
    &operand_data[16126],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx2hi3 },
    &operand_data[16126],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx2hi3 },
    &operand_data[16129],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx2hi3 },
    &operand_data[16129],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx4si3 },
    &operand_data[16132],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx4si3 },
    &operand_data[16132],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx4si3 },
    &operand_data[16132],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx4si3 },
    &operand_data[16135],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx4si3 },
    &operand_data[16135],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx2si3 },
    &operand_data[16138],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx2si3 },
    &operand_data[16138],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx2si3 },
    &operand_data[16138],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx2si3 },
    &operand_data[16141],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx2si3 },
    &operand_data[16141],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "mulvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx2di3 },
    &operand_data[16144],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "smaxvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx2di3 },
    &operand_data[16144],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "sminvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx2di3 },
    &operand_data[16144],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "umaxvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umaxvnx2di3 },
    &operand_data[16147],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3630 */
  {
    "uminvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uminvnx2di3 },
    &operand_data[16147],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx16qi },
    &operand_data[16155],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx16qi },
    &operand_data[16160],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx16qi },
    &operand_data[16160],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx16qi },
    &operand_data[16165],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx8qi },
    &operand_data[16175],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx8qi },
    &operand_data[16180],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx8qi },
    &operand_data[16180],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx8qi },
    &operand_data[16185],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx8qi },
    &operand_data[16170],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx4qi },
    &operand_data[16195],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx4qi },
    &operand_data[16200],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx4qi },
    &operand_data[16200],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx4qi },
    &operand_data[16205],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx4qi },
    &operand_data[16190],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx2qi },
    &operand_data[16215],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx2qi },
    &operand_data[16220],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx2qi },
    &operand_data[16220],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx2qi },
    &operand_data[16225],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx2qi },
    &operand_data[16210],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx8hi },
    &operand_data[16235],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx8hi },
    &operand_data[16240],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx8hi },
    &operand_data[16240],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx8hi },
    &operand_data[16245],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx4hi },
    &operand_data[16255],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx4hi },
    &operand_data[16260],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx4hi },
    &operand_data[16260],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx4hi },
    &operand_data[16265],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx4hi },
    &operand_data[16250],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx2hi },
    &operand_data[16275],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx2hi },
    &operand_data[16280],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx2hi },
    &operand_data[16280],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx2hi },
    &operand_data[16285],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx2hi },
    &operand_data[16270],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx4si },
    &operand_data[16295],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx4si },
    &operand_data[16300],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx4si },
    &operand_data[16300],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx4si },
    &operand_data[16305],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx2si },
    &operand_data[16315],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx2si },
    &operand_data[16320],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx2si },
    &operand_data[16320],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx2si },
    &operand_data[16325],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx2si },
    &operand_data[16310],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_addvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_subvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_mulvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_smaxvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_umaxvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umaxvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sminvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_uminvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uminvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashlvnx2di },
    &operand_data[16335],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ashrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ashrvnx2di },
    &operand_data[16340],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_lshrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lshrvnx2di },
    &operand_data[16340],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_andvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_andvnx2di },
    &operand_data[16345],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_iorvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_iorvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_xorvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_xorvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ssaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ssaddvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_usaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usaddvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_sssubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sssubvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3689 */
  {
    "cond_ussubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ussubvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3887 */
  {
    "aarch64_adrvnx4si_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_adrvnx4si_shift },
    &operand_data[16350],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3887 */
  {
    "aarch64_adrvnx2di_shift",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_adrvnx2di_shift },
    &operand_data[16354],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx16qi_3 },
    &operand_data[16358],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx16qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx16qi_3 },
    &operand_data[16358],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx8qi_3 },
    &operand_data[16361],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx8qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx8qi_3 },
    &operand_data[16361],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx4qi_3 },
    &operand_data[16364],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx4qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx4qi_3 },
    &operand_data[16364],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx2qi_3 },
    &operand_data[16367],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx2qi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx2qi_3 },
    &operand_data[16367],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx8hi_3 },
    &operand_data[16370],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx8hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx8hi_3 },
    &operand_data[16370],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx4hi_3 },
    &operand_data[16373],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx4hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx4hi_3 },
    &operand_data[16373],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx2hi_3 },
    &operand_data[16376],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx2hi_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx2hi_3 },
    &operand_data[16376],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx4si_3 },
    &operand_data[16350],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx4si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx4si_3 },
    &operand_data[16350],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx2si_3 },
    &operand_data[16379],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx2si_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx2si_3 },
    &operand_data[16379],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "sabdvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sabdvnx2di_3 },
    &operand_data[16354],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:3975 */
  {
    "uabdvnx2di_3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uabdvnx2di_3 },
    &operand_data[16354],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_sabdvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sabdvnx16qi },
    &operand_data[16150],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_uabdvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_uabdvnx16qi },
    &operand_data[16150],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_sabdvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sabdvnx8hi },
    &operand_data[16230],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_uabdvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_uabdvnx8hi },
    &operand_data[16230],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_sabdvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sabdvnx4si },
    &operand_data[16290],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_uabdvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_uabdvnx4si },
    &operand_data[16290],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_sabdvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_sabdvnx2di },
    &operand_data[16330],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4012 */
  {
    "aarch64_cond_uabdvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_uabdvnx2di },
    &operand_data[16330],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx16qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx16qi3_highpart },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx16qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx16qi3_highpart },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx8qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx8qi3_highpart },
    &operand_data[16361],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx8qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx8qi3_highpart },
    &operand_data[16361],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx4qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx4qi3_highpart },
    &operand_data[16364],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx4qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx4qi3_highpart },
    &operand_data[16364],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx2qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx2qi3_highpart },
    &operand_data[16367],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx2qi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx2qi3_highpart },
    &operand_data[16367],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx8hi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx8hi3_highpart },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx8hi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx8hi3_highpart },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx4hi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx4hi3_highpart },
    &operand_data[16373],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx4hi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx4hi3_highpart },
    &operand_data[16373],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx2hi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx2hi3_highpart },
    &operand_data[16376],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx2hi3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx2hi3_highpart },
    &operand_data[16376],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx4si3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx4si3_highpart },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx4si3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx4si3_highpart },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx2si3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx2si3_highpart },
    &operand_data[16379],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx2si3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx2si3_highpart },
    &operand_data[16379],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "smulvnx2di3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulvnx2di3_highpart },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4194 */
  {
    "umulvnx2di3_highpart",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulvnx2di3_highpart },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_smulhvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smulhvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_umulhvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umulhvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_smulhvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smulhvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_umulhvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umulhvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_smulhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smulhvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_umulhvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umulhvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_smulhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smulhvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4227 */
  {
    "cond_umulhvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_umulhvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4290 */
  {
    "divvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divvnx4si3 },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4290 */
  {
    "udivvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udivvnx4si3 },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4290 */
  {
    "divvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divvnx2di3 },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4290 */
  {
    "udivvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_udivvnx2di3 },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4322 */
  {
    "cond_divvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_divvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4322 */
  {
    "cond_udivvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_udivvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4322 */
  {
    "cond_divvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_divvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4322 */
  {
    "cond_udivvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_udivvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx16qi },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx8qi },
    &operand_data[16361],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx4qi },
    &operand_data[16364],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx2qi },
    &operand_data[16367],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx8hi },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx4hi },
    &operand_data[16373],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx2hi },
    &operand_data[16376],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx4si },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx2si },
    &operand_data[16379],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4431 */
  {
    "aarch64_bicvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_bicvnx2di },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4464 */
  {
    "cond_bicvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_bicvnx16qi },
    &operand_data[16150],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4464 */
  {
    "cond_bicvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_bicvnx8hi },
    &operand_data[16230],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4464 */
  {
    "cond_bicvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_bicvnx4si },
    &operand_data[16290],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4464 */
  {
    "cond_bicvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_bicvnx2di },
    &operand_data[16330],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx16qi3 },
    &operand_data[16382],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx16qi3 },
    &operand_data[16382],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx16qi3 },
    &operand_data[16382],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx8qi3 },
    &operand_data[16385],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx8qi3 },
    &operand_data[16385],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx8qi3 },
    &operand_data[16385],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx4qi3 },
    &operand_data[16388],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx4qi3 },
    &operand_data[16388],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx4qi3 },
    &operand_data[16388],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx2qi3 },
    &operand_data[16391],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx2qi3 },
    &operand_data[16391],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx2qi3 },
    &operand_data[16391],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx8hi3 },
    &operand_data[16394],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx8hi3 },
    &operand_data[16394],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx8hi3 },
    &operand_data[16394],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx4hi3 },
    &operand_data[16397],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx4hi3 },
    &operand_data[16397],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx4hi3 },
    &operand_data[16397],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx2hi3 },
    &operand_data[16400],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx2hi3 },
    &operand_data[16400],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx2hi3 },
    &operand_data[16400],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx4si3 },
    &operand_data[16403],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx4si3 },
    &operand_data[16403],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx4si3 },
    &operand_data[16403],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx2si3 },
    &operand_data[16406],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx2si3 },
    &operand_data[16406],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx2si3 },
    &operand_data[16406],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashlvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashlvnx2di3 },
    &operand_data[16409],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "ashrvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ashrvnx2di3 },
    &operand_data[16409],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4536 */
  {
    "lshrvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_lshrvnx2di3 },
    &operand_data[16409],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx16qi3 },
    &operand_data[16412],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx16qi3 },
    &operand_data[16415],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx16qi3 },
    &operand_data[16415],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx8qi3 },
    &operand_data[16418],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx8qi3 },
    &operand_data[16421],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx8qi3 },
    &operand_data[16421],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx4qi3 },
    &operand_data[16424],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx4qi3 },
    &operand_data[16427],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx4qi3 },
    &operand_data[16427],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx2qi3 },
    &operand_data[16430],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx2qi3 },
    &operand_data[16433],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx2qi3 },
    &operand_data[16433],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx8hi3 },
    &operand_data[16436],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx8hi3 },
    &operand_data[16439],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx8hi3 },
    &operand_data[16439],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx4hi3 },
    &operand_data[16442],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx4hi3 },
    &operand_data[16445],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx4hi3 },
    &operand_data[16445],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx2hi3 },
    &operand_data[16448],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx2hi3 },
    &operand_data[16451],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx2hi3 },
    &operand_data[16451],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx4si3 },
    &operand_data[16454],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx4si3 },
    &operand_data[16457],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx4si3 },
    &operand_data[16457],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx2si3 },
    &operand_data[16460],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx2si3 },
    &operand_data[16463],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx2si3 },
    &operand_data[16463],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashlvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashlvnx2di3 },
    &operand_data[16466],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vashrvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vashrvnx2di3 },
    &operand_data[16469],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4561 */
  {
    "vlshrvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vlshrvnx2di3 },
    &operand_data[16469],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_lslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lslvnx16qi },
    &operand_data[16472],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_asrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrvnx16qi },
    &operand_data[16472],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_lsrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lsrvnx16qi },
    &operand_data[16472],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_lslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lslvnx8hi },
    &operand_data[16477],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_asrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrvnx8hi },
    &operand_data[16477],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_lsrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lsrvnx8hi },
    &operand_data[16477],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_lslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lslvnx4si },
    &operand_data[16482],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_asrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrvnx4si },
    &operand_data[16482],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4667 */
  {
    "cond_lsrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_lsrvnx4si },
    &operand_data[16482],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx16qi3 },
    &operand_data[16487],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx8qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx8qi3 },
    &operand_data[16490],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx4qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx4qi3 },
    &operand_data[16493],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx2qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx2qi3 },
    &operand_data[16496],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx8hi3 },
    &operand_data[16499],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx4hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx4hi3 },
    &operand_data[16502],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx2hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx2hi3 },
    &operand_data[16505],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx4si3 },
    &operand_data[16508],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx2si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx2si3 },
    &operand_data[16511],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4726 */
  {
    "sdiv_pow2vnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sdiv_pow2vnx2di3 },
    &operand_data[16514],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx16qi },
    &operand_data[16517],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx16qi },
    &operand_data[16522],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx16qi },
    &operand_data[16517],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx16qi },
    &operand_data[16517],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx8qi },
    &operand_data[16527],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx8qi },
    &operand_data[16532],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx8qi },
    &operand_data[16527],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx8qi },
    &operand_data[16527],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx4qi },
    &operand_data[16537],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx4qi },
    &operand_data[16542],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx4qi },
    &operand_data[16537],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx4qi },
    &operand_data[16537],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx2qi },
    &operand_data[16547],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx2qi },
    &operand_data[16552],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx2qi },
    &operand_data[16547],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx2qi },
    &operand_data[16547],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx8hi },
    &operand_data[16557],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx8hi },
    &operand_data[16562],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx8hi },
    &operand_data[16557],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx8hi },
    &operand_data[16557],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx4hi },
    &operand_data[16567],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx4hi },
    &operand_data[16572],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx4hi },
    &operand_data[16567],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx4hi },
    &operand_data[16567],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx2hi },
    &operand_data[16577],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx2hi },
    &operand_data[16582],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx2hi },
    &operand_data[16577],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx2hi },
    &operand_data[16577],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx4si },
    &operand_data[16587],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx4si },
    &operand_data[16592],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx4si },
    &operand_data[16587],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx4si },
    &operand_data[16587],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx2si },
    &operand_data[16597],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx2si },
    &operand_data[16602],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx2si },
    &operand_data[16597],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx2si },
    &operand_data[16597],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_asrdvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_asrdvnx2di },
    &operand_data[16607],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_sqshluvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshluvnx2di },
    &operand_data[16612],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_srshrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshrvnx2di },
    &operand_data[16607],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4758 */
  {
    "cond_urshrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshrvnx2di },
    &operand_data[16607],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4871 */
  {
    "cond_fscalevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fscalevnx8hf },
    &operand_data[16617],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4871 */
  {
    "cond_fscalevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fscalevnx4sf },
    &operand_data[16622],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:4871 */
  {
    "cond_fscalevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fscalevnx2df },
    &operand_data[16627],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "addvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx8hf3 },
    &operand_data[16632],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "fmax_nanvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanvnx8hf3 },
    &operand_data[16635],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "smaxvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx8hf3 },
    &operand_data[16635],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "fmin_nanvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanvnx8hf3 },
    &operand_data[16635],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "sminvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx8hf3 },
    &operand_data[16635],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "mulvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx8hf3 },
    &operand_data[16638],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "mulxvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulxvnx8hf3 },
    &operand_data[16641],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "subvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx8hf3 },
    &operand_data[16643],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "addvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx4sf3 },
    &operand_data[16646],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "fmax_nanvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanvnx4sf3 },
    &operand_data[16649],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "smaxvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx4sf3 },
    &operand_data[16649],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "fmin_nanvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanvnx4sf3 },
    &operand_data[16649],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "sminvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx4sf3 },
    &operand_data[16649],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "mulvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx4sf3 },
    &operand_data[16652],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "mulxvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulxvnx4sf3 },
    &operand_data[16076],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "subvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx4sf3 },
    &operand_data[16655],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "addvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_addvnx2df3 },
    &operand_data[16658],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "fmax_nanvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmax_nanvnx2df3 },
    &operand_data[16661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "smaxvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smaxvnx2df3 },
    &operand_data[16661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "fmin_nanvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmin_nanvnx2df3 },
    &operand_data[16661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "sminvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_sminvnx2df3 },
    &operand_data[16661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "mulvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulvnx2df3 },
    &operand_data[16664],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "mulxvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_mulxvnx2df3 },
    &operand_data[16079],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5050 */
  {
    "subvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_subvnx2df3 },
    &operand_data[16667],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_addvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx8hf },
    &operand_data[16670],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_divvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_divvnx8hf },
    &operand_data[16675],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_fmax_nanvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmax_nanvnx8hf },
    &operand_data[16680],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_smaxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx8hf },
    &operand_data[16680],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_fmin_nanvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmin_nanvnx8hf },
    &operand_data[16680],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_sminvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx8hf },
    &operand_data[16680],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_mulvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx8hf },
    &operand_data[16685],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_mulxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulxvnx8hf },
    &operand_data[16675],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_subvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx8hf },
    &operand_data[16690],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_addvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx4sf },
    &operand_data[16695],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_divvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_divvnx4sf },
    &operand_data[16700],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_fmax_nanvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmax_nanvnx4sf },
    &operand_data[16705],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_smaxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx4sf },
    &operand_data[16705],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_fmin_nanvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmin_nanvnx4sf },
    &operand_data[16705],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_sminvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx4sf },
    &operand_data[16705],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_mulvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx4sf },
    &operand_data[16710],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_mulxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulxvnx4sf },
    &operand_data[16700],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_subvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx4sf },
    &operand_data[16715],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_addvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_addvnx2df },
    &operand_data[16720],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_divvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_divvnx2df },
    &operand_data[16725],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_fmax_nanvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmax_nanvnx2df },
    &operand_data[16730],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_smaxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_smaxvnx2df },
    &operand_data[16730],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_fmin_nanvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmin_nanvnx2df },
    &operand_data[16730],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_sminvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sminvnx2df },
    &operand_data[16730],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_mulvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulvnx2df },
    &operand_data[16735],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_mulxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_mulxvnx2df },
    &operand_data[16725],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5082 */
  {
    "cond_subvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_subvnx2df },
    &operand_data[16740],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5543 */
  {
    "cond_cadd90vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cadd90vnx8hf },
    &operand_data[16675],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5543 */
  {
    "cond_cadd270vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cadd270vnx8hf },
    &operand_data[16675],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5543 */
  {
    "cond_cadd90vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cadd90vnx4sf },
    &operand_data[16700],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5543 */
  {
    "cond_cadd270vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cadd270vnx4sf },
    &operand_data[16700],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5543 */
  {
    "cond_cadd90vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cadd90vnx2df },
    &operand_data[16725],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5543 */
  {
    "cond_cadd270vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_cadd270vnx2df },
    &operand_data[16725],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5559 */
  {
    "cadd90vnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90vnx8hf3 },
    &operand_data[16641],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5559 */
  {
    "cadd270vnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270vnx8hf3 },
    &operand_data[16641],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5559 */
  {
    "cadd90vnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90vnx4sf3 },
    &operand_data[16076],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5559 */
  {
    "cadd270vnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270vnx4sf3 },
    &operand_data[16076],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5559 */
  {
    "cadd90vnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90vnx2df3 },
    &operand_data[16079],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5559 */
  {
    "cadd270vnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270vnx2df3 },
    &operand_data[16079],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5834 */
  {
    "aarch64_pred_abdvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_abdvnx8hf },
    &operand_data[16745],
    5,
    5,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5834 */
  {
    "aarch64_pred_abdvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_abdvnx4sf },
    &operand_data[16750],
    5,
    5,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5834 */
  {
    "aarch64_pred_abdvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_abdvnx2df },
    &operand_data[16755],
    5,
    5,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5892 */
  {
    "aarch64_cond_abdvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_abdvnx8hf },
    &operand_data[16675],
    5,
    5,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5892 */
  {
    "aarch64_cond_abdvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_abdvnx4sf },
    &operand_data[16700],
    5,
    5,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:5892 */
  {
    "aarch64_cond_abdvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_cond_abdvnx2df },
    &operand_data[16725],
    5,
    5,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6162 */
  {
    "divvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divvnx8hf3 },
    &operand_data[16760],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6162 */
  {
    "divvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divvnx4sf3 },
    &operand_data[16763],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6162 */
  {
    "divvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_divvnx2df3 },
    &operand_data[16766],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6180 */
  {
    "aarch64_frecpevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpevnx8hf },
    &operand_data[16058],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6180 */
  {
    "aarch64_frecpevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpevnx4sf },
    &operand_data[16060],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6180 */
  {
    "aarch64_frecpevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpevnx2df },
    &operand_data[16062],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6188 */
  {
    "aarch64_frecpsvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsvnx8hf },
    &operand_data[16641],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6188 */
  {
    "aarch64_frecpsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsvnx4sf },
    &operand_data[16076],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6188 */
  {
    "aarch64_frecpsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_frecpsvnx2df },
    &operand_data[16079],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6225 */
  {
    "copysignvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignvnx8hf3 },
    &operand_data[16641],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6225 */
  {
    "copysignvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignvnx4sf3 },
    &operand_data[16076],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6225 */
  {
    "copysignvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_copysignvnx2df3 },
    &operand_data[16079],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6255 */
  {
    "xorsignvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignvnx8hf3 },
    &operand_data[16641],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6255 */
  {
    "xorsignvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignvnx4sf3 },
    &operand_data[16076],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6255 */
  {
    "xorsignvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorsignvnx2df3 },
    &operand_data[16079],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6291 */
  {
    "fmaxvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxvnx8hf3 },
    &operand_data[16635],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6291 */
  {
    "fminvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminvnx8hf3 },
    &operand_data[16635],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6291 */
  {
    "fmaxvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxvnx4sf3 },
    &operand_data[16649],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6291 */
  {
    "fminvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminvnx4sf3 },
    &operand_data[16649],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6291 */
  {
    "fmaxvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmaxvnx2df3 },
    &operand_data[16661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6291 */
  {
    "fminvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fminvnx2df3 },
    &operand_data[16661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6307 */
  {
    "cond_fmaxvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmaxvnx8hf },
    &operand_data[16680],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6307 */
  {
    "cond_fminvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fminvnx8hf },
    &operand_data[16680],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6307 */
  {
    "cond_fmaxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmaxvnx4sf },
    &operand_data[16705],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6307 */
  {
    "cond_fminvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fminvnx4sf },
    &operand_data[16705],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6307 */
  {
    "cond_fmaxvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmaxvnx2df },
    &operand_data[16730],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6307 */
  {
    "cond_fminvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fminvnx2df },
    &operand_data[16730],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "iorvnx16bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx16bi3 },
    &operand_data[16769],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "xorvnx16bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx16bi3 },
    &operand_data[16769],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "iorvnx8bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx8bi3 },
    &operand_data[16772],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "xorvnx8bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx8bi3 },
    &operand_data[16772],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "iorvnx4bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx4bi3 },
    &operand_data[16775],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "xorvnx4bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx4bi3 },
    &operand_data[16775],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "iorvnx2bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_iorvnx2bi3 },
    &operand_data[16778],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6367 */
  {
    "xorvnx2bi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_xorvnx2bi3 },
    &operand_data[16778],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx16qi4 },
    &operand_data[16781],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx8qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx8qi4 },
    &operand_data[16785],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx4qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx4qi4 },
    &operand_data[16789],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx2qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx2qi4 },
    &operand_data[16793],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx8hi4 },
    &operand_data[16797],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx4hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx4hi4 },
    &operand_data[16801],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx2hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx2hi4 },
    &operand_data[16805],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx4si4 },
    &operand_data[16809],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx2si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx2si4 },
    &operand_data[16813],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6571 */
  {
    "fmavnx2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx2di4 },
    &operand_data[16817],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx16qi },
    &operand_data[16821],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx8qi },
    &operand_data[16827],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx4qi },
    &operand_data[16833],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx2qi },
    &operand_data[16839],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx8hi },
    &operand_data[16845],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx4hi },
    &operand_data[16851],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx2hi },
    &operand_data[16857],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx4si },
    &operand_data[16863],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx2si },
    &operand_data[16869],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6609 */
  {
    "cond_fmavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx2di },
    &operand_data[16875],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx16qi4 },
    &operand_data[16881],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx8qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx8qi4 },
    &operand_data[16885],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx4qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx4qi4 },
    &operand_data[16889],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx2qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx2qi4 },
    &operand_data[16893],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx8hi4 },
    &operand_data[16897],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx4hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx4hi4 },
    &operand_data[16901],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx2hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx2hi4 },
    &operand_data[16905],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx4si4 },
    &operand_data[16909],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx2si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx2si4 },
    &operand_data[16913],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6712 */
  {
    "fnmavnx2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx2di4 },
    &operand_data[16917],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx16qi },
    &operand_data[16821],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx8qi },
    &operand_data[16827],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx4qi },
    &operand_data[16833],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx2qi },
    &operand_data[16839],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx8hi },
    &operand_data[16845],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx4hi },
    &operand_data[16851],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx2hi },
    &operand_data[16857],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx4si },
    &operand_data[16863],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx2si },
    &operand_data[16869],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6750 */
  {
    "cond_fnmavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx2di },
    &operand_data[16875],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6938 */
  {
    "ssadvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ssadvnx16qi },
    &operand_data[16921],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6938 */
  {
    "usadvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usadvnx16qi },
    &operand_data[16921],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6938 */
  {
    "ssadvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_ssadvnx8hi },
    &operand_data[16925],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6938 */
  {
    "usadvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_usadvnx8hi },
    &operand_data[16925],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fmavnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx8hf4 },
    &operand_data[16929],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fnmavnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx8hf4 },
    &operand_data[16929],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fnmsvnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmsvnx8hf4 },
    &operand_data[16929],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fmsvnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmsvnx8hf4 },
    &operand_data[16929],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fmavnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx4sf4 },
    &operand_data[16933],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fnmavnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx4sf4 },
    &operand_data[16933],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fnmsvnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmsvnx4sf4 },
    &operand_data[16933],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fmsvnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmsvnx4sf4 },
    &operand_data[16933],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fmavnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmavnx2df4 },
    &operand_data[16937],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fnmavnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmavnx2df4 },
    &operand_data[16937],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fnmsvnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fnmsvnx2df4 },
    &operand_data[16937],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:6992 */
  {
    "fmsvnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fmsvnx2df4 },
    &operand_data[16937],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fmavnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fnmavnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fnmsvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmsvnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fmsvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmsvnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fmavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fnmavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fnmsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmsvnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fmsvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmsvnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fmavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmavnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fnmavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmavnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fnmsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fnmsvnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7026 */
  {
    "cond_fmsvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fmsvnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmlavnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlavnx8hf4 },
    &operand_data[16929],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmlsvnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsvnx8hf4 },
    &operand_data[16929],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmla_conjvnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjvnx8hf4 },
    &operand_data[16929],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmls_conjvnx8hf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjvnx8hf4 },
    &operand_data[16929],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmlavnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlavnx4sf4 },
    &operand_data[16933],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmlsvnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsvnx4sf4 },
    &operand_data[16933],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmla_conjvnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjvnx4sf4 },
    &operand_data[16933],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmls_conjvnx4sf4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjvnx4sf4 },
    &operand_data[16933],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmlavnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlavnx2df4 },
    &operand_data[16937],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmlsvnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsvnx2df4 },
    &operand_data[16937],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmla_conjvnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjvnx2df4 },
    &operand_data[16937],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7265 */
  {
    "cmls_conjvnx2df4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjvnx2df4 },
    &operand_data[16937],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7294 */
  {
    "cmulvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulvnx8hf3 },
    &operand_data[16641],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7294 */
  {
    "cmul_conjvnx8hf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjvnx8hf3 },
    &operand_data[16641],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7294 */
  {
    "cmulvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulvnx4sf3 },
    &operand_data[16076],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7294 */
  {
    "cmul_conjvnx4sf3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjvnx4sf3 },
    &operand_data[16076],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7294 */
  {
    "cmulvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulvnx2df3 },
    &operand_data[16079],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7294 */
  {
    "cmul_conjvnx2df3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjvnx2df3 },
    &operand_data[16079],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmlavnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmlavnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla90vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla90vnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla180vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla180vnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla270vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla270vnx8hf },
    &operand_data[16941],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmlavnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmlavnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla90vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla90vnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla180vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla180vnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla270vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla270vnx4sf },
    &operand_data[16947],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmlavnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmlavnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla90vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla90vnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla180vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla180vnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7318 */
  {
    "cond_fcmla270vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcmla270vnx2df },
    &operand_data[16953],
    6,
    6,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx16qivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx16qivnx16bi },
    &operand_data[16959],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx8qivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx8qivnx8bi },
    &operand_data[16963],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx4qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx4qivnx4bi },
    &operand_data[16967],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2qivnx2bi },
    &operand_data[16971],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx8hivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx8hivnx8bi },
    &operand_data[16975],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx4hivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx4hivnx4bi },
    &operand_data[16979],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2hivnx2bi },
    &operand_data[16983],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx8hfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx8hfvnx8bi },
    &operand_data[16987],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx4hfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx4hfvnx4bi },
    &operand_data[16991],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2hfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2hfvnx2bi },
    &operand_data[16995],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx8bfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx8bfvnx8bi },
    &operand_data[16999],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx4bfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx4bfvnx4bi },
    &operand_data[17003],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2bfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2bfvnx2bi },
    &operand_data[17007],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx4sivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx4sivnx4bi },
    &operand_data[17011],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2sivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2sivnx2bi },
    &operand_data[17015],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx4sfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx4sfvnx4bi },
    &operand_data[17019],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2sfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2sfvnx2bi },
    &operand_data[17023],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2divnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2divnx2bi },
    &operand_data[17027],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7564 */
  {
    "vcond_mask_vnx2dfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcond_mask_vnx2dfvnx2bi },
    &operand_data[17031],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx16qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx16qivnx16qi },
    &operand_data[17035],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8qivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8qivnx8qi },
    &operand_data[17041],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8hivnx8qi },
    &operand_data[17047],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8hfvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8hfvnx8qi },
    &operand_data[17053],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8bfvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8bfvnx8qi },
    &operand_data[17059],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4qivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4qivnx4qi },
    &operand_data[17065],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4hivnx4qi },
    &operand_data[17071],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4hfvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4hfvnx4qi },
    &operand_data[17077],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4bfvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4bfvnx4qi },
    &operand_data[17083],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sivnx4qi },
    &operand_data[17089],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4sfvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sfvnx4qi },
    &operand_data[17095],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2qivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2qivnx2qi },
    &operand_data[17101],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hivnx2qi },
    &operand_data[17107],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hfvnx2qi },
    &operand_data[17113],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2bfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2bfvnx2qi },
    &operand_data[17119],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sivnx2qi },
    &operand_data[17125],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sfvnx2qi },
    &operand_data[17131],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2divnx2qi },
    &operand_data[17137],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2dfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2dfvnx2qi },
    &operand_data[17143],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8qivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8qivnx8hi },
    &operand_data[17149],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8hivnx8hi },
    &operand_data[17153],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8hfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8hfvnx8hi },
    &operand_data[17159],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx8bfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8bfvnx8hi },
    &operand_data[17165],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4qivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4qivnx4hi },
    &operand_data[17171],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4hivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4hivnx4hi },
    &operand_data[17175],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4hfvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4hfvnx4hi },
    &operand_data[17181],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4bfvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4bfvnx4hi },
    &operand_data[17187],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sivnx4hi },
    &operand_data[17193],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4sfvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sfvnx4hi },
    &operand_data[17199],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2qivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2qivnx2hi },
    &operand_data[17205],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hivnx2hi },
    &operand_data[17209],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hfvnx2hi },
    &operand_data[17215],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2bfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2bfvnx2hi },
    &operand_data[17221],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sivnx2hi },
    &operand_data[17227],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sfvnx2hi },
    &operand_data[17233],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2divnx2hi },
    &operand_data[17239],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2dfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2dfvnx2hi },
    &operand_data[17245],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4qivnx4si },
    &operand_data[17251],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4hivnx4si },
    &operand_data[17257],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4hfvnx4si },
    &operand_data[17263],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4bfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4bfvnx4si },
    &operand_data[17269],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sivnx4si },
    &operand_data[17273],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sfvnx4si },
    &operand_data[17279],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2qivnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2qivnx2si },
    &operand_data[17285],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hivnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hivnx2si },
    &operand_data[17291],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hfvnx2si },
    &operand_data[17297],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2bfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2bfvnx2si },
    &operand_data[17303],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sivnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sivnx2si },
    &operand_data[17307],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sfvnx2si },
    &operand_data[17313],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2divnx2si },
    &operand_data[17319],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2dfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2dfvnx2si },
    &operand_data[17325],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2qivnx2di },
    &operand_data[17331],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hivnx2di },
    &operand_data[17337],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2hfvnx2di },
    &operand_data[17343],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2bfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2bfvnx2di },
    &operand_data[17349],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sivnx2di },
    &operand_data[17355],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2sfvnx2di },
    &operand_data[17361],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2divnx2di },
    &operand_data[17365],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7647 */
  {
    "vcondvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2dfvnx2di },
    &operand_data[17371],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx16qivnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx16qivnx16qi },
    &operand_data[17035],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8qivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8qivnx8qi },
    &operand_data[17041],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8hivnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8hivnx8qi },
    &operand_data[17047],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8hfvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8hfvnx8qi },
    &operand_data[17053],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8bfvnx8qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8bfvnx8qi },
    &operand_data[17059],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4qivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4qivnx4qi },
    &operand_data[17065],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4hivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4hivnx4qi },
    &operand_data[17071],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4hfvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4hfvnx4qi },
    &operand_data[17077],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4bfvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4bfvnx4qi },
    &operand_data[17083],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4sivnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4sivnx4qi },
    &operand_data[17089],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4sfvnx4qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4sfvnx4qi },
    &operand_data[17095],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2qivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2qivnx2qi },
    &operand_data[17101],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hivnx2qi },
    &operand_data[17107],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hfvnx2qi },
    &operand_data[17113],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2bfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2bfvnx2qi },
    &operand_data[17119],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sivnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sivnx2qi },
    &operand_data[17125],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sfvnx2qi },
    &operand_data[17131],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2divnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2divnx2qi },
    &operand_data[17137],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2dfvnx2qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2dfvnx2qi },
    &operand_data[17143],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8qivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8qivnx8hi },
    &operand_data[17149],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8hivnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8hivnx8hi },
    &operand_data[17153],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8hfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8hfvnx8hi },
    &operand_data[17159],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx8bfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx8bfvnx8hi },
    &operand_data[17165],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4qivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4qivnx4hi },
    &operand_data[17171],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4hivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4hivnx4hi },
    &operand_data[17175],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4hfvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4hfvnx4hi },
    &operand_data[17181],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4bfvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4bfvnx4hi },
    &operand_data[17187],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4sivnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4sivnx4hi },
    &operand_data[17193],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4sfvnx4hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4sfvnx4hi },
    &operand_data[17199],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2qivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2qivnx2hi },
    &operand_data[17205],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hivnx2hi },
    &operand_data[17209],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hfvnx2hi },
    &operand_data[17215],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2bfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2bfvnx2hi },
    &operand_data[17221],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sivnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sivnx2hi },
    &operand_data[17227],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sfvnx2hi },
    &operand_data[17233],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2divnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2divnx2hi },
    &operand_data[17239],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2dfvnx2hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2dfvnx2hi },
    &operand_data[17245],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4qivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4qivnx4si },
    &operand_data[17251],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4hivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4hivnx4si },
    &operand_data[17257],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4hfvnx4si },
    &operand_data[17263],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4bfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4bfvnx4si },
    &operand_data[17269],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4sivnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4sivnx4si },
    &operand_data[17273],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx4sfvnx4si },
    &operand_data[17279],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2qivnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2qivnx2si },
    &operand_data[17285],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hivnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hivnx2si },
    &operand_data[17291],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hfvnx2si },
    &operand_data[17297],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2bfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2bfvnx2si },
    &operand_data[17303],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sivnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sivnx2si },
    &operand_data[17307],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sfvnx2si },
    &operand_data[17313],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2divnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2divnx2si },
    &operand_data[17319],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2dfvnx2si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2dfvnx2si },
    &operand_data[17325],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2qivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2qivnx2di },
    &operand_data[17331],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hivnx2di },
    &operand_data[17337],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2hfvnx2di },
    &operand_data[17343],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2bfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2bfvnx2di },
    &operand_data[17349],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sivnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sivnx2di },
    &operand_data[17355],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2sfvnx2di },
    &operand_data[17361],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2divnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2divnx2di },
    &operand_data[17365],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7664 */
  {
    "vconduvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vconduvnx2dfvnx2di },
    &operand_data[17371],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7681 */
  {
    "vcondvnx8hivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8hivnx8hf },
    &operand_data[17377],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7681 */
  {
    "vcondvnx4sivnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sivnx4sf },
    &operand_data[17383],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7681 */
  {
    "vcondvnx2divnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2divnx2df },
    &operand_data[17389],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7681 */
  {
    "vcondvnx8bfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8bfvnx8hf },
    &operand_data[17395],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7681 */
  {
    "vcondvnx8hfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx8hfvnx8hf },
    &operand_data[17401],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7681 */
  {
    "vcondvnx4sfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx4sfvnx4sf },
    &operand_data[17407],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7681 */
  {
    "vcondvnx2dfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vcondvnx2dfvnx2df },
    &operand_data[17413],
    6,
    6,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx16qivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx16qivnx16bi },
    &operand_data[17419],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx8qivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx8qivnx8bi },
    &operand_data[17423],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx4qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx4qivnx4bi },
    &operand_data[17427],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx2qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx2qivnx2bi },
    &operand_data[17431],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx8hivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx8hivnx8bi },
    &operand_data[17435],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx4hivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx4hivnx4bi },
    &operand_data[17439],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx2hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx2hivnx2bi },
    &operand_data[17443],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx4sivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx4sivnx4bi },
    &operand_data[17447],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx2sivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx2sivnx2bi },
    &operand_data[17451],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7715 */
  {
    "vec_cmpvnx2divnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx2divnx2bi },
    &operand_data[17455],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx16qivnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx16qivnx16bi },
    &operand_data[17419],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx8qivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx8qivnx8bi },
    &operand_data[17423],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx4qivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx4qivnx4bi },
    &operand_data[17427],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx2qivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx2qivnx2bi },
    &operand_data[17431],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx8hivnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx8hivnx8bi },
    &operand_data[17435],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx4hivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx4hivnx4bi },
    &operand_data[17439],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx2hivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx2hivnx2bi },
    &operand_data[17443],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx4sivnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx4sivnx4bi },
    &operand_data[17447],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx2sivnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx2sivnx2bi },
    &operand_data[17451],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:7733 */
  {
    "vec_cmpuvnx2divnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpuvnx2divnx2bi },
    &operand_data[17455],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8052 */
  {
    "vec_cmpvnx8hfvnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx8hfvnx8bi },
    &operand_data[17459],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8052 */
  {
    "vec_cmpvnx4sfvnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx4sfvnx4bi },
    &operand_data[17463],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8052 */
  {
    "vec_cmpvnx2dfvnx2bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_cmpvnx2dfvnx2bi },
    &operand_data[17467],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facgevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facgevnx8hf },
    &operand_data[17471],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facgtvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facgtvnx8hf },
    &operand_data[17471],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_faclevnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_faclevnx8hf },
    &operand_data[17471],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facltvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facltvnx8hf },
    &operand_data[17471],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facgevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facgevnx4sf },
    &operand_data[17476],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facgtvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facgtvnx4sf },
    &operand_data[17476],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_faclevnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_faclevnx4sf },
    &operand_data[17476],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facltvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facltvnx4sf },
    &operand_data[17476],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facgevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facgevnx2df },
    &operand_data[17481],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facgtvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facgtvnx2df },
    &operand_data[17481],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_faclevnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_faclevnx2df },
    &operand_data[17481],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8311 */
  {
    "aarch64_pred_facltvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_pred_facltvnx2df },
    &operand_data[17481],
    5,
    5,
    4,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8404 */
  {
    "cbranchvnx16bi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchvnx16bi4 },
    &operand_data[17486],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8404 */
  {
    "cbranchvnx8bi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchvnx8bi4 },
    &operand_data[17490],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8404 */
  {
    "cbranchvnx4bi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchvnx4bi4 },
    &operand_data[17494],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8404 */
  {
    "cbranchvnx2bi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cbranchvnx2bi4 },
    &operand_data[17498],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8500 */
  {
    "reduc_plus_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8500 */
  {
    "reduc_plus_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8500 */
  {
    "reduc_plus_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8500 */
  {
    "reduc_plus_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_and_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_and_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_ior_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_ior_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smax_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smin_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umax_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umin_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_xor_scal_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_xor_scal_vnx16qi },
    &operand_data[15926],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_and_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_and_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_ior_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_ior_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smax_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smin_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umax_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umin_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_xor_scal_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_xor_scal_vnx8hi },
    &operand_data[15929],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_and_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_and_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_ior_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_ior_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smax_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smin_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umax_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umin_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_xor_scal_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_xor_scal_vnx4si },
    &operand_data[15932],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_and_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_and_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_ior_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_ior_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smax_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_smin_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umax_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umax_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_umin_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_umin_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8525 */
  {
    "reduc_xor_scal_vnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_xor_scal_vnx2di },
    &operand_data[15935],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_plus_scal_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_vnx8hf },
    &operand_data[15941],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smax_nan_scal_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_vnx8hf },
    &operand_data[15941],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smax_scal_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_vnx8hf },
    &operand_data[15941],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smin_nan_scal_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_vnx8hf },
    &operand_data[15941],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smin_scal_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_vnx8hf },
    &operand_data[15941],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_plus_scal_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_vnx4sf },
    &operand_data[15944],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smax_nan_scal_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_vnx4sf },
    &operand_data[15944],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smax_scal_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_vnx4sf },
    &operand_data[15944],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smin_nan_scal_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_vnx4sf },
    &operand_data[15944],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smin_scal_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_vnx4sf },
    &operand_data[15944],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_plus_scal_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_plus_scal_vnx2df },
    &operand_data[15947],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smax_nan_scal_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_nan_scal_vnx2df },
    &operand_data[15947],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smax_scal_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smax_scal_vnx2df },
    &operand_data[15947],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smin_nan_scal_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_nan_scal_vnx2df },
    &operand_data[15947],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8558 */
  {
    "reduc_smin_scal_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_smin_scal_vnx2df },
    &operand_data[15947],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8569 */
  {
    "reduc_fmax_scal_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_vnx8hf },
    &operand_data[15941],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8569 */
  {
    "reduc_fmin_scal_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_vnx8hf },
    &operand_data[15941],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8569 */
  {
    "reduc_fmax_scal_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_vnx4sf },
    &operand_data[15944],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8569 */
  {
    "reduc_fmin_scal_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_vnx4sf },
    &operand_data[15944],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8569 */
  {
    "reduc_fmax_scal_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmax_scal_vnx2df },
    &operand_data[15947],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8569 */
  {
    "reduc_fmin_scal_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_reduc_fmin_scal_vnx2df },
    &operand_data[15947],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8598 */
  {
    "fold_left_plus_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_left_plus_vnx8hf },
    &operand_data[17502],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8598 */
  {
    "fold_left_plus_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_left_plus_vnx4sf },
    &operand_data[17505],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8598 */
  {
    "fold_left_plus_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fold_left_plus_vnx2df },
    &operand_data[17508],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx16qi },
    &operand_data[17511],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx8hi },
    &operand_data[17515],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx4si },
    &operand_data[17519],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx2di },
    &operand_data[17523],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx8bf },
    &operand_data[17527],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx8hf },
    &operand_data[17531],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx4sf },
    &operand_data[17535],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8632 */
  {
    "vec_permvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_permvnx2df },
    &operand_data[17539],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacks_hi_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx16qi },
    &operand_data[17543],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacku_hi_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_vnx16qi },
    &operand_data[17543],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacks_lo_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx16qi },
    &operand_data[17543],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacku_lo_vnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_vnx16qi },
    &operand_data[17543],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacks_hi_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx8hi },
    &operand_data[17545],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacku_hi_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_vnx8hi },
    &operand_data[17545],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacks_lo_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx8hi },
    &operand_data[17545],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacku_lo_vnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_vnx8hi },
    &operand_data[17545],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacks_hi_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx4si },
    &operand_data[16920],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacku_hi_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_vnx4si },
    &operand_data[16920],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacks_lo_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx4si },
    &operand_data[16920],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8892 */
  {
    "vec_unpacku_lo_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_vnx4si },
    &operand_data[16920],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8925 */
  {
    "fix_truncvnx8hfvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncvnx8hfvnx8hi2 },
    &operand_data[17546],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8925 */
  {
    "fixuns_truncvnx8hfvnx8hi2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncvnx8hfvnx8hi2 },
    &operand_data[17546],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8925 */
  {
    "fix_truncvnx4sfvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncvnx4sfvnx4si2 },
    &operand_data[17548],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8925 */
  {
    "fixuns_truncvnx4sfvnx4si2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncvnx4sfvnx4si2 },
    &operand_data[17548],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8925 */
  {
    "fix_truncvnx2dfvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fix_truncvnx2dfvnx2di2 },
    &operand_data[17550],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8925 */
  {
    "fixuns_truncvnx2dfvnx2di2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_fixuns_truncvnx2dfvnx2di2 },
    &operand_data[17550],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fix_trunc_nontruncvnx8hfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fix_trunc_nontruncvnx8hfvnx8hi },
    &operand_data[17552],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fixuns_trunc_nontruncvnx8hfvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fixuns_trunc_nontruncvnx8hfvnx8hi },
    &operand_data[17552],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fix_trunc_nontruncvnx8hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fix_trunc_nontruncvnx8hfvnx4si },
    &operand_data[17556],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fixuns_trunc_nontruncvnx8hfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fixuns_trunc_nontruncvnx8hfvnx4si },
    &operand_data[17556],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fix_trunc_nontruncvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fix_trunc_nontruncvnx4sfvnx4si },
    &operand_data[17560],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fixuns_trunc_nontruncvnx4sfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fixuns_trunc_nontruncvnx4sfvnx4si },
    &operand_data[17560],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fix_trunc_nontruncvnx8hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fix_trunc_nontruncvnx8hfvnx2di },
    &operand_data[17564],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fixuns_trunc_nontruncvnx8hfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fixuns_trunc_nontruncvnx8hfvnx2di },
    &operand_data[17564],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fix_trunc_nontruncvnx4sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fix_trunc_nontruncvnx4sfvnx2di },
    &operand_data[17568],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fixuns_trunc_nontruncvnx4sfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fixuns_trunc_nontruncvnx4sfvnx2di },
    &operand_data[17568],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fix_trunc_nontruncvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fix_trunc_nontruncvnx2dfvnx2di },
    &operand_data[17572],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:8970 */
  {
    "cond_fixuns_trunc_nontruncvnx2dfvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fixuns_trunc_nontruncvnx2dfvnx2di },
    &operand_data[17572],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9032 */
  {
    "cond_fix_trunc_truncvnx2dfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fix_trunc_truncvnx2dfvnx4si },
    &operand_data[17576],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9032 */
  {
    "cond_fixuns_trunc_truncvnx2dfvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fixuns_trunc_truncvnx2dfvnx4si },
    &operand_data[17576],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9072 */
  {
    "vec_pack_sfix_trunc_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_sfix_trunc_vnx2df },
    &operand_data[17580],
    3,
    3,
    6,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9072 */
  {
    "vec_pack_ufix_trunc_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_ufix_trunc_vnx2df },
    &operand_data[17580],
    3,
    3,
    6,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9111 */
  {
    "floatvnx8hivnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatvnx8hivnx8hf2 },
    &operand_data[16619],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9111 */
  {
    "floatunsvnx8hivnx8hf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsvnx8hivnx8hf2 },
    &operand_data[16619],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9111 */
  {
    "floatvnx4sivnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatvnx4sivnx4sf2 },
    &operand_data[16624],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9111 */
  {
    "floatunsvnx4sivnx4sf2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsvnx4sivnx4sf2 },
    &operand_data[16624],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9111 */
  {
    "floatvnx2divnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatvnx2divnx2df2 },
    &operand_data[16629],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9111 */
  {
    "floatunsvnx2divnx2df2",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_floatunsvnx2divnx2df2 },
    &operand_data[16629],
    2,
    2,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_float_nonextendvnx8hivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_float_nonextendvnx8hivnx8hf },
    &operand_data[17583],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_floatuns_nonextendvnx8hivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floatuns_nonextendvnx8hivnx8hf },
    &operand_data[17583],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_float_nonextendvnx4sivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_float_nonextendvnx4sivnx8hf },
    &operand_data[17587],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_floatuns_nonextendvnx4sivnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floatuns_nonextendvnx4sivnx8hf },
    &operand_data[17587],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_float_nonextendvnx4sivnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_float_nonextendvnx4sivnx4sf },
    &operand_data[17591],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_floatuns_nonextendvnx4sivnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floatuns_nonextendvnx4sivnx4sf },
    &operand_data[17591],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_float_nonextendvnx2divnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_float_nonextendvnx2divnx8hf },
    &operand_data[17595],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_floatuns_nonextendvnx2divnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floatuns_nonextendvnx2divnx8hf },
    &operand_data[17595],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_float_nonextendvnx2divnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_float_nonextendvnx2divnx4sf },
    &operand_data[17599],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_floatuns_nonextendvnx2divnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floatuns_nonextendvnx2divnx4sf },
    &operand_data[17599],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_float_nonextendvnx2divnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_float_nonextendvnx2divnx2df },
    &operand_data[17603],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9157 */
  {
    "cond_floatuns_nonextendvnx2divnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floatuns_nonextendvnx2divnx2df },
    &operand_data[17603],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9219 */
  {
    "cond_float_extendvnx4sivnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_float_extendvnx4sivnx2df },
    &operand_data[17607],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9219 */
  {
    "cond_floatuns_extendvnx4sivnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_floatuns_extendvnx4sivnx2df },
    &operand_data[17607],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9267 */
  {
    "vec_unpacks_float_lo_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_float_lo_vnx4si },
    &operand_data[17611],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9267 */
  {
    "vec_unpacks_float_hi_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_float_hi_vnx4si },
    &operand_data[17611],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9267 */
  {
    "vec_unpacku_float_lo_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_float_lo_vnx4si },
    &operand_data[17611],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9267 */
  {
    "vec_unpacku_float_hi_vnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_float_hi_vnx4si },
    &operand_data[17611],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9300 */
  {
    "vec_pack_trunc_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx4sf },
    &operand_data[16059],
    3,
    3,
    6,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9300 */
  {
    "vec_pack_trunc_vnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_pack_trunc_vnx2df },
    &operand_data[16061],
    3,
    3,
    6,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9339 */
  {
    "cond_fcvt_truncvnx4sfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvt_truncvnx4sfvnx8hf },
    &operand_data[17613],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9339 */
  {
    "cond_fcvt_truncvnx2dfvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvt_truncvnx2dfvnx8hf },
    &operand_data[17617],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9339 */
  {
    "cond_fcvt_truncvnx2dfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvt_truncvnx2dfvnx4sf },
    &operand_data[17621],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9396 */
  {
    "cond_fcvt_truncvnx4sfvnx8bf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvt_truncvnx4sfvnx8bf },
    &operand_data[17625],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9456 */
  {
    "vec_unpacks_lo_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx8hf },
    &operand_data[17629],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9456 */
  {
    "vec_unpacks_hi_vnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx8hf },
    &operand_data[17629],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9456 */
  {
    "vec_unpacks_lo_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx4sf },
    &operand_data[17631],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9456 */
  {
    "vec_unpacks_hi_vnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx4sf },
    &operand_data[17631],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9496 */
  {
    "cond_fcvt_nontruncvnx8hfvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvt_nontruncvnx8hfvnx4sf },
    &operand_data[17632],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9496 */
  {
    "cond_fcvt_nontruncvnx8hfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvt_nontruncvnx8hfvnx2df },
    &operand_data[17636],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9496 */
  {
    "cond_fcvt_nontruncvnx4sfvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvt_nontruncvnx4sfvnx2df },
    &operand_data[17640],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacks_hi_vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx16bi },
    &operand_data[17644],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacku_hi_vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_vnx16bi },
    &operand_data[17644],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacks_lo_vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx16bi },
    &operand_data[17644],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacku_lo_vnx16bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_vnx16bi },
    &operand_data[17644],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacks_hi_vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx8bi },
    &operand_data[17646],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacku_hi_vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_vnx8bi },
    &operand_data[17646],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacks_lo_vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx8bi },
    &operand_data[17646],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacku_lo_vnx8bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_vnx8bi },
    &operand_data[17646],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacks_hi_vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_hi_vnx4bi },
    &operand_data[17648],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacku_hi_vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_hi_vnx4bi },
    &operand_data[17648],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacks_lo_vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacks_lo_vnx4bi },
    &operand_data[17648],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9559 */
  {
    "vec_unpacku_lo_vnx4bi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_vec_unpacku_lo_vnx4bi },
    &operand_data[17648],
    2,
    2,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9945 */
  {
    "aarch64_sve_incvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incvnx8hi_pat },
    &operand_data[17650],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9945 */
  {
    "aarch64_sve_sqincvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincvnx8hi_pat },
    &operand_data[17650],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:9945 */
  {
    "aarch64_sve_uqincvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincvnx8hi_pat },
    &operand_data[17650],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10095 */
  {
    "aarch64_sve_decvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decvnx8hi_pat },
    &operand_data[17650],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10095 */
  {
    "aarch64_sve_sqdecvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecvnx8hi_pat },
    &operand_data[17650],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10095 */
  {
    "aarch64_sve_uqdecvnx8hi_pat",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecvnx8hi_pat },
    &operand_data[17650],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_incdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incdivnx16bi_cntp },
    &operand_data[17655],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_sqincdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincdivnx16bi_cntp },
    &operand_data[17655],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_uqincdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincdivnx16bi_cntp },
    &operand_data[17655],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_incdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incdivnx8bi_cntp },
    &operand_data[17658],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_sqincdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincdivnx8bi_cntp },
    &operand_data[17658],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_uqincdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincdivnx8bi_cntp },
    &operand_data[17658],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_incdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incdivnx4bi_cntp },
    &operand_data[17661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_sqincdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincdivnx4bi_cntp },
    &operand_data[17661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_uqincdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincdivnx4bi_cntp },
    &operand_data[17661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_incdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incdivnx2bi_cntp },
    &operand_data[17664],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_sqincdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincdivnx2bi_cntp },
    &operand_data[17664],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10158 */
  {
    "aarch64_sve_uqincdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincdivnx2bi_cntp },
    &operand_data[17664],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_sqincsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincsivnx16bi_cntp },
    &operand_data[17667],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_uqincsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincsivnx16bi_cntp },
    &operand_data[17667],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_sqincsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincsivnx8bi_cntp },
    &operand_data[17670],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_uqincsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincsivnx8bi_cntp },
    &operand_data[17670],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_sqincsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincsivnx4bi_cntp },
    &operand_data[17673],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_uqincsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincsivnx4bi_cntp },
    &operand_data[17673],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_sqincsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincsivnx2bi_cntp },
    &operand_data[17676],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10213 */
  {
    "aarch64_sve_uqincsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincsivnx2bi_cntp },
    &operand_data[17676],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10261 */
  {
    "aarch64_sve_incvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incvnx2di_cntp },
    &operand_data[17679],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10261 */
  {
    "aarch64_sve_sqincvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincvnx2di_cntp },
    &operand_data[17679],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10261 */
  {
    "aarch64_sve_uqincvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincvnx2di_cntp },
    &operand_data[17679],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10302 */
  {
    "aarch64_sve_incvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incvnx4si_cntp },
    &operand_data[17682],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10302 */
  {
    "aarch64_sve_sqincvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincvnx4si_cntp },
    &operand_data[17682],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10302 */
  {
    "aarch64_sve_uqincvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincvnx4si_cntp },
    &operand_data[17682],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10341 */
  {
    "aarch64_sve_incvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_incvnx8hi_cntp },
    &operand_data[17685],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10341 */
  {
    "aarch64_sve_sqincvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqincvnx8hi_cntp },
    &operand_data[17685],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10341 */
  {
    "aarch64_sve_uqincvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqincvnx8hi_cntp },
    &operand_data[17685],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_decdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decdivnx16bi_cntp },
    &operand_data[17655],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_sqdecdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecdivnx16bi_cntp },
    &operand_data[17655],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_uqdecdivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecdivnx16bi_cntp },
    &operand_data[17655],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_decdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decdivnx8bi_cntp },
    &operand_data[17658],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_sqdecdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecdivnx8bi_cntp },
    &operand_data[17658],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_uqdecdivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecdivnx8bi_cntp },
    &operand_data[17658],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_decdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decdivnx4bi_cntp },
    &operand_data[17661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_sqdecdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecdivnx4bi_cntp },
    &operand_data[17661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_uqdecdivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecdivnx4bi_cntp },
    &operand_data[17661],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_decdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decdivnx2bi_cntp },
    &operand_data[17664],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_sqdecdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecdivnx2bi_cntp },
    &operand_data[17664],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10391 */
  {
    "aarch64_sve_uqdecdivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecdivnx2bi_cntp },
    &operand_data[17664],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_sqdecsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecsivnx16bi_cntp },
    &operand_data[17667],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_uqdecsivnx16bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecsivnx16bi_cntp },
    &operand_data[17667],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_sqdecsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecsivnx8bi_cntp },
    &operand_data[17670],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_uqdecsivnx8bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecsivnx8bi_cntp },
    &operand_data[17670],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_sqdecsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecsivnx4bi_cntp },
    &operand_data[17673],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_uqdecsivnx4bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecsivnx4bi_cntp },
    &operand_data[17673],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_sqdecsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecsivnx2bi_cntp },
    &operand_data[17676],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10446 */
  {
    "aarch64_sve_uqdecsivnx2bi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecsivnx2bi_cntp },
    &operand_data[17676],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10494 */
  {
    "aarch64_sve_decvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decvnx2di_cntp },
    &operand_data[17679],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10494 */
  {
    "aarch64_sve_sqdecvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecvnx2di_cntp },
    &operand_data[17679],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10494 */
  {
    "aarch64_sve_uqdecvnx2di_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecvnx2di_cntp },
    &operand_data[17679],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10535 */
  {
    "aarch64_sve_decvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decvnx4si_cntp },
    &operand_data[17682],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10535 */
  {
    "aarch64_sve_sqdecvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecvnx4si_cntp },
    &operand_data[17682],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10535 */
  {
    "aarch64_sve_uqdecvnx4si_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecvnx4si_cntp },
    &operand_data[17682],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10574 */
  {
    "aarch64_sve_decvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_decvnx8hi_cntp },
    &operand_data[17685],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10574 */
  {
    "aarch64_sve_sqdecvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_sqdecvnx8hi_cntp },
    &operand_data[17685],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve.md:10574 */
  {
    "aarch64_sve_uqdecvnx8hi_cntp",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_uqdecvnx8hi_cntp },
    &operand_data[17685],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "smulhsvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulhsvnx16qi3 },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "umulhsvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulhsvnx16qi3 },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "smulhrsvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulhrsvnx16qi3 },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "umulhrsvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulhrsvnx16qi3 },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "smulhsvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulhsvnx8hi3 },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "umulhsvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulhsvnx8hi3 },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "smulhrsvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulhrsvnx8hi3 },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "umulhrsvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulhrsvnx8hi3 },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "smulhsvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulhsvnx4si3 },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "umulhsvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulhsvnx4si3 },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "smulhrsvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_smulhrsvnx4si3 },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:215 */
  {
    "umulhrsvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_umulhrsvnx4si3 },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "avgvnx16qi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx16qi3_floor },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "uavgvnx16qi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx16qi3_floor },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "avgvnx8hi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx8hi3_floor },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "uavgvnx8hi3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx8hi3_floor },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "avgvnx4si3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx4si3_floor },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "uavgvnx4si3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx4si3_floor },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "avgvnx2di3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx2di3_floor },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:269 */
  {
    "uavgvnx2di3_floor",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx2di3_floor },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "avgvnx16qi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx16qi3_ceil },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "uavgvnx16qi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx16qi3_ceil },
    &operand_data[16358],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "avgvnx8hi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx8hi3_ceil },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "uavgvnx8hi3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx8hi3_ceil },
    &operand_data[16370],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "avgvnx4si3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx4si3_ceil },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "uavgvnx4si3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx4si3_ceil },
    &operand_data[16350],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "avgvnx2di3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_avgvnx2di3_ceil },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:285 */
  {
    "uavgvnx2di3_ceil",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_uavgvnx2di3_ceil },
    &operand_data[16354],
    3,
    3,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shsubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shsubvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_sqrshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqrshlvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srhaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srhaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshlvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_suqaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_suqaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhsubvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhsubvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uqrshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqrshlvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urhaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urhaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshlvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_usqaddvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usqaddvnx16qi },
    &operand_data[16150],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shsubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shsubvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_sqrshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqrshlvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srhaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srhaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshlvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_suqaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_suqaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhsubvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhsubvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uqrshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqrshlvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urhaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urhaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshlvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_usqaddvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usqaddvnx8hi },
    &operand_data[16230],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shaddvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shsubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shsubvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_sqrshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqrshlvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srhaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srhaddvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshlvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_suqaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_suqaddvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhaddvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhsubvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhsubvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uqrshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqrshlvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urhaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urhaddvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshlvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_usqaddvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usqaddvnx4si },
    &operand_data[16290],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shaddvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_shsubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_shsubvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_sqrshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqrshlvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srhaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srhaddvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_srshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_srshlvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_suqaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_suqaddvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhaddvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uhsubvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uhsubvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_uqrshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqrshlvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urhaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urhaddvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_urshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urshlvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:348 */
  {
    "cond_usqaddvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_usqaddvnx2di },
    &operand_data[16330],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_sqshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshlvnx16qi },
    &operand_data[17688],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_uqshlvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqshlvnx16qi },
    &operand_data[17688],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_sqshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshlvnx8hi },
    &operand_data[17693],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_uqshlvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqshlvnx8hi },
    &operand_data[17693],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_sqshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshlvnx4si },
    &operand_data[17698],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_uqshlvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqshlvnx4si },
    &operand_data[17698],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_sqshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sqshlvnx2di },
    &operand_data[17703],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:548 */
  {
    "cond_uqshlvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uqshlvnx2di },
    &operand_data[17703],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:789 */
  {
    "aarch64_sve2_bcaxvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bcaxvnx16qi },
    &operand_data[17708],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:789 */
  {
    "aarch64_sve2_bcaxvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bcaxvnx8hi },
    &operand_data[17712],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:789 */
  {
    "aarch64_sve2_bcaxvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bcaxvnx4si },
    &operand_data[17716],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:789 */
  {
    "aarch64_sve2_bcaxvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bcaxvnx2di },
    &operand_data[17720],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:891 */
  {
    "aarch64_sve2_bslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bslvnx16qi },
    &operand_data[17708],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:891 */
  {
    "aarch64_sve2_bslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bslvnx8hi },
    &operand_data[17712],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:891 */
  {
    "aarch64_sve2_bslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bslvnx4si },
    &operand_data[17716],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:891 */
  {
    "aarch64_sve2_bslvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bslvnx2di },
    &operand_data[17720],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:921 */
  {
    "aarch64_sve2_nbslvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_nbslvnx16qi },
    &operand_data[17708],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:921 */
  {
    "aarch64_sve2_nbslvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_nbslvnx8hi },
    &operand_data[17712],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:921 */
  {
    "aarch64_sve2_nbslvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_nbslvnx4si },
    &operand_data[17716],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:921 */
  {
    "aarch64_sve2_nbslvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_nbslvnx2di },
    &operand_data[17720],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:966 */
  {
    "aarch64_sve2_bsl1nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl1nvnx16qi },
    &operand_data[17708],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:966 */
  {
    "aarch64_sve2_bsl1nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl1nvnx8hi },
    &operand_data[17712],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:966 */
  {
    "aarch64_sve2_bsl1nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl1nvnx4si },
    &operand_data[17716],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:966 */
  {
    "aarch64_sve2_bsl1nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl1nvnx2di },
    &operand_data[17720],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1011 */
  {
    "aarch64_sve2_bsl2nvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl2nvnx16qi },
    &operand_data[17708],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1011 */
  {
    "aarch64_sve2_bsl2nvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl2nvnx8hi },
    &operand_data[17712],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1011 */
  {
    "aarch64_sve2_bsl2nvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl2nvnx4si },
    &operand_data[17716],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1011 */
  {
    "aarch64_sve2_bsl2nvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_bsl2nvnx2di },
    &operand_data[17720],
    4,
    4,
    2,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_asrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_asrvnx16qi },
    &operand_data[17724],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_lsrvnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_lsrvnx16qi },
    &operand_data[17724],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_asrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_asrvnx8hi },
    &operand_data[17728],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_lsrvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_lsrvnx8hi },
    &operand_data[17728],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_asrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_asrvnx4si },
    &operand_data[17732],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_lsrvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_lsrvnx4si },
    &operand_data[17732],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_asrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_asrvnx2di },
    &operand_data[17736],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1094 */
  {
    "aarch64_sve_add_lsrvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve_add_lsrvnx2di },
    &operand_data[17736],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_sabavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_sabavnx16qi },
    &operand_data[13127],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_uabavnx16qi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_uabavnx16qi },
    &operand_data[13127],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_sabavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_sabavnx8hi },
    &operand_data[13131],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_uabavnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_uabavnx8hi },
    &operand_data[13131],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_sabavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_sabavnx4si },
    &operand_data[13135],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_uabavnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_uabavnx4si },
    &operand_data[13135],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_sabavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_sabavnx2di },
    &operand_data[13139],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1178 */
  {
    "aarch64_sve2_uabavnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_aarch64_sve2_uabavnx2di },
    &operand_data[13139],
    4,
    4,
    4,
    2,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1711 */
  {
    "cond_sadalpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sadalpvnx8hi },
    &operand_data[17740],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1711 */
  {
    "cond_uadalpvnx8hi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uadalpvnx8hi },
    &operand_data[17740],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1711 */
  {
    "cond_sadalpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sadalpvnx4si },
    &operand_data[17745],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1711 */
  {
    "cond_uadalpvnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uadalpvnx4si },
    &operand_data[17745],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1711 */
  {
    "cond_sadalpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_sadalpvnx2di },
    &operand_data[17750],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1711 */
  {
    "cond_uadalpvnx2di",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_uadalpvnx2di },
    &operand_data[17750],
    5,
    5,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd90vnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90vnx16qi3 },
    &operand_data[16358],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd270vnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270vnx16qi3 },
    &operand_data[16358],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd90vnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90vnx8hi3 },
    &operand_data[16370],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd270vnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270vnx8hi3 },
    &operand_data[16370],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd90vnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90vnx4si3 },
    &operand_data[16350],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd270vnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270vnx4si3 },
    &operand_data[16350],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd90vnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd90vnx2di3 },
    &operand_data[16354],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1803 */
  {
    "cadd270vnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cadd270vnx2di3 },
    &operand_data[16354],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlavnx16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlavnx16qi4 },
    &operand_data[17708],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmla_conjvnx16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjvnx16qi4 },
    &operand_data[17708],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlsvnx16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsvnx16qi4 },
    &operand_data[17708],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmls_conjvnx16qi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjvnx16qi4 },
    &operand_data[17708],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlavnx8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlavnx8hi4 },
    &operand_data[17712],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmla_conjvnx8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjvnx8hi4 },
    &operand_data[17712],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlsvnx8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsvnx8hi4 },
    &operand_data[17712],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmls_conjvnx8hi4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjvnx8hi4 },
    &operand_data[17712],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlavnx4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlavnx4si4 },
    &operand_data[17716],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmla_conjvnx4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjvnx4si4 },
    &operand_data[17716],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlsvnx4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsvnx4si4 },
    &operand_data[17716],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmls_conjvnx4si4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjvnx4si4 },
    &operand_data[17716],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlavnx2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlavnx2di4 },
    &operand_data[17720],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmla_conjvnx2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmla_conjvnx2di4 },
    &operand_data[17720],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmlsvnx2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmlsvnx2di4 },
    &operand_data[17720],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1855 */
  {
    "cmls_conjvnx2di4",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmls_conjvnx2di4 },
    &operand_data[17720],
    4,
    4,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmulvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulvnx16qi3 },
    &operand_data[16358],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmul_conjvnx16qi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjvnx16qi3 },
    &operand_data[16358],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmulvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulvnx8hi3 },
    &operand_data[16370],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmul_conjvnx8hi3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjvnx8hi3 },
    &operand_data[16370],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmulvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulvnx4si3 },
    &operand_data[16350],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmul_conjvnx4si3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjvnx4si3 },
    &operand_data[16350],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmulvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmulvnx2di3 },
    &operand_data[16354],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1876 */
  {
    "cmul_conjvnx2di3",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cmul_conjvnx2di3 },
    &operand_data[16354],
    3,
    3,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1955 */
  {
    "cond_fcvtltvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvtltvnx4sf },
    &operand_data[17755],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:1955 */
  {
    "cond_fcvtltvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvtltvnx2df },
    &operand_data[17759],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2047 */
  {
    "cond_fcvtxvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_fcvtxvnx4sf },
    &operand_data[17621],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2149 */
  {
    "cond_urecpevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_urecpevnx4si },
    &operand_data[16010],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2149 */
  {
    "cond_ursqrtevnx4si",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_ursqrtevnx4si },
    &operand_data[16010],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2214 */
  {
    "cond_flogbvnx8hf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_flogbvnx8hf },
    &operand_data[17552],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2214 */
  {
    "cond_flogbvnx4sf",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_flogbvnx4sf },
    &operand_data[17560],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2214 */
  {
    "cond_flogbvnx2df",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_cond_flogbvnx2df },
    &operand_data[17572],
    4,
    4,
    1,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2383 */
  {
    "check_raw_ptrssi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_check_raw_ptrssi },
    &operand_data[17763],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2383 */
  {
    "check_war_ptrssi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_check_war_ptrssi },
    &operand_data[17763],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2383 */
  {
    "check_raw_ptrsdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_check_raw_ptrsdi },
    &operand_data[17768],
    5,
    5,
    0,
    0,
    0
  },
  /* ../../../../../../../work-shared/gcc-12.2.0-r0/gcc-12.2.0/gcc/config/aarch64/aarch64-sve2.md:2383 */
  {
    "check_war_ptrsdi",
#if HAVE_DESIGNATED_UNION_INITIALIZERS
    { 0 },
#else
    { 0, 0, 0 },
#endif
    { (insn_gen_fn::stored_funcptr) gen_check_war_ptrsdi },
    &operand_data[17768],
    5,
    5,
    0,
    0,
    0
  },
};


const char *
get_insn_name (int code)
{
  if (code == NOOP_MOVE_INSN_CODE)
    return "NOOP_MOVE";
  else
    return insn_data[code].name;
}
